part of '../t.dart';

/// Read binary data and advance the position.
class BinaryReader {
  /// Constructs a new binary reader.
  BinaryReader(this.buffer);

  /// Buffer.
  final Uint8List buffer;
  int _position = 0;

  /// Read Int32.
  int readInt32() {
    final b = Uint8List.fromList(buffer.skip(_position).take(4).toList());
    final x = b.buffer.asUint32List(0, 1).first;

    _position += 4;
    return x;
  }

  /// Read Int64.
  int readInt64() {
    final b = Uint8List.fromList(buffer.skip(_position).take(8).toList());
    final x = b.buffer.asUint64List(0, 1);

    _position += 8;
    return x.first;
  }

  /// Read Int128.
  Int128 readInt128() {
    final b = Uint8List.fromList(buffer.skip(_position).take(16).toList());

    _position += 16;
    return Int128(b);
  }

  /// Read Int256.
  Int256 readInt256() {
    final b = Uint8List.fromList(buffer.skip(_position).take(32).toList());

    _position += 32;
    return Int256(b);
  }

  /// Read double.
  double readFloat64() {
    final b = Uint8List.fromList(buffer.skip(_position).take(8).toList());
    final x = b.buffer.asFloat64List(0, 1);

    _position += 8;
    return x.first;
  }

  /// Read boolean.
  bool readBool() {
    final b = buffer[_position];

    if (b == 0x997275B5) {
      _position++;
      return true;
    } else if (b == 0xBC799737) {
      _position++;
      return false;
    }

    throw Exception('Invalid boolean value.');
  }

  /// Read DateTime.
  DateTime readDateTime() {
    final seconds = readInt32();
    final tmp = DateTime.fromMillisecondsSinceEpoch(seconds * 1000);

    return tmp;
  }

  /// Read List<TlObject>.
  List<T> readVectorObject<T extends TlObject>() {
    final count = readInt32();
    final items = <T>[];

    for (int i = 0; i < count; i++) {
      items.add(readObject<T>());
    }

    return items;
  }

  /// Read List<int32>.
  List<int> readVectorInt32() {
    final count = readInt32();
    final items = <int>[];

    for (int i = 0; i < count; i++) {
      items.add(readInt32());
    }

    return items;
  }

  /// Read List<int64>.
  List<int> readVectorInt64() {
    final count = readInt32();
    final items = <int>[];

    for (int i = 0; i < count; i++) {
      items.add(readInt64());
    }

    return items;
  }

  /// Read List<Uint8List>.
  List<Uint8List> readVectorBytes() {
    final count = readInt32();
    final items = <Uint8List>[];

    for (int i = 0; i < count; i++) {
      items.add(readBytes());
    }

    return items;
  }

  /// Read List<String>.
  List<String> readVectorString() {
    final count = readInt32();
    final items = <String>[];

    for (int i = 0; i < count; i++) {
      items.add(readString());
    }

    return items;
  }

  /// Read Uint8List.
  Uint8List readBytes() {
    var length = buffer[_position];

    if (length < 254) {
      _position++;
    } else {
      length = readInt32();
    }

    final tmp = buffer.skip(_position).take(length).toList();

    _position += length;
    while (++length % 4 != 0) {
      _position++;
    }

    return Uint8List.fromList(tmp);
  }

  /// Read String.
  String readString() {
    final codeUnits = readBytes();
    final tmp = utf8.decode(codeUnits);
    return tmp;
  }

  /// Read TlObject.
  T readObject<T extends TlObject>() {
    final obj = _readObject(this);
    final t = obj as T;

    return t;
  }
}
