part of '../t.dart';

/// Error.
///
/// ID: `c4b9f9bb`.
class Error extends ErrorBase {
  /// Error constructor.
  const Error({
    required this.code,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory Error.deserialize(BinaryReader reader) {
    // Read [Error] fields.
    final code = reader.readInt32();
    final text = reader.readString();

    // Construct [Error] object.
    final returnValue = Error(
      code: code,
      text: text,
    );

    // Now return the deserialized [Error].
    return returnValue;
  }

  /// Code.
  ///
  /// Field type is Int32.
  final int code;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc4b9f9bb.
    buffer.writeInt32(0xc4b9f9bb);

    // Write fields.
    buffer.writeInt32(code);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Input Peer Empty.
///
/// ID: `7f3b18ea`.
class InputPeerEmpty extends InputPeerBase {
  /// Input Peer Empty constructor.
  const InputPeerEmpty() : super._();

  /// Deserialize.
  factory InputPeerEmpty.deserialize(BinaryReader reader) {
    // Construct [InputPeerEmpty] object.
    final returnValue = InputPeerEmpty();

    // Now return the deserialized [InputPeerEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7f3b18ea.
    buffer.writeInt32(0x7f3b18ea);

    // Finished serialization.
  }
}

/// Input Peer Self.
///
/// ID: `7da07ec9`.
class InputPeerSelf extends InputPeerBase {
  /// Input Peer Self constructor.
  const InputPeerSelf() : super._();

  /// Deserialize.
  factory InputPeerSelf.deserialize(BinaryReader reader) {
    // Construct [InputPeerSelf] object.
    final returnValue = InputPeerSelf();

    // Now return the deserialized [InputPeerSelf].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7da07ec9.
    buffer.writeInt32(0x7da07ec9);

    // Finished serialization.
  }
}

/// Input Peer Chat.
///
/// ID: `35a95cb9`.
class InputPeerChat extends InputPeerBase {
  /// Input Peer Chat constructor.
  const InputPeerChat({
    required this.chatId,
  }) : super._();

  /// Deserialize.
  factory InputPeerChat.deserialize(BinaryReader reader) {
    // Read [InputPeerChat] fields.
    final chatId = reader.readInt64();

    // Construct [InputPeerChat] object.
    final returnValue = InputPeerChat(
      chatId: chatId,
    );

    // Now return the deserialized [InputPeerChat].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x35a95cb9.
    buffer.writeInt32(0x35a95cb9);

    // Write fields.
    buffer.writeInt64(chatId);

    // Finished serialization.
  }
}

/// Input Peer User.
///
/// ID: `dde8a54c`.
class InputPeerUser extends InputPeerBase {
  /// Input Peer User constructor.
  const InputPeerUser({
    required this.userId,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputPeerUser.deserialize(BinaryReader reader) {
    // Read [InputPeerUser] fields.
    final userId = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputPeerUser] object.
    final returnValue = InputPeerUser(
      userId: userId,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputPeerUser].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdde8a54c.
    buffer.writeInt32(0xdde8a54c);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Peer Channel.
///
/// ID: `27bcbbfc`.
class InputPeerChannel extends InputPeerBase {
  /// Input Peer Channel constructor.
  const InputPeerChannel({
    required this.channelId,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputPeerChannel.deserialize(BinaryReader reader) {
    // Read [InputPeerChannel] fields.
    final channelId = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputPeerChannel] object.
    final returnValue = InputPeerChannel(
      channelId: channelId,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputPeerChannel].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x27bcbbfc.
    buffer.writeInt32(0x27bcbbfc);

    // Write fields.
    buffer.writeInt64(channelId);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Peer User From Message.
///
/// ID: `a87b0a1c`.
class InputPeerUserFromMessage extends InputPeerBase {
  /// Input Peer User From Message constructor.
  const InputPeerUserFromMessage({
    required this.peer,
    required this.msgId,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory InputPeerUserFromMessage.deserialize(BinaryReader reader) {
    // Read [InputPeerUserFromMessage] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final userId = reader.readInt64();

    // Construct [InputPeerUserFromMessage] object.
    final returnValue = InputPeerUserFromMessage(
      peer: peer,
      msgId: msgId,
      userId: userId,
    );

    // Now return the deserialized [InputPeerUserFromMessage].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa87b0a1c.
    buffer.writeInt32(0xa87b0a1c);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Input Peer Channel From Message.
///
/// ID: `bd2a0840`.
class InputPeerChannelFromMessage extends InputPeerBase {
  /// Input Peer Channel From Message constructor.
  const InputPeerChannelFromMessage({
    required this.peer,
    required this.msgId,
    required this.channelId,
  }) : super._();

  /// Deserialize.
  factory InputPeerChannelFromMessage.deserialize(BinaryReader reader) {
    // Read [InputPeerChannelFromMessage] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final channelId = reader.readInt64();

    // Construct [InputPeerChannelFromMessage] object.
    final returnValue = InputPeerChannelFromMessage(
      peer: peer,
      msgId: msgId,
      channelId: channelId,
    );

    // Now return the deserialized [InputPeerChannelFromMessage].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbd2a0840.
    buffer.writeInt32(0xbd2a0840);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeInt64(channelId);

    // Finished serialization.
  }
}

/// Input User Empty.
///
/// ID: `b98886cf`.
class InputUserEmpty extends InputUserBase {
  /// Input User Empty constructor.
  const InputUserEmpty() : super._();

  /// Deserialize.
  factory InputUserEmpty.deserialize(BinaryReader reader) {
    // Construct [InputUserEmpty] object.
    final returnValue = InputUserEmpty();

    // Now return the deserialized [InputUserEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb98886cf.
    buffer.writeInt32(0xb98886cf);

    // Finished serialization.
  }
}

/// Input User Self.
///
/// ID: `f7c1b13f`.
class InputUserSelf extends InputUserBase {
  /// Input User Self constructor.
  const InputUserSelf() : super._();

  /// Deserialize.
  factory InputUserSelf.deserialize(BinaryReader reader) {
    // Construct [InputUserSelf] object.
    final returnValue = InputUserSelf();

    // Now return the deserialized [InputUserSelf].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf7c1b13f.
    buffer.writeInt32(0xf7c1b13f);

    // Finished serialization.
  }
}

/// Input User.
///
/// ID: `f21158c6`.
class InputUser extends InputUserBase {
  /// Input User constructor.
  const InputUser({
    required this.userId,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputUser.deserialize(BinaryReader reader) {
    // Read [InputUser] fields.
    final userId = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputUser] object.
    final returnValue = InputUser(
      userId: userId,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputUser].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf21158c6.
    buffer.writeInt32(0xf21158c6);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input User From Message.
///
/// ID: `1da448e2`.
class InputUserFromMessage extends InputUserBase {
  /// Input User From Message constructor.
  const InputUserFromMessage({
    required this.peer,
    required this.msgId,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory InputUserFromMessage.deserialize(BinaryReader reader) {
    // Read [InputUserFromMessage] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final userId = reader.readInt64();

    // Construct [InputUserFromMessage] object.
    final returnValue = InputUserFromMessage(
      peer: peer,
      msgId: msgId,
      userId: userId,
    );

    // Now return the deserialized [InputUserFromMessage].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1da448e2.
    buffer.writeInt32(0x1da448e2);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Input Phone Contact.
///
/// ID: `f392b7f4`.
class InputPhoneContact extends InputContactBase {
  /// Input Phone Contact constructor.
  const InputPhoneContact({
    required this.clientId,
    required this.phone,
    required this.firstName,
    required this.lastName,
  }) : super._();

  /// Deserialize.
  factory InputPhoneContact.deserialize(BinaryReader reader) {
    // Read [InputPhoneContact] fields.
    final clientId = reader.readInt64();
    final phone = reader.readString();
    final firstName = reader.readString();
    final lastName = reader.readString();

    // Construct [InputPhoneContact] object.
    final returnValue = InputPhoneContact(
      clientId: clientId,
      phone: phone,
      firstName: firstName,
      lastName: lastName,
    );

    // Now return the deserialized [InputPhoneContact].
    return returnValue;
  }

  /// Client Id.
  ///
  /// Field type is Int64.
  final int clientId;

  /// Phone.
  final String phone;

  /// First Name.
  final String firstName;

  /// Last Name.
  final String lastName;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf392b7f4.
    buffer.writeInt32(0xf392b7f4);

    // Write fields.
    buffer.writeInt64(clientId);
    buffer.writeString(phone);
    buffer.writeString(firstName);
    buffer.writeString(lastName);

    // Finished serialization.
  }
}

/// Input File.
///
/// ID: `f52ff27f`.
class InputFile extends InputFileBase {
  /// Input File constructor.
  const InputFile({
    required this.id,
    required this.parts,
    required this.name,
    required this.md5Checksum,
  }) : super._();

  /// Deserialize.
  factory InputFile.deserialize(BinaryReader reader) {
    // Read [InputFile] fields.
    final id = reader.readInt64();
    final parts = reader.readInt32();
    final name = reader.readString();
    final md5Checksum = reader.readString();

    // Construct [InputFile] object.
    final returnValue = InputFile(
      id: id,
      parts: parts,
      name: name,
      md5Checksum: md5Checksum,
    );

    // Now return the deserialized [InputFile].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Parts.
  ///
  /// Field type is Int32.
  final int parts;

  /// Name.
  final String name;

  /// Md5 Checksum.
  final String md5Checksum;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf52ff27f.
    buffer.writeInt32(0xf52ff27f);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt32(parts);
    buffer.writeString(name);
    buffer.writeString(md5Checksum);

    // Finished serialization.
  }
}

/// Input File Big.
///
/// ID: `fa4f0bb5`.
class InputFileBig extends InputFileBase {
  /// Input File Big constructor.
  const InputFileBig({
    required this.id,
    required this.parts,
    required this.name,
  }) : super._();

  /// Deserialize.
  factory InputFileBig.deserialize(BinaryReader reader) {
    // Read [InputFileBig] fields.
    final id = reader.readInt64();
    final parts = reader.readInt32();
    final name = reader.readString();

    // Construct [InputFileBig] object.
    final returnValue = InputFileBig(
      id: id,
      parts: parts,
      name: name,
    );

    // Now return the deserialized [InputFileBig].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Parts.
  ///
  /// Field type is Int32.
  final int parts;

  /// Name.
  final String name;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfa4f0bb5.
    buffer.writeInt32(0xfa4f0bb5);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt32(parts);
    buffer.writeString(name);

    // Finished serialization.
  }
}

/// Input Media Empty.
///
/// ID: `9664f57f`.
class InputMediaEmpty extends InputMediaBase {
  /// Input Media Empty constructor.
  const InputMediaEmpty() : super._();

  /// Deserialize.
  factory InputMediaEmpty.deserialize(BinaryReader reader) {
    // Construct [InputMediaEmpty] object.
    final returnValue = InputMediaEmpty();

    // Now return the deserialized [InputMediaEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9664f57f.
    buffer.writeInt32(0x9664f57f);

    // Finished serialization.
  }
}

/// Input Media Uploaded Photo.
///
/// ID: `1e287d04`.
class InputMediaUploadedPhoto extends InputMediaBase {
  /// Input Media Uploaded Photo constructor.
  const InputMediaUploadedPhoto({
    required this.spoiler,
    required this.file,
    this.stickers,
    this.ttlSeconds,
  }) : super._();

  /// Deserialize.
  factory InputMediaUploadedPhoto.deserialize(BinaryReader reader) {
    // Read [InputMediaUploadedPhoto] fields.
    final flags = reader.readInt32();
    final spoiler = (flags & 4) != 0;
    final file = reader.readObject() as InputFileBase;
    final hasStickersField = (flags & 1) != 0;
    final stickers =
        hasStickersField ? reader.readVectorObject<InputDocumentBase>() : null;
    final hasTtlSecondsField = (flags & 2) != 0;
    final ttlSeconds = hasTtlSecondsField ? reader.readInt32() : null;

    // Construct [InputMediaUploadedPhoto] object.
    final returnValue = InputMediaUploadedPhoto(
      spoiler: spoiler,
      file: file,
      stickers: stickers,
      ttlSeconds: ttlSeconds,
    );

    // Now return the deserialized [InputMediaUploadedPhoto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: spoiler,
      b00: stickers != null,
      b01: ttlSeconds != null,
    );

    return v;
  }

  /// spoiler: bit 2 of flags.2?true
  final bool spoiler;

  /// File.
  final InputFileBase file;

  /// Stickers.
  final List<InputDocumentBase>? stickers;

  /// Ttl Seconds.
  final int? ttlSeconds;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1e287d04.
    buffer.writeInt32(0x1e287d04);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(file);
    final localStickersCopy = stickers;
    if (localStickersCopy != null) {
      buffer.writeVectorObject(localStickersCopy);
    }
    final localTtlSecondsCopy = ttlSeconds;
    if (localTtlSecondsCopy != null) {
      buffer.writeInt32(localTtlSecondsCopy);
    }

    // Finished serialization.
  }
}

/// Input Media Photo.
///
/// ID: `b3ba0635`.
class InputMediaPhoto extends InputMediaBase {
  /// Input Media Photo constructor.
  const InputMediaPhoto({
    required this.spoiler,
    required this.id,
    this.ttlSeconds,
  }) : super._();

  /// Deserialize.
  factory InputMediaPhoto.deserialize(BinaryReader reader) {
    // Read [InputMediaPhoto] fields.
    final flags = reader.readInt32();
    final spoiler = (flags & 2) != 0;
    final id = reader.readObject() as InputPhotoBase;
    final hasTtlSecondsField = (flags & 1) != 0;
    final ttlSeconds = hasTtlSecondsField ? reader.readInt32() : null;

    // Construct [InputMediaPhoto] object.
    final returnValue = InputMediaPhoto(
      spoiler: spoiler,
      id: id,
      ttlSeconds: ttlSeconds,
    );

    // Now return the deserialized [InputMediaPhoto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: spoiler,
      b00: ttlSeconds != null,
    );

    return v;
  }

  /// spoiler: bit 1 of flags.1?true
  final bool spoiler;

  /// Id.
  final InputPhotoBase id;

  /// Ttl Seconds.
  final int? ttlSeconds;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb3ba0635.
    buffer.writeInt32(0xb3ba0635);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(id);
    final localTtlSecondsCopy = ttlSeconds;
    if (localTtlSecondsCopy != null) {
      buffer.writeInt32(localTtlSecondsCopy);
    }

    // Finished serialization.
  }
}

/// Input Media Geo Point.
///
/// ID: `f9c44144`.
class InputMediaGeoPoint extends InputMediaBase {
  /// Input Media Geo Point constructor.
  const InputMediaGeoPoint({
    required this.geoPoint,
  }) : super._();

  /// Deserialize.
  factory InputMediaGeoPoint.deserialize(BinaryReader reader) {
    // Read [InputMediaGeoPoint] fields.
    final geoPoint = reader.readObject() as InputGeoPointBase;

    // Construct [InputMediaGeoPoint] object.
    final returnValue = InputMediaGeoPoint(
      geoPoint: geoPoint,
    );

    // Now return the deserialized [InputMediaGeoPoint].
    return returnValue;
  }

  /// Geo Point.
  final InputGeoPointBase geoPoint;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf9c44144.
    buffer.writeInt32(0xf9c44144);

    // Write fields.
    buffer.writeObject(geoPoint);

    // Finished serialization.
  }
}

/// Input Media Contact.
///
/// ID: `f8ab7dfb`.
class InputMediaContact extends InputMediaBase {
  /// Input Media Contact constructor.
  const InputMediaContact({
    required this.phoneNumber,
    required this.firstName,
    required this.lastName,
    required this.vcard,
  }) : super._();

  /// Deserialize.
  factory InputMediaContact.deserialize(BinaryReader reader) {
    // Read [InputMediaContact] fields.
    final phoneNumber = reader.readString();
    final firstName = reader.readString();
    final lastName = reader.readString();
    final vcard = reader.readString();

    // Construct [InputMediaContact] object.
    final returnValue = InputMediaContact(
      phoneNumber: phoneNumber,
      firstName: firstName,
      lastName: lastName,
      vcard: vcard,
    );

    // Now return the deserialized [InputMediaContact].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// First Name.
  final String firstName;

  /// Last Name.
  final String lastName;

  /// Vcard.
  final String vcard;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf8ab7dfb.
    buffer.writeInt32(0xf8ab7dfb);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeString(firstName);
    buffer.writeString(lastName);
    buffer.writeString(vcard);

    // Finished serialization.
  }
}

/// Input Media Uploaded Document.
///
/// ID: `5b38c6c1`.
class InputMediaUploadedDocument extends InputMediaBase {
  /// Input Media Uploaded Document constructor.
  const InputMediaUploadedDocument({
    required this.nosoundVideo,
    required this.forceFile,
    required this.spoiler,
    required this.file,
    this.thumb,
    required this.mimeType,
    required this.attributes,
    this.stickers,
    this.ttlSeconds,
  }) : super._();

  /// Deserialize.
  factory InputMediaUploadedDocument.deserialize(BinaryReader reader) {
    // Read [InputMediaUploadedDocument] fields.
    final flags = reader.readInt32();
    final nosoundVideo = (flags & 8) != 0;
    final forceFile = (flags & 16) != 0;
    final spoiler = (flags & 32) != 0;
    final file = reader.readObject() as InputFileBase;
    final hasThumbField = (flags & 4) != 0;
    final thumb = hasThumbField ? reader.readObject() as InputFileBase : null;
    final mimeType = reader.readString();
    final attributes = reader.readVectorObject<DocumentAttributeBase>();
    final hasStickersField = (flags & 1) != 0;
    final stickers =
        hasStickersField ? reader.readVectorObject<InputDocumentBase>() : null;
    final hasTtlSecondsField = (flags & 2) != 0;
    final ttlSeconds = hasTtlSecondsField ? reader.readInt32() : null;

    // Construct [InputMediaUploadedDocument] object.
    final returnValue = InputMediaUploadedDocument(
      nosoundVideo: nosoundVideo,
      forceFile: forceFile,
      spoiler: spoiler,
      file: file,
      thumb: thumb,
      mimeType: mimeType,
      attributes: attributes,
      stickers: stickers,
      ttlSeconds: ttlSeconds,
    );

    // Now return the deserialized [InputMediaUploadedDocument].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: nosoundVideo,
      b04: forceFile,
      b05: spoiler,
      b02: thumb != null,
      b00: stickers != null,
      b01: ttlSeconds != null,
    );

    return v;
  }

  /// nosound_video: bit 3 of flags.3?true
  final bool nosoundVideo;

  /// force_file: bit 4 of flags.4?true
  final bool forceFile;

  /// spoiler: bit 5 of flags.5?true
  final bool spoiler;

  /// File.
  final InputFileBase file;

  /// Thumb.
  final InputFileBase? thumb;

  /// Mime Type.
  final String mimeType;

  /// Attributes.
  final List<DocumentAttributeBase> attributes;

  /// Stickers.
  final List<InputDocumentBase>? stickers;

  /// Ttl Seconds.
  final int? ttlSeconds;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5b38c6c1.
    buffer.writeInt32(0x5b38c6c1);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(file);
    final localThumbCopy = thumb;
    if (localThumbCopy != null) {
      buffer.writeObject(localThumbCopy);
    }
    buffer.writeString(mimeType);
    buffer.writeVectorObject(attributes);
    final localStickersCopy = stickers;
    if (localStickersCopy != null) {
      buffer.writeVectorObject(localStickersCopy);
    }
    final localTtlSecondsCopy = ttlSeconds;
    if (localTtlSecondsCopy != null) {
      buffer.writeInt32(localTtlSecondsCopy);
    }

    // Finished serialization.
  }
}

/// Input Media Document.
///
/// ID: `33473058`.
class InputMediaDocument extends InputMediaBase {
  /// Input Media Document constructor.
  const InputMediaDocument({
    required this.spoiler,
    required this.id,
    this.ttlSeconds,
    this.query,
  }) : super._();

  /// Deserialize.
  factory InputMediaDocument.deserialize(BinaryReader reader) {
    // Read [InputMediaDocument] fields.
    final flags = reader.readInt32();
    final spoiler = (flags & 4) != 0;
    final id = reader.readObject() as InputDocumentBase;
    final hasTtlSecondsField = (flags & 1) != 0;
    final ttlSeconds = hasTtlSecondsField ? reader.readInt32() : null;
    final hasQueryField = (flags & 2) != 0;
    final query = hasQueryField ? reader.readString() : null;

    // Construct [InputMediaDocument] object.
    final returnValue = InputMediaDocument(
      spoiler: spoiler,
      id: id,
      ttlSeconds: ttlSeconds,
      query: query,
    );

    // Now return the deserialized [InputMediaDocument].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: spoiler,
      b00: ttlSeconds != null,
      b01: query != null,
    );

    return v;
  }

  /// spoiler: bit 2 of flags.2?true
  final bool spoiler;

  /// Id.
  final InputDocumentBase id;

  /// Ttl Seconds.
  final int? ttlSeconds;

  /// Query.
  final String? query;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x33473058.
    buffer.writeInt32(0x33473058);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(id);
    final localTtlSecondsCopy = ttlSeconds;
    if (localTtlSecondsCopy != null) {
      buffer.writeInt32(localTtlSecondsCopy);
    }
    final localQueryCopy = query;
    if (localQueryCopy != null) {
      buffer.writeString(localQueryCopy);
    }

    // Finished serialization.
  }
}

/// Input Media Venue.
///
/// ID: `c13d1c11`.
class InputMediaVenue extends InputMediaBase {
  /// Input Media Venue constructor.
  const InputMediaVenue({
    required this.geoPoint,
    required this.title,
    required this.address,
    required this.provider,
    required this.venueId,
    required this.venueType,
  }) : super._();

  /// Deserialize.
  factory InputMediaVenue.deserialize(BinaryReader reader) {
    // Read [InputMediaVenue] fields.
    final geoPoint = reader.readObject() as InputGeoPointBase;
    final title = reader.readString();
    final address = reader.readString();
    final provider = reader.readString();
    final venueId = reader.readString();
    final venueType = reader.readString();

    // Construct [InputMediaVenue] object.
    final returnValue = InputMediaVenue(
      geoPoint: geoPoint,
      title: title,
      address: address,
      provider: provider,
      venueId: venueId,
      venueType: venueType,
    );

    // Now return the deserialized [InputMediaVenue].
    return returnValue;
  }

  /// Geo Point.
  final InputGeoPointBase geoPoint;

  /// Title.
  final String title;

  /// Address.
  final String address;

  /// Provider.
  final String provider;

  /// Venue Id.
  final String venueId;

  /// Venue Type.
  final String venueType;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc13d1c11.
    buffer.writeInt32(0xc13d1c11);

    // Write fields.
    buffer.writeObject(geoPoint);
    buffer.writeString(title);
    buffer.writeString(address);
    buffer.writeString(provider);
    buffer.writeString(venueId);
    buffer.writeString(venueType);

    // Finished serialization.
  }
}

/// Input Media Photo External.
///
/// ID: `e5bbfe1a`.
class InputMediaPhotoExternal extends InputMediaBase {
  /// Input Media Photo External constructor.
  const InputMediaPhotoExternal({
    required this.spoiler,
    required this.url,
    this.ttlSeconds,
  }) : super._();

  /// Deserialize.
  factory InputMediaPhotoExternal.deserialize(BinaryReader reader) {
    // Read [InputMediaPhotoExternal] fields.
    final flags = reader.readInt32();
    final spoiler = (flags & 2) != 0;
    final url = reader.readString();
    final hasTtlSecondsField = (flags & 1) != 0;
    final ttlSeconds = hasTtlSecondsField ? reader.readInt32() : null;

    // Construct [InputMediaPhotoExternal] object.
    final returnValue = InputMediaPhotoExternal(
      spoiler: spoiler,
      url: url,
      ttlSeconds: ttlSeconds,
    );

    // Now return the deserialized [InputMediaPhotoExternal].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: spoiler,
      b00: ttlSeconds != null,
    );

    return v;
  }

  /// spoiler: bit 1 of flags.1?true
  final bool spoiler;

  /// Url.
  final String url;

  /// Ttl Seconds.
  final int? ttlSeconds;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe5bbfe1a.
    buffer.writeInt32(0xe5bbfe1a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(url);
    final localTtlSecondsCopy = ttlSeconds;
    if (localTtlSecondsCopy != null) {
      buffer.writeInt32(localTtlSecondsCopy);
    }

    // Finished serialization.
  }
}

/// Input Media Document External.
///
/// ID: `fb52dc99`.
class InputMediaDocumentExternal extends InputMediaBase {
  /// Input Media Document External constructor.
  const InputMediaDocumentExternal({
    required this.spoiler,
    required this.url,
    this.ttlSeconds,
  }) : super._();

  /// Deserialize.
  factory InputMediaDocumentExternal.deserialize(BinaryReader reader) {
    // Read [InputMediaDocumentExternal] fields.
    final flags = reader.readInt32();
    final spoiler = (flags & 2) != 0;
    final url = reader.readString();
    final hasTtlSecondsField = (flags & 1) != 0;
    final ttlSeconds = hasTtlSecondsField ? reader.readInt32() : null;

    // Construct [InputMediaDocumentExternal] object.
    final returnValue = InputMediaDocumentExternal(
      spoiler: spoiler,
      url: url,
      ttlSeconds: ttlSeconds,
    );

    // Now return the deserialized [InputMediaDocumentExternal].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: spoiler,
      b00: ttlSeconds != null,
    );

    return v;
  }

  /// spoiler: bit 1 of flags.1?true
  final bool spoiler;

  /// Url.
  final String url;

  /// Ttl Seconds.
  final int? ttlSeconds;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfb52dc99.
    buffer.writeInt32(0xfb52dc99);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(url);
    final localTtlSecondsCopy = ttlSeconds;
    if (localTtlSecondsCopy != null) {
      buffer.writeInt32(localTtlSecondsCopy);
    }

    // Finished serialization.
  }
}

/// Input Media Game.
///
/// ID: `d33f43f3`.
class InputMediaGame extends InputMediaBase {
  /// Input Media Game constructor.
  const InputMediaGame({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory InputMediaGame.deserialize(BinaryReader reader) {
    // Read [InputMediaGame] fields.
    final id = reader.readObject() as InputGameBase;

    // Construct [InputMediaGame] object.
    final returnValue = InputMediaGame(
      id: id,
    );

    // Now return the deserialized [InputMediaGame].
    return returnValue;
  }

  /// Id.
  final InputGameBase id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd33f43f3.
    buffer.writeInt32(0xd33f43f3);

    // Write fields.
    buffer.writeObject(id);

    // Finished serialization.
  }
}

/// Input Media Invoice.
///
/// ID: `8eb5a6d5`.
class InputMediaInvoice extends InputMediaBase {
  /// Input Media Invoice constructor.
  const InputMediaInvoice({
    required this.title,
    required this.description,
    this.photo,
    required this.invoice,
    required this.payload,
    required this.provider,
    required this.providerData,
    this.startParam,
    this.extendedMedia,
  }) : super._();

  /// Deserialize.
  factory InputMediaInvoice.deserialize(BinaryReader reader) {
    // Read [InputMediaInvoice] fields.
    final flags = reader.readInt32();
    final title = reader.readString();
    final description = reader.readString();
    final hasPhotoField = (flags & 1) != 0;
    final photo =
        hasPhotoField ? reader.readObject() as InputWebDocumentBase : null;
    final invoice = reader.readObject() as InvoiceBase;
    final payload = reader.readBytes();
    final provider = reader.readString();
    final providerData = reader.readObject() as DataJSONBase;
    final hasStartParamField = (flags & 2) != 0;
    final startParam = hasStartParamField ? reader.readString() : null;
    final hasExtendedMediaField = (flags & 4) != 0;
    final extendedMedia =
        hasExtendedMediaField ? reader.readObject() as InputMediaBase : null;

    // Construct [InputMediaInvoice] object.
    final returnValue = InputMediaInvoice(
      title: title,
      description: description,
      photo: photo,
      invoice: invoice,
      payload: payload,
      provider: provider,
      providerData: providerData,
      startParam: startParam,
      extendedMedia: extendedMedia,
    );

    // Now return the deserialized [InputMediaInvoice].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: photo != null,
      b01: startParam != null,
      b02: extendedMedia != null,
    );

    return v;
  }

  /// Title.
  final String title;

  /// Description.
  final String description;

  /// Photo.
  final InputWebDocumentBase? photo;

  /// Invoice.
  final InvoiceBase invoice;

  /// Payload.
  final Uint8List payload;

  /// Provider.
  final String provider;

  /// Provider Data.
  final DataJSONBase providerData;

  /// Start Param.
  final String? startParam;

  /// Extended Media.
  final InputMediaBase? extendedMedia;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8eb5a6d5.
    buffer.writeInt32(0x8eb5a6d5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(title);
    buffer.writeString(description);
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }
    buffer.writeObject(invoice);
    buffer.writeBytes(payload);
    buffer.writeString(provider);
    buffer.writeObject(providerData);
    final localStartParamCopy = startParam;
    if (localStartParamCopy != null) {
      buffer.writeString(localStartParamCopy);
    }
    final localExtendedMediaCopy = extendedMedia;
    if (localExtendedMediaCopy != null) {
      buffer.writeObject(localExtendedMediaCopy);
    }

    // Finished serialization.
  }
}

/// Input Media Geo Live.
///
/// ID: `971fa843`.
class InputMediaGeoLive extends InputMediaBase {
  /// Input Media Geo Live constructor.
  const InputMediaGeoLive({
    required this.stopped,
    required this.geoPoint,
    this.heading,
    this.period,
    this.proximityNotificationRadius,
  }) : super._();

  /// Deserialize.
  factory InputMediaGeoLive.deserialize(BinaryReader reader) {
    // Read [InputMediaGeoLive] fields.
    final flags = reader.readInt32();
    final stopped = (flags & 1) != 0;
    final geoPoint = reader.readObject() as InputGeoPointBase;
    final hasHeadingField = (flags & 4) != 0;
    final heading = hasHeadingField ? reader.readInt32() : null;
    final hasPeriodField = (flags & 2) != 0;
    final period = hasPeriodField ? reader.readInt32() : null;
    final hasProximityNotificationRadiusField = (flags & 8) != 0;
    final proximityNotificationRadius =
        hasProximityNotificationRadiusField ? reader.readInt32() : null;

    // Construct [InputMediaGeoLive] object.
    final returnValue = InputMediaGeoLive(
      stopped: stopped,
      geoPoint: geoPoint,
      heading: heading,
      period: period,
      proximityNotificationRadius: proximityNotificationRadius,
    );

    // Now return the deserialized [InputMediaGeoLive].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: stopped,
      b02: heading != null,
      b01: period != null,
      b03: proximityNotificationRadius != null,
    );

    return v;
  }

  /// stopped: bit 0 of flags.0?true
  final bool stopped;

  /// Geo Point.
  final InputGeoPointBase geoPoint;

  /// Heading.
  final int? heading;

  /// Period.
  final int? period;

  /// Proximity Notification Radius.
  final int? proximityNotificationRadius;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x971fa843.
    buffer.writeInt32(0x971fa843);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(geoPoint);
    final localHeadingCopy = heading;
    if (localHeadingCopy != null) {
      buffer.writeInt32(localHeadingCopy);
    }
    final localPeriodCopy = period;
    if (localPeriodCopy != null) {
      buffer.writeInt32(localPeriodCopy);
    }
    final localProximityNotificationRadiusCopy = proximityNotificationRadius;
    if (localProximityNotificationRadiusCopy != null) {
      buffer.writeInt32(localProximityNotificationRadiusCopy);
    }

    // Finished serialization.
  }
}

/// Input Media Poll.
///
/// ID: `0f94e5f1`.
class InputMediaPoll extends InputMediaBase {
  /// Input Media Poll constructor.
  const InputMediaPoll({
    required this.poll,
    this.correctAnswers,
    this.solution,
    this.solutionEntities,
  }) : super._();

  /// Deserialize.
  factory InputMediaPoll.deserialize(BinaryReader reader) {
    // Read [InputMediaPoll] fields.
    final flags = reader.readInt32();
    final poll = reader.readObject() as PollBase;
    final hasCorrectAnswersField = (flags & 1) != 0;
    final correctAnswers =
        hasCorrectAnswersField ? reader.readVectorBytes() : null;
    final hasSolutionField = (flags & 2) != 0;
    final solution = hasSolutionField ? reader.readString() : null;
    final hasSolutionEntitiesField = (flags & 2) != 0;
    final solutionEntities = hasSolutionEntitiesField
        ? reader.readVectorObject<MessageEntityBase>()
        : null;

    // Construct [InputMediaPoll] object.
    final returnValue = InputMediaPoll(
      poll: poll,
      correctAnswers: correctAnswers,
      solution: solution,
      solutionEntities: solutionEntities,
    );

    // Now return the deserialized [InputMediaPoll].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: correctAnswers != null,
      b01: solution != null || solutionEntities != null,
    );

    return v;
  }

  /// Poll.
  final PollBase poll;

  /// Correct Answers.
  final List<Uint8List>? correctAnswers;

  /// Solution.
  final String? solution;

  /// Solution Entities.
  final List<MessageEntityBase>? solutionEntities;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0f94e5f1.
    buffer.writeInt32(0x0f94e5f1);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(poll);
    final localCorrectAnswersCopy = correctAnswers;
    if (localCorrectAnswersCopy != null) {
      buffer.writeVectorBytes(localCorrectAnswersCopy);
    }
    final localSolutionCopy = solution;
    if (localSolutionCopy != null) {
      buffer.writeString(localSolutionCopy);
    }
    final localSolutionEntitiesCopy = solutionEntities;
    if (localSolutionEntitiesCopy != null) {
      buffer.writeVectorObject(localSolutionEntitiesCopy);
    }

    // Finished serialization.
  }
}

/// Input Media Dice.
///
/// ID: `e66fbf7b`.
class InputMediaDice extends InputMediaBase {
  /// Input Media Dice constructor.
  const InputMediaDice({
    required this.emoticon,
  }) : super._();

  /// Deserialize.
  factory InputMediaDice.deserialize(BinaryReader reader) {
    // Read [InputMediaDice] fields.
    final emoticon = reader.readString();

    // Construct [InputMediaDice] object.
    final returnValue = InputMediaDice(
      emoticon: emoticon,
    );

    // Now return the deserialized [InputMediaDice].
    return returnValue;
  }

  /// Emoticon.
  final String emoticon;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe66fbf7b.
    buffer.writeInt32(0xe66fbf7b);

    // Write fields.
    buffer.writeString(emoticon);

    // Finished serialization.
  }
}

/// Input Media Story.
///
/// ID: `89fdd778`.
class InputMediaStory extends InputMediaBase {
  /// Input Media Story constructor.
  const InputMediaStory({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory InputMediaStory.deserialize(BinaryReader reader) {
    // Read [InputMediaStory] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();

    // Construct [InputMediaStory] object.
    final returnValue = InputMediaStory(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [InputMediaStory].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x89fdd778.
    buffer.writeInt32(0x89fdd778);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Input Media Web Page.
///
/// ID: `c21b8849`.
class InputMediaWebPage extends InputMediaBase {
  /// Input Media Web Page constructor.
  const InputMediaWebPage({
    required this.forceLargeMedia,
    required this.forceSmallMedia,
    required this.optional,
    required this.url,
  }) : super._();

  /// Deserialize.
  factory InputMediaWebPage.deserialize(BinaryReader reader) {
    // Read [InputMediaWebPage] fields.
    final flags = reader.readInt32();
    final forceLargeMedia = (flags & 1) != 0;
    final forceSmallMedia = (flags & 2) != 0;
    final optional = (flags & 4) != 0;
    final url = reader.readString();

    // Construct [InputMediaWebPage] object.
    final returnValue = InputMediaWebPage(
      forceLargeMedia: forceLargeMedia,
      forceSmallMedia: forceSmallMedia,
      optional: optional,
      url: url,
    );

    // Now return the deserialized [InputMediaWebPage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: forceLargeMedia,
      b01: forceSmallMedia,
      b02: optional,
    );

    return v;
  }

  /// force_large_media: bit 0 of flags.0?true
  final bool forceLargeMedia;

  /// force_small_media: bit 1 of flags.1?true
  final bool forceSmallMedia;

  /// optional: bit 2 of flags.2?true
  final bool optional;

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc21b8849.
    buffer.writeInt32(0xc21b8849);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Input Chat Photo Empty.
///
/// ID: `1ca48f57`.
class InputChatPhotoEmpty extends InputChatPhotoBase {
  /// Input Chat Photo Empty constructor.
  const InputChatPhotoEmpty() : super._();

  /// Deserialize.
  factory InputChatPhotoEmpty.deserialize(BinaryReader reader) {
    // Construct [InputChatPhotoEmpty] object.
    final returnValue = InputChatPhotoEmpty();

    // Now return the deserialized [InputChatPhotoEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1ca48f57.
    buffer.writeInt32(0x1ca48f57);

    // Finished serialization.
  }
}

/// Input Chat Uploaded Photo.
///
/// ID: `bdcdaec0`.
class InputChatUploadedPhoto extends InputChatPhotoBase {
  /// Input Chat Uploaded Photo constructor.
  const InputChatUploadedPhoto({
    this.file,
    this.video,
    this.videoStartTs,
    this.videoEmojiMarkup,
  }) : super._();

  /// Deserialize.
  factory InputChatUploadedPhoto.deserialize(BinaryReader reader) {
    // Read [InputChatUploadedPhoto] fields.
    final flags = reader.readInt32();
    final hasFileField = (flags & 1) != 0;
    final file = hasFileField ? reader.readObject() as InputFileBase : null;
    final hasVideoField = (flags & 2) != 0;
    final video = hasVideoField ? reader.readObject() as InputFileBase : null;
    final hasVideoStartTsField = (flags & 4) != 0;
    final videoStartTs = hasVideoStartTsField ? reader.readFloat64() : null;
    final hasVideoEmojiMarkupField = (flags & 8) != 0;
    final videoEmojiMarkup =
        hasVideoEmojiMarkupField ? reader.readObject() as VideoSizeBase : null;

    // Construct [InputChatUploadedPhoto] object.
    final returnValue = InputChatUploadedPhoto(
      file: file,
      video: video,
      videoStartTs: videoStartTs,
      videoEmojiMarkup: videoEmojiMarkup,
    );

    // Now return the deserialized [InputChatUploadedPhoto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: file != null,
      b01: video != null,
      b02: videoStartTs != null,
      b03: videoEmojiMarkup != null,
    );

    return v;
  }

  /// File.
  final InputFileBase? file;

  /// Video.
  final InputFileBase? video;

  /// Video Start Ts.
  final double? videoStartTs;

  /// Video Emoji Markup.
  final VideoSizeBase? videoEmojiMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbdcdaec0.
    buffer.writeInt32(0xbdcdaec0);

    // Write fields.
    buffer.writeInt32(flags);
    final localFileCopy = file;
    if (localFileCopy != null) {
      buffer.writeObject(localFileCopy);
    }
    final localVideoCopy = video;
    if (localVideoCopy != null) {
      buffer.writeObject(localVideoCopy);
    }
    final localVideoStartTsCopy = videoStartTs;
    if (localVideoStartTsCopy != null) {
      buffer.writeDouble(localVideoStartTsCopy);
    }
    final localVideoEmojiMarkupCopy = videoEmojiMarkup;
    if (localVideoEmojiMarkupCopy != null) {
      buffer.writeObject(localVideoEmojiMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Input Chat Photo.
///
/// ID: `8953ad37`.
class InputChatPhoto extends InputChatPhotoBase {
  /// Input Chat Photo constructor.
  const InputChatPhoto({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory InputChatPhoto.deserialize(BinaryReader reader) {
    // Read [InputChatPhoto] fields.
    final id = reader.readObject() as InputPhotoBase;

    // Construct [InputChatPhoto] object.
    final returnValue = InputChatPhoto(
      id: id,
    );

    // Now return the deserialized [InputChatPhoto].
    return returnValue;
  }

  /// Id.
  final InputPhotoBase id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8953ad37.
    buffer.writeInt32(0x8953ad37);

    // Write fields.
    buffer.writeObject(id);

    // Finished serialization.
  }
}

/// Input Geo Point Empty.
///
/// ID: `e4c123d6`.
class InputGeoPointEmpty extends InputGeoPointBase {
  /// Input Geo Point Empty constructor.
  const InputGeoPointEmpty() : super._();

  /// Deserialize.
  factory InputGeoPointEmpty.deserialize(BinaryReader reader) {
    // Construct [InputGeoPointEmpty] object.
    final returnValue = InputGeoPointEmpty();

    // Now return the deserialized [InputGeoPointEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe4c123d6.
    buffer.writeInt32(0xe4c123d6);

    // Finished serialization.
  }
}

/// Input Geo Point.
///
/// ID: `48222faf`.
class InputGeoPoint extends InputGeoPointBase {
  /// Input Geo Point constructor.
  const InputGeoPoint({
    required this.lat,
    required this.long,
    this.accuracyRadius,
  }) : super._();

  /// Deserialize.
  factory InputGeoPoint.deserialize(BinaryReader reader) {
    // Read [InputGeoPoint] fields.
    final flags = reader.readInt32();
    final lat = reader.readFloat64();
    final long = reader.readFloat64();
    final hasAccuracyRadiusField = (flags & 1) != 0;
    final accuracyRadius = hasAccuracyRadiusField ? reader.readInt32() : null;

    // Construct [InputGeoPoint] object.
    final returnValue = InputGeoPoint(
      lat: lat,
      long: long,
      accuracyRadius: accuracyRadius,
    );

    // Now return the deserialized [InputGeoPoint].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: accuracyRadius != null,
    );

    return v;
  }

  /// Lat.
  final double lat;

  /// Long.
  final double long;

  /// Accuracy Radius.
  final int? accuracyRadius;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x48222faf.
    buffer.writeInt32(0x48222faf);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeDouble(lat);
    buffer.writeDouble(long);
    final localAccuracyRadiusCopy = accuracyRadius;
    if (localAccuracyRadiusCopy != null) {
      buffer.writeInt32(localAccuracyRadiusCopy);
    }

    // Finished serialization.
  }
}

/// Input Photo Empty.
///
/// ID: `1cd7bf0d`.
class InputPhotoEmpty extends InputPhotoBase {
  /// Input Photo Empty constructor.
  const InputPhotoEmpty() : super._();

  /// Deserialize.
  factory InputPhotoEmpty.deserialize(BinaryReader reader) {
    // Construct [InputPhotoEmpty] object.
    final returnValue = InputPhotoEmpty();

    // Now return the deserialized [InputPhotoEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1cd7bf0d.
    buffer.writeInt32(0x1cd7bf0d);

    // Finished serialization.
  }
}

/// Input Photo.
///
/// ID: `3bb3b94a`.
class InputPhoto extends InputPhotoBase {
  /// Input Photo constructor.
  const InputPhoto({
    required this.id,
    required this.accessHash,
    required this.fileReference,
  }) : super._();

  /// Deserialize.
  factory InputPhoto.deserialize(BinaryReader reader) {
    // Read [InputPhoto] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final fileReference = reader.readBytes();

    // Construct [InputPhoto] object.
    final returnValue = InputPhoto(
      id: id,
      accessHash: accessHash,
      fileReference: fileReference,
    );

    // Now return the deserialized [InputPhoto].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// File Reference.
  final Uint8List fileReference;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3bb3b94a.
    buffer.writeInt32(0x3bb3b94a);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeBytes(fileReference);

    // Finished serialization.
  }
}

/// Input File Location.
///
/// ID: `dfdaabe1`.
class InputFileLocation extends InputFileLocationBase {
  /// Input File Location constructor.
  const InputFileLocation({
    required this.volumeId,
    required this.localId,
    required this.secret,
    required this.fileReference,
  }) : super._();

  /// Deserialize.
  factory InputFileLocation.deserialize(BinaryReader reader) {
    // Read [InputFileLocation] fields.
    final volumeId = reader.readInt64();
    final localId = reader.readInt32();
    final secret = reader.readInt64();
    final fileReference = reader.readBytes();

    // Construct [InputFileLocation] object.
    final returnValue = InputFileLocation(
      volumeId: volumeId,
      localId: localId,
      secret: secret,
      fileReference: fileReference,
    );

    // Now return the deserialized [InputFileLocation].
    return returnValue;
  }

  /// Volume Id.
  ///
  /// Field type is Int64.
  final int volumeId;

  /// Local Id.
  ///
  /// Field type is Int32.
  final int localId;

  /// Secret.
  ///
  /// Field type is Int64.
  final int secret;

  /// File Reference.
  final Uint8List fileReference;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdfdaabe1.
    buffer.writeInt32(0xdfdaabe1);

    // Write fields.
    buffer.writeInt64(volumeId);
    buffer.writeInt32(localId);
    buffer.writeInt64(secret);
    buffer.writeBytes(fileReference);

    // Finished serialization.
  }
}

/// Input Encrypted File Location.
///
/// ID: `f5235d55`.
class InputEncryptedFileLocation extends InputFileLocationBase {
  /// Input Encrypted File Location constructor.
  const InputEncryptedFileLocation({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputEncryptedFileLocation.deserialize(BinaryReader reader) {
    // Read [InputEncryptedFileLocation] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputEncryptedFileLocation] object.
    final returnValue = InputEncryptedFileLocation(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputEncryptedFileLocation].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf5235d55.
    buffer.writeInt32(0xf5235d55);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Document File Location.
///
/// ID: `bad07584`.
class InputDocumentFileLocation extends InputFileLocationBase {
  /// Input Document File Location constructor.
  const InputDocumentFileLocation({
    required this.id,
    required this.accessHash,
    required this.fileReference,
    required this.thumbSize,
  }) : super._();

  /// Deserialize.
  factory InputDocumentFileLocation.deserialize(BinaryReader reader) {
    // Read [InputDocumentFileLocation] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final fileReference = reader.readBytes();
    final thumbSize = reader.readString();

    // Construct [InputDocumentFileLocation] object.
    final returnValue = InputDocumentFileLocation(
      id: id,
      accessHash: accessHash,
      fileReference: fileReference,
      thumbSize: thumbSize,
    );

    // Now return the deserialized [InputDocumentFileLocation].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// File Reference.
  final Uint8List fileReference;

  /// Thumb Size.
  final String thumbSize;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbad07584.
    buffer.writeInt32(0xbad07584);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeBytes(fileReference);
    buffer.writeString(thumbSize);

    // Finished serialization.
  }
}

/// Input Secure File Location.
///
/// ID: `cbc7ee28`.
class InputSecureFileLocation extends InputFileLocationBase {
  /// Input Secure File Location constructor.
  const InputSecureFileLocation({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputSecureFileLocation.deserialize(BinaryReader reader) {
    // Read [InputSecureFileLocation] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputSecureFileLocation] object.
    final returnValue = InputSecureFileLocation(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputSecureFileLocation].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcbc7ee28.
    buffer.writeInt32(0xcbc7ee28);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Takeout File Location.
///
/// ID: `29be5899`.
class InputTakeoutFileLocation extends InputFileLocationBase {
  /// Input Takeout File Location constructor.
  const InputTakeoutFileLocation() : super._();

  /// Deserialize.
  factory InputTakeoutFileLocation.deserialize(BinaryReader reader) {
    // Construct [InputTakeoutFileLocation] object.
    final returnValue = InputTakeoutFileLocation();

    // Now return the deserialized [InputTakeoutFileLocation].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x29be5899.
    buffer.writeInt32(0x29be5899);

    // Finished serialization.
  }
}

/// Input Photo File Location.
///
/// ID: `40181ffe`.
class InputPhotoFileLocation extends InputFileLocationBase {
  /// Input Photo File Location constructor.
  const InputPhotoFileLocation({
    required this.id,
    required this.accessHash,
    required this.fileReference,
    required this.thumbSize,
  }) : super._();

  /// Deserialize.
  factory InputPhotoFileLocation.deserialize(BinaryReader reader) {
    // Read [InputPhotoFileLocation] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final fileReference = reader.readBytes();
    final thumbSize = reader.readString();

    // Construct [InputPhotoFileLocation] object.
    final returnValue = InputPhotoFileLocation(
      id: id,
      accessHash: accessHash,
      fileReference: fileReference,
      thumbSize: thumbSize,
    );

    // Now return the deserialized [InputPhotoFileLocation].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// File Reference.
  final Uint8List fileReference;

  /// Thumb Size.
  final String thumbSize;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x40181ffe.
    buffer.writeInt32(0x40181ffe);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeBytes(fileReference);
    buffer.writeString(thumbSize);

    // Finished serialization.
  }
}

/// Input Photo Legacy File Location.
///
/// ID: `d83466f3`.
class InputPhotoLegacyFileLocation extends InputFileLocationBase {
  /// Input Photo Legacy File Location constructor.
  const InputPhotoLegacyFileLocation({
    required this.id,
    required this.accessHash,
    required this.fileReference,
    required this.volumeId,
    required this.localId,
    required this.secret,
  }) : super._();

  /// Deserialize.
  factory InputPhotoLegacyFileLocation.deserialize(BinaryReader reader) {
    // Read [InputPhotoLegacyFileLocation] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final fileReference = reader.readBytes();
    final volumeId = reader.readInt64();
    final localId = reader.readInt32();
    final secret = reader.readInt64();

    // Construct [InputPhotoLegacyFileLocation] object.
    final returnValue = InputPhotoLegacyFileLocation(
      id: id,
      accessHash: accessHash,
      fileReference: fileReference,
      volumeId: volumeId,
      localId: localId,
      secret: secret,
    );

    // Now return the deserialized [InputPhotoLegacyFileLocation].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// File Reference.
  final Uint8List fileReference;

  /// Volume Id.
  ///
  /// Field type is Int64.
  final int volumeId;

  /// Local Id.
  ///
  /// Field type is Int32.
  final int localId;

  /// Secret.
  ///
  /// Field type is Int64.
  final int secret;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd83466f3.
    buffer.writeInt32(0xd83466f3);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeBytes(fileReference);
    buffer.writeInt64(volumeId);
    buffer.writeInt32(localId);
    buffer.writeInt64(secret);

    // Finished serialization.
  }
}

/// Input Peer Photo File Location.
///
/// ID: `37257e99`.
class InputPeerPhotoFileLocation extends InputFileLocationBase {
  /// Input Peer Photo File Location constructor.
  const InputPeerPhotoFileLocation({
    required this.big,
    required this.peer,
    required this.photoId,
  }) : super._();

  /// Deserialize.
  factory InputPeerPhotoFileLocation.deserialize(BinaryReader reader) {
    // Read [InputPeerPhotoFileLocation] fields.
    final flags = reader.readInt32();
    final big = (flags & 1) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final photoId = reader.readInt64();

    // Construct [InputPeerPhotoFileLocation] object.
    final returnValue = InputPeerPhotoFileLocation(
      big: big,
      peer: peer,
      photoId: photoId,
    );

    // Now return the deserialized [InputPeerPhotoFileLocation].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: big,
    );

    return v;
  }

  /// big: bit 0 of flags.0?true
  final bool big;

  /// Peer.
  final InputPeerBase peer;

  /// Photo Id.
  ///
  /// Field type is Int64.
  final int photoId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x37257e99.
    buffer.writeInt32(0x37257e99);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt64(photoId);

    // Finished serialization.
  }
}

/// Input Sticker Set Thumb.
///
/// ID: `9d84f3db`.
class InputStickerSetThumb extends InputFileLocationBase {
  /// Input Sticker Set Thumb constructor.
  const InputStickerSetThumb({
    required this.stickerset,
    required this.thumbVersion,
  }) : super._();

  /// Deserialize.
  factory InputStickerSetThumb.deserialize(BinaryReader reader) {
    // Read [InputStickerSetThumb] fields.
    final stickerset = reader.readObject() as InputStickerSetBase;
    final thumbVersion = reader.readInt32();

    // Construct [InputStickerSetThumb] object.
    final returnValue = InputStickerSetThumb(
      stickerset: stickerset,
      thumbVersion: thumbVersion,
    );

    // Now return the deserialized [InputStickerSetThumb].
    return returnValue;
  }

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Thumb Version.
  ///
  /// Field type is Int32.
  final int thumbVersion;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9d84f3db.
    buffer.writeInt32(0x9d84f3db);

    // Write fields.
    buffer.writeObject(stickerset);
    buffer.writeInt32(thumbVersion);

    // Finished serialization.
  }
}

/// Input Group Call Stream.
///
/// ID: `0598a92a`.
class InputGroupCallStream extends InputFileLocationBase {
  /// Input Group Call Stream constructor.
  const InputGroupCallStream({
    required this.call,
    required this.timeMs,
    required this.scale,
    this.videoChannel,
    this.videoQuality,
  }) : super._();

  /// Deserialize.
  factory InputGroupCallStream.deserialize(BinaryReader reader) {
    // Read [InputGroupCallStream] fields.
    final flags = reader.readInt32();
    final call = reader.readObject() as InputGroupCallBase;
    final timeMs = reader.readInt64();
    final scale = reader.readInt32();
    final hasVideoChannelField = (flags & 1) != 0;
    final videoChannel = hasVideoChannelField ? reader.readInt32() : null;
    final hasVideoQualityField = (flags & 1) != 0;
    final videoQuality = hasVideoQualityField ? reader.readInt32() : null;

    // Construct [InputGroupCallStream] object.
    final returnValue = InputGroupCallStream(
      call: call,
      timeMs: timeMs,
      scale: scale,
      videoChannel: videoChannel,
      videoQuality: videoQuality,
    );

    // Now return the deserialized [InputGroupCallStream].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: videoChannel != null || videoQuality != null,
    );

    return v;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Time Ms.
  ///
  /// Field type is Int64.
  final int timeMs;

  /// Scale.
  ///
  /// Field type is Int32.
  final int scale;

  /// Video Channel.
  final int? videoChannel;

  /// Video Quality.
  final int? videoQuality;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0598a92a.
    buffer.writeInt32(0x0598a92a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(call);
    buffer.writeInt64(timeMs);
    buffer.writeInt32(scale);
    final localVideoChannelCopy = videoChannel;
    if (localVideoChannelCopy != null) {
      buffer.writeInt32(localVideoChannelCopy);
    }
    final localVideoQualityCopy = videoQuality;
    if (localVideoQualityCopy != null) {
      buffer.writeInt32(localVideoQualityCopy);
    }

    // Finished serialization.
  }
}

/// Peer User.
///
/// ID: `59511722`.
class PeerUser extends PeerBase {
  /// Peer User constructor.
  const PeerUser({
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory PeerUser.deserialize(BinaryReader reader) {
    // Read [PeerUser] fields.
    final userId = reader.readInt64();

    // Construct [PeerUser] object.
    final returnValue = PeerUser(
      userId: userId,
    );

    // Now return the deserialized [PeerUser].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x59511722.
    buffer.writeInt32(0x59511722);

    // Write fields.
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Peer Chat.
///
/// ID: `36c6019a`.
class PeerChat extends PeerBase {
  /// Peer Chat constructor.
  const PeerChat({
    required this.chatId,
  }) : super._();

  /// Deserialize.
  factory PeerChat.deserialize(BinaryReader reader) {
    // Read [PeerChat] fields.
    final chatId = reader.readInt64();

    // Construct [PeerChat] object.
    final returnValue = PeerChat(
      chatId: chatId,
    );

    // Now return the deserialized [PeerChat].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x36c6019a.
    buffer.writeInt32(0x36c6019a);

    // Write fields.
    buffer.writeInt64(chatId);

    // Finished serialization.
  }
}

/// Peer Channel.
///
/// ID: `a2a5371e`.
class PeerChannel extends PeerBase {
  /// Peer Channel constructor.
  const PeerChannel({
    required this.channelId,
  }) : super._();

  /// Deserialize.
  factory PeerChannel.deserialize(BinaryReader reader) {
    // Read [PeerChannel] fields.
    final channelId = reader.readInt64();

    // Construct [PeerChannel] object.
    final returnValue = PeerChannel(
      channelId: channelId,
    );

    // Now return the deserialized [PeerChannel].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa2a5371e.
    buffer.writeInt32(0xa2a5371e);

    // Write fields.
    buffer.writeInt64(channelId);

    // Finished serialization.
  }
}

/// Storage File Unknown.
///
/// ID: `aa963b05`.
class StorageFileUnknown extends StorageFileTypeBase {
  /// Storage File Unknown constructor.
  const StorageFileUnknown() : super._();

  /// Deserialize.
  factory StorageFileUnknown.deserialize(BinaryReader reader) {
    // Construct [StorageFileUnknown] object.
    final returnValue = StorageFileUnknown();

    // Now return the deserialized [StorageFileUnknown].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaa963b05.
    buffer.writeInt32(0xaa963b05);

    // Finished serialization.
  }
}

/// Storage File Partial.
///
/// ID: `40bc6f52`.
class StorageFilePartial extends StorageFileTypeBase {
  /// Storage File Partial constructor.
  const StorageFilePartial() : super._();

  /// Deserialize.
  factory StorageFilePartial.deserialize(BinaryReader reader) {
    // Construct [StorageFilePartial] object.
    final returnValue = StorageFilePartial();

    // Now return the deserialized [StorageFilePartial].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x40bc6f52.
    buffer.writeInt32(0x40bc6f52);

    // Finished serialization.
  }
}

/// Storage File Jpeg.
///
/// ID: `007efe0e`.
class StorageFileJpeg extends StorageFileTypeBase {
  /// Storage File Jpeg constructor.
  const StorageFileJpeg() : super._();

  /// Deserialize.
  factory StorageFileJpeg.deserialize(BinaryReader reader) {
    // Construct [StorageFileJpeg] object.
    final returnValue = StorageFileJpeg();

    // Now return the deserialized [StorageFileJpeg].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x007efe0e.
    buffer.writeInt32(0x007efe0e);

    // Finished serialization.
  }
}

/// Storage File Gif.
///
/// ID: `cae1aadf`.
class StorageFileGif extends StorageFileTypeBase {
  /// Storage File Gif constructor.
  const StorageFileGif() : super._();

  /// Deserialize.
  factory StorageFileGif.deserialize(BinaryReader reader) {
    // Construct [StorageFileGif] object.
    final returnValue = StorageFileGif();

    // Now return the deserialized [StorageFileGif].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcae1aadf.
    buffer.writeInt32(0xcae1aadf);

    // Finished serialization.
  }
}

/// Storage File Png.
///
/// ID: `0a4f63c0`.
class StorageFilePng extends StorageFileTypeBase {
  /// Storage File Png constructor.
  const StorageFilePng() : super._();

  /// Deserialize.
  factory StorageFilePng.deserialize(BinaryReader reader) {
    // Construct [StorageFilePng] object.
    final returnValue = StorageFilePng();

    // Now return the deserialized [StorageFilePng].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0a4f63c0.
    buffer.writeInt32(0x0a4f63c0);

    // Finished serialization.
  }
}

/// Storage File Pdf.
///
/// ID: `ae1e508d`.
class StorageFilePdf extends StorageFileTypeBase {
  /// Storage File Pdf constructor.
  const StorageFilePdf() : super._();

  /// Deserialize.
  factory StorageFilePdf.deserialize(BinaryReader reader) {
    // Construct [StorageFilePdf] object.
    final returnValue = StorageFilePdf();

    // Now return the deserialized [StorageFilePdf].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xae1e508d.
    buffer.writeInt32(0xae1e508d);

    // Finished serialization.
  }
}

/// Storage File Mp3.
///
/// ID: `528a0677`.
class StorageFileMp3 extends StorageFileTypeBase {
  /// Storage File Mp3 constructor.
  const StorageFileMp3() : super._();

  /// Deserialize.
  factory StorageFileMp3.deserialize(BinaryReader reader) {
    // Construct [StorageFileMp3] object.
    final returnValue = StorageFileMp3();

    // Now return the deserialized [StorageFileMp3].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x528a0677.
    buffer.writeInt32(0x528a0677);

    // Finished serialization.
  }
}

/// Storage File Mov.
///
/// ID: `4b09ebbc`.
class StorageFileMov extends StorageFileTypeBase {
  /// Storage File Mov constructor.
  const StorageFileMov() : super._();

  /// Deserialize.
  factory StorageFileMov.deserialize(BinaryReader reader) {
    // Construct [StorageFileMov] object.
    final returnValue = StorageFileMov();

    // Now return the deserialized [StorageFileMov].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4b09ebbc.
    buffer.writeInt32(0x4b09ebbc);

    // Finished serialization.
  }
}

/// Storage File Mp4.
///
/// ID: `b3cea0e4`.
class StorageFileMp4 extends StorageFileTypeBase {
  /// Storage File Mp4 constructor.
  const StorageFileMp4() : super._();

  /// Deserialize.
  factory StorageFileMp4.deserialize(BinaryReader reader) {
    // Construct [StorageFileMp4] object.
    final returnValue = StorageFileMp4();

    // Now return the deserialized [StorageFileMp4].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb3cea0e4.
    buffer.writeInt32(0xb3cea0e4);

    // Finished serialization.
  }
}

/// Storage File Webp.
///
/// ID: `1081464c`.
class StorageFileWebp extends StorageFileTypeBase {
  /// Storage File Webp constructor.
  const StorageFileWebp() : super._();

  /// Deserialize.
  factory StorageFileWebp.deserialize(BinaryReader reader) {
    // Construct [StorageFileWebp] object.
    final returnValue = StorageFileWebp();

    // Now return the deserialized [StorageFileWebp].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1081464c.
    buffer.writeInt32(0x1081464c);

    // Finished serialization.
  }
}

/// User Empty.
///
/// ID: `d3bc4b7a`.
class UserEmpty extends UserBase {
  /// User Empty constructor.
  const UserEmpty({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory UserEmpty.deserialize(BinaryReader reader) {
    // Read [UserEmpty] fields.
    final id = reader.readInt64();

    // Construct [UserEmpty] object.
    final returnValue = UserEmpty(
      id: id,
    );

    // Now return the deserialized [UserEmpty].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd3bc4b7a.
    buffer.writeInt32(0xd3bc4b7a);

    // Write fields.
    buffer.writeInt64(id);

    // Finished serialization.
  }
}

/// User.
///
/// ID: `215c4438`.
class User extends UserBase {
  /// User constructor.
  const User({
    required this.self,
    required this.contact,
    required this.mutualContact,
    required this.deleted,
    required this.bot,
    required this.botChatHistory,
    required this.botNochats,
    required this.verified,
    required this.restricted,
    required this.min,
    required this.botInlineGeo,
    required this.support,
    required this.scam,
    required this.applyMinPhoto,
    required this.fake,
    required this.botAttachMenu,
    required this.premium,
    required this.attachMenuEnabled,
    required this.botCanEdit,
    required this.closeFriend,
    required this.storiesHidden,
    required this.storiesUnavailable,
    required this.id,
    this.accessHash,
    this.firstName,
    this.lastName,
    this.username,
    this.phone,
    this.photo,
    this.status,
    this.botInfoVersion,
    this.restrictionReason,
    this.botInlinePlaceholder,
    this.langCode,
    this.emojiStatus,
    this.usernames,
    this.storiesMaxId,
    this.color,
    this.profileColor,
  }) : super._();

  /// Deserialize.
  factory User.deserialize(BinaryReader reader) {
    // Read [User] fields.
    final flags = reader.readInt32();
    final self = (flags & 1024) != 0;
    final contact = (flags & 2048) != 0;
    final mutualContact = (flags & 4096) != 0;
    final deleted = (flags & 8192) != 0;
    final bot = (flags & 16384) != 0;
    final botChatHistory = (flags & 32768) != 0;
    final botNochats = (flags & 65536) != 0;
    final verified = (flags & 131072) != 0;
    final restricted = (flags & 262144) != 0;
    final min = (flags & 1048576) != 0;
    final botInlineGeo = (flags & 2097152) != 0;
    final support = (flags & 8388608) != 0;
    final scam = (flags & 16777216) != 0;
    final applyMinPhoto = (flags & 33554432) != 0;
    final fake = (flags & 67108864) != 0;
    final botAttachMenu = (flags & 134217728) != 0;
    final premium = (flags & 268435456) != 0;
    final attachMenuEnabled = (flags & 536870912) != 0;
    final flags2 = reader.readInt32();
    final botCanEdit = (flags2 & 2) != 0;
    final closeFriend = (flags2 & 4) != 0;
    final storiesHidden = (flags2 & 8) != 0;
    final storiesUnavailable = (flags2 & 16) != 0;
    final id = reader.readInt64();
    final hasAccessHashField = (flags & 1) != 0;
    final accessHash = hasAccessHashField ? reader.readInt64() : null;
    final hasFirstNameField = (flags & 2) != 0;
    final firstName = hasFirstNameField ? reader.readString() : null;
    final hasLastNameField = (flags & 4) != 0;
    final lastName = hasLastNameField ? reader.readString() : null;
    final hasUsernameField = (flags & 8) != 0;
    final username = hasUsernameField ? reader.readString() : null;
    final hasPhoneField = (flags & 16) != 0;
    final phone = hasPhoneField ? reader.readString() : null;
    final hasPhotoField = (flags & 32) != 0;
    final photo =
        hasPhotoField ? reader.readObject() as UserProfilePhotoBase : null;
    final hasStatusField = (flags & 64) != 0;
    final status =
        hasStatusField ? reader.readObject() as UserStatusBase : null;
    final hasBotInfoVersionField = (flags & 16384) != 0;
    final botInfoVersion = hasBotInfoVersionField ? reader.readInt32() : null;
    final hasRestrictionReasonField = (flags & 262144) != 0;
    final restrictionReason = hasRestrictionReasonField
        ? reader.readVectorObject<RestrictionReasonBase>()
        : null;
    final hasBotInlinePlaceholderField = (flags & 524288) != 0;
    final botInlinePlaceholder =
        hasBotInlinePlaceholderField ? reader.readString() : null;
    final hasLangCodeField = (flags & 4194304) != 0;
    final langCode = hasLangCodeField ? reader.readString() : null;
    final hasEmojiStatusField = (flags & 1073741824) != 0;
    final emojiStatus =
        hasEmojiStatusField ? reader.readObject() as EmojiStatusBase : null;
    final hasUsernamesField = (flags2 & 1) != 0;
    final usernames =
        hasUsernamesField ? reader.readVectorObject<UsernameBase>() : null;
    final hasStoriesMaxIdField = (flags2 & 32) != 0;
    final storiesMaxId = hasStoriesMaxIdField ? reader.readInt32() : null;
    final hasColorField = (flags2 & 256) != 0;
    final color = hasColorField ? reader.readObject() as PeerColorBase : null;
    final hasProfileColorField = (flags2 & 512) != 0;
    final profileColor =
        hasProfileColorField ? reader.readObject() as PeerColorBase : null;

    // Construct [User] object.
    final returnValue = User(
      self: self,
      contact: contact,
      mutualContact: mutualContact,
      deleted: deleted,
      bot: bot,
      botChatHistory: botChatHistory,
      botNochats: botNochats,
      verified: verified,
      restricted: restricted,
      min: min,
      botInlineGeo: botInlineGeo,
      support: support,
      scam: scam,
      applyMinPhoto: applyMinPhoto,
      fake: fake,
      botAttachMenu: botAttachMenu,
      premium: premium,
      attachMenuEnabled: attachMenuEnabled,
      botCanEdit: botCanEdit,
      closeFriend: closeFriend,
      storiesHidden: storiesHidden,
      storiesUnavailable: storiesUnavailable,
      id: id,
      accessHash: accessHash,
      firstName: firstName,
      lastName: lastName,
      username: username,
      phone: phone,
      photo: photo,
      status: status,
      botInfoVersion: botInfoVersion,
      restrictionReason: restrictionReason,
      botInlinePlaceholder: botInlinePlaceholder,
      langCode: langCode,
      emojiStatus: emojiStatus,
      usernames: usernames,
      storiesMaxId: storiesMaxId,
      color: color,
      profileColor: profileColor,
    );

    // Now return the deserialized [User].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b10: self,
      b11: contact,
      b12: mutualContact,
      b13: deleted,
      b14: bot || botInfoVersion != null,
      b15: botChatHistory,
      b16: botNochats,
      b17: verified,
      b18: restricted || restrictionReason != null,
      b20: min,
      b21: botInlineGeo,
      b23: support,
      b24: scam,
      b25: applyMinPhoto,
      b26: fake,
      b27: botAttachMenu,
      b28: premium,
      b29: attachMenuEnabled,
      b00: accessHash != null,
      b01: firstName != null,
      b02: lastName != null,
      b03: username != null,
      b04: phone != null,
      b05: photo != null,
      b06: status != null,
      b19: botInlinePlaceholder != null,
      b22: langCode != null,
      b30: emojiStatus != null,
    );

    return v;
  }

  /// Flags2.
  int get flags2 {
    final v = _flag(
      b01: botCanEdit,
      b02: closeFriend,
      b03: storiesHidden,
      b04: storiesUnavailable,
      b00: usernames != null,
      b05: storiesMaxId != null,
      b08: color != null,
      b09: profileColor != null,
    );

    return v;
  }

  /// self: bit 10 of flags.10?true
  final bool self;

  /// contact: bit 11 of flags.11?true
  final bool contact;

  /// mutual_contact: bit 12 of flags.12?true
  final bool mutualContact;

  /// deleted: bit 13 of flags.13?true
  final bool deleted;

  /// bot: bit 14 of flags.14?true
  final bool bot;

  /// bot_chat_history: bit 15 of flags.15?true
  final bool botChatHistory;

  /// bot_nochats: bit 16 of flags.16?true
  final bool botNochats;

  /// verified: bit 17 of flags.17?true
  final bool verified;

  /// restricted: bit 18 of flags.18?true
  final bool restricted;

  /// min: bit 20 of flags.20?true
  final bool min;

  /// bot_inline_geo: bit 21 of flags.21?true
  final bool botInlineGeo;

  /// support: bit 23 of flags.23?true
  final bool support;

  /// scam: bit 24 of flags.24?true
  final bool scam;

  /// apply_min_photo: bit 25 of flags.25?true
  final bool applyMinPhoto;

  /// fake: bit 26 of flags.26?true
  final bool fake;

  /// bot_attach_menu: bit 27 of flags.27?true
  final bool botAttachMenu;

  /// premium: bit 28 of flags.28?true
  final bool premium;

  /// attach_menu_enabled: bit 29 of flags.29?true
  final bool attachMenuEnabled;

  /// bot_can_edit: bit 1 of flags2.1?true
  final bool botCanEdit;

  /// close_friend: bit 2 of flags2.2?true
  final bool closeFriend;

  /// stories_hidden: bit 3 of flags2.3?true
  final bool storiesHidden;

  /// stories_unavailable: bit 4 of flags2.4?true
  final bool storiesUnavailable;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  final int? accessHash;

  /// First Name.
  final String? firstName;

  /// Last Name.
  final String? lastName;

  /// Username.
  final String? username;

  /// Phone.
  final String? phone;

  /// Photo.
  final UserProfilePhotoBase? photo;

  /// Status.
  final UserStatusBase? status;

  /// Bot Info Version.
  final int? botInfoVersion;

  /// Restriction Reason.
  final List<RestrictionReasonBase>? restrictionReason;

  /// Bot Inline Placeholder.
  final String? botInlinePlaceholder;

  /// Lang Code.
  final String? langCode;

  /// Emoji Status.
  final EmojiStatusBase? emojiStatus;

  /// Usernames.
  final List<UsernameBase>? usernames;

  /// Stories Max Id.
  final int? storiesMaxId;

  /// Color.
  final PeerColorBase? color;

  /// Profile Color.
  final PeerColorBase? profileColor;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x215c4438.
    buffer.writeInt32(0x215c4438);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(flags2);
    buffer.writeInt64(id);
    final localAccessHashCopy = accessHash;
    if (localAccessHashCopy != null) {
      buffer.writeInt64(localAccessHashCopy);
    }
    final localFirstNameCopy = firstName;
    if (localFirstNameCopy != null) {
      buffer.writeString(localFirstNameCopy);
    }
    final localLastNameCopy = lastName;
    if (localLastNameCopy != null) {
      buffer.writeString(localLastNameCopy);
    }
    final localUsernameCopy = username;
    if (localUsernameCopy != null) {
      buffer.writeString(localUsernameCopy);
    }
    final localPhoneCopy = phone;
    if (localPhoneCopy != null) {
      buffer.writeString(localPhoneCopy);
    }
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }
    final localStatusCopy = status;
    if (localStatusCopy != null) {
      buffer.writeObject(localStatusCopy);
    }
    final localBotInfoVersionCopy = botInfoVersion;
    if (localBotInfoVersionCopy != null) {
      buffer.writeInt32(localBotInfoVersionCopy);
    }
    final localRestrictionReasonCopy = restrictionReason;
    if (localRestrictionReasonCopy != null) {
      buffer.writeVectorObject(localRestrictionReasonCopy);
    }
    final localBotInlinePlaceholderCopy = botInlinePlaceholder;
    if (localBotInlinePlaceholderCopy != null) {
      buffer.writeString(localBotInlinePlaceholderCopy);
    }
    final localLangCodeCopy = langCode;
    if (localLangCodeCopy != null) {
      buffer.writeString(localLangCodeCopy);
    }
    final localEmojiStatusCopy = emojiStatus;
    if (localEmojiStatusCopy != null) {
      buffer.writeObject(localEmojiStatusCopy);
    }
    final localUsernamesCopy = usernames;
    if (localUsernamesCopy != null) {
      buffer.writeVectorObject(localUsernamesCopy);
    }
    final localStoriesMaxIdCopy = storiesMaxId;
    if (localStoriesMaxIdCopy != null) {
      buffer.writeInt32(localStoriesMaxIdCopy);
    }
    final localColorCopy = color;
    if (localColorCopy != null) {
      buffer.writeObject(localColorCopy);
    }
    final localProfileColorCopy = profileColor;
    if (localProfileColorCopy != null) {
      buffer.writeObject(localProfileColorCopy);
    }

    // Finished serialization.
  }
}

/// User Profile Photo Empty.
///
/// ID: `4f11bae1`.
class UserProfilePhotoEmpty extends UserProfilePhotoBase {
  /// User Profile Photo Empty constructor.
  const UserProfilePhotoEmpty() : super._();

  /// Deserialize.
  factory UserProfilePhotoEmpty.deserialize(BinaryReader reader) {
    // Construct [UserProfilePhotoEmpty] object.
    final returnValue = UserProfilePhotoEmpty();

    // Now return the deserialized [UserProfilePhotoEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4f11bae1.
    buffer.writeInt32(0x4f11bae1);

    // Finished serialization.
  }
}

/// User Profile Photo.
///
/// ID: `82d1f706`.
class UserProfilePhoto extends UserProfilePhotoBase {
  /// User Profile Photo constructor.
  const UserProfilePhoto({
    required this.hasVideo,
    required this.personal,
    required this.photoId,
    this.strippedThumb,
    required this.dcId,
  }) : super._();

  /// Deserialize.
  factory UserProfilePhoto.deserialize(BinaryReader reader) {
    // Read [UserProfilePhoto] fields.
    final flags = reader.readInt32();
    final hasVideo = (flags & 1) != 0;
    final personal = (flags & 4) != 0;
    final photoId = reader.readInt64();
    final hasStrippedThumbField = (flags & 2) != 0;
    final strippedThumb = hasStrippedThumbField ? reader.readBytes() : null;
    final dcId = reader.readInt32();

    // Construct [UserProfilePhoto] object.
    final returnValue = UserProfilePhoto(
      hasVideo: hasVideo,
      personal: personal,
      photoId: photoId,
      strippedThumb: strippedThumb,
      dcId: dcId,
    );

    // Now return the deserialized [UserProfilePhoto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: hasVideo,
      b02: personal,
      b01: strippedThumb != null,
    );

    return v;
  }

  /// has_video: bit 0 of flags.0?true
  final bool hasVideo;

  /// personal: bit 2 of flags.2?true
  final bool personal;

  /// Photo Id.
  ///
  /// Field type is Int64.
  final int photoId;

  /// Stripped Thumb.
  final Uint8List? strippedThumb;

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x82d1f706.
    buffer.writeInt32(0x82d1f706);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(photoId);
    final localStrippedThumbCopy = strippedThumb;
    if (localStrippedThumbCopy != null) {
      buffer.writeBytes(localStrippedThumbCopy);
    }
    buffer.writeInt32(dcId);

    // Finished serialization.
  }
}

/// User Status Empty.
///
/// ID: `09d05049`.
class UserStatusEmpty extends UserStatusBase {
  /// User Status Empty constructor.
  const UserStatusEmpty() : super._();

  /// Deserialize.
  factory UserStatusEmpty.deserialize(BinaryReader reader) {
    // Construct [UserStatusEmpty] object.
    final returnValue = UserStatusEmpty();

    // Now return the deserialized [UserStatusEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x09d05049.
    buffer.writeInt32(0x09d05049);

    // Finished serialization.
  }
}

/// User Status Online.
///
/// ID: `edb93949`.
class UserStatusOnline extends UserStatusBase {
  /// User Status Online constructor.
  const UserStatusOnline({
    required this.expires,
  }) : super._();

  /// Deserialize.
  factory UserStatusOnline.deserialize(BinaryReader reader) {
    // Read [UserStatusOnline] fields.
    final expires = reader.readInt32();

    // Construct [UserStatusOnline] object.
    final returnValue = UserStatusOnline(
      expires: expires,
    );

    // Now return the deserialized [UserStatusOnline].
    return returnValue;
  }

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xedb93949.
    buffer.writeInt32(0xedb93949);

    // Write fields.
    buffer.writeInt32(expires);

    // Finished serialization.
  }
}

/// User Status Offline.
///
/// ID: `008c703f`.
class UserStatusOffline extends UserStatusBase {
  /// User Status Offline constructor.
  const UserStatusOffline({
    required this.wasOnline,
  }) : super._();

  /// Deserialize.
  factory UserStatusOffline.deserialize(BinaryReader reader) {
    // Read [UserStatusOffline] fields.
    final wasOnline = reader.readInt32();

    // Construct [UserStatusOffline] object.
    final returnValue = UserStatusOffline(
      wasOnline: wasOnline,
    );

    // Now return the deserialized [UserStatusOffline].
    return returnValue;
  }

  /// Was Online.
  ///
  /// Field type is Int32.
  final int wasOnline;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x008c703f.
    buffer.writeInt32(0x008c703f);

    // Write fields.
    buffer.writeInt32(wasOnline);

    // Finished serialization.
  }
}

/// User Status Recently.
///
/// ID: `e26f42f1`.
class UserStatusRecently extends UserStatusBase {
  /// User Status Recently constructor.
  const UserStatusRecently() : super._();

  /// Deserialize.
  factory UserStatusRecently.deserialize(BinaryReader reader) {
    // Construct [UserStatusRecently] object.
    final returnValue = UserStatusRecently();

    // Now return the deserialized [UserStatusRecently].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe26f42f1.
    buffer.writeInt32(0xe26f42f1);

    // Finished serialization.
  }
}

/// User Status Last Week.
///
/// ID: `07bf09fc`.
class UserStatusLastWeek extends UserStatusBase {
  /// User Status Last Week constructor.
  const UserStatusLastWeek() : super._();

  /// Deserialize.
  factory UserStatusLastWeek.deserialize(BinaryReader reader) {
    // Construct [UserStatusLastWeek] object.
    final returnValue = UserStatusLastWeek();

    // Now return the deserialized [UserStatusLastWeek].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x07bf09fc.
    buffer.writeInt32(0x07bf09fc);

    // Finished serialization.
  }
}

/// User Status Last Month.
///
/// ID: `77ebc742`.
class UserStatusLastMonth extends UserStatusBase {
  /// User Status Last Month constructor.
  const UserStatusLastMonth() : super._();

  /// Deserialize.
  factory UserStatusLastMonth.deserialize(BinaryReader reader) {
    // Construct [UserStatusLastMonth] object.
    final returnValue = UserStatusLastMonth();

    // Now return the deserialized [UserStatusLastMonth].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x77ebc742.
    buffer.writeInt32(0x77ebc742);

    // Finished serialization.
  }
}

/// Chat Empty.
///
/// ID: `29562865`.
class ChatEmpty extends ChatBase {
  /// Chat Empty constructor.
  const ChatEmpty({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ChatEmpty.deserialize(BinaryReader reader) {
    // Read [ChatEmpty] fields.
    final id = reader.readInt64();

    // Construct [ChatEmpty] object.
    final returnValue = ChatEmpty(
      id: id,
    );

    // Now return the deserialized [ChatEmpty].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x29562865.
    buffer.writeInt32(0x29562865);

    // Write fields.
    buffer.writeInt64(id);

    // Finished serialization.
  }
}

/// Chat.
///
/// ID: `41cbf256`.
class Chat extends ChatBase {
  /// Chat constructor.
  const Chat({
    required this.creator,
    required this.left,
    required this.deactivated,
    required this.callActive,
    required this.callNotEmpty,
    required this.noforwards,
    required this.id,
    required this.title,
    required this.photo,
    required this.participantsCount,
    required this.date,
    required this.version,
    this.migratedTo,
    this.adminRights,
    this.defaultBannedRights,
  }) : super._();

  /// Deserialize.
  factory Chat.deserialize(BinaryReader reader) {
    // Read [Chat] fields.
    final flags = reader.readInt32();
    final creator = (flags & 1) != 0;
    final left = (flags & 4) != 0;
    final deactivated = (flags & 32) != 0;
    final callActive = (flags & 8388608) != 0;
    final callNotEmpty = (flags & 16777216) != 0;
    final noforwards = (flags & 33554432) != 0;
    final id = reader.readInt64();
    final title = reader.readString();
    final photo = reader.readObject() as ChatPhotoBase;
    final participantsCount = reader.readInt32();
    final date = reader.readDateTime();
    final version = reader.readInt32();
    final hasMigratedToField = (flags & 64) != 0;
    final migratedTo =
        hasMigratedToField ? reader.readObject() as InputChannelBase : null;
    final hasAdminRightsField = (flags & 16384) != 0;
    final adminRights =
        hasAdminRightsField ? reader.readObject() as ChatAdminRightsBase : null;
    final hasDefaultBannedRightsField = (flags & 262144) != 0;
    final defaultBannedRights = hasDefaultBannedRightsField
        ? reader.readObject() as ChatBannedRightsBase
        : null;

    // Construct [Chat] object.
    final returnValue = Chat(
      creator: creator,
      left: left,
      deactivated: deactivated,
      callActive: callActive,
      callNotEmpty: callNotEmpty,
      noforwards: noforwards,
      id: id,
      title: title,
      photo: photo,
      participantsCount: participantsCount,
      date: date,
      version: version,
      migratedTo: migratedTo,
      adminRights: adminRights,
      defaultBannedRights: defaultBannedRights,
    );

    // Now return the deserialized [Chat].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: creator,
      b02: left,
      b05: deactivated,
      b23: callActive,
      b24: callNotEmpty,
      b25: noforwards,
      b06: migratedTo != null,
      b14: adminRights != null,
      b18: defaultBannedRights != null,
    );

    return v;
  }

  /// creator: bit 0 of flags.0?true
  final bool creator;

  /// left: bit 2 of flags.2?true
  final bool left;

  /// deactivated: bit 5 of flags.5?true
  final bool deactivated;

  /// call_active: bit 23 of flags.23?true
  final bool callActive;

  /// call_not_empty: bit 24 of flags.24?true
  final bool callNotEmpty;

  /// noforwards: bit 25 of flags.25?true
  final bool noforwards;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Title.
  final String title;

  /// Photo.
  final ChatPhotoBase photo;

  /// Participants Count.
  ///
  /// Field type is Int32.
  final int participantsCount;

  /// Date.
  final DateTime date;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Migrated To.
  final InputChannelBase? migratedTo;

  /// Admin Rights.
  final ChatAdminRightsBase? adminRights;

  /// Default Banned Rights.
  final ChatBannedRightsBase? defaultBannedRights;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x41cbf256.
    buffer.writeInt32(0x41cbf256);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeString(title);
    buffer.writeObject(photo);
    buffer.writeInt32(participantsCount);
    buffer.writeDateTime(date);
    buffer.writeInt32(version);
    final localMigratedToCopy = migratedTo;
    if (localMigratedToCopy != null) {
      buffer.writeObject(localMigratedToCopy);
    }
    final localAdminRightsCopy = adminRights;
    if (localAdminRightsCopy != null) {
      buffer.writeObject(localAdminRightsCopy);
    }
    final localDefaultBannedRightsCopy = defaultBannedRights;
    if (localDefaultBannedRightsCopy != null) {
      buffer.writeObject(localDefaultBannedRightsCopy);
    }

    // Finished serialization.
  }
}

/// Chat Forbidden.
///
/// ID: `6592a1a7`.
class ChatForbidden extends ChatBase {
  /// Chat Forbidden constructor.
  const ChatForbidden({
    required this.id,
    required this.title,
  }) : super._();

  /// Deserialize.
  factory ChatForbidden.deserialize(BinaryReader reader) {
    // Read [ChatForbidden] fields.
    final id = reader.readInt64();
    final title = reader.readString();

    // Construct [ChatForbidden] object.
    final returnValue = ChatForbidden(
      id: id,
      title: title,
    );

    // Now return the deserialized [ChatForbidden].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Title.
  final String title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6592a1a7.
    buffer.writeInt32(0x6592a1a7);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeString(title);

    // Finished serialization.
  }
}

/// Channel.
///
/// ID: `0aadfc8f`.
class Channel extends ChatBase {
  /// Channel constructor.
  const Channel({
    required this.creator,
    required this.left,
    required this.broadcast,
    required this.verified,
    required this.megagroup,
    required this.restricted,
    required this.signatures,
    required this.min,
    required this.scam,
    required this.hasLink,
    required this.hasGeo,
    required this.slowmodeEnabled,
    required this.callActive,
    required this.callNotEmpty,
    required this.fake,
    required this.gigagroup,
    required this.noforwards,
    required this.joinToSend,
    required this.joinRequest,
    required this.forum,
    required this.storiesHidden,
    required this.storiesHiddenMin,
    required this.storiesUnavailable,
    required this.id,
    this.accessHash,
    required this.title,
    this.username,
    required this.photo,
    required this.date,
    this.restrictionReason,
    this.adminRights,
    this.bannedRights,
    this.defaultBannedRights,
    this.participantsCount,
    this.usernames,
    this.storiesMaxId,
    this.color,
    this.profileColor,
    this.emojiStatus,
    this.level,
  }) : super._();

  /// Deserialize.
  factory Channel.deserialize(BinaryReader reader) {
    // Read [Channel] fields.
    final flags = reader.readInt32();
    final creator = (flags & 1) != 0;
    final left = (flags & 4) != 0;
    final broadcast = (flags & 32) != 0;
    final verified = (flags & 128) != 0;
    final megagroup = (flags & 256) != 0;
    final restricted = (flags & 512) != 0;
    final signatures = (flags & 2048) != 0;
    final min = (flags & 4096) != 0;
    final scam = (flags & 524288) != 0;
    final hasLink = (flags & 1048576) != 0;
    final hasGeo = (flags & 2097152) != 0;
    final slowmodeEnabled = (flags & 4194304) != 0;
    final callActive = (flags & 8388608) != 0;
    final callNotEmpty = (flags & 16777216) != 0;
    final fake = (flags & 33554432) != 0;
    final gigagroup = (flags & 67108864) != 0;
    final noforwards = (flags & 134217728) != 0;
    final joinToSend = (flags & 268435456) != 0;
    final joinRequest = (flags & 536870912) != 0;
    final forum = (flags & 1073741824) != 0;
    final flags2 = reader.readInt32();
    final storiesHidden = (flags2 & 2) != 0;
    final storiesHiddenMin = (flags2 & 4) != 0;
    final storiesUnavailable = (flags2 & 8) != 0;
    final id = reader.readInt64();
    final hasAccessHashField = (flags & 8192) != 0;
    final accessHash = hasAccessHashField ? reader.readInt64() : null;
    final title = reader.readString();
    final hasUsernameField = (flags & 64) != 0;
    final username = hasUsernameField ? reader.readString() : null;
    final photo = reader.readObject() as ChatPhotoBase;
    final date = reader.readDateTime();
    final hasRestrictionReasonField = (flags & 512) != 0;
    final restrictionReason = hasRestrictionReasonField
        ? reader.readVectorObject<RestrictionReasonBase>()
        : null;
    final hasAdminRightsField = (flags & 16384) != 0;
    final adminRights =
        hasAdminRightsField ? reader.readObject() as ChatAdminRightsBase : null;
    final hasBannedRightsField = (flags & 32768) != 0;
    final bannedRights = hasBannedRightsField
        ? reader.readObject() as ChatBannedRightsBase
        : null;
    final hasDefaultBannedRightsField = (flags & 262144) != 0;
    final defaultBannedRights = hasDefaultBannedRightsField
        ? reader.readObject() as ChatBannedRightsBase
        : null;
    final hasParticipantsCountField = (flags & 131072) != 0;
    final participantsCount =
        hasParticipantsCountField ? reader.readInt32() : null;
    final hasUsernamesField = (flags2 & 1) != 0;
    final usernames =
        hasUsernamesField ? reader.readVectorObject<UsernameBase>() : null;
    final hasStoriesMaxIdField = (flags2 & 16) != 0;
    final storiesMaxId = hasStoriesMaxIdField ? reader.readInt32() : null;
    final hasColorField = (flags2 & 128) != 0;
    final color = hasColorField ? reader.readObject() as PeerColorBase : null;
    final hasProfileColorField = (flags2 & 256) != 0;
    final profileColor =
        hasProfileColorField ? reader.readObject() as PeerColorBase : null;
    final hasEmojiStatusField = (flags2 & 512) != 0;
    final emojiStatus =
        hasEmojiStatusField ? reader.readObject() as EmojiStatusBase : null;
    final hasLevelField = (flags2 & 1024) != 0;
    final level = hasLevelField ? reader.readInt32() : null;

    // Construct [Channel] object.
    final returnValue = Channel(
      creator: creator,
      left: left,
      broadcast: broadcast,
      verified: verified,
      megagroup: megagroup,
      restricted: restricted,
      signatures: signatures,
      min: min,
      scam: scam,
      hasLink: hasLink,
      hasGeo: hasGeo,
      slowmodeEnabled: slowmodeEnabled,
      callActive: callActive,
      callNotEmpty: callNotEmpty,
      fake: fake,
      gigagroup: gigagroup,
      noforwards: noforwards,
      joinToSend: joinToSend,
      joinRequest: joinRequest,
      forum: forum,
      storiesHidden: storiesHidden,
      storiesHiddenMin: storiesHiddenMin,
      storiesUnavailable: storiesUnavailable,
      id: id,
      accessHash: accessHash,
      title: title,
      username: username,
      photo: photo,
      date: date,
      restrictionReason: restrictionReason,
      adminRights: adminRights,
      bannedRights: bannedRights,
      defaultBannedRights: defaultBannedRights,
      participantsCount: participantsCount,
      usernames: usernames,
      storiesMaxId: storiesMaxId,
      color: color,
      profileColor: profileColor,
      emojiStatus: emojiStatus,
      level: level,
    );

    // Now return the deserialized [Channel].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: creator,
      b02: left,
      b05: broadcast,
      b07: verified,
      b08: megagroup,
      b09: restricted || restrictionReason != null,
      b11: signatures,
      b12: min,
      b19: scam,
      b20: hasLink,
      b21: hasGeo,
      b22: slowmodeEnabled,
      b23: callActive,
      b24: callNotEmpty,
      b25: fake,
      b26: gigagroup,
      b27: noforwards,
      b28: joinToSend,
      b29: joinRequest,
      b30: forum,
      b13: accessHash != null,
      b06: username != null,
      b14: adminRights != null,
      b15: bannedRights != null,
      b18: defaultBannedRights != null,
      b17: participantsCount != null,
    );

    return v;
  }

  /// Flags2.
  int get flags2 {
    final v = _flag(
      b01: storiesHidden,
      b02: storiesHiddenMin,
      b03: storiesUnavailable,
      b00: usernames != null,
      b04: storiesMaxId != null,
      b07: color != null,
      b08: profileColor != null,
      b09: emojiStatus != null,
      b10: level != null,
    );

    return v;
  }

  /// creator: bit 0 of flags.0?true
  final bool creator;

  /// left: bit 2 of flags.2?true
  final bool left;

  /// broadcast: bit 5 of flags.5?true
  final bool broadcast;

  /// verified: bit 7 of flags.7?true
  final bool verified;

  /// megagroup: bit 8 of flags.8?true
  final bool megagroup;

  /// restricted: bit 9 of flags.9?true
  final bool restricted;

  /// signatures: bit 11 of flags.11?true
  final bool signatures;

  /// min: bit 12 of flags.12?true
  final bool min;

  /// scam: bit 19 of flags.19?true
  final bool scam;

  /// has_link: bit 20 of flags.20?true
  final bool hasLink;

  /// has_geo: bit 21 of flags.21?true
  final bool hasGeo;

  /// slowmode_enabled: bit 22 of flags.22?true
  final bool slowmodeEnabled;

  /// call_active: bit 23 of flags.23?true
  final bool callActive;

  /// call_not_empty: bit 24 of flags.24?true
  final bool callNotEmpty;

  /// fake: bit 25 of flags.25?true
  final bool fake;

  /// gigagroup: bit 26 of flags.26?true
  final bool gigagroup;

  /// noforwards: bit 27 of flags.27?true
  final bool noforwards;

  /// join_to_send: bit 28 of flags.28?true
  final bool joinToSend;

  /// join_request: bit 29 of flags.29?true
  final bool joinRequest;

  /// forum: bit 30 of flags.30?true
  final bool forum;

  /// stories_hidden: bit 1 of flags2.1?true
  final bool storiesHidden;

  /// stories_hidden_min: bit 2 of flags2.2?true
  final bool storiesHiddenMin;

  /// stories_unavailable: bit 3 of flags2.3?true
  final bool storiesUnavailable;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  final int? accessHash;

  /// Title.
  final String title;

  /// Username.
  final String? username;

  /// Photo.
  final ChatPhotoBase photo;

  /// Date.
  final DateTime date;

  /// Restriction Reason.
  final List<RestrictionReasonBase>? restrictionReason;

  /// Admin Rights.
  final ChatAdminRightsBase? adminRights;

  /// Banned Rights.
  final ChatBannedRightsBase? bannedRights;

  /// Default Banned Rights.
  final ChatBannedRightsBase? defaultBannedRights;

  /// Participants Count.
  final int? participantsCount;

  /// Usernames.
  final List<UsernameBase>? usernames;

  /// Stories Max Id.
  final int? storiesMaxId;

  /// Color.
  final PeerColorBase? color;

  /// Profile Color.
  final PeerColorBase? profileColor;

  /// Emoji Status.
  final EmojiStatusBase? emojiStatus;

  /// Level.
  final int? level;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0aadfc8f.
    buffer.writeInt32(0x0aadfc8f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(flags2);
    buffer.writeInt64(id);
    final localAccessHashCopy = accessHash;
    if (localAccessHashCopy != null) {
      buffer.writeInt64(localAccessHashCopy);
    }
    buffer.writeString(title);
    final localUsernameCopy = username;
    if (localUsernameCopy != null) {
      buffer.writeString(localUsernameCopy);
    }
    buffer.writeObject(photo);
    buffer.writeDateTime(date);
    final localRestrictionReasonCopy = restrictionReason;
    if (localRestrictionReasonCopy != null) {
      buffer.writeVectorObject(localRestrictionReasonCopy);
    }
    final localAdminRightsCopy = adminRights;
    if (localAdminRightsCopy != null) {
      buffer.writeObject(localAdminRightsCopy);
    }
    final localBannedRightsCopy = bannedRights;
    if (localBannedRightsCopy != null) {
      buffer.writeObject(localBannedRightsCopy);
    }
    final localDefaultBannedRightsCopy = defaultBannedRights;
    if (localDefaultBannedRightsCopy != null) {
      buffer.writeObject(localDefaultBannedRightsCopy);
    }
    final localParticipantsCountCopy = participantsCount;
    if (localParticipantsCountCopy != null) {
      buffer.writeInt32(localParticipantsCountCopy);
    }
    final localUsernamesCopy = usernames;
    if (localUsernamesCopy != null) {
      buffer.writeVectorObject(localUsernamesCopy);
    }
    final localStoriesMaxIdCopy = storiesMaxId;
    if (localStoriesMaxIdCopy != null) {
      buffer.writeInt32(localStoriesMaxIdCopy);
    }
    final localColorCopy = color;
    if (localColorCopy != null) {
      buffer.writeObject(localColorCopy);
    }
    final localProfileColorCopy = profileColor;
    if (localProfileColorCopy != null) {
      buffer.writeObject(localProfileColorCopy);
    }
    final localEmojiStatusCopy = emojiStatus;
    if (localEmojiStatusCopy != null) {
      buffer.writeObject(localEmojiStatusCopy);
    }
    final localLevelCopy = level;
    if (localLevelCopy != null) {
      buffer.writeInt32(localLevelCopy);
    }

    // Finished serialization.
  }
}

/// Channel Forbidden.
///
/// ID: `17d493d5`.
class ChannelForbidden extends ChatBase {
  /// Channel Forbidden constructor.
  const ChannelForbidden({
    required this.broadcast,
    required this.megagroup,
    required this.id,
    required this.accessHash,
    required this.title,
    this.untilDate,
  }) : super._();

  /// Deserialize.
  factory ChannelForbidden.deserialize(BinaryReader reader) {
    // Read [ChannelForbidden] fields.
    final flags = reader.readInt32();
    final broadcast = (flags & 32) != 0;
    final megagroup = (flags & 256) != 0;
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final title = reader.readString();
    final hasUntilDateField = (flags & 65536) != 0;
    final untilDate = hasUntilDateField ? reader.readDateTime() : null;

    // Construct [ChannelForbidden] object.
    final returnValue = ChannelForbidden(
      broadcast: broadcast,
      megagroup: megagroup,
      id: id,
      accessHash: accessHash,
      title: title,
      untilDate: untilDate,
    );

    // Now return the deserialized [ChannelForbidden].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b05: broadcast,
      b08: megagroup,
      b16: untilDate != null,
    );

    return v;
  }

  /// broadcast: bit 5 of flags.5?true
  final bool broadcast;

  /// megagroup: bit 8 of flags.8?true
  final bool megagroup;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Title.
  final String title;

  /// Until Date.
  final DateTime? untilDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x17d493d5.
    buffer.writeInt32(0x17d493d5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeString(title);
    final localUntilDateCopy = untilDate;
    if (localUntilDateCopy != null) {
      buffer.writeDateTime(localUntilDateCopy);
    }

    // Finished serialization.
  }
}

/// Chat Full.
///
/// ID: `c9d31138`.
class ChatFull extends ChatFullBase {
  /// Chat Full constructor.
  const ChatFull({
    required this.canSetUsername,
    required this.hasScheduled,
    required this.translationsDisabled,
    required this.id,
    required this.about,
    required this.participants,
    this.chatPhoto,
    required this.notifySettings,
    this.exportedInvite,
    this.botInfo,
    this.pinnedMsgId,
    this.folderId,
    this.call,
    this.ttlPeriod,
    this.groupcallDefaultJoinAs,
    this.themeEmoticon,
    this.requestsPending,
    this.recentRequesters,
    this.availableReactions,
  }) : super._();

  /// Deserialize.
  factory ChatFull.deserialize(BinaryReader reader) {
    // Read [ChatFull] fields.
    final flags = reader.readInt32();
    final canSetUsername = (flags & 128) != 0;
    final hasScheduled = (flags & 256) != 0;
    final translationsDisabled = (flags & 524288) != 0;
    final id = reader.readInt64();
    final about = reader.readString();
    final participants = reader.readObject() as ChatParticipantsBase;
    final hasChatPhotoField = (flags & 4) != 0;
    final chatPhoto =
        hasChatPhotoField ? reader.readObject() as PhotoBase : null;
    final notifySettings = reader.readObject() as PeerNotifySettingsBase;
    final hasExportedInviteField = (flags & 8192) != 0;
    final exportedInvite = hasExportedInviteField
        ? reader.readObject() as ExportedChatInviteBase
        : null;
    final hasBotInfoField = (flags & 8) != 0;
    final botInfo =
        hasBotInfoField ? reader.readVectorObject<BotInfoBase>() : null;
    final hasPinnedMsgIdField = (flags & 64) != 0;
    final pinnedMsgId = hasPinnedMsgIdField ? reader.readInt32() : null;
    final hasFolderIdField = (flags & 2048) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final hasCallField = (flags & 4096) != 0;
    final call =
        hasCallField ? reader.readObject() as InputGroupCallBase : null;
    final hasTtlPeriodField = (flags & 16384) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;
    final hasGroupcallDefaultJoinAsField = (flags & 32768) != 0;
    final groupcallDefaultJoinAs =
        hasGroupcallDefaultJoinAsField ? reader.readObject() as PeerBase : null;
    final hasThemeEmoticonField = (flags & 65536) != 0;
    final themeEmoticon = hasThemeEmoticonField ? reader.readString() : null;
    final hasRequestsPendingField = (flags & 131072) != 0;
    final requestsPending = hasRequestsPendingField ? reader.readInt32() : null;
    final hasRecentRequestersField = (flags & 131072) != 0;
    final recentRequesters =
        hasRecentRequestersField ? reader.readVectorInt64() : null;
    final hasAvailableReactionsField = (flags & 262144) != 0;
    final availableReactions = hasAvailableReactionsField
        ? reader.readObject() as ChatReactionsBase
        : null;

    // Construct [ChatFull] object.
    final returnValue = ChatFull(
      canSetUsername: canSetUsername,
      hasScheduled: hasScheduled,
      translationsDisabled: translationsDisabled,
      id: id,
      about: about,
      participants: participants,
      chatPhoto: chatPhoto,
      notifySettings: notifySettings,
      exportedInvite: exportedInvite,
      botInfo: botInfo,
      pinnedMsgId: pinnedMsgId,
      folderId: folderId,
      call: call,
      ttlPeriod: ttlPeriod,
      groupcallDefaultJoinAs: groupcallDefaultJoinAs,
      themeEmoticon: themeEmoticon,
      requestsPending: requestsPending,
      recentRequesters: recentRequesters,
      availableReactions: availableReactions,
    );

    // Now return the deserialized [ChatFull].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b07: canSetUsername,
      b08: hasScheduled,
      b19: translationsDisabled,
      b02: chatPhoto != null,
      b13: exportedInvite != null,
      b03: botInfo != null,
      b06: pinnedMsgId != null,
      b11: folderId != null,
      b12: call != null,
      b14: ttlPeriod != null,
      b15: groupcallDefaultJoinAs != null,
      b16: themeEmoticon != null,
      b17: requestsPending != null || recentRequesters != null,
      b18: availableReactions != null,
    );

    return v;
  }

  /// can_set_username: bit 7 of flags.7?true
  final bool canSetUsername;

  /// has_scheduled: bit 8 of flags.8?true
  final bool hasScheduled;

  /// translations_disabled: bit 19 of flags.19?true
  final bool translationsDisabled;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// About.
  final String about;

  /// Participants.
  final ChatParticipantsBase participants;

  /// Chat Photo.
  final PhotoBase? chatPhoto;

  /// Notify Settings.
  final PeerNotifySettingsBase notifySettings;

  /// Exported Invite.
  final ExportedChatInviteBase? exportedInvite;

  /// Bot Info.
  final List<BotInfoBase>? botInfo;

  /// Pinned Msg Id.
  final int? pinnedMsgId;

  /// Folder Id.
  final int? folderId;

  /// Call.
  final InputGroupCallBase? call;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Groupcall Default Join As.
  final PeerBase? groupcallDefaultJoinAs;

  /// Theme Emoticon.
  final String? themeEmoticon;

  /// Requests Pending.
  final int? requestsPending;

  /// Recent Requesters.
  final List<int>? recentRequesters;

  /// Available Reactions.
  final ChatReactionsBase? availableReactions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc9d31138.
    buffer.writeInt32(0xc9d31138);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeString(about);
    buffer.writeObject(participants);
    final localChatPhotoCopy = chatPhoto;
    if (localChatPhotoCopy != null) {
      buffer.writeObject(localChatPhotoCopy);
    }
    buffer.writeObject(notifySettings);
    final localExportedInviteCopy = exportedInvite;
    if (localExportedInviteCopy != null) {
      buffer.writeObject(localExportedInviteCopy);
    }
    final localBotInfoCopy = botInfo;
    if (localBotInfoCopy != null) {
      buffer.writeVectorObject(localBotInfoCopy);
    }
    final localPinnedMsgIdCopy = pinnedMsgId;
    if (localPinnedMsgIdCopy != null) {
      buffer.writeInt32(localPinnedMsgIdCopy);
    }
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    final localCallCopy = call;
    if (localCallCopy != null) {
      buffer.writeObject(localCallCopy);
    }
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }
    final localGroupcallDefaultJoinAsCopy = groupcallDefaultJoinAs;
    if (localGroupcallDefaultJoinAsCopy != null) {
      buffer.writeObject(localGroupcallDefaultJoinAsCopy);
    }
    final localThemeEmoticonCopy = themeEmoticon;
    if (localThemeEmoticonCopy != null) {
      buffer.writeString(localThemeEmoticonCopy);
    }
    final localRequestsPendingCopy = requestsPending;
    if (localRequestsPendingCopy != null) {
      buffer.writeInt32(localRequestsPendingCopy);
    }
    final localRecentRequestersCopy = recentRequesters;
    if (localRecentRequestersCopy != null) {
      buffer.writeVectorInt64(localRecentRequestersCopy);
    }
    final localAvailableReactionsCopy = availableReactions;
    if (localAvailableReactionsCopy != null) {
      buffer.writeObject(localAvailableReactionsCopy);
    }

    // Finished serialization.
  }
}

/// Channel Full.
///
/// ID: `0f2bcb6f`.
class ChannelFull extends ChatFullBase {
  /// Channel Full constructor.
  const ChannelFull({
    required this.canViewParticipants,
    required this.canSetUsername,
    required this.canSetStickers,
    required this.hiddenPrehistory,
    required this.canSetLocation,
    required this.hasScheduled,
    required this.canViewStats,
    required this.blocked,
    required this.canDeleteChannel,
    required this.antispam,
    required this.participantsHidden,
    required this.translationsDisabled,
    required this.storiesPinnedAvailable,
    required this.viewForumAsMessages,
    required this.id,
    required this.about,
    this.participantsCount,
    this.adminsCount,
    this.kickedCount,
    this.bannedCount,
    this.onlineCount,
    required this.readInboxMaxId,
    required this.readOutboxMaxId,
    required this.unreadCount,
    required this.chatPhoto,
    required this.notifySettings,
    this.exportedInvite,
    required this.botInfo,
    this.migratedFromChatId,
    this.migratedFromMaxId,
    this.pinnedMsgId,
    this.stickerset,
    this.availableMinId,
    this.folderId,
    this.linkedChatId,
    this.location,
    this.slowmodeSeconds,
    this.slowmodeNextSendDate,
    this.statsDc,
    required this.pts,
    this.call,
    this.ttlPeriod,
    this.pendingSuggestions,
    this.groupcallDefaultJoinAs,
    this.themeEmoticon,
    this.requestsPending,
    this.recentRequesters,
    this.defaultSendAs,
    this.availableReactions,
    this.stories,
    this.wallpaper,
  }) : super._();

  /// Deserialize.
  factory ChannelFull.deserialize(BinaryReader reader) {
    // Read [ChannelFull] fields.
    final flags = reader.readInt32();
    final canViewParticipants = (flags & 8) != 0;
    final canSetUsername = (flags & 64) != 0;
    final canSetStickers = (flags & 128) != 0;
    final hiddenPrehistory = (flags & 1024) != 0;
    final canSetLocation = (flags & 65536) != 0;
    final hasScheduled = (flags & 524288) != 0;
    final canViewStats = (flags & 1048576) != 0;
    final blocked = (flags & 4194304) != 0;
    final flags2 = reader.readInt32();
    final canDeleteChannel = (flags2 & 1) != 0;
    final antispam = (flags2 & 2) != 0;
    final participantsHidden = (flags2 & 4) != 0;
    final translationsDisabled = (flags2 & 8) != 0;
    final storiesPinnedAvailable = (flags2 & 32) != 0;
    final viewForumAsMessages = (flags2 & 64) != 0;
    final id = reader.readInt64();
    final about = reader.readString();
    final hasParticipantsCountField = (flags & 1) != 0;
    final participantsCount =
        hasParticipantsCountField ? reader.readInt32() : null;
    final hasAdminsCountField = (flags & 2) != 0;
    final adminsCount = hasAdminsCountField ? reader.readInt32() : null;
    final hasKickedCountField = (flags & 4) != 0;
    final kickedCount = hasKickedCountField ? reader.readInt32() : null;
    final hasBannedCountField = (flags & 4) != 0;
    final bannedCount = hasBannedCountField ? reader.readInt32() : null;
    final hasOnlineCountField = (flags & 8192) != 0;
    final onlineCount = hasOnlineCountField ? reader.readInt32() : null;
    final readInboxMaxId = reader.readInt32();
    final readOutboxMaxId = reader.readInt32();
    final unreadCount = reader.readInt32();
    final chatPhoto = reader.readObject() as PhotoBase;
    final notifySettings = reader.readObject() as PeerNotifySettingsBase;
    final hasExportedInviteField = (flags & 8388608) != 0;
    final exportedInvite = hasExportedInviteField
        ? reader.readObject() as ExportedChatInviteBase
        : null;
    final botInfo = reader.readVectorObject<BotInfoBase>();
    final hasMigratedFromChatIdField = (flags & 16) != 0;
    final migratedFromChatId =
        hasMigratedFromChatIdField ? reader.readInt64() : null;
    final hasMigratedFromMaxIdField = (flags & 16) != 0;
    final migratedFromMaxId =
        hasMigratedFromMaxIdField ? reader.readInt32() : null;
    final hasPinnedMsgIdField = (flags & 32) != 0;
    final pinnedMsgId = hasPinnedMsgIdField ? reader.readInt32() : null;
    final hasStickersetField = (flags & 256) != 0;
    final stickerset =
        hasStickersetField ? reader.readObject() as StickerSetBase : null;
    final hasAvailableMinIdField = (flags & 512) != 0;
    final availableMinId = hasAvailableMinIdField ? reader.readInt32() : null;
    final hasFolderIdField = (flags & 2048) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final hasLinkedChatIdField = (flags & 16384) != 0;
    final linkedChatId = hasLinkedChatIdField ? reader.readInt64() : null;
    final hasLocationField = (flags & 32768) != 0;
    final location =
        hasLocationField ? reader.readObject() as ChannelLocationBase : null;
    final hasSlowmodeSecondsField = (flags & 131072) != 0;
    final slowmodeSeconds = hasSlowmodeSecondsField ? reader.readInt32() : null;
    final hasSlowmodeNextSendDateField = (flags & 262144) != 0;
    final slowmodeNextSendDate =
        hasSlowmodeNextSendDateField ? reader.readDateTime() : null;
    final hasStatsDcField = (flags & 4096) != 0;
    final statsDc = hasStatsDcField ? reader.readInt32() : null;
    final pts = reader.readInt32();
    final hasCallField = (flags & 2097152) != 0;
    final call =
        hasCallField ? reader.readObject() as InputGroupCallBase : null;
    final hasTtlPeriodField = (flags & 16777216) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;
    final hasPendingSuggestionsField = (flags & 33554432) != 0;
    final pendingSuggestions =
        hasPendingSuggestionsField ? reader.readVectorString() : null;
    final hasGroupcallDefaultJoinAsField = (flags & 67108864) != 0;
    final groupcallDefaultJoinAs =
        hasGroupcallDefaultJoinAsField ? reader.readObject() as PeerBase : null;
    final hasThemeEmoticonField = (flags & 134217728) != 0;
    final themeEmoticon = hasThemeEmoticonField ? reader.readString() : null;
    final hasRequestsPendingField = (flags & 268435456) != 0;
    final requestsPending = hasRequestsPendingField ? reader.readInt32() : null;
    final hasRecentRequestersField = (flags & 268435456) != 0;
    final recentRequesters =
        hasRecentRequestersField ? reader.readVectorInt64() : null;
    final hasDefaultSendAsField = (flags & 536870912) != 0;
    final defaultSendAs =
        hasDefaultSendAsField ? reader.readObject() as PeerBase : null;
    final hasAvailableReactionsField = (flags & 1073741824) != 0;
    final availableReactions = hasAvailableReactionsField
        ? reader.readObject() as ChatReactionsBase
        : null;
    final hasStoriesField = (flags2 & 16) != 0;
    final stories =
        hasStoriesField ? reader.readObject() as PeerStoriesBase : null;
    final hasWallpaperField = (flags2 & 128) != 0;
    final wallpaper =
        hasWallpaperField ? reader.readObject() as WallPaperBase : null;

    // Construct [ChannelFull] object.
    final returnValue = ChannelFull(
      canViewParticipants: canViewParticipants,
      canSetUsername: canSetUsername,
      canSetStickers: canSetStickers,
      hiddenPrehistory: hiddenPrehistory,
      canSetLocation: canSetLocation,
      hasScheduled: hasScheduled,
      canViewStats: canViewStats,
      blocked: blocked,
      canDeleteChannel: canDeleteChannel,
      antispam: antispam,
      participantsHidden: participantsHidden,
      translationsDisabled: translationsDisabled,
      storiesPinnedAvailable: storiesPinnedAvailable,
      viewForumAsMessages: viewForumAsMessages,
      id: id,
      about: about,
      participantsCount: participantsCount,
      adminsCount: adminsCount,
      kickedCount: kickedCount,
      bannedCount: bannedCount,
      onlineCount: onlineCount,
      readInboxMaxId: readInboxMaxId,
      readOutboxMaxId: readOutboxMaxId,
      unreadCount: unreadCount,
      chatPhoto: chatPhoto,
      notifySettings: notifySettings,
      exportedInvite: exportedInvite,
      botInfo: botInfo,
      migratedFromChatId: migratedFromChatId,
      migratedFromMaxId: migratedFromMaxId,
      pinnedMsgId: pinnedMsgId,
      stickerset: stickerset,
      availableMinId: availableMinId,
      folderId: folderId,
      linkedChatId: linkedChatId,
      location: location,
      slowmodeSeconds: slowmodeSeconds,
      slowmodeNextSendDate: slowmodeNextSendDate,
      statsDc: statsDc,
      pts: pts,
      call: call,
      ttlPeriod: ttlPeriod,
      pendingSuggestions: pendingSuggestions,
      groupcallDefaultJoinAs: groupcallDefaultJoinAs,
      themeEmoticon: themeEmoticon,
      requestsPending: requestsPending,
      recentRequesters: recentRequesters,
      defaultSendAs: defaultSendAs,
      availableReactions: availableReactions,
      stories: stories,
      wallpaper: wallpaper,
    );

    // Now return the deserialized [ChannelFull].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: canViewParticipants,
      b06: canSetUsername,
      b07: canSetStickers,
      b10: hiddenPrehistory,
      b16: canSetLocation,
      b19: hasScheduled,
      b20: canViewStats,
      b22: blocked,
      b00: participantsCount != null,
      b01: adminsCount != null,
      b02: kickedCount != null || bannedCount != null,
      b13: onlineCount != null,
      b23: exportedInvite != null,
      b04: migratedFromChatId != null || migratedFromMaxId != null,
      b05: pinnedMsgId != null,
      b08: stickerset != null,
      b09: availableMinId != null,
      b11: folderId != null,
      b14: linkedChatId != null,
      b15: location != null,
      b17: slowmodeSeconds != null,
      b18: slowmodeNextSendDate != null,
      b12: statsDc != null,
      b21: call != null,
      b24: ttlPeriod != null,
      b25: pendingSuggestions != null,
      b26: groupcallDefaultJoinAs != null,
      b27: themeEmoticon != null,
      b28: requestsPending != null || recentRequesters != null,
      b29: defaultSendAs != null,
      b30: availableReactions != null,
    );

    return v;
  }

  /// Flags2.
  int get flags2 {
    final v = _flag(
      b00: canDeleteChannel,
      b01: antispam,
      b02: participantsHidden,
      b03: translationsDisabled,
      b05: storiesPinnedAvailable,
      b06: viewForumAsMessages,
      b04: stories != null,
      b07: wallpaper != null,
    );

    return v;
  }

  /// can_view_participants: bit 3 of flags.3?true
  final bool canViewParticipants;

  /// can_set_username: bit 6 of flags.6?true
  final bool canSetUsername;

  /// can_set_stickers: bit 7 of flags.7?true
  final bool canSetStickers;

  /// hidden_prehistory: bit 10 of flags.10?true
  final bool hiddenPrehistory;

  /// can_set_location: bit 16 of flags.16?true
  final bool canSetLocation;

  /// has_scheduled: bit 19 of flags.19?true
  final bool hasScheduled;

  /// can_view_stats: bit 20 of flags.20?true
  final bool canViewStats;

  /// blocked: bit 22 of flags.22?true
  final bool blocked;

  /// can_delete_channel: bit 0 of flags2.0?true
  final bool canDeleteChannel;

  /// antispam: bit 1 of flags2.1?true
  final bool antispam;

  /// participants_hidden: bit 2 of flags2.2?true
  final bool participantsHidden;

  /// translations_disabled: bit 3 of flags2.3?true
  final bool translationsDisabled;

  /// stories_pinned_available: bit 5 of flags2.5?true
  final bool storiesPinnedAvailable;

  /// view_forum_as_messages: bit 6 of flags2.6?true
  final bool viewForumAsMessages;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// About.
  final String about;

  /// Participants Count.
  final int? participantsCount;

  /// Admins Count.
  final int? adminsCount;

  /// Kicked Count.
  final int? kickedCount;

  /// Banned Count.
  final int? bannedCount;

  /// Online Count.
  final int? onlineCount;

  /// Read Inbox Max Id.
  ///
  /// Field type is Int32.
  final int readInboxMaxId;

  /// Read Outbox Max Id.
  ///
  /// Field type is Int32.
  final int readOutboxMaxId;

  /// Unread Count.
  ///
  /// Field type is Int32.
  final int unreadCount;

  /// Chat Photo.
  final PhotoBase chatPhoto;

  /// Notify Settings.
  final PeerNotifySettingsBase notifySettings;

  /// Exported Invite.
  final ExportedChatInviteBase? exportedInvite;

  /// Bot Info.
  final List<BotInfoBase> botInfo;

  /// Migrated From Chat Id.
  final int? migratedFromChatId;

  /// Migrated From Max Id.
  final int? migratedFromMaxId;

  /// Pinned Msg Id.
  final int? pinnedMsgId;

  /// Stickerset.
  final StickerSetBase? stickerset;

  /// Available Min Id.
  final int? availableMinId;

  /// Folder Id.
  final int? folderId;

  /// Linked Chat Id.
  final int? linkedChatId;

  /// Location.
  final ChannelLocationBase? location;

  /// Slowmode Seconds.
  final int? slowmodeSeconds;

  /// Slowmode Next Send Date.
  final DateTime? slowmodeNextSendDate;

  /// Stats Dc.
  final int? statsDc;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Call.
  final InputGroupCallBase? call;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Pending Suggestions.
  final List<String>? pendingSuggestions;

  /// Groupcall Default Join As.
  final PeerBase? groupcallDefaultJoinAs;

  /// Theme Emoticon.
  final String? themeEmoticon;

  /// Requests Pending.
  final int? requestsPending;

  /// Recent Requesters.
  final List<int>? recentRequesters;

  /// Default Send As.
  final PeerBase? defaultSendAs;

  /// Available Reactions.
  final ChatReactionsBase? availableReactions;

  /// Stories.
  final PeerStoriesBase? stories;

  /// Wallpaper.
  final WallPaperBase? wallpaper;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0f2bcb6f.
    buffer.writeInt32(0x0f2bcb6f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(flags2);
    buffer.writeInt64(id);
    buffer.writeString(about);
    final localParticipantsCountCopy = participantsCount;
    if (localParticipantsCountCopy != null) {
      buffer.writeInt32(localParticipantsCountCopy);
    }
    final localAdminsCountCopy = adminsCount;
    if (localAdminsCountCopy != null) {
      buffer.writeInt32(localAdminsCountCopy);
    }
    final localKickedCountCopy = kickedCount;
    if (localKickedCountCopy != null) {
      buffer.writeInt32(localKickedCountCopy);
    }
    final localBannedCountCopy = bannedCount;
    if (localBannedCountCopy != null) {
      buffer.writeInt32(localBannedCountCopy);
    }
    final localOnlineCountCopy = onlineCount;
    if (localOnlineCountCopy != null) {
      buffer.writeInt32(localOnlineCountCopy);
    }
    buffer.writeInt32(readInboxMaxId);
    buffer.writeInt32(readOutboxMaxId);
    buffer.writeInt32(unreadCount);
    buffer.writeObject(chatPhoto);
    buffer.writeObject(notifySettings);
    final localExportedInviteCopy = exportedInvite;
    if (localExportedInviteCopy != null) {
      buffer.writeObject(localExportedInviteCopy);
    }
    buffer.writeVectorObject(botInfo);
    final localMigratedFromChatIdCopy = migratedFromChatId;
    if (localMigratedFromChatIdCopy != null) {
      buffer.writeInt64(localMigratedFromChatIdCopy);
    }
    final localMigratedFromMaxIdCopy = migratedFromMaxId;
    if (localMigratedFromMaxIdCopy != null) {
      buffer.writeInt32(localMigratedFromMaxIdCopy);
    }
    final localPinnedMsgIdCopy = pinnedMsgId;
    if (localPinnedMsgIdCopy != null) {
      buffer.writeInt32(localPinnedMsgIdCopy);
    }
    final localStickersetCopy = stickerset;
    if (localStickersetCopy != null) {
      buffer.writeObject(localStickersetCopy);
    }
    final localAvailableMinIdCopy = availableMinId;
    if (localAvailableMinIdCopy != null) {
      buffer.writeInt32(localAvailableMinIdCopy);
    }
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    final localLinkedChatIdCopy = linkedChatId;
    if (localLinkedChatIdCopy != null) {
      buffer.writeInt64(localLinkedChatIdCopy);
    }
    final localLocationCopy = location;
    if (localLocationCopy != null) {
      buffer.writeObject(localLocationCopy);
    }
    final localSlowmodeSecondsCopy = slowmodeSeconds;
    if (localSlowmodeSecondsCopy != null) {
      buffer.writeInt32(localSlowmodeSecondsCopy);
    }
    final localSlowmodeNextSendDateCopy = slowmodeNextSendDate;
    if (localSlowmodeNextSendDateCopy != null) {
      buffer.writeDateTime(localSlowmodeNextSendDateCopy);
    }
    final localStatsDcCopy = statsDc;
    if (localStatsDcCopy != null) {
      buffer.writeInt32(localStatsDcCopy);
    }
    buffer.writeInt32(pts);
    final localCallCopy = call;
    if (localCallCopy != null) {
      buffer.writeObject(localCallCopy);
    }
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }
    final localPendingSuggestionsCopy = pendingSuggestions;
    if (localPendingSuggestionsCopy != null) {
      buffer.writeVectorString(localPendingSuggestionsCopy);
    }
    final localGroupcallDefaultJoinAsCopy = groupcallDefaultJoinAs;
    if (localGroupcallDefaultJoinAsCopy != null) {
      buffer.writeObject(localGroupcallDefaultJoinAsCopy);
    }
    final localThemeEmoticonCopy = themeEmoticon;
    if (localThemeEmoticonCopy != null) {
      buffer.writeString(localThemeEmoticonCopy);
    }
    final localRequestsPendingCopy = requestsPending;
    if (localRequestsPendingCopy != null) {
      buffer.writeInt32(localRequestsPendingCopy);
    }
    final localRecentRequestersCopy = recentRequesters;
    if (localRecentRequestersCopy != null) {
      buffer.writeVectorInt64(localRecentRequestersCopy);
    }
    final localDefaultSendAsCopy = defaultSendAs;
    if (localDefaultSendAsCopy != null) {
      buffer.writeObject(localDefaultSendAsCopy);
    }
    final localAvailableReactionsCopy = availableReactions;
    if (localAvailableReactionsCopy != null) {
      buffer.writeObject(localAvailableReactionsCopy);
    }
    final localStoriesCopy = stories;
    if (localStoriesCopy != null) {
      buffer.writeObject(localStoriesCopy);
    }
    final localWallpaperCopy = wallpaper;
    if (localWallpaperCopy != null) {
      buffer.writeObject(localWallpaperCopy);
    }

    // Finished serialization.
  }
}

/// Chat Participant.
///
/// ID: `c02d4007`.
class ChatParticipant extends ChatParticipantBase {
  /// Chat Participant constructor.
  const ChatParticipant({
    required this.userId,
    required this.inviterId,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory ChatParticipant.deserialize(BinaryReader reader) {
    // Read [ChatParticipant] fields.
    final userId = reader.readInt64();
    final inviterId = reader.readInt64();
    final date = reader.readDateTime();

    // Construct [ChatParticipant] object.
    final returnValue = ChatParticipant(
      userId: userId,
      inviterId: inviterId,
      date: date,
    );

    // Now return the deserialized [ChatParticipant].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Inviter Id.
  ///
  /// Field type is Int64.
  final int inviterId;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc02d4007.
    buffer.writeInt32(0xc02d4007);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeInt64(inviterId);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Chat Participant Creator.
///
/// ID: `e46bcee4`.
class ChatParticipantCreator extends ChatParticipantBase {
  /// Chat Participant Creator constructor.
  const ChatParticipantCreator({
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory ChatParticipantCreator.deserialize(BinaryReader reader) {
    // Read [ChatParticipantCreator] fields.
    final userId = reader.readInt64();

    // Construct [ChatParticipantCreator] object.
    final returnValue = ChatParticipantCreator(
      userId: userId,
    );

    // Now return the deserialized [ChatParticipantCreator].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe46bcee4.
    buffer.writeInt32(0xe46bcee4);

    // Write fields.
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Chat Participant Admin.
///
/// ID: `a0933f5b`.
class ChatParticipantAdmin extends ChatParticipantBase {
  /// Chat Participant Admin constructor.
  const ChatParticipantAdmin({
    required this.userId,
    required this.inviterId,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory ChatParticipantAdmin.deserialize(BinaryReader reader) {
    // Read [ChatParticipantAdmin] fields.
    final userId = reader.readInt64();
    final inviterId = reader.readInt64();
    final date = reader.readDateTime();

    // Construct [ChatParticipantAdmin] object.
    final returnValue = ChatParticipantAdmin(
      userId: userId,
      inviterId: inviterId,
      date: date,
    );

    // Now return the deserialized [ChatParticipantAdmin].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Inviter Id.
  ///
  /// Field type is Int64.
  final int inviterId;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa0933f5b.
    buffer.writeInt32(0xa0933f5b);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeInt64(inviterId);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Chat Participants Forbidden.
///
/// ID: `8763d3e1`.
class ChatParticipantsForbidden extends ChatParticipantsBase {
  /// Chat Participants Forbidden constructor.
  const ChatParticipantsForbidden({
    required this.chatId,
    this.selfParticipant,
  }) : super._();

  /// Deserialize.
  factory ChatParticipantsForbidden.deserialize(BinaryReader reader) {
    // Read [ChatParticipantsForbidden] fields.
    final flags = reader.readInt32();
    final chatId = reader.readInt64();
    final hasSelfParticipantField = (flags & 1) != 0;
    final selfParticipant = hasSelfParticipantField
        ? reader.readObject() as ChatParticipantBase
        : null;

    // Construct [ChatParticipantsForbidden] object.
    final returnValue = ChatParticipantsForbidden(
      chatId: chatId,
      selfParticipant: selfParticipant,
    );

    // Now return the deserialized [ChatParticipantsForbidden].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: selfParticipant != null,
    );

    return v;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Self Participant.
  final ChatParticipantBase? selfParticipant;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8763d3e1.
    buffer.writeInt32(0x8763d3e1);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(chatId);
    final localSelfParticipantCopy = selfParticipant;
    if (localSelfParticipantCopy != null) {
      buffer.writeObject(localSelfParticipantCopy);
    }

    // Finished serialization.
  }
}

/// Chat Participants.
///
/// ID: `3cbc93f8`.
class ChatParticipants extends ChatParticipantsBase {
  /// Chat Participants constructor.
  const ChatParticipants({
    required this.chatId,
    required this.participants,
    required this.version,
  }) : super._();

  /// Deserialize.
  factory ChatParticipants.deserialize(BinaryReader reader) {
    // Read [ChatParticipants] fields.
    final chatId = reader.readInt64();
    final participants = reader.readVectorObject<ChatParticipantBase>();
    final version = reader.readInt32();

    // Construct [ChatParticipants] object.
    final returnValue = ChatParticipants(
      chatId: chatId,
      participants: participants,
      version: version,
    );

    // Now return the deserialized [ChatParticipants].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Participants.
  final List<ChatParticipantBase> participants;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3cbc93f8.
    buffer.writeInt32(0x3cbc93f8);

    // Write fields.
    buffer.writeInt64(chatId);
    buffer.writeVectorObject(participants);
    buffer.writeInt32(version);

    // Finished serialization.
  }
}

/// Chat Photo Empty.
///
/// ID: `37c1011c`.
class ChatPhotoEmpty extends ChatPhotoBase {
  /// Chat Photo Empty constructor.
  const ChatPhotoEmpty() : super._();

  /// Deserialize.
  factory ChatPhotoEmpty.deserialize(BinaryReader reader) {
    // Construct [ChatPhotoEmpty] object.
    final returnValue = ChatPhotoEmpty();

    // Now return the deserialized [ChatPhotoEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x37c1011c.
    buffer.writeInt32(0x37c1011c);

    // Finished serialization.
  }
}

/// Chat Photo.
///
/// ID: `1c6e1c11`.
class ChatPhoto extends ChatPhotoBase {
  /// Chat Photo constructor.
  const ChatPhoto({
    required this.hasVideo,
    required this.photoId,
    this.strippedThumb,
    required this.dcId,
  }) : super._();

  /// Deserialize.
  factory ChatPhoto.deserialize(BinaryReader reader) {
    // Read [ChatPhoto] fields.
    final flags = reader.readInt32();
    final hasVideo = (flags & 1) != 0;
    final photoId = reader.readInt64();
    final hasStrippedThumbField = (flags & 2) != 0;
    final strippedThumb = hasStrippedThumbField ? reader.readBytes() : null;
    final dcId = reader.readInt32();

    // Construct [ChatPhoto] object.
    final returnValue = ChatPhoto(
      hasVideo: hasVideo,
      photoId: photoId,
      strippedThumb: strippedThumb,
      dcId: dcId,
    );

    // Now return the deserialized [ChatPhoto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: hasVideo,
      b01: strippedThumb != null,
    );

    return v;
  }

  /// has_video: bit 0 of flags.0?true
  final bool hasVideo;

  /// Photo Id.
  ///
  /// Field type is Int64.
  final int photoId;

  /// Stripped Thumb.
  final Uint8List? strippedThumb;

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1c6e1c11.
    buffer.writeInt32(0x1c6e1c11);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(photoId);
    final localStrippedThumbCopy = strippedThumb;
    if (localStrippedThumbCopy != null) {
      buffer.writeBytes(localStrippedThumbCopy);
    }
    buffer.writeInt32(dcId);

    // Finished serialization.
  }
}

/// Message Empty.
///
/// ID: `90a6ca84`.
class MessageEmpty extends MessageBase {
  /// Message Empty constructor.
  const MessageEmpty({
    required this.id,
    this.peerId,
  }) : super._();

  /// Deserialize.
  factory MessageEmpty.deserialize(BinaryReader reader) {
    // Read [MessageEmpty] fields.
    final flags = reader.readInt32();
    final id = reader.readInt32();
    final hasPeerIdField = (flags & 1) != 0;
    final peerId = hasPeerIdField ? reader.readObject() as PeerBase : null;

    // Construct [MessageEmpty] object.
    final returnValue = MessageEmpty(
      id: id,
      peerId: peerId,
    );

    // Now return the deserialized [MessageEmpty].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: peerId != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Peer Id.
  final PeerBase? peerId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x90a6ca84.
    buffer.writeInt32(0x90a6ca84);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    final localPeerIdCopy = peerId;
    if (localPeerIdCopy != null) {
      buffer.writeObject(localPeerIdCopy);
    }

    // Finished serialization.
  }
}

/// Message.
///
/// ID: `76bec211`.
class Message extends MessageBase {
  /// Message constructor.
  const Message({
    required this.out,
    required this.mentioned,
    required this.mediaUnread,
    required this.silent,
    required this.post,
    required this.fromScheduled,
    required this.legacy,
    required this.editHide,
    required this.pinned,
    required this.noforwards,
    required this.invertMedia,
    required this.id,
    this.fromId,
    required this.peerId,
    this.savedPeerId,
    this.fwdFrom,
    this.viaBotId,
    this.replyTo,
    required this.date,
    required this.message,
    this.media,
    this.replyMarkup,
    this.entities,
    this.views,
    this.forwards,
    this.replies,
    this.editDate,
    this.postAuthor,
    this.groupedId,
    this.reactions,
    this.restrictionReason,
    this.ttlPeriod,
  }) : super._();

  /// Deserialize.
  factory Message.deserialize(BinaryReader reader) {
    // Read [Message] fields.
    final flags = reader.readInt32();
    final out = (flags & 2) != 0;
    final mentioned = (flags & 16) != 0;
    final mediaUnread = (flags & 32) != 0;
    final silent = (flags & 8192) != 0;
    final post = (flags & 16384) != 0;
    final fromScheduled = (flags & 262144) != 0;
    final legacy = (flags & 524288) != 0;
    final editHide = (flags & 2097152) != 0;
    final pinned = (flags & 16777216) != 0;
    final noforwards = (flags & 67108864) != 0;
    final invertMedia = (flags & 134217728) != 0;
    final id = reader.readInt32();
    final hasFromIdField = (flags & 256) != 0;
    final fromId = hasFromIdField ? reader.readObject() as PeerBase : null;
    final peerId = reader.readObject() as PeerBase;
    final hasSavedPeerIdField = (flags & 268435456) != 0;
    final savedPeerId =
        hasSavedPeerIdField ? reader.readObject() as PeerBase : null;
    final hasFwdFromField = (flags & 4) != 0;
    final fwdFrom =
        hasFwdFromField ? reader.readObject() as MessageFwdHeaderBase : null;
    final hasViaBotIdField = (flags & 2048) != 0;
    final viaBotId = hasViaBotIdField ? reader.readInt64() : null;
    final hasReplyToField = (flags & 8) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as MessageReplyHeaderBase : null;
    final date = reader.readDateTime();
    final message = reader.readString();
    final hasMediaField = (flags & 512) != 0;
    final media =
        hasMediaField ? reader.readObject() as MessageMediaBase : null;
    final hasReplyMarkupField = (flags & 64) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;
    final hasEntitiesField = (flags & 128) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasViewsField = (flags & 1024) != 0;
    final views = hasViewsField ? reader.readInt32() : null;
    final hasForwardsField = (flags & 1024) != 0;
    final forwards = hasForwardsField ? reader.readInt32() : null;
    final hasRepliesField = (flags & 8388608) != 0;
    final replies =
        hasRepliesField ? reader.readObject() as MessageRepliesBase : null;
    final hasEditDateField = (flags & 32768) != 0;
    final editDate = hasEditDateField ? reader.readDateTime() : null;
    final hasPostAuthorField = (flags & 65536) != 0;
    final postAuthor = hasPostAuthorField ? reader.readString() : null;
    final hasGroupedIdField = (flags & 131072) != 0;
    final groupedId = hasGroupedIdField ? reader.readInt64() : null;
    final hasReactionsField = (flags & 1048576) != 0;
    final reactions =
        hasReactionsField ? reader.readObject() as MessageReactionsBase : null;
    final hasRestrictionReasonField = (flags & 4194304) != 0;
    final restrictionReason = hasRestrictionReasonField
        ? reader.readVectorObject<RestrictionReasonBase>()
        : null;
    final hasTtlPeriodField = (flags & 33554432) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;

    // Construct [Message] object.
    final returnValue = Message(
      out: out,
      mentioned: mentioned,
      mediaUnread: mediaUnread,
      silent: silent,
      post: post,
      fromScheduled: fromScheduled,
      legacy: legacy,
      editHide: editHide,
      pinned: pinned,
      noforwards: noforwards,
      invertMedia: invertMedia,
      id: id,
      fromId: fromId,
      peerId: peerId,
      savedPeerId: savedPeerId,
      fwdFrom: fwdFrom,
      viaBotId: viaBotId,
      replyTo: replyTo,
      date: date,
      message: message,
      media: media,
      replyMarkup: replyMarkup,
      entities: entities,
      views: views,
      forwards: forwards,
      replies: replies,
      editDate: editDate,
      postAuthor: postAuthor,
      groupedId: groupedId,
      reactions: reactions,
      restrictionReason: restrictionReason,
      ttlPeriod: ttlPeriod,
    );

    // Now return the deserialized [Message].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: out,
      b04: mentioned,
      b05: mediaUnread,
      b13: silent,
      b14: post,
      b18: fromScheduled,
      b19: legacy,
      b21: editHide,
      b24: pinned,
      b26: noforwards,
      b27: invertMedia,
      b08: fromId != null,
      b28: savedPeerId != null,
      b02: fwdFrom != null,
      b11: viaBotId != null,
      b03: replyTo != null,
      b09: media != null,
      b06: replyMarkup != null,
      b07: entities != null,
      b10: views != null || forwards != null,
      b23: replies != null,
      b15: editDate != null,
      b16: postAuthor != null,
      b17: groupedId != null,
      b20: reactions != null,
      b22: restrictionReason != null,
      b25: ttlPeriod != null,
    );

    return v;
  }

  /// out: bit 1 of flags.1?true
  final bool out;

  /// mentioned: bit 4 of flags.4?true
  final bool mentioned;

  /// media_unread: bit 5 of flags.5?true
  final bool mediaUnread;

  /// silent: bit 13 of flags.13?true
  final bool silent;

  /// post: bit 14 of flags.14?true
  final bool post;

  /// from_scheduled: bit 18 of flags.18?true
  final bool fromScheduled;

  /// legacy: bit 19 of flags.19?true
  final bool legacy;

  /// edit_hide: bit 21 of flags.21?true
  final bool editHide;

  /// pinned: bit 24 of flags.24?true
  final bool pinned;

  /// noforwards: bit 26 of flags.26?true
  final bool noforwards;

  /// invert_media: bit 27 of flags.27?true
  final bool invertMedia;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// From Id.
  final PeerBase? fromId;

  /// Peer Id.
  final PeerBase peerId;

  /// Saved Peer Id.
  final PeerBase? savedPeerId;

  /// Fwd From.
  final MessageFwdHeaderBase? fwdFrom;

  /// Via Bot Id.
  final int? viaBotId;

  /// Reply To.
  final MessageReplyHeaderBase? replyTo;

  /// Date.
  final DateTime date;

  /// Message.
  final String message;

  /// Media.
  final MessageMediaBase? media;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Views.
  final int? views;

  /// Forwards.
  final int? forwards;

  /// Replies.
  final MessageRepliesBase? replies;

  /// Edit Date.
  final DateTime? editDate;

  /// Post Author.
  final String? postAuthor;

  /// Grouped Id.
  final int? groupedId;

  /// Reactions.
  final MessageReactionsBase? reactions;

  /// Restriction Reason.
  final List<RestrictionReasonBase>? restrictionReason;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x76bec211.
    buffer.writeInt32(0x76bec211);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    final localFromIdCopy = fromId;
    if (localFromIdCopy != null) {
      buffer.writeObject(localFromIdCopy);
    }
    buffer.writeObject(peerId);
    final localSavedPeerIdCopy = savedPeerId;
    if (localSavedPeerIdCopy != null) {
      buffer.writeObject(localSavedPeerIdCopy);
    }
    final localFwdFromCopy = fwdFrom;
    if (localFwdFromCopy != null) {
      buffer.writeObject(localFwdFromCopy);
    }
    final localViaBotIdCopy = viaBotId;
    if (localViaBotIdCopy != null) {
      buffer.writeInt64(localViaBotIdCopy);
    }
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    buffer.writeDateTime(date);
    buffer.writeString(message);
    final localMediaCopy = media;
    if (localMediaCopy != null) {
      buffer.writeObject(localMediaCopy);
    }
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localViewsCopy = views;
    if (localViewsCopy != null) {
      buffer.writeInt32(localViewsCopy);
    }
    final localForwardsCopy = forwards;
    if (localForwardsCopy != null) {
      buffer.writeInt32(localForwardsCopy);
    }
    final localRepliesCopy = replies;
    if (localRepliesCopy != null) {
      buffer.writeObject(localRepliesCopy);
    }
    final localEditDateCopy = editDate;
    if (localEditDateCopy != null) {
      buffer.writeDateTime(localEditDateCopy);
    }
    final localPostAuthorCopy = postAuthor;
    if (localPostAuthorCopy != null) {
      buffer.writeString(localPostAuthorCopy);
    }
    final localGroupedIdCopy = groupedId;
    if (localGroupedIdCopy != null) {
      buffer.writeInt64(localGroupedIdCopy);
    }
    final localReactionsCopy = reactions;
    if (localReactionsCopy != null) {
      buffer.writeObject(localReactionsCopy);
    }
    final localRestrictionReasonCopy = restrictionReason;
    if (localRestrictionReasonCopy != null) {
      buffer.writeVectorObject(localRestrictionReasonCopy);
    }
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }

    // Finished serialization.
  }
}

/// Message Service.
///
/// ID: `2b085862`.
class MessageService extends MessageBase {
  /// Message Service constructor.
  const MessageService({
    required this.out,
    required this.mentioned,
    required this.mediaUnread,
    required this.silent,
    required this.post,
    required this.legacy,
    required this.id,
    this.fromId,
    required this.peerId,
    this.replyTo,
    required this.date,
    required this.action,
    this.ttlPeriod,
  }) : super._();

  /// Deserialize.
  factory MessageService.deserialize(BinaryReader reader) {
    // Read [MessageService] fields.
    final flags = reader.readInt32();
    final out = (flags & 2) != 0;
    final mentioned = (flags & 16) != 0;
    final mediaUnread = (flags & 32) != 0;
    final silent = (flags & 8192) != 0;
    final post = (flags & 16384) != 0;
    final legacy = (flags & 524288) != 0;
    final id = reader.readInt32();
    final hasFromIdField = (flags & 256) != 0;
    final fromId = hasFromIdField ? reader.readObject() as PeerBase : null;
    final peerId = reader.readObject() as PeerBase;
    final hasReplyToField = (flags & 8) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as MessageReplyHeaderBase : null;
    final date = reader.readDateTime();
    final action = reader.readObject() as MessageActionBase;
    final hasTtlPeriodField = (flags & 33554432) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;

    // Construct [MessageService] object.
    final returnValue = MessageService(
      out: out,
      mentioned: mentioned,
      mediaUnread: mediaUnread,
      silent: silent,
      post: post,
      legacy: legacy,
      id: id,
      fromId: fromId,
      peerId: peerId,
      replyTo: replyTo,
      date: date,
      action: action,
      ttlPeriod: ttlPeriod,
    );

    // Now return the deserialized [MessageService].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: out,
      b04: mentioned,
      b05: mediaUnread,
      b13: silent,
      b14: post,
      b19: legacy,
      b08: fromId != null,
      b03: replyTo != null,
      b25: ttlPeriod != null,
    );

    return v;
  }

  /// out: bit 1 of flags.1?true
  final bool out;

  /// mentioned: bit 4 of flags.4?true
  final bool mentioned;

  /// media_unread: bit 5 of flags.5?true
  final bool mediaUnread;

  /// silent: bit 13 of flags.13?true
  final bool silent;

  /// post: bit 14 of flags.14?true
  final bool post;

  /// legacy: bit 19 of flags.19?true
  final bool legacy;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// From Id.
  final PeerBase? fromId;

  /// Peer Id.
  final PeerBase peerId;

  /// Reply To.
  final MessageReplyHeaderBase? replyTo;

  /// Date.
  final DateTime date;

  /// Action.
  final MessageActionBase action;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2b085862.
    buffer.writeInt32(0x2b085862);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    final localFromIdCopy = fromId;
    if (localFromIdCopy != null) {
      buffer.writeObject(localFromIdCopy);
    }
    buffer.writeObject(peerId);
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    buffer.writeDateTime(date);
    buffer.writeObject(action);
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }

    // Finished serialization.
  }
}

/// Message Media Empty.
///
/// ID: `3ded6320`.
class MessageMediaEmpty extends MessageMediaBase {
  /// Message Media Empty constructor.
  const MessageMediaEmpty() : super._();

  /// Deserialize.
  factory MessageMediaEmpty.deserialize(BinaryReader reader) {
    // Construct [MessageMediaEmpty] object.
    final returnValue = MessageMediaEmpty();

    // Now return the deserialized [MessageMediaEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3ded6320.
    buffer.writeInt32(0x3ded6320);

    // Finished serialization.
  }
}

/// Message Media Photo.
///
/// ID: `695150d7`.
class MessageMediaPhoto extends MessageMediaBase {
  /// Message Media Photo constructor.
  const MessageMediaPhoto({
    required this.spoiler,
    this.photo,
    this.ttlSeconds,
  }) : super._();

  /// Deserialize.
  factory MessageMediaPhoto.deserialize(BinaryReader reader) {
    // Read [MessageMediaPhoto] fields.
    final flags = reader.readInt32();
    final spoiler = (flags & 8) != 0;
    final hasPhotoField = (flags & 1) != 0;
    final photo = hasPhotoField ? reader.readObject() as PhotoBase : null;
    final hasTtlSecondsField = (flags & 4) != 0;
    final ttlSeconds = hasTtlSecondsField ? reader.readInt32() : null;

    // Construct [MessageMediaPhoto] object.
    final returnValue = MessageMediaPhoto(
      spoiler: spoiler,
      photo: photo,
      ttlSeconds: ttlSeconds,
    );

    // Now return the deserialized [MessageMediaPhoto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: spoiler,
      b00: photo != null,
      b02: ttlSeconds != null,
    );

    return v;
  }

  /// spoiler: bit 3 of flags.3?true
  final bool spoiler;

  /// Photo.
  final PhotoBase? photo;

  /// Ttl Seconds.
  final int? ttlSeconds;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x695150d7.
    buffer.writeInt32(0x695150d7);

    // Write fields.
    buffer.writeInt32(flags);
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }
    final localTtlSecondsCopy = ttlSeconds;
    if (localTtlSecondsCopy != null) {
      buffer.writeInt32(localTtlSecondsCopy);
    }

    // Finished serialization.
  }
}

/// Message Media Geo.
///
/// ID: `56e0d474`.
class MessageMediaGeo extends MessageMediaBase {
  /// Message Media Geo constructor.
  const MessageMediaGeo({
    required this.geo,
  }) : super._();

  /// Deserialize.
  factory MessageMediaGeo.deserialize(BinaryReader reader) {
    // Read [MessageMediaGeo] fields.
    final geo = reader.readObject() as GeoPointBase;

    // Construct [MessageMediaGeo] object.
    final returnValue = MessageMediaGeo(
      geo: geo,
    );

    // Now return the deserialized [MessageMediaGeo].
    return returnValue;
  }

  /// Geo.
  final GeoPointBase geo;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x56e0d474.
    buffer.writeInt32(0x56e0d474);

    // Write fields.
    buffer.writeObject(geo);

    // Finished serialization.
  }
}

/// Message Media Contact.
///
/// ID: `70322949`.
class MessageMediaContact extends MessageMediaBase {
  /// Message Media Contact constructor.
  const MessageMediaContact({
    required this.phoneNumber,
    required this.firstName,
    required this.lastName,
    required this.vcard,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory MessageMediaContact.deserialize(BinaryReader reader) {
    // Read [MessageMediaContact] fields.
    final phoneNumber = reader.readString();
    final firstName = reader.readString();
    final lastName = reader.readString();
    final vcard = reader.readString();
    final userId = reader.readInt64();

    // Construct [MessageMediaContact] object.
    final returnValue = MessageMediaContact(
      phoneNumber: phoneNumber,
      firstName: firstName,
      lastName: lastName,
      vcard: vcard,
      userId: userId,
    );

    // Now return the deserialized [MessageMediaContact].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// First Name.
  final String firstName;

  /// Last Name.
  final String lastName;

  /// Vcard.
  final String vcard;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x70322949.
    buffer.writeInt32(0x70322949);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeString(firstName);
    buffer.writeString(lastName);
    buffer.writeString(vcard);
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Message Media Unsupported.
///
/// ID: `9f84f49e`.
class MessageMediaUnsupported extends MessageMediaBase {
  /// Message Media Unsupported constructor.
  const MessageMediaUnsupported() : super._();

  /// Deserialize.
  factory MessageMediaUnsupported.deserialize(BinaryReader reader) {
    // Construct [MessageMediaUnsupported] object.
    final returnValue = MessageMediaUnsupported();

    // Now return the deserialized [MessageMediaUnsupported].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9f84f49e.
    buffer.writeInt32(0x9f84f49e);

    // Finished serialization.
  }
}

/// Message Media Document.
///
/// ID: `4cf4d72d`.
class MessageMediaDocument extends MessageMediaBase {
  /// Message Media Document constructor.
  const MessageMediaDocument({
    required this.nopremium,
    required this.spoiler,
    required this.video,
    required this.round,
    required this.voice,
    this.document,
    this.altDocument,
    this.ttlSeconds,
  }) : super._();

  /// Deserialize.
  factory MessageMediaDocument.deserialize(BinaryReader reader) {
    // Read [MessageMediaDocument] fields.
    final flags = reader.readInt32();
    final nopremium = (flags & 8) != 0;
    final spoiler = (flags & 16) != 0;
    final video = (flags & 64) != 0;
    final round = (flags & 128) != 0;
    final voice = (flags & 256) != 0;
    final hasDocumentField = (flags & 1) != 0;
    final document =
        hasDocumentField ? reader.readObject() as DocumentBase : null;
    final hasAltDocumentField = (flags & 32) != 0;
    final altDocument =
        hasAltDocumentField ? reader.readObject() as DocumentBase : null;
    final hasTtlSecondsField = (flags & 4) != 0;
    final ttlSeconds = hasTtlSecondsField ? reader.readInt32() : null;

    // Construct [MessageMediaDocument] object.
    final returnValue = MessageMediaDocument(
      nopremium: nopremium,
      spoiler: spoiler,
      video: video,
      round: round,
      voice: voice,
      document: document,
      altDocument: altDocument,
      ttlSeconds: ttlSeconds,
    );

    // Now return the deserialized [MessageMediaDocument].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: nopremium,
      b04: spoiler,
      b06: video,
      b07: round,
      b08: voice,
      b00: document != null,
      b05: altDocument != null,
      b02: ttlSeconds != null,
    );

    return v;
  }

  /// nopremium: bit 3 of flags.3?true
  final bool nopremium;

  /// spoiler: bit 4 of flags.4?true
  final bool spoiler;

  /// video: bit 6 of flags.6?true
  final bool video;

  /// round: bit 7 of flags.7?true
  final bool round;

  /// voice: bit 8 of flags.8?true
  final bool voice;

  /// Document.
  final DocumentBase? document;

  /// Alt Document.
  final DocumentBase? altDocument;

  /// Ttl Seconds.
  final int? ttlSeconds;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4cf4d72d.
    buffer.writeInt32(0x4cf4d72d);

    // Write fields.
    buffer.writeInt32(flags);
    final localDocumentCopy = document;
    if (localDocumentCopy != null) {
      buffer.writeObject(localDocumentCopy);
    }
    final localAltDocumentCopy = altDocument;
    if (localAltDocumentCopy != null) {
      buffer.writeObject(localAltDocumentCopy);
    }
    final localTtlSecondsCopy = ttlSeconds;
    if (localTtlSecondsCopy != null) {
      buffer.writeInt32(localTtlSecondsCopy);
    }

    // Finished serialization.
  }
}

/// Message Media Web Page.
///
/// ID: `ddf10c3b`.
class MessageMediaWebPage extends MessageMediaBase {
  /// Message Media Web Page constructor.
  const MessageMediaWebPage({
    required this.forceLargeMedia,
    required this.forceSmallMedia,
    required this.manual,
    required this.safe,
    required this.webpage,
  }) : super._();

  /// Deserialize.
  factory MessageMediaWebPage.deserialize(BinaryReader reader) {
    // Read [MessageMediaWebPage] fields.
    final flags = reader.readInt32();
    final forceLargeMedia = (flags & 1) != 0;
    final forceSmallMedia = (flags & 2) != 0;
    final manual = (flags & 8) != 0;
    final safe = (flags & 16) != 0;
    final webpage = reader.readObject() as WebPageBase;

    // Construct [MessageMediaWebPage] object.
    final returnValue = MessageMediaWebPage(
      forceLargeMedia: forceLargeMedia,
      forceSmallMedia: forceSmallMedia,
      manual: manual,
      safe: safe,
      webpage: webpage,
    );

    // Now return the deserialized [MessageMediaWebPage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: forceLargeMedia,
      b01: forceSmallMedia,
      b03: manual,
      b04: safe,
    );

    return v;
  }

  /// force_large_media: bit 0 of flags.0?true
  final bool forceLargeMedia;

  /// force_small_media: bit 1 of flags.1?true
  final bool forceSmallMedia;

  /// manual: bit 3 of flags.3?true
  final bool manual;

  /// safe: bit 4 of flags.4?true
  final bool safe;

  /// Webpage.
  final WebPageBase webpage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xddf10c3b.
    buffer.writeInt32(0xddf10c3b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(webpage);

    // Finished serialization.
  }
}

/// Message Media Venue.
///
/// ID: `2ec0533f`.
class MessageMediaVenue extends MessageMediaBase {
  /// Message Media Venue constructor.
  const MessageMediaVenue({
    required this.geo,
    required this.title,
    required this.address,
    required this.provider,
    required this.venueId,
    required this.venueType,
  }) : super._();

  /// Deserialize.
  factory MessageMediaVenue.deserialize(BinaryReader reader) {
    // Read [MessageMediaVenue] fields.
    final geo = reader.readObject() as GeoPointBase;
    final title = reader.readString();
    final address = reader.readString();
    final provider = reader.readString();
    final venueId = reader.readString();
    final venueType = reader.readString();

    // Construct [MessageMediaVenue] object.
    final returnValue = MessageMediaVenue(
      geo: geo,
      title: title,
      address: address,
      provider: provider,
      venueId: venueId,
      venueType: venueType,
    );

    // Now return the deserialized [MessageMediaVenue].
    return returnValue;
  }

  /// Geo.
  final GeoPointBase geo;

  /// Title.
  final String title;

  /// Address.
  final String address;

  /// Provider.
  final String provider;

  /// Venue Id.
  final String venueId;

  /// Venue Type.
  final String venueType;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2ec0533f.
    buffer.writeInt32(0x2ec0533f);

    // Write fields.
    buffer.writeObject(geo);
    buffer.writeString(title);
    buffer.writeString(address);
    buffer.writeString(provider);
    buffer.writeString(venueId);
    buffer.writeString(venueType);

    // Finished serialization.
  }
}

/// Message Media Game.
///
/// ID: `fdb19008`.
class MessageMediaGame extends MessageMediaBase {
  /// Message Media Game constructor.
  const MessageMediaGame({
    required this.game,
  }) : super._();

  /// Deserialize.
  factory MessageMediaGame.deserialize(BinaryReader reader) {
    // Read [MessageMediaGame] fields.
    final game = reader.readObject() as GameBase;

    // Construct [MessageMediaGame] object.
    final returnValue = MessageMediaGame(
      game: game,
    );

    // Now return the deserialized [MessageMediaGame].
    return returnValue;
  }

  /// Game.
  final GameBase game;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfdb19008.
    buffer.writeInt32(0xfdb19008);

    // Write fields.
    buffer.writeObject(game);

    // Finished serialization.
  }
}

/// Message Media Invoice.
///
/// ID: `f6a548d3`.
class MessageMediaInvoice extends MessageMediaBase {
  /// Message Media Invoice constructor.
  const MessageMediaInvoice({
    required this.shippingAddressRequested,
    required this.test,
    required this.title,
    required this.description,
    this.photo,
    this.receiptMsgId,
    required this.currency,
    required this.totalAmount,
    required this.startParam,
    this.extendedMedia,
  }) : super._();

  /// Deserialize.
  factory MessageMediaInvoice.deserialize(BinaryReader reader) {
    // Read [MessageMediaInvoice] fields.
    final flags = reader.readInt32();
    final shippingAddressRequested = (flags & 2) != 0;
    final test = (flags & 8) != 0;
    final title = reader.readString();
    final description = reader.readString();
    final hasPhotoField = (flags & 1) != 0;
    final photo = hasPhotoField ? reader.readObject() as WebDocumentBase : null;
    final hasReceiptMsgIdField = (flags & 4) != 0;
    final receiptMsgId = hasReceiptMsgIdField ? reader.readInt32() : null;
    final currency = reader.readString();
    final totalAmount = reader.readInt64();
    final startParam = reader.readString();
    final hasExtendedMediaField = (flags & 16) != 0;
    final extendedMedia = hasExtendedMediaField
        ? reader.readObject() as MessageExtendedMediaBase
        : null;

    // Construct [MessageMediaInvoice] object.
    final returnValue = MessageMediaInvoice(
      shippingAddressRequested: shippingAddressRequested,
      test: test,
      title: title,
      description: description,
      photo: photo,
      receiptMsgId: receiptMsgId,
      currency: currency,
      totalAmount: totalAmount,
      startParam: startParam,
      extendedMedia: extendedMedia,
    );

    // Now return the deserialized [MessageMediaInvoice].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: shippingAddressRequested,
      b03: test,
      b00: photo != null,
      b02: receiptMsgId != null,
      b04: extendedMedia != null,
    );

    return v;
  }

  /// shipping_address_requested: bit 1 of flags.1?true
  final bool shippingAddressRequested;

  /// test: bit 3 of flags.3?true
  final bool test;

  /// Title.
  final String title;

  /// Description.
  final String description;

  /// Photo.
  final WebDocumentBase? photo;

  /// Receipt Msg Id.
  final int? receiptMsgId;

  /// Currency.
  final String currency;

  /// Total Amount.
  ///
  /// Field type is Int64.
  final int totalAmount;

  /// Start Param.
  final String startParam;

  /// Extended Media.
  final MessageExtendedMediaBase? extendedMedia;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf6a548d3.
    buffer.writeInt32(0xf6a548d3);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(title);
    buffer.writeString(description);
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }
    final localReceiptMsgIdCopy = receiptMsgId;
    if (localReceiptMsgIdCopy != null) {
      buffer.writeInt32(localReceiptMsgIdCopy);
    }
    buffer.writeString(currency);
    buffer.writeInt64(totalAmount);
    buffer.writeString(startParam);
    final localExtendedMediaCopy = extendedMedia;
    if (localExtendedMediaCopy != null) {
      buffer.writeObject(localExtendedMediaCopy);
    }

    // Finished serialization.
  }
}

/// Message Media Geo Live.
///
/// ID: `b940c666`.
class MessageMediaGeoLive extends MessageMediaBase {
  /// Message Media Geo Live constructor.
  const MessageMediaGeoLive({
    required this.geo,
    this.heading,
    required this.period,
    this.proximityNotificationRadius,
  }) : super._();

  /// Deserialize.
  factory MessageMediaGeoLive.deserialize(BinaryReader reader) {
    // Read [MessageMediaGeoLive] fields.
    final flags = reader.readInt32();
    final geo = reader.readObject() as GeoPointBase;
    final hasHeadingField = (flags & 1) != 0;
    final heading = hasHeadingField ? reader.readInt32() : null;
    final period = reader.readInt32();
    final hasProximityNotificationRadiusField = (flags & 2) != 0;
    final proximityNotificationRadius =
        hasProximityNotificationRadiusField ? reader.readInt32() : null;

    // Construct [MessageMediaGeoLive] object.
    final returnValue = MessageMediaGeoLive(
      geo: geo,
      heading: heading,
      period: period,
      proximityNotificationRadius: proximityNotificationRadius,
    );

    // Now return the deserialized [MessageMediaGeoLive].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: heading != null,
      b01: proximityNotificationRadius != null,
    );

    return v;
  }

  /// Geo.
  final GeoPointBase geo;

  /// Heading.
  final int? heading;

  /// Period.
  ///
  /// Field type is Int32.
  final int period;

  /// Proximity Notification Radius.
  final int? proximityNotificationRadius;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb940c666.
    buffer.writeInt32(0xb940c666);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(geo);
    final localHeadingCopy = heading;
    if (localHeadingCopy != null) {
      buffer.writeInt32(localHeadingCopy);
    }
    buffer.writeInt32(period);
    final localProximityNotificationRadiusCopy = proximityNotificationRadius;
    if (localProximityNotificationRadiusCopy != null) {
      buffer.writeInt32(localProximityNotificationRadiusCopy);
    }

    // Finished serialization.
  }
}

/// Message Media Poll.
///
/// ID: `4bd6e798`.
class MessageMediaPoll extends MessageMediaBase {
  /// Message Media Poll constructor.
  const MessageMediaPoll({
    required this.poll,
    required this.results,
  }) : super._();

  /// Deserialize.
  factory MessageMediaPoll.deserialize(BinaryReader reader) {
    // Read [MessageMediaPoll] fields.
    final poll = reader.readObject() as PollBase;
    final results = reader.readObject() as PollResultsBase;

    // Construct [MessageMediaPoll] object.
    final returnValue = MessageMediaPoll(
      poll: poll,
      results: results,
    );

    // Now return the deserialized [MessageMediaPoll].
    return returnValue;
  }

  /// Poll.
  final PollBase poll;

  /// Results.
  final PollResultsBase results;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4bd6e798.
    buffer.writeInt32(0x4bd6e798);

    // Write fields.
    buffer.writeObject(poll);
    buffer.writeObject(results);

    // Finished serialization.
  }
}

/// Message Media Dice.
///
/// ID: `3f7ee58b`.
class MessageMediaDice extends MessageMediaBase {
  /// Message Media Dice constructor.
  const MessageMediaDice({
    required this.value,
    required this.emoticon,
  }) : super._();

  /// Deserialize.
  factory MessageMediaDice.deserialize(BinaryReader reader) {
    // Read [MessageMediaDice] fields.
    final value = reader.readInt32();
    final emoticon = reader.readString();

    // Construct [MessageMediaDice] object.
    final returnValue = MessageMediaDice(
      value: value,
      emoticon: emoticon,
    );

    // Now return the deserialized [MessageMediaDice].
    return returnValue;
  }

  /// Value.
  ///
  /// Field type is Int32.
  final int value;

  /// Emoticon.
  final String emoticon;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3f7ee58b.
    buffer.writeInt32(0x3f7ee58b);

    // Write fields.
    buffer.writeInt32(value);
    buffer.writeString(emoticon);

    // Finished serialization.
  }
}

/// Message Media Story.
///
/// ID: `68cb6283`.
class MessageMediaStory extends MessageMediaBase {
  /// Message Media Story constructor.
  const MessageMediaStory({
    required this.viaMention,
    required this.peer,
    required this.id,
    this.story,
  }) : super._();

  /// Deserialize.
  factory MessageMediaStory.deserialize(BinaryReader reader) {
    // Read [MessageMediaStory] fields.
    final flags = reader.readInt32();
    final viaMention = (flags & 2) != 0;
    final peer = reader.readObject() as PeerBase;
    final id = reader.readInt32();
    final hasStoryField = (flags & 1) != 0;
    final story = hasStoryField ? reader.readObject() as StoryItemBase : null;

    // Construct [MessageMediaStory] object.
    final returnValue = MessageMediaStory(
      viaMention: viaMention,
      peer: peer,
      id: id,
      story: story,
    );

    // Now return the deserialized [MessageMediaStory].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: viaMention,
      b00: story != null,
    );

    return v;
  }

  /// via_mention: bit 1 of flags.1?true
  final bool viaMention;

  /// Peer.
  final PeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Story.
  final StoryItemBase? story;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x68cb6283.
    buffer.writeInt32(0x68cb6283);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    final localStoryCopy = story;
    if (localStoryCopy != null) {
      buffer.writeObject(localStoryCopy);
    }

    // Finished serialization.
  }
}

/// Message Media Giveaway.
///
/// ID: `daad85b0`.
class MessageMediaGiveaway extends MessageMediaBase {
  /// Message Media Giveaway constructor.
  const MessageMediaGiveaway({
    required this.onlyNewSubscribers,
    required this.winnersAreVisible,
    required this.channels,
    this.countriesIso2,
    this.prizeDescription,
    required this.quantity,
    required this.months,
    required this.untilDate,
  }) : super._();

  /// Deserialize.
  factory MessageMediaGiveaway.deserialize(BinaryReader reader) {
    // Read [MessageMediaGiveaway] fields.
    final flags = reader.readInt32();
    final onlyNewSubscribers = (flags & 1) != 0;
    final winnersAreVisible = (flags & 4) != 0;
    final channels = reader.readVectorInt64();
    final hasCountriesIso2Field = (flags & 2) != 0;
    final countriesIso2 =
        hasCountriesIso2Field ? reader.readVectorString() : null;
    final hasPrizeDescriptionField = (flags & 8) != 0;
    final prizeDescription =
        hasPrizeDescriptionField ? reader.readString() : null;
    final quantity = reader.readInt32();
    final months = reader.readInt32();
    final untilDate = reader.readDateTime();

    // Construct [MessageMediaGiveaway] object.
    final returnValue = MessageMediaGiveaway(
      onlyNewSubscribers: onlyNewSubscribers,
      winnersAreVisible: winnersAreVisible,
      channels: channels,
      countriesIso2: countriesIso2,
      prizeDescription: prizeDescription,
      quantity: quantity,
      months: months,
      untilDate: untilDate,
    );

    // Now return the deserialized [MessageMediaGiveaway].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: onlyNewSubscribers,
      b02: winnersAreVisible,
      b01: countriesIso2 != null,
      b03: prizeDescription != null,
    );

    return v;
  }

  /// only_new_subscribers: bit 0 of flags.0?true
  final bool onlyNewSubscribers;

  /// winners_are_visible: bit 2 of flags.2?true
  final bool winnersAreVisible;

  /// Channels.
  final List<int> channels;

  /// Countries Iso2.
  final List<String>? countriesIso2;

  /// Prize Description.
  final String? prizeDescription;

  /// Quantity.
  ///
  /// Field type is Int32.
  final int quantity;

  /// Months.
  ///
  /// Field type is Int32.
  final int months;

  /// Until Date.
  final DateTime untilDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdaad85b0.
    buffer.writeInt32(0xdaad85b0);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorInt64(channels);
    final localCountriesIso2Copy = countriesIso2;
    if (localCountriesIso2Copy != null) {
      buffer.writeVectorString(localCountriesIso2Copy);
    }
    final localPrizeDescriptionCopy = prizeDescription;
    if (localPrizeDescriptionCopy != null) {
      buffer.writeString(localPrizeDescriptionCopy);
    }
    buffer.writeInt32(quantity);
    buffer.writeInt32(months);
    buffer.writeDateTime(untilDate);

    // Finished serialization.
  }
}

/// Message Media Giveaway Results.
///
/// ID: `c6991068`.
class MessageMediaGiveawayResults extends MessageMediaBase {
  /// Message Media Giveaway Results constructor.
  const MessageMediaGiveawayResults({
    required this.onlyNewSubscribers,
    required this.refunded,
    required this.channelId,
    this.additionalPeersCount,
    required this.launchMsgId,
    required this.winnersCount,
    required this.unclaimedCount,
    required this.winners,
    required this.months,
    this.prizeDescription,
    required this.untilDate,
  }) : super._();

  /// Deserialize.
  factory MessageMediaGiveawayResults.deserialize(BinaryReader reader) {
    // Read [MessageMediaGiveawayResults] fields.
    final flags = reader.readInt32();
    final onlyNewSubscribers = (flags & 1) != 0;
    final refunded = (flags & 4) != 0;
    final channelId = reader.readInt64();
    final hasAdditionalPeersCountField = (flags & 8) != 0;
    final additionalPeersCount =
        hasAdditionalPeersCountField ? reader.readInt32() : null;
    final launchMsgId = reader.readInt32();
    final winnersCount = reader.readInt32();
    final unclaimedCount = reader.readInt32();
    final winners = reader.readVectorInt64();
    final months = reader.readInt32();
    final hasPrizeDescriptionField = (flags & 2) != 0;
    final prizeDescription =
        hasPrizeDescriptionField ? reader.readString() : null;
    final untilDate = reader.readDateTime();

    // Construct [MessageMediaGiveawayResults] object.
    final returnValue = MessageMediaGiveawayResults(
      onlyNewSubscribers: onlyNewSubscribers,
      refunded: refunded,
      channelId: channelId,
      additionalPeersCount: additionalPeersCount,
      launchMsgId: launchMsgId,
      winnersCount: winnersCount,
      unclaimedCount: unclaimedCount,
      winners: winners,
      months: months,
      prizeDescription: prizeDescription,
      untilDate: untilDate,
    );

    // Now return the deserialized [MessageMediaGiveawayResults].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: onlyNewSubscribers,
      b02: refunded,
      b03: additionalPeersCount != null,
      b01: prizeDescription != null,
    );

    return v;
  }

  /// only_new_subscribers: bit 0 of flags.0?true
  final bool onlyNewSubscribers;

  /// refunded: bit 2 of flags.2?true
  final bool refunded;

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Additional Peers Count.
  final int? additionalPeersCount;

  /// Launch Msg Id.
  ///
  /// Field type is Int32.
  final int launchMsgId;

  /// Winners Count.
  ///
  /// Field type is Int32.
  final int winnersCount;

  /// Unclaimed Count.
  ///
  /// Field type is Int32.
  final int unclaimedCount;

  /// Winners.
  final List<int> winners;

  /// Months.
  ///
  /// Field type is Int32.
  final int months;

  /// Prize Description.
  final String? prizeDescription;

  /// Until Date.
  final DateTime untilDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc6991068.
    buffer.writeInt32(0xc6991068);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(channelId);
    final localAdditionalPeersCountCopy = additionalPeersCount;
    if (localAdditionalPeersCountCopy != null) {
      buffer.writeInt32(localAdditionalPeersCountCopy);
    }
    buffer.writeInt32(launchMsgId);
    buffer.writeInt32(winnersCount);
    buffer.writeInt32(unclaimedCount);
    buffer.writeVectorInt64(winners);
    buffer.writeInt32(months);
    final localPrizeDescriptionCopy = prizeDescription;
    if (localPrizeDescriptionCopy != null) {
      buffer.writeString(localPrizeDescriptionCopy);
    }
    buffer.writeDateTime(untilDate);

    // Finished serialization.
  }
}

/// Message Action Empty.
///
/// ID: `b6aef7b0`.
class MessageActionEmpty extends MessageActionBase {
  /// Message Action Empty constructor.
  const MessageActionEmpty() : super._();

  /// Deserialize.
  factory MessageActionEmpty.deserialize(BinaryReader reader) {
    // Construct [MessageActionEmpty] object.
    final returnValue = MessageActionEmpty();

    // Now return the deserialized [MessageActionEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb6aef7b0.
    buffer.writeInt32(0xb6aef7b0);

    // Finished serialization.
  }
}

/// Message Action Chat Create.
///
/// ID: `bd47cbad`.
class MessageActionChatCreate extends MessageActionBase {
  /// Message Action Chat Create constructor.
  const MessageActionChatCreate({
    required this.title,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessageActionChatCreate.deserialize(BinaryReader reader) {
    // Read [MessageActionChatCreate] fields.
    final title = reader.readString();
    final users = reader.readVectorInt64();

    // Construct [MessageActionChatCreate] object.
    final returnValue = MessageActionChatCreate(
      title: title,
      users: users,
    );

    // Now return the deserialized [MessageActionChatCreate].
    return returnValue;
  }

  /// Title.
  final String title;

  /// Users.
  final List<int> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbd47cbad.
    buffer.writeInt32(0xbd47cbad);

    // Write fields.
    buffer.writeString(title);
    buffer.writeVectorInt64(users);

    // Finished serialization.
  }
}

/// Message Action Chat Edit Title.
///
/// ID: `b5a1ce5a`.
class MessageActionChatEditTitle extends MessageActionBase {
  /// Message Action Chat Edit Title constructor.
  const MessageActionChatEditTitle({
    required this.title,
  }) : super._();

  /// Deserialize.
  factory MessageActionChatEditTitle.deserialize(BinaryReader reader) {
    // Read [MessageActionChatEditTitle] fields.
    final title = reader.readString();

    // Construct [MessageActionChatEditTitle] object.
    final returnValue = MessageActionChatEditTitle(
      title: title,
    );

    // Now return the deserialized [MessageActionChatEditTitle].
    return returnValue;
  }

  /// Title.
  final String title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb5a1ce5a.
    buffer.writeInt32(0xb5a1ce5a);

    // Write fields.
    buffer.writeString(title);

    // Finished serialization.
  }
}

/// Message Action Chat Edit Photo.
///
/// ID: `7fcb13a8`.
class MessageActionChatEditPhoto extends MessageActionBase {
  /// Message Action Chat Edit Photo constructor.
  const MessageActionChatEditPhoto({
    required this.photo,
  }) : super._();

  /// Deserialize.
  factory MessageActionChatEditPhoto.deserialize(BinaryReader reader) {
    // Read [MessageActionChatEditPhoto] fields.
    final photo = reader.readObject() as PhotoBase;

    // Construct [MessageActionChatEditPhoto] object.
    final returnValue = MessageActionChatEditPhoto(
      photo: photo,
    );

    // Now return the deserialized [MessageActionChatEditPhoto].
    return returnValue;
  }

  /// Photo.
  final PhotoBase photo;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7fcb13a8.
    buffer.writeInt32(0x7fcb13a8);

    // Write fields.
    buffer.writeObject(photo);

    // Finished serialization.
  }
}

/// Message Action Chat Delete Photo.
///
/// ID: `95e3fbef`.
class MessageActionChatDeletePhoto extends MessageActionBase {
  /// Message Action Chat Delete Photo constructor.
  const MessageActionChatDeletePhoto() : super._();

  /// Deserialize.
  factory MessageActionChatDeletePhoto.deserialize(BinaryReader reader) {
    // Construct [MessageActionChatDeletePhoto] object.
    final returnValue = MessageActionChatDeletePhoto();

    // Now return the deserialized [MessageActionChatDeletePhoto].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x95e3fbef.
    buffer.writeInt32(0x95e3fbef);

    // Finished serialization.
  }
}

/// Message Action Chat Add User.
///
/// ID: `15cefd00`.
class MessageActionChatAddUser extends MessageActionBase {
  /// Message Action Chat Add User constructor.
  const MessageActionChatAddUser({
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessageActionChatAddUser.deserialize(BinaryReader reader) {
    // Read [MessageActionChatAddUser] fields.
    final users = reader.readVectorInt64();

    // Construct [MessageActionChatAddUser] object.
    final returnValue = MessageActionChatAddUser(
      users: users,
    );

    // Now return the deserialized [MessageActionChatAddUser].
    return returnValue;
  }

  /// Users.
  final List<int> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x15cefd00.
    buffer.writeInt32(0x15cefd00);

    // Write fields.
    buffer.writeVectorInt64(users);

    // Finished serialization.
  }
}

/// Message Action Chat Delete User.
///
/// ID: `a43f30cc`.
class MessageActionChatDeleteUser extends MessageActionBase {
  /// Message Action Chat Delete User constructor.
  const MessageActionChatDeleteUser({
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory MessageActionChatDeleteUser.deserialize(BinaryReader reader) {
    // Read [MessageActionChatDeleteUser] fields.
    final userId = reader.readInt64();

    // Construct [MessageActionChatDeleteUser] object.
    final returnValue = MessageActionChatDeleteUser(
      userId: userId,
    );

    // Now return the deserialized [MessageActionChatDeleteUser].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa43f30cc.
    buffer.writeInt32(0xa43f30cc);

    // Write fields.
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Message Action Chat Joined By Link.
///
/// ID: `031224c3`.
class MessageActionChatJoinedByLink extends MessageActionBase {
  /// Message Action Chat Joined By Link constructor.
  const MessageActionChatJoinedByLink({
    required this.inviterId,
  }) : super._();

  /// Deserialize.
  factory MessageActionChatJoinedByLink.deserialize(BinaryReader reader) {
    // Read [MessageActionChatJoinedByLink] fields.
    final inviterId = reader.readInt64();

    // Construct [MessageActionChatJoinedByLink] object.
    final returnValue = MessageActionChatJoinedByLink(
      inviterId: inviterId,
    );

    // Now return the deserialized [MessageActionChatJoinedByLink].
    return returnValue;
  }

  /// Inviter Id.
  ///
  /// Field type is Int64.
  final int inviterId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x031224c3.
    buffer.writeInt32(0x031224c3);

    // Write fields.
    buffer.writeInt64(inviterId);

    // Finished serialization.
  }
}

/// Message Action Channel Create.
///
/// ID: `95d2ac92`.
class MessageActionChannelCreate extends MessageActionBase {
  /// Message Action Channel Create constructor.
  const MessageActionChannelCreate({
    required this.title,
  }) : super._();

  /// Deserialize.
  factory MessageActionChannelCreate.deserialize(BinaryReader reader) {
    // Read [MessageActionChannelCreate] fields.
    final title = reader.readString();

    // Construct [MessageActionChannelCreate] object.
    final returnValue = MessageActionChannelCreate(
      title: title,
    );

    // Now return the deserialized [MessageActionChannelCreate].
    return returnValue;
  }

  /// Title.
  final String title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x95d2ac92.
    buffer.writeInt32(0x95d2ac92);

    // Write fields.
    buffer.writeString(title);

    // Finished serialization.
  }
}

/// Message Action Chat Migrate To.
///
/// ID: `e1037f92`.
class MessageActionChatMigrateTo extends MessageActionBase {
  /// Message Action Chat Migrate To constructor.
  const MessageActionChatMigrateTo({
    required this.channelId,
  }) : super._();

  /// Deserialize.
  factory MessageActionChatMigrateTo.deserialize(BinaryReader reader) {
    // Read [MessageActionChatMigrateTo] fields.
    final channelId = reader.readInt64();

    // Construct [MessageActionChatMigrateTo] object.
    final returnValue = MessageActionChatMigrateTo(
      channelId: channelId,
    );

    // Now return the deserialized [MessageActionChatMigrateTo].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe1037f92.
    buffer.writeInt32(0xe1037f92);

    // Write fields.
    buffer.writeInt64(channelId);

    // Finished serialization.
  }
}

/// Message Action Channel Migrate From.
///
/// ID: `ea3948e9`.
class MessageActionChannelMigrateFrom extends MessageActionBase {
  /// Message Action Channel Migrate From constructor.
  const MessageActionChannelMigrateFrom({
    required this.title,
    required this.chatId,
  }) : super._();

  /// Deserialize.
  factory MessageActionChannelMigrateFrom.deserialize(BinaryReader reader) {
    // Read [MessageActionChannelMigrateFrom] fields.
    final title = reader.readString();
    final chatId = reader.readInt64();

    // Construct [MessageActionChannelMigrateFrom] object.
    final returnValue = MessageActionChannelMigrateFrom(
      title: title,
      chatId: chatId,
    );

    // Now return the deserialized [MessageActionChannelMigrateFrom].
    return returnValue;
  }

  /// Title.
  final String title;

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xea3948e9.
    buffer.writeInt32(0xea3948e9);

    // Write fields.
    buffer.writeString(title);
    buffer.writeInt64(chatId);

    // Finished serialization.
  }
}

/// Message Action Pin Message.
///
/// ID: `94bd38ed`.
class MessageActionPinMessage extends MessageActionBase {
  /// Message Action Pin Message constructor.
  const MessageActionPinMessage() : super._();

  /// Deserialize.
  factory MessageActionPinMessage.deserialize(BinaryReader reader) {
    // Construct [MessageActionPinMessage] object.
    final returnValue = MessageActionPinMessage();

    // Now return the deserialized [MessageActionPinMessage].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x94bd38ed.
    buffer.writeInt32(0x94bd38ed);

    // Finished serialization.
  }
}

/// Message Action History Clear.
///
/// ID: `9fbab604`.
class MessageActionHistoryClear extends MessageActionBase {
  /// Message Action History Clear constructor.
  const MessageActionHistoryClear() : super._();

  /// Deserialize.
  factory MessageActionHistoryClear.deserialize(BinaryReader reader) {
    // Construct [MessageActionHistoryClear] object.
    final returnValue = MessageActionHistoryClear();

    // Now return the deserialized [MessageActionHistoryClear].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9fbab604.
    buffer.writeInt32(0x9fbab604);

    // Finished serialization.
  }
}

/// Message Action Game Score.
///
/// ID: `92a72876`.
class MessageActionGameScore extends MessageActionBase {
  /// Message Action Game Score constructor.
  const MessageActionGameScore({
    required this.gameId,
    required this.score,
  }) : super._();

  /// Deserialize.
  factory MessageActionGameScore.deserialize(BinaryReader reader) {
    // Read [MessageActionGameScore] fields.
    final gameId = reader.readInt64();
    final score = reader.readInt32();

    // Construct [MessageActionGameScore] object.
    final returnValue = MessageActionGameScore(
      gameId: gameId,
      score: score,
    );

    // Now return the deserialized [MessageActionGameScore].
    return returnValue;
  }

  /// Game Id.
  ///
  /// Field type is Int64.
  final int gameId;

  /// Score.
  ///
  /// Field type is Int32.
  final int score;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x92a72876.
    buffer.writeInt32(0x92a72876);

    // Write fields.
    buffer.writeInt64(gameId);
    buffer.writeInt32(score);

    // Finished serialization.
  }
}

/// Message Action Payment Sent Me.
///
/// ID: `8f31b327`.
class MessageActionPaymentSentMe extends MessageActionBase {
  /// Message Action Payment Sent Me constructor.
  const MessageActionPaymentSentMe({
    required this.recurringInit,
    required this.recurringUsed,
    required this.currency,
    required this.totalAmount,
    required this.payload,
    this.info,
    this.shippingOptionId,
    required this.charge,
  }) : super._();

  /// Deserialize.
  factory MessageActionPaymentSentMe.deserialize(BinaryReader reader) {
    // Read [MessageActionPaymentSentMe] fields.
    final flags = reader.readInt32();
    final recurringInit = (flags & 4) != 0;
    final recurringUsed = (flags & 8) != 0;
    final currency = reader.readString();
    final totalAmount = reader.readInt64();
    final payload = reader.readBytes();
    final hasInfoField = (flags & 1) != 0;
    final info =
        hasInfoField ? reader.readObject() as PaymentRequestedInfoBase : null;
    final hasShippingOptionIdField = (flags & 2) != 0;
    final shippingOptionId =
        hasShippingOptionIdField ? reader.readString() : null;
    final charge = reader.readObject() as PaymentChargeBase;

    // Construct [MessageActionPaymentSentMe] object.
    final returnValue = MessageActionPaymentSentMe(
      recurringInit: recurringInit,
      recurringUsed: recurringUsed,
      currency: currency,
      totalAmount: totalAmount,
      payload: payload,
      info: info,
      shippingOptionId: shippingOptionId,
      charge: charge,
    );

    // Now return the deserialized [MessageActionPaymentSentMe].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: recurringInit,
      b03: recurringUsed,
      b00: info != null,
      b01: shippingOptionId != null,
    );

    return v;
  }

  /// recurring_init: bit 2 of flags.2?true
  final bool recurringInit;

  /// recurring_used: bit 3 of flags.3?true
  final bool recurringUsed;

  /// Currency.
  final String currency;

  /// Total Amount.
  ///
  /// Field type is Int64.
  final int totalAmount;

  /// Payload.
  final Uint8List payload;

  /// Info.
  final PaymentRequestedInfoBase? info;

  /// Shipping Option Id.
  final String? shippingOptionId;

  /// Charge.
  final PaymentChargeBase charge;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8f31b327.
    buffer.writeInt32(0x8f31b327);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(currency);
    buffer.writeInt64(totalAmount);
    buffer.writeBytes(payload);
    final localInfoCopy = info;
    if (localInfoCopy != null) {
      buffer.writeObject(localInfoCopy);
    }
    final localShippingOptionIdCopy = shippingOptionId;
    if (localShippingOptionIdCopy != null) {
      buffer.writeString(localShippingOptionIdCopy);
    }
    buffer.writeObject(charge);

    // Finished serialization.
  }
}

/// Message Action Payment Sent.
///
/// ID: `96163f56`.
class MessageActionPaymentSent extends MessageActionBase {
  /// Message Action Payment Sent constructor.
  const MessageActionPaymentSent({
    required this.recurringInit,
    required this.recurringUsed,
    required this.currency,
    required this.totalAmount,
    this.invoiceSlug,
  }) : super._();

  /// Deserialize.
  factory MessageActionPaymentSent.deserialize(BinaryReader reader) {
    // Read [MessageActionPaymentSent] fields.
    final flags = reader.readInt32();
    final recurringInit = (flags & 4) != 0;
    final recurringUsed = (flags & 8) != 0;
    final currency = reader.readString();
    final totalAmount = reader.readInt64();
    final hasInvoiceSlugField = (flags & 1) != 0;
    final invoiceSlug = hasInvoiceSlugField ? reader.readString() : null;

    // Construct [MessageActionPaymentSent] object.
    final returnValue = MessageActionPaymentSent(
      recurringInit: recurringInit,
      recurringUsed: recurringUsed,
      currency: currency,
      totalAmount: totalAmount,
      invoiceSlug: invoiceSlug,
    );

    // Now return the deserialized [MessageActionPaymentSent].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: recurringInit,
      b03: recurringUsed,
      b00: invoiceSlug != null,
    );

    return v;
  }

  /// recurring_init: bit 2 of flags.2?true
  final bool recurringInit;

  /// recurring_used: bit 3 of flags.3?true
  final bool recurringUsed;

  /// Currency.
  final String currency;

  /// Total Amount.
  ///
  /// Field type is Int64.
  final int totalAmount;

  /// Invoice Slug.
  final String? invoiceSlug;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x96163f56.
    buffer.writeInt32(0x96163f56);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(currency);
    buffer.writeInt64(totalAmount);
    final localInvoiceSlugCopy = invoiceSlug;
    if (localInvoiceSlugCopy != null) {
      buffer.writeString(localInvoiceSlugCopy);
    }

    // Finished serialization.
  }
}

/// Message Action Phone Call.
///
/// ID: `80e11a7f`.
class MessageActionPhoneCall extends MessageActionBase {
  /// Message Action Phone Call constructor.
  const MessageActionPhoneCall({
    required this.video,
    required this.callId,
    this.reason,
    this.duration,
  }) : super._();

  /// Deserialize.
  factory MessageActionPhoneCall.deserialize(BinaryReader reader) {
    // Read [MessageActionPhoneCall] fields.
    final flags = reader.readInt32();
    final video = (flags & 4) != 0;
    final callId = reader.readInt64();
    final hasReasonField = (flags & 1) != 0;
    final reason = hasReasonField
        ? reader.readObject() as PhoneCallDiscardReasonBase
        : null;
    final hasDurationField = (flags & 2) != 0;
    final duration = hasDurationField ? reader.readInt32() : null;

    // Construct [MessageActionPhoneCall] object.
    final returnValue = MessageActionPhoneCall(
      video: video,
      callId: callId,
      reason: reason,
      duration: duration,
    );

    // Now return the deserialized [MessageActionPhoneCall].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: video,
      b00: reason != null,
      b01: duration != null,
    );

    return v;
  }

  /// video: bit 2 of flags.2?true
  final bool video;

  /// Call Id.
  ///
  /// Field type is Int64.
  final int callId;

  /// Reason.
  final PhoneCallDiscardReasonBase? reason;

  /// Duration.
  final int? duration;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x80e11a7f.
    buffer.writeInt32(0x80e11a7f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(callId);
    final localReasonCopy = reason;
    if (localReasonCopy != null) {
      buffer.writeObject(localReasonCopy);
    }
    final localDurationCopy = duration;
    if (localDurationCopy != null) {
      buffer.writeInt32(localDurationCopy);
    }

    // Finished serialization.
  }
}

/// Message Action Screenshot Taken.
///
/// ID: `4792929b`.
class MessageActionScreenshotTaken extends MessageActionBase {
  /// Message Action Screenshot Taken constructor.
  const MessageActionScreenshotTaken() : super._();

  /// Deserialize.
  factory MessageActionScreenshotTaken.deserialize(BinaryReader reader) {
    // Construct [MessageActionScreenshotTaken] object.
    final returnValue = MessageActionScreenshotTaken();

    // Now return the deserialized [MessageActionScreenshotTaken].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4792929b.
    buffer.writeInt32(0x4792929b);

    // Finished serialization.
  }
}

/// Message Action Custom Action.
///
/// ID: `fae69f56`.
class MessageActionCustomAction extends MessageActionBase {
  /// Message Action Custom Action constructor.
  const MessageActionCustomAction({
    required this.message,
  }) : super._();

  /// Deserialize.
  factory MessageActionCustomAction.deserialize(BinaryReader reader) {
    // Read [MessageActionCustomAction] fields.
    final message = reader.readString();

    // Construct [MessageActionCustomAction] object.
    final returnValue = MessageActionCustomAction(
      message: message,
    );

    // Now return the deserialized [MessageActionCustomAction].
    return returnValue;
  }

  /// Message.
  final String message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfae69f56.
    buffer.writeInt32(0xfae69f56);

    // Write fields.
    buffer.writeString(message);

    // Finished serialization.
  }
}

/// Message Action Bot Allowed.
///
/// ID: `c516d679`.
class MessageActionBotAllowed extends MessageActionBase {
  /// Message Action Bot Allowed constructor.
  const MessageActionBotAllowed({
    required this.attachMenu,
    required this.fromRequest,
    this.domain,
    this.app,
  }) : super._();

  /// Deserialize.
  factory MessageActionBotAllowed.deserialize(BinaryReader reader) {
    // Read [MessageActionBotAllowed] fields.
    final flags = reader.readInt32();
    final attachMenu = (flags & 2) != 0;
    final fromRequest = (flags & 8) != 0;
    final hasDomainField = (flags & 1) != 0;
    final domain = hasDomainField ? reader.readString() : null;
    final hasAppField = (flags & 4) != 0;
    final app = hasAppField ? reader.readObject() as BotAppBase : null;

    // Construct [MessageActionBotAllowed] object.
    final returnValue = MessageActionBotAllowed(
      attachMenu: attachMenu,
      fromRequest: fromRequest,
      domain: domain,
      app: app,
    );

    // Now return the deserialized [MessageActionBotAllowed].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: attachMenu,
      b03: fromRequest,
      b00: domain != null,
      b02: app != null,
    );

    return v;
  }

  /// attach_menu: bit 1 of flags.1?true
  final bool attachMenu;

  /// from_request: bit 3 of flags.3?true
  final bool fromRequest;

  /// Domain.
  final String? domain;

  /// App.
  final BotAppBase? app;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc516d679.
    buffer.writeInt32(0xc516d679);

    // Write fields.
    buffer.writeInt32(flags);
    final localDomainCopy = domain;
    if (localDomainCopy != null) {
      buffer.writeString(localDomainCopy);
    }
    final localAppCopy = app;
    if (localAppCopy != null) {
      buffer.writeObject(localAppCopy);
    }

    // Finished serialization.
  }
}

/// Message Action Secure Values Sent Me.
///
/// ID: `1b287353`.
class MessageActionSecureValuesSentMe extends MessageActionBase {
  /// Message Action Secure Values Sent Me constructor.
  const MessageActionSecureValuesSentMe({
    required this.values,
    required this.credentials,
  }) : super._();

  /// Deserialize.
  factory MessageActionSecureValuesSentMe.deserialize(BinaryReader reader) {
    // Read [MessageActionSecureValuesSentMe] fields.
    final values = reader.readVectorObject<SecureValueBase>();
    final credentials = reader.readObject() as SecureCredentialsEncryptedBase;

    // Construct [MessageActionSecureValuesSentMe] object.
    final returnValue = MessageActionSecureValuesSentMe(
      values: values,
      credentials: credentials,
    );

    // Now return the deserialized [MessageActionSecureValuesSentMe].
    return returnValue;
  }

  /// Values.
  final List<SecureValueBase> values;

  /// Credentials.
  final SecureCredentialsEncryptedBase credentials;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1b287353.
    buffer.writeInt32(0x1b287353);

    // Write fields.
    buffer.writeVectorObject(values);
    buffer.writeObject(credentials);

    // Finished serialization.
  }
}

/// Message Action Secure Values Sent.
///
/// ID: `d95c6154`.
class MessageActionSecureValuesSent extends MessageActionBase {
  /// Message Action Secure Values Sent constructor.
  const MessageActionSecureValuesSent({
    required this.types,
  }) : super._();

  /// Deserialize.
  factory MessageActionSecureValuesSent.deserialize(BinaryReader reader) {
    // Read [MessageActionSecureValuesSent] fields.
    final types = reader.readVectorObject<SecureValueTypeBase>();

    // Construct [MessageActionSecureValuesSent] object.
    final returnValue = MessageActionSecureValuesSent(
      types: types,
    );

    // Now return the deserialized [MessageActionSecureValuesSent].
    return returnValue;
  }

  /// Types.
  final List<SecureValueTypeBase> types;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd95c6154.
    buffer.writeInt32(0xd95c6154);

    // Write fields.
    buffer.writeVectorObject(types);

    // Finished serialization.
  }
}

/// Message Action Contact Sign Up.
///
/// ID: `f3f25f76`.
class MessageActionContactSignUp extends MessageActionBase {
  /// Message Action Contact Sign Up constructor.
  const MessageActionContactSignUp() : super._();

  /// Deserialize.
  factory MessageActionContactSignUp.deserialize(BinaryReader reader) {
    // Construct [MessageActionContactSignUp] object.
    final returnValue = MessageActionContactSignUp();

    // Now return the deserialized [MessageActionContactSignUp].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf3f25f76.
    buffer.writeInt32(0xf3f25f76);

    // Finished serialization.
  }
}

/// Message Action Geo Proximity Reached.
///
/// ID: `98e0d697`.
class MessageActionGeoProximityReached extends MessageActionBase {
  /// Message Action Geo Proximity Reached constructor.
  const MessageActionGeoProximityReached({
    required this.fromId,
    required this.toId,
    required this.distance,
  }) : super._();

  /// Deserialize.
  factory MessageActionGeoProximityReached.deserialize(BinaryReader reader) {
    // Read [MessageActionGeoProximityReached] fields.
    final fromId = reader.readObject() as PeerBase;
    final toId = reader.readObject() as PeerBase;
    final distance = reader.readInt32();

    // Construct [MessageActionGeoProximityReached] object.
    final returnValue = MessageActionGeoProximityReached(
      fromId: fromId,
      toId: toId,
      distance: distance,
    );

    // Now return the deserialized [MessageActionGeoProximityReached].
    return returnValue;
  }

  /// From Id.
  final PeerBase fromId;

  /// To Id.
  final PeerBase toId;

  /// Distance.
  ///
  /// Field type is Int32.
  final int distance;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x98e0d697.
    buffer.writeInt32(0x98e0d697);

    // Write fields.
    buffer.writeObject(fromId);
    buffer.writeObject(toId);
    buffer.writeInt32(distance);

    // Finished serialization.
  }
}

/// Message Action Group Call.
///
/// ID: `7a0d7f42`.
class MessageActionGroupCall extends MessageActionBase {
  /// Message Action Group Call constructor.
  const MessageActionGroupCall({
    required this.call,
    this.duration,
  }) : super._();

  /// Deserialize.
  factory MessageActionGroupCall.deserialize(BinaryReader reader) {
    // Read [MessageActionGroupCall] fields.
    final flags = reader.readInt32();
    final call = reader.readObject() as InputGroupCallBase;
    final hasDurationField = (flags & 1) != 0;
    final duration = hasDurationField ? reader.readInt32() : null;

    // Construct [MessageActionGroupCall] object.
    final returnValue = MessageActionGroupCall(
      call: call,
      duration: duration,
    );

    // Now return the deserialized [MessageActionGroupCall].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: duration != null,
    );

    return v;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Duration.
  final int? duration;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7a0d7f42.
    buffer.writeInt32(0x7a0d7f42);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(call);
    final localDurationCopy = duration;
    if (localDurationCopy != null) {
      buffer.writeInt32(localDurationCopy);
    }

    // Finished serialization.
  }
}

/// Message Action Invite To Group Call.
///
/// ID: `502f92f7`.
class MessageActionInviteToGroupCall extends MessageActionBase {
  /// Message Action Invite To Group Call constructor.
  const MessageActionInviteToGroupCall({
    required this.call,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessageActionInviteToGroupCall.deserialize(BinaryReader reader) {
    // Read [MessageActionInviteToGroupCall] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final users = reader.readVectorInt64();

    // Construct [MessageActionInviteToGroupCall] object.
    final returnValue = MessageActionInviteToGroupCall(
      call: call,
      users: users,
    );

    // Now return the deserialized [MessageActionInviteToGroupCall].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Users.
  final List<int> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x502f92f7.
    buffer.writeInt32(0x502f92f7);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeVectorInt64(users);

    // Finished serialization.
  }
}

/// Message Action Set Messages T T L.
///
/// ID: `3c134d7b`.
class MessageActionSetMessagesTTL extends MessageActionBase {
  /// Message Action Set Messages T T L constructor.
  const MessageActionSetMessagesTTL({
    required this.period,
    this.autoSettingFrom,
  }) : super._();

  /// Deserialize.
  factory MessageActionSetMessagesTTL.deserialize(BinaryReader reader) {
    // Read [MessageActionSetMessagesTTL] fields.
    final flags = reader.readInt32();
    final period = reader.readInt32();
    final hasAutoSettingFromField = (flags & 1) != 0;
    final autoSettingFrom = hasAutoSettingFromField ? reader.readInt64() : null;

    // Construct [MessageActionSetMessagesTTL] object.
    final returnValue = MessageActionSetMessagesTTL(
      period: period,
      autoSettingFrom: autoSettingFrom,
    );

    // Now return the deserialized [MessageActionSetMessagesTTL].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: autoSettingFrom != null,
    );

    return v;
  }

  /// Period.
  ///
  /// Field type is Int32.
  final int period;

  /// Auto Setting From.
  final int? autoSettingFrom;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3c134d7b.
    buffer.writeInt32(0x3c134d7b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(period);
    final localAutoSettingFromCopy = autoSettingFrom;
    if (localAutoSettingFromCopy != null) {
      buffer.writeInt64(localAutoSettingFromCopy);
    }

    // Finished serialization.
  }
}

/// Message Action Group Call Scheduled.
///
/// ID: `b3a07661`.
class MessageActionGroupCallScheduled extends MessageActionBase {
  /// Message Action Group Call Scheduled constructor.
  const MessageActionGroupCallScheduled({
    required this.call,
    required this.scheduleDate,
  }) : super._();

  /// Deserialize.
  factory MessageActionGroupCallScheduled.deserialize(BinaryReader reader) {
    // Read [MessageActionGroupCallScheduled] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final scheduleDate = reader.readDateTime();

    // Construct [MessageActionGroupCallScheduled] object.
    final returnValue = MessageActionGroupCallScheduled(
      call: call,
      scheduleDate: scheduleDate,
    );

    // Now return the deserialized [MessageActionGroupCallScheduled].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Schedule Date.
  final DateTime scheduleDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb3a07661.
    buffer.writeInt32(0xb3a07661);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeDateTime(scheduleDate);

    // Finished serialization.
  }
}

/// Message Action Set Chat Theme.
///
/// ID: `aa786345`.
class MessageActionSetChatTheme extends MessageActionBase {
  /// Message Action Set Chat Theme constructor.
  const MessageActionSetChatTheme({
    required this.emoticon,
  }) : super._();

  /// Deserialize.
  factory MessageActionSetChatTheme.deserialize(BinaryReader reader) {
    // Read [MessageActionSetChatTheme] fields.
    final emoticon = reader.readString();

    // Construct [MessageActionSetChatTheme] object.
    final returnValue = MessageActionSetChatTheme(
      emoticon: emoticon,
    );

    // Now return the deserialized [MessageActionSetChatTheme].
    return returnValue;
  }

  /// Emoticon.
  final String emoticon;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaa786345.
    buffer.writeInt32(0xaa786345);

    // Write fields.
    buffer.writeString(emoticon);

    // Finished serialization.
  }
}

/// Message Action Chat Joined By Request.
///
/// ID: `ebbca3cb`.
class MessageActionChatJoinedByRequest extends MessageActionBase {
  /// Message Action Chat Joined By Request constructor.
  const MessageActionChatJoinedByRequest() : super._();

  /// Deserialize.
  factory MessageActionChatJoinedByRequest.deserialize(BinaryReader reader) {
    // Construct [MessageActionChatJoinedByRequest] object.
    final returnValue = MessageActionChatJoinedByRequest();

    // Now return the deserialized [MessageActionChatJoinedByRequest].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xebbca3cb.
    buffer.writeInt32(0xebbca3cb);

    // Finished serialization.
  }
}

/// Message Action Web View Data Sent Me.
///
/// ID: `47dd8079`.
class MessageActionWebViewDataSentMe extends MessageActionBase {
  /// Message Action Web View Data Sent Me constructor.
  const MessageActionWebViewDataSentMe({
    required this.text,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory MessageActionWebViewDataSentMe.deserialize(BinaryReader reader) {
    // Read [MessageActionWebViewDataSentMe] fields.
    final text = reader.readString();
    final data = reader.readString();

    // Construct [MessageActionWebViewDataSentMe] object.
    final returnValue = MessageActionWebViewDataSentMe(
      text: text,
      data: data,
    );

    // Now return the deserialized [MessageActionWebViewDataSentMe].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Data.
  final String data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x47dd8079.
    buffer.writeInt32(0x47dd8079);

    // Write fields.
    buffer.writeString(text);
    buffer.writeString(data);

    // Finished serialization.
  }
}

/// Message Action Web View Data Sent.
///
/// ID: `b4c38cb5`.
class MessageActionWebViewDataSent extends MessageActionBase {
  /// Message Action Web View Data Sent constructor.
  const MessageActionWebViewDataSent({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory MessageActionWebViewDataSent.deserialize(BinaryReader reader) {
    // Read [MessageActionWebViewDataSent] fields.
    final text = reader.readString();

    // Construct [MessageActionWebViewDataSent] object.
    final returnValue = MessageActionWebViewDataSent(
      text: text,
    );

    // Now return the deserialized [MessageActionWebViewDataSent].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb4c38cb5.
    buffer.writeInt32(0xb4c38cb5);

    // Write fields.
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Message Action Gift Premium.
///
/// ID: `c83d6aec`.
class MessageActionGiftPremium extends MessageActionBase {
  /// Message Action Gift Premium constructor.
  const MessageActionGiftPremium({
    required this.currency,
    required this.amount,
    required this.months,
    this.cryptoCurrency,
    this.cryptoAmount,
  }) : super._();

  /// Deserialize.
  factory MessageActionGiftPremium.deserialize(BinaryReader reader) {
    // Read [MessageActionGiftPremium] fields.
    final flags = reader.readInt32();
    final currency = reader.readString();
    final amount = reader.readInt64();
    final months = reader.readInt32();
    final hasCryptoCurrencyField = (flags & 1) != 0;
    final cryptoCurrency = hasCryptoCurrencyField ? reader.readString() : null;
    final hasCryptoAmountField = (flags & 1) != 0;
    final cryptoAmount = hasCryptoAmountField ? reader.readInt64() : null;

    // Construct [MessageActionGiftPremium] object.
    final returnValue = MessageActionGiftPremium(
      currency: currency,
      amount: amount,
      months: months,
      cryptoCurrency: cryptoCurrency,
      cryptoAmount: cryptoAmount,
    );

    // Now return the deserialized [MessageActionGiftPremium].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: cryptoCurrency != null || cryptoAmount != null,
    );

    return v;
  }

  /// Currency.
  final String currency;

  /// Amount.
  ///
  /// Field type is Int64.
  final int amount;

  /// Months.
  ///
  /// Field type is Int32.
  final int months;

  /// Crypto Currency.
  final String? cryptoCurrency;

  /// Crypto Amount.
  final int? cryptoAmount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc83d6aec.
    buffer.writeInt32(0xc83d6aec);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(currency);
    buffer.writeInt64(amount);
    buffer.writeInt32(months);
    final localCryptoCurrencyCopy = cryptoCurrency;
    if (localCryptoCurrencyCopy != null) {
      buffer.writeString(localCryptoCurrencyCopy);
    }
    final localCryptoAmountCopy = cryptoAmount;
    if (localCryptoAmountCopy != null) {
      buffer.writeInt64(localCryptoAmountCopy);
    }

    // Finished serialization.
  }
}

/// Message Action Topic Create.
///
/// ID: `0d999256`.
class MessageActionTopicCreate extends MessageActionBase {
  /// Message Action Topic Create constructor.
  const MessageActionTopicCreate({
    required this.title,
    required this.iconColor,
    this.iconEmojiId,
  }) : super._();

  /// Deserialize.
  factory MessageActionTopicCreate.deserialize(BinaryReader reader) {
    // Read [MessageActionTopicCreate] fields.
    final flags = reader.readInt32();
    final title = reader.readString();
    final iconColor = reader.readInt32();
    final hasIconEmojiIdField = (flags & 1) != 0;
    final iconEmojiId = hasIconEmojiIdField ? reader.readInt64() : null;

    // Construct [MessageActionTopicCreate] object.
    final returnValue = MessageActionTopicCreate(
      title: title,
      iconColor: iconColor,
      iconEmojiId: iconEmojiId,
    );

    // Now return the deserialized [MessageActionTopicCreate].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: iconEmojiId != null,
    );

    return v;
  }

  /// Title.
  final String title;

  /// Icon Color.
  ///
  /// Field type is Int32.
  final int iconColor;

  /// Icon Emoji Id.
  final int? iconEmojiId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0d999256.
    buffer.writeInt32(0x0d999256);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(title);
    buffer.writeInt32(iconColor);
    final localIconEmojiIdCopy = iconEmojiId;
    if (localIconEmojiIdCopy != null) {
      buffer.writeInt64(localIconEmojiIdCopy);
    }

    // Finished serialization.
  }
}

/// Message Action Topic Edit.
///
/// ID: `c0944820`.
class MessageActionTopicEdit extends MessageActionBase {
  /// Message Action Topic Edit constructor.
  const MessageActionTopicEdit({
    this.title,
    this.iconEmojiId,
    required this.closed,
    required this.hidden,
  }) : super._();

  /// Deserialize.
  factory MessageActionTopicEdit.deserialize(BinaryReader reader) {
    // Read [MessageActionTopicEdit] fields.
    final flags = reader.readInt32();
    final hasTitleField = (flags & 1) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasIconEmojiIdField = (flags & 2) != 0;
    final iconEmojiId = hasIconEmojiIdField ? reader.readInt64() : null;
    final closed = (flags & 4) != 0;
    final hidden = (flags & 8) != 0;

    // Construct [MessageActionTopicEdit] object.
    final returnValue = MessageActionTopicEdit(
      title: title,
      iconEmojiId: iconEmojiId,
      closed: closed,
      hidden: hidden,
    );

    // Now return the deserialized [MessageActionTopicEdit].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: title != null,
      b01: iconEmojiId != null,
      b02: closed,
      b03: hidden,
    );

    return v;
  }

  /// Title.
  final String? title;

  /// Icon Emoji Id.
  final int? iconEmojiId;

  /// closed: bit 2 of flags.2?Bool
  final bool closed;

  /// hidden: bit 3 of flags.3?Bool
  final bool hidden;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc0944820.
    buffer.writeInt32(0xc0944820);

    // Write fields.
    buffer.writeInt32(flags);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localIconEmojiIdCopy = iconEmojiId;
    if (localIconEmojiIdCopy != null) {
      buffer.writeInt64(localIconEmojiIdCopy);
    }

    // Finished serialization.
  }
}

/// Message Action Suggest Profile Photo.
///
/// ID: `57de635e`.
class MessageActionSuggestProfilePhoto extends MessageActionBase {
  /// Message Action Suggest Profile Photo constructor.
  const MessageActionSuggestProfilePhoto({
    required this.photo,
  }) : super._();

  /// Deserialize.
  factory MessageActionSuggestProfilePhoto.deserialize(BinaryReader reader) {
    // Read [MessageActionSuggestProfilePhoto] fields.
    final photo = reader.readObject() as PhotoBase;

    // Construct [MessageActionSuggestProfilePhoto] object.
    final returnValue = MessageActionSuggestProfilePhoto(
      photo: photo,
    );

    // Now return the deserialized [MessageActionSuggestProfilePhoto].
    return returnValue;
  }

  /// Photo.
  final PhotoBase photo;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x57de635e.
    buffer.writeInt32(0x57de635e);

    // Write fields.
    buffer.writeObject(photo);

    // Finished serialization.
  }
}

/// Message Action Requested Peer.
///
/// ID: `31518e9b`.
class MessageActionRequestedPeer extends MessageActionBase {
  /// Message Action Requested Peer constructor.
  const MessageActionRequestedPeer({
    required this.buttonId,
    required this.peers,
  }) : super._();

  /// Deserialize.
  factory MessageActionRequestedPeer.deserialize(BinaryReader reader) {
    // Read [MessageActionRequestedPeer] fields.
    final buttonId = reader.readInt32();
    final peers = reader.readVectorObject<PeerBase>();

    // Construct [MessageActionRequestedPeer] object.
    final returnValue = MessageActionRequestedPeer(
      buttonId: buttonId,
      peers: peers,
    );

    // Now return the deserialized [MessageActionRequestedPeer].
    return returnValue;
  }

  /// Button Id.
  ///
  /// Field type is Int32.
  final int buttonId;

  /// Peers.
  final List<PeerBase> peers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x31518e9b.
    buffer.writeInt32(0x31518e9b);

    // Write fields.
    buffer.writeInt32(buttonId);
    buffer.writeVectorObject(peers);

    // Finished serialization.
  }
}

/// Message Action Set Chat Wall Paper.
///
/// ID: `5060a3f4`.
class MessageActionSetChatWallPaper extends MessageActionBase {
  /// Message Action Set Chat Wall Paper constructor.
  const MessageActionSetChatWallPaper({
    required this.same,
    required this.forBoth,
    required this.wallpaper,
  }) : super._();

  /// Deserialize.
  factory MessageActionSetChatWallPaper.deserialize(BinaryReader reader) {
    // Read [MessageActionSetChatWallPaper] fields.
    final flags = reader.readInt32();
    final same = (flags & 1) != 0;
    final forBoth = (flags & 2) != 0;
    final wallpaper = reader.readObject() as WallPaperBase;

    // Construct [MessageActionSetChatWallPaper] object.
    final returnValue = MessageActionSetChatWallPaper(
      same: same,
      forBoth: forBoth,
      wallpaper: wallpaper,
    );

    // Now return the deserialized [MessageActionSetChatWallPaper].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: same,
      b01: forBoth,
    );

    return v;
  }

  /// same: bit 0 of flags.0?true
  final bool same;

  /// for_both: bit 1 of flags.1?true
  final bool forBoth;

  /// Wallpaper.
  final WallPaperBase wallpaper;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5060a3f4.
    buffer.writeInt32(0x5060a3f4);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(wallpaper);

    // Finished serialization.
  }
}

/// Message Action Gift Code.
///
/// ID: `678c2e09`.
class MessageActionGiftCode extends MessageActionBase {
  /// Message Action Gift Code constructor.
  const MessageActionGiftCode({
    required this.viaGiveaway,
    required this.unclaimed,
    this.boostPeer,
    required this.months,
    required this.slug,
    this.currency,
    this.amount,
    this.cryptoCurrency,
    this.cryptoAmount,
  }) : super._();

  /// Deserialize.
  factory MessageActionGiftCode.deserialize(BinaryReader reader) {
    // Read [MessageActionGiftCode] fields.
    final flags = reader.readInt32();
    final viaGiveaway = (flags & 1) != 0;
    final unclaimed = (flags & 4) != 0;
    final hasBoostPeerField = (flags & 2) != 0;
    final boostPeer =
        hasBoostPeerField ? reader.readObject() as PeerBase : null;
    final months = reader.readInt32();
    final slug = reader.readString();
    final hasCurrencyField = (flags & 4) != 0;
    final currency = hasCurrencyField ? reader.readString() : null;
    final hasAmountField = (flags & 4) != 0;
    final amount = hasAmountField ? reader.readInt64() : null;
    final hasCryptoCurrencyField = (flags & 8) != 0;
    final cryptoCurrency = hasCryptoCurrencyField ? reader.readString() : null;
    final hasCryptoAmountField = (flags & 8) != 0;
    final cryptoAmount = hasCryptoAmountField ? reader.readInt64() : null;

    // Construct [MessageActionGiftCode] object.
    final returnValue = MessageActionGiftCode(
      viaGiveaway: viaGiveaway,
      unclaimed: unclaimed,
      boostPeer: boostPeer,
      months: months,
      slug: slug,
      currency: currency,
      amount: amount,
      cryptoCurrency: cryptoCurrency,
      cryptoAmount: cryptoAmount,
    );

    // Now return the deserialized [MessageActionGiftCode].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: viaGiveaway,
      b02: unclaimed || currency != null || amount != null,
      b01: boostPeer != null,
      b03: cryptoCurrency != null || cryptoAmount != null,
    );

    return v;
  }

  /// via_giveaway: bit 0 of flags.0?true
  final bool viaGiveaway;

  /// unclaimed: bit 2 of flags.2?true
  final bool unclaimed;

  /// Boost Peer.
  final PeerBase? boostPeer;

  /// Months.
  ///
  /// Field type is Int32.
  final int months;

  /// Slug.
  final String slug;

  /// Currency.
  final String? currency;

  /// Amount.
  final int? amount;

  /// Crypto Currency.
  final String? cryptoCurrency;

  /// Crypto Amount.
  final int? cryptoAmount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x678c2e09.
    buffer.writeInt32(0x678c2e09);

    // Write fields.
    buffer.writeInt32(flags);
    final localBoostPeerCopy = boostPeer;
    if (localBoostPeerCopy != null) {
      buffer.writeObject(localBoostPeerCopy);
    }
    buffer.writeInt32(months);
    buffer.writeString(slug);
    final localCurrencyCopy = currency;
    if (localCurrencyCopy != null) {
      buffer.writeString(localCurrencyCopy);
    }
    final localAmountCopy = amount;
    if (localAmountCopy != null) {
      buffer.writeInt64(localAmountCopy);
    }
    final localCryptoCurrencyCopy = cryptoCurrency;
    if (localCryptoCurrencyCopy != null) {
      buffer.writeString(localCryptoCurrencyCopy);
    }
    final localCryptoAmountCopy = cryptoAmount;
    if (localCryptoAmountCopy != null) {
      buffer.writeInt64(localCryptoAmountCopy);
    }

    // Finished serialization.
  }
}

/// Message Action Giveaway Launch.
///
/// ID: `332ba9ed`.
class MessageActionGiveawayLaunch extends MessageActionBase {
  /// Message Action Giveaway Launch constructor.
  const MessageActionGiveawayLaunch() : super._();

  /// Deserialize.
  factory MessageActionGiveawayLaunch.deserialize(BinaryReader reader) {
    // Construct [MessageActionGiveawayLaunch] object.
    final returnValue = MessageActionGiveawayLaunch();

    // Now return the deserialized [MessageActionGiveawayLaunch].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x332ba9ed.
    buffer.writeInt32(0x332ba9ed);

    // Finished serialization.
  }
}

/// Message Action Giveaway Results.
///
/// ID: `2a9fadc5`.
class MessageActionGiveawayResults extends MessageActionBase {
  /// Message Action Giveaway Results constructor.
  const MessageActionGiveawayResults({
    required this.winnersCount,
    required this.unclaimedCount,
  }) : super._();

  /// Deserialize.
  factory MessageActionGiveawayResults.deserialize(BinaryReader reader) {
    // Read [MessageActionGiveawayResults] fields.
    final winnersCount = reader.readInt32();
    final unclaimedCount = reader.readInt32();

    // Construct [MessageActionGiveawayResults] object.
    final returnValue = MessageActionGiveawayResults(
      winnersCount: winnersCount,
      unclaimedCount: unclaimedCount,
    );

    // Now return the deserialized [MessageActionGiveawayResults].
    return returnValue;
  }

  /// Winners Count.
  ///
  /// Field type is Int32.
  final int winnersCount;

  /// Unclaimed Count.
  ///
  /// Field type is Int32.
  final int unclaimedCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2a9fadc5.
    buffer.writeInt32(0x2a9fadc5);

    // Write fields.
    buffer.writeInt32(winnersCount);
    buffer.writeInt32(unclaimedCount);

    // Finished serialization.
  }
}

/// Dialog.
///
/// ID: `d58a08c6`.
class Dialog extends DialogBase {
  /// Dialog constructor.
  const Dialog({
    required this.pinned,
    required this.unreadMark,
    required this.viewForumAsMessages,
    required this.peer,
    required this.topMessage,
    required this.readInboxMaxId,
    required this.readOutboxMaxId,
    required this.unreadCount,
    required this.unreadMentionsCount,
    required this.unreadReactionsCount,
    required this.notifySettings,
    this.pts,
    this.draft,
    this.folderId,
    this.ttlPeriod,
  }) : super._();

  /// Deserialize.
  factory Dialog.deserialize(BinaryReader reader) {
    // Read [Dialog] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 4) != 0;
    final unreadMark = (flags & 8) != 0;
    final viewForumAsMessages = (flags & 64) != 0;
    final peer = reader.readObject() as PeerBase;
    final topMessage = reader.readInt32();
    final readInboxMaxId = reader.readInt32();
    final readOutboxMaxId = reader.readInt32();
    final unreadCount = reader.readInt32();
    final unreadMentionsCount = reader.readInt32();
    final unreadReactionsCount = reader.readInt32();
    final notifySettings = reader.readObject() as PeerNotifySettingsBase;
    final hasPtsField = (flags & 1) != 0;
    final pts = hasPtsField ? reader.readInt32() : null;
    final hasDraftField = (flags & 2) != 0;
    final draft =
        hasDraftField ? reader.readObject() as DraftMessageBase : null;
    final hasFolderIdField = (flags & 16) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final hasTtlPeriodField = (flags & 32) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;

    // Construct [Dialog] object.
    final returnValue = Dialog(
      pinned: pinned,
      unreadMark: unreadMark,
      viewForumAsMessages: viewForumAsMessages,
      peer: peer,
      topMessage: topMessage,
      readInboxMaxId: readInboxMaxId,
      readOutboxMaxId: readOutboxMaxId,
      unreadCount: unreadCount,
      unreadMentionsCount: unreadMentionsCount,
      unreadReactionsCount: unreadReactionsCount,
      notifySettings: notifySettings,
      pts: pts,
      draft: draft,
      folderId: folderId,
      ttlPeriod: ttlPeriod,
    );

    // Now return the deserialized [Dialog].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: pinned,
      b03: unreadMark,
      b06: viewForumAsMessages,
      b00: pts != null,
      b01: draft != null,
      b04: folderId != null,
      b05: ttlPeriod != null,
    );

    return v;
  }

  /// pinned: bit 2 of flags.2?true
  final bool pinned;

  /// unread_mark: bit 3 of flags.3?true
  final bool unreadMark;

  /// view_forum_as_messages: bit 6 of flags.6?true
  final bool viewForumAsMessages;

  /// Peer.
  final PeerBase peer;

  /// Top Message.
  ///
  /// Field type is Int32.
  final int topMessage;

  /// Read Inbox Max Id.
  ///
  /// Field type is Int32.
  final int readInboxMaxId;

  /// Read Outbox Max Id.
  ///
  /// Field type is Int32.
  final int readOutboxMaxId;

  /// Unread Count.
  ///
  /// Field type is Int32.
  final int unreadCount;

  /// Unread Mentions Count.
  ///
  /// Field type is Int32.
  final int unreadMentionsCount;

  /// Unread Reactions Count.
  ///
  /// Field type is Int32.
  final int unreadReactionsCount;

  /// Notify Settings.
  final PeerNotifySettingsBase notifySettings;

  /// Pts.
  final int? pts;

  /// Draft.
  final DraftMessageBase? draft;

  /// Folder Id.
  final int? folderId;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd58a08c6.
    buffer.writeInt32(0xd58a08c6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(topMessage);
    buffer.writeInt32(readInboxMaxId);
    buffer.writeInt32(readOutboxMaxId);
    buffer.writeInt32(unreadCount);
    buffer.writeInt32(unreadMentionsCount);
    buffer.writeInt32(unreadReactionsCount);
    buffer.writeObject(notifySettings);
    final localPtsCopy = pts;
    if (localPtsCopy != null) {
      buffer.writeInt32(localPtsCopy);
    }
    final localDraftCopy = draft;
    if (localDraftCopy != null) {
      buffer.writeObject(localDraftCopy);
    }
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }

    // Finished serialization.
  }
}

/// Dialog Folder.
///
/// ID: `71bd134c`.
class DialogFolder extends DialogBase {
  /// Dialog Folder constructor.
  const DialogFolder({
    required this.pinned,
    required this.folder,
    required this.peer,
    required this.topMessage,
    required this.unreadMutedPeersCount,
    required this.unreadUnmutedPeersCount,
    required this.unreadMutedMessagesCount,
    required this.unreadUnmutedMessagesCount,
  }) : super._();

  /// Deserialize.
  factory DialogFolder.deserialize(BinaryReader reader) {
    // Read [DialogFolder] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 4) != 0;
    final folder = reader.readObject() as FolderBase;
    final peer = reader.readObject() as PeerBase;
    final topMessage = reader.readInt32();
    final unreadMutedPeersCount = reader.readInt32();
    final unreadUnmutedPeersCount = reader.readInt32();
    final unreadMutedMessagesCount = reader.readInt32();
    final unreadUnmutedMessagesCount = reader.readInt32();

    // Construct [DialogFolder] object.
    final returnValue = DialogFolder(
      pinned: pinned,
      folder: folder,
      peer: peer,
      topMessage: topMessage,
      unreadMutedPeersCount: unreadMutedPeersCount,
      unreadUnmutedPeersCount: unreadUnmutedPeersCount,
      unreadMutedMessagesCount: unreadMutedMessagesCount,
      unreadUnmutedMessagesCount: unreadUnmutedMessagesCount,
    );

    // Now return the deserialized [DialogFolder].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: pinned,
    );

    return v;
  }

  /// pinned: bit 2 of flags.2?true
  final bool pinned;

  /// Folder.
  final FolderBase folder;

  /// Peer.
  final PeerBase peer;

  /// Top Message.
  ///
  /// Field type is Int32.
  final int topMessage;

  /// Unread Muted Peers Count.
  ///
  /// Field type is Int32.
  final int unreadMutedPeersCount;

  /// Unread Unmuted Peers Count.
  ///
  /// Field type is Int32.
  final int unreadUnmutedPeersCount;

  /// Unread Muted Messages Count.
  ///
  /// Field type is Int32.
  final int unreadMutedMessagesCount;

  /// Unread Unmuted Messages Count.
  ///
  /// Field type is Int32.
  final int unreadUnmutedMessagesCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x71bd134c.
    buffer.writeInt32(0x71bd134c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(folder);
    buffer.writeObject(peer);
    buffer.writeInt32(topMessage);
    buffer.writeInt32(unreadMutedPeersCount);
    buffer.writeInt32(unreadUnmutedPeersCount);
    buffer.writeInt32(unreadMutedMessagesCount);
    buffer.writeInt32(unreadUnmutedMessagesCount);

    // Finished serialization.
  }
}

/// Photo Empty.
///
/// ID: `2331b22d`.
class PhotoEmpty extends PhotoBase {
  /// Photo Empty constructor.
  const PhotoEmpty({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory PhotoEmpty.deserialize(BinaryReader reader) {
    // Read [PhotoEmpty] fields.
    final id = reader.readInt64();

    // Construct [PhotoEmpty] object.
    final returnValue = PhotoEmpty(
      id: id,
    );

    // Now return the deserialized [PhotoEmpty].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2331b22d.
    buffer.writeInt32(0x2331b22d);

    // Write fields.
    buffer.writeInt64(id);

    // Finished serialization.
  }
}

/// Photo.
///
/// ID: `fb197a65`.
class Photo extends PhotoBase {
  /// Photo constructor.
  const Photo({
    required this.hasStickers,
    required this.id,
    required this.accessHash,
    required this.fileReference,
    required this.date,
    required this.sizes,
    this.videoSizes,
    required this.dcId,
  }) : super._();

  /// Deserialize.
  factory Photo.deserialize(BinaryReader reader) {
    // Read [Photo] fields.
    final flags = reader.readInt32();
    final hasStickers = (flags & 1) != 0;
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final fileReference = reader.readBytes();
    final date = reader.readDateTime();
    final sizes = reader.readVectorObject<PhotoSizeBase>();
    final hasVideoSizesField = (flags & 2) != 0;
    final videoSizes =
        hasVideoSizesField ? reader.readVectorObject<VideoSizeBase>() : null;
    final dcId = reader.readInt32();

    // Construct [Photo] object.
    final returnValue = Photo(
      hasStickers: hasStickers,
      id: id,
      accessHash: accessHash,
      fileReference: fileReference,
      date: date,
      sizes: sizes,
      videoSizes: videoSizes,
      dcId: dcId,
    );

    // Now return the deserialized [Photo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: hasStickers,
      b01: videoSizes != null,
    );

    return v;
  }

  /// has_stickers: bit 0 of flags.0?true
  final bool hasStickers;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// File Reference.
  final Uint8List fileReference;

  /// Date.
  final DateTime date;

  /// Sizes.
  final List<PhotoSizeBase> sizes;

  /// Video Sizes.
  final List<VideoSizeBase>? videoSizes;

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfb197a65.
    buffer.writeInt32(0xfb197a65);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeBytes(fileReference);
    buffer.writeDateTime(date);
    buffer.writeVectorObject(sizes);
    final localVideoSizesCopy = videoSizes;
    if (localVideoSizesCopy != null) {
      buffer.writeVectorObject(localVideoSizesCopy);
    }
    buffer.writeInt32(dcId);

    // Finished serialization.
  }
}

/// Photo Size Empty.
///
/// ID: `0e17e23c`.
class PhotoSizeEmpty extends PhotoSizeBase {
  /// Photo Size Empty constructor.
  const PhotoSizeEmpty({
    required this.type,
  }) : super._();

  /// Deserialize.
  factory PhotoSizeEmpty.deserialize(BinaryReader reader) {
    // Read [PhotoSizeEmpty] fields.
    final type = reader.readString();

    // Construct [PhotoSizeEmpty] object.
    final returnValue = PhotoSizeEmpty(
      type: type,
    );

    // Now return the deserialized [PhotoSizeEmpty].
    return returnValue;
  }

  /// Type.
  final String type;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0e17e23c.
    buffer.writeInt32(0x0e17e23c);

    // Write fields.
    buffer.writeString(type);

    // Finished serialization.
  }
}

/// Photo Size.
///
/// ID: `75c78e60`.
class PhotoSize extends PhotoSizeBase {
  /// Photo Size constructor.
  const PhotoSize({
    required this.type,
    required this.w,
    required this.h,
    required this.size,
  }) : super._();

  /// Deserialize.
  factory PhotoSize.deserialize(BinaryReader reader) {
    // Read [PhotoSize] fields.
    final type = reader.readString();
    final w = reader.readInt32();
    final h = reader.readInt32();
    final size = reader.readInt32();

    // Construct [PhotoSize] object.
    final returnValue = PhotoSize(
      type: type,
      w: w,
      h: h,
      size: size,
    );

    // Now return the deserialized [PhotoSize].
    return returnValue;
  }

  /// Type.
  final String type;

  /// W.
  ///
  /// Field type is Int32.
  final int w;

  /// H.
  ///
  /// Field type is Int32.
  final int h;

  /// Size.
  ///
  /// Field type is Int32.
  final int size;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x75c78e60.
    buffer.writeInt32(0x75c78e60);

    // Write fields.
    buffer.writeString(type);
    buffer.writeInt32(w);
    buffer.writeInt32(h);
    buffer.writeInt32(size);

    // Finished serialization.
  }
}

/// Photo Cached Size.
///
/// ID: `021e1ad6`.
class PhotoCachedSize extends PhotoSizeBase {
  /// Photo Cached Size constructor.
  const PhotoCachedSize({
    required this.type,
    required this.w,
    required this.h,
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory PhotoCachedSize.deserialize(BinaryReader reader) {
    // Read [PhotoCachedSize] fields.
    final type = reader.readString();
    final w = reader.readInt32();
    final h = reader.readInt32();
    final bytes = reader.readBytes();

    // Construct [PhotoCachedSize] object.
    final returnValue = PhotoCachedSize(
      type: type,
      w: w,
      h: h,
      bytes: bytes,
    );

    // Now return the deserialized [PhotoCachedSize].
    return returnValue;
  }

  /// Type.
  final String type;

  /// W.
  ///
  /// Field type is Int32.
  final int w;

  /// H.
  ///
  /// Field type is Int32.
  final int h;

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x021e1ad6.
    buffer.writeInt32(0x021e1ad6);

    // Write fields.
    buffer.writeString(type);
    buffer.writeInt32(w);
    buffer.writeInt32(h);
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Photo Stripped Size.
///
/// ID: `e0b0bc2e`.
class PhotoStrippedSize extends PhotoSizeBase {
  /// Photo Stripped Size constructor.
  const PhotoStrippedSize({
    required this.type,
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory PhotoStrippedSize.deserialize(BinaryReader reader) {
    // Read [PhotoStrippedSize] fields.
    final type = reader.readString();
    final bytes = reader.readBytes();

    // Construct [PhotoStrippedSize] object.
    final returnValue = PhotoStrippedSize(
      type: type,
      bytes: bytes,
    );

    // Now return the deserialized [PhotoStrippedSize].
    return returnValue;
  }

  /// Type.
  final String type;

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe0b0bc2e.
    buffer.writeInt32(0xe0b0bc2e);

    // Write fields.
    buffer.writeString(type);
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Photo Size Progressive.
///
/// ID: `fa3efb95`.
class PhotoSizeProgressive extends PhotoSizeBase {
  /// Photo Size Progressive constructor.
  const PhotoSizeProgressive({
    required this.type,
    required this.w,
    required this.h,
    required this.sizes,
  }) : super._();

  /// Deserialize.
  factory PhotoSizeProgressive.deserialize(BinaryReader reader) {
    // Read [PhotoSizeProgressive] fields.
    final type = reader.readString();
    final w = reader.readInt32();
    final h = reader.readInt32();
    final sizes = reader.readVectorInt32();

    // Construct [PhotoSizeProgressive] object.
    final returnValue = PhotoSizeProgressive(
      type: type,
      w: w,
      h: h,
      sizes: sizes,
    );

    // Now return the deserialized [PhotoSizeProgressive].
    return returnValue;
  }

  /// Type.
  final String type;

  /// W.
  ///
  /// Field type is Int32.
  final int w;

  /// H.
  ///
  /// Field type is Int32.
  final int h;

  /// Sizes.
  final List<int> sizes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfa3efb95.
    buffer.writeInt32(0xfa3efb95);

    // Write fields.
    buffer.writeString(type);
    buffer.writeInt32(w);
    buffer.writeInt32(h);
    buffer.writeVectorInt32(sizes);

    // Finished serialization.
  }
}

/// Photo Path Size.
///
/// ID: `d8214d41`.
class PhotoPathSize extends PhotoSizeBase {
  /// Photo Path Size constructor.
  const PhotoPathSize({
    required this.type,
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory PhotoPathSize.deserialize(BinaryReader reader) {
    // Read [PhotoPathSize] fields.
    final type = reader.readString();
    final bytes = reader.readBytes();

    // Construct [PhotoPathSize] object.
    final returnValue = PhotoPathSize(
      type: type,
      bytes: bytes,
    );

    // Now return the deserialized [PhotoPathSize].
    return returnValue;
  }

  /// Type.
  final String type;

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd8214d41.
    buffer.writeInt32(0xd8214d41);

    // Write fields.
    buffer.writeString(type);
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Geo Point Empty.
///
/// ID: `1117dd5f`.
class GeoPointEmpty extends GeoPointBase {
  /// Geo Point Empty constructor.
  const GeoPointEmpty() : super._();

  /// Deserialize.
  factory GeoPointEmpty.deserialize(BinaryReader reader) {
    // Construct [GeoPointEmpty] object.
    final returnValue = GeoPointEmpty();

    // Now return the deserialized [GeoPointEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1117dd5f.
    buffer.writeInt32(0x1117dd5f);

    // Finished serialization.
  }
}

/// Geo Point.
///
/// ID: `b2a2f663`.
class GeoPoint extends GeoPointBase {
  /// Geo Point constructor.
  const GeoPoint({
    required this.long,
    required this.lat,
    required this.accessHash,
    this.accuracyRadius,
  }) : super._();

  /// Deserialize.
  factory GeoPoint.deserialize(BinaryReader reader) {
    // Read [GeoPoint] fields.
    final flags = reader.readInt32();
    final long = reader.readFloat64();
    final lat = reader.readFloat64();
    final accessHash = reader.readInt64();
    final hasAccuracyRadiusField = (flags & 1) != 0;
    final accuracyRadius = hasAccuracyRadiusField ? reader.readInt32() : null;

    // Construct [GeoPoint] object.
    final returnValue = GeoPoint(
      long: long,
      lat: lat,
      accessHash: accessHash,
      accuracyRadius: accuracyRadius,
    );

    // Now return the deserialized [GeoPoint].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: accuracyRadius != null,
    );

    return v;
  }

  /// Long.
  final double long;

  /// Lat.
  final double lat;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Accuracy Radius.
  final int? accuracyRadius;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb2a2f663.
    buffer.writeInt32(0xb2a2f663);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeDouble(long);
    buffer.writeDouble(lat);
    buffer.writeInt64(accessHash);
    final localAccuracyRadiusCopy = accuracyRadius;
    if (localAccuracyRadiusCopy != null) {
      buffer.writeInt32(localAccuracyRadiusCopy);
    }

    // Finished serialization.
  }
}

/// Auth Sent Code.
///
/// ID: `5e002502`.
class AuthSentCode extends AuthSentCodeBase {
  /// Auth Sent Code constructor.
  const AuthSentCode({
    required this.type,
    required this.phoneCodeHash,
    this.nextType,
    this.timeout,
  }) : super._();

  /// Deserialize.
  factory AuthSentCode.deserialize(BinaryReader reader) {
    // Read [AuthSentCode] fields.
    final flags = reader.readInt32();
    final type = reader.readObject() as AuthSentCodeTypeBase;
    final phoneCodeHash = reader.readString();
    final hasNextTypeField = (flags & 2) != 0;
    final nextType =
        hasNextTypeField ? reader.readObject() as AuthCodeTypeBase : null;
    final hasTimeoutField = (flags & 4) != 0;
    final timeout = hasTimeoutField ? reader.readInt32() : null;

    // Construct [AuthSentCode] object.
    final returnValue = AuthSentCode(
      type: type,
      phoneCodeHash: phoneCodeHash,
      nextType: nextType,
      timeout: timeout,
    );

    // Now return the deserialized [AuthSentCode].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: nextType != null,
      b02: timeout != null,
    );

    return v;
  }

  /// Type.
  final AuthSentCodeTypeBase type;

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// Next Type.
  final AuthCodeTypeBase? nextType;

  /// Timeout.
  final int? timeout;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5e002502.
    buffer.writeInt32(0x5e002502);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(type);
    buffer.writeString(phoneCodeHash);
    final localNextTypeCopy = nextType;
    if (localNextTypeCopy != null) {
      buffer.writeObject(localNextTypeCopy);
    }
    final localTimeoutCopy = timeout;
    if (localTimeoutCopy != null) {
      buffer.writeInt32(localTimeoutCopy);
    }

    // Finished serialization.
  }
}

/// Auth Sent Code Success.
///
/// ID: `2390fe44`.
class AuthSentCodeSuccess extends AuthSentCodeBase {
  /// Auth Sent Code Success constructor.
  const AuthSentCodeSuccess({
    required this.authorization,
  }) : super._();

  /// Deserialize.
  factory AuthSentCodeSuccess.deserialize(BinaryReader reader) {
    // Read [AuthSentCodeSuccess] fields.
    final authorization = reader.readObject() as AuthAuthorizationBase;

    // Construct [AuthSentCodeSuccess] object.
    final returnValue = AuthSentCodeSuccess(
      authorization: authorization,
    );

    // Now return the deserialized [AuthSentCodeSuccess].
    return returnValue;
  }

  /// Authorization.
  final AuthAuthorizationBase authorization;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2390fe44.
    buffer.writeInt32(0x2390fe44);

    // Write fields.
    buffer.writeObject(authorization);

    // Finished serialization.
  }
}

/// Auth Authorization.
///
/// ID: `2ea2c0d4`.
class AuthAuthorization extends AuthAuthorizationBase {
  /// Auth Authorization constructor.
  const AuthAuthorization({
    required this.setupPasswordRequired,
    this.otherwiseReloginDays,
    this.tmpSessions,
    this.futureAuthToken,
    required this.user,
  }) : super._();

  /// Deserialize.
  factory AuthAuthorization.deserialize(BinaryReader reader) {
    // Read [AuthAuthorization] fields.
    final flags = reader.readInt32();
    final setupPasswordRequired = (flags & 2) != 0;
    final hasOtherwiseReloginDaysField = (flags & 2) != 0;
    final otherwiseReloginDays =
        hasOtherwiseReloginDaysField ? reader.readInt32() : null;
    final hasTmpSessionsField = (flags & 1) != 0;
    final tmpSessions = hasTmpSessionsField ? reader.readInt32() : null;
    final hasFutureAuthTokenField = (flags & 4) != 0;
    final futureAuthToken = hasFutureAuthTokenField ? reader.readBytes() : null;
    final user = reader.readObject() as UserBase;

    // Construct [AuthAuthorization] object.
    final returnValue = AuthAuthorization(
      setupPasswordRequired: setupPasswordRequired,
      otherwiseReloginDays: otherwiseReloginDays,
      tmpSessions: tmpSessions,
      futureAuthToken: futureAuthToken,
      user: user,
    );

    // Now return the deserialized [AuthAuthorization].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: setupPasswordRequired || otherwiseReloginDays != null,
      b00: tmpSessions != null,
      b02: futureAuthToken != null,
    );

    return v;
  }

  /// setup_password_required: bit 1 of flags.1?true
  final bool setupPasswordRequired;

  /// Otherwise Relogin Days.
  final int? otherwiseReloginDays;

  /// Tmp Sessions.
  final int? tmpSessions;

  /// Future Auth Token.
  final Uint8List? futureAuthToken;

  /// User.
  final UserBase user;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2ea2c0d4.
    buffer.writeInt32(0x2ea2c0d4);

    // Write fields.
    buffer.writeInt32(flags);
    final localOtherwiseReloginDaysCopy = otherwiseReloginDays;
    if (localOtherwiseReloginDaysCopy != null) {
      buffer.writeInt32(localOtherwiseReloginDaysCopy);
    }
    final localTmpSessionsCopy = tmpSessions;
    if (localTmpSessionsCopy != null) {
      buffer.writeInt32(localTmpSessionsCopy);
    }
    final localFutureAuthTokenCopy = futureAuthToken;
    if (localFutureAuthTokenCopy != null) {
      buffer.writeBytes(localFutureAuthTokenCopy);
    }
    buffer.writeObject(user);

    // Finished serialization.
  }
}

/// Auth Authorization Sign Up Required.
///
/// ID: `44747e9a`.
class AuthAuthorizationSignUpRequired extends AuthAuthorizationBase {
  /// Auth Authorization Sign Up Required constructor.
  const AuthAuthorizationSignUpRequired({
    this.termsOfService,
  }) : super._();

  /// Deserialize.
  factory AuthAuthorizationSignUpRequired.deserialize(BinaryReader reader) {
    // Read [AuthAuthorizationSignUpRequired] fields.
    final flags = reader.readInt32();
    final hasTermsOfServiceField = (flags & 1) != 0;
    final termsOfService = hasTermsOfServiceField
        ? reader.readObject() as HelpTermsOfServiceBase
        : null;

    // Construct [AuthAuthorizationSignUpRequired] object.
    final returnValue = AuthAuthorizationSignUpRequired(
      termsOfService: termsOfService,
    );

    // Now return the deserialized [AuthAuthorizationSignUpRequired].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: termsOfService != null,
    );

    return v;
  }

  /// Terms Of Service.
  final HelpTermsOfServiceBase? termsOfService;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x44747e9a.
    buffer.writeInt32(0x44747e9a);

    // Write fields.
    buffer.writeInt32(flags);
    final localTermsOfServiceCopy = termsOfService;
    if (localTermsOfServiceCopy != null) {
      buffer.writeObject(localTermsOfServiceCopy);
    }

    // Finished serialization.
  }
}

/// Auth Exported Authorization.
///
/// ID: `b434e2b8`.
class AuthExportedAuthorization extends AuthExportedAuthorizationBase {
  /// Auth Exported Authorization constructor.
  const AuthExportedAuthorization({
    required this.id,
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory AuthExportedAuthorization.deserialize(BinaryReader reader) {
    // Read [AuthExportedAuthorization] fields.
    final id = reader.readInt64();
    final bytes = reader.readBytes();

    // Construct [AuthExportedAuthorization] object.
    final returnValue = AuthExportedAuthorization(
      id: id,
      bytes: bytes,
    );

    // Now return the deserialized [AuthExportedAuthorization].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb434e2b8.
    buffer.writeInt32(0xb434e2b8);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Input Notify Peer.
///
/// ID: `b8bc5b0c`.
class InputNotifyPeer extends InputNotifyPeerBase {
  /// Input Notify Peer constructor.
  const InputNotifyPeer({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory InputNotifyPeer.deserialize(BinaryReader reader) {
    // Read [InputNotifyPeer] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [InputNotifyPeer] object.
    final returnValue = InputNotifyPeer(
      peer: peer,
    );

    // Now return the deserialized [InputNotifyPeer].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb8bc5b0c.
    buffer.writeInt32(0xb8bc5b0c);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Input Notify Users.
///
/// ID: `193b4417`.
class InputNotifyUsers extends InputNotifyPeerBase {
  /// Input Notify Users constructor.
  const InputNotifyUsers() : super._();

  /// Deserialize.
  factory InputNotifyUsers.deserialize(BinaryReader reader) {
    // Construct [InputNotifyUsers] object.
    final returnValue = InputNotifyUsers();

    // Now return the deserialized [InputNotifyUsers].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x193b4417.
    buffer.writeInt32(0x193b4417);

    // Finished serialization.
  }
}

/// Input Notify Chats.
///
/// ID: `4a95e84e`.
class InputNotifyChats extends InputNotifyPeerBase {
  /// Input Notify Chats constructor.
  const InputNotifyChats() : super._();

  /// Deserialize.
  factory InputNotifyChats.deserialize(BinaryReader reader) {
    // Construct [InputNotifyChats] object.
    final returnValue = InputNotifyChats();

    // Now return the deserialized [InputNotifyChats].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4a95e84e.
    buffer.writeInt32(0x4a95e84e);

    // Finished serialization.
  }
}

/// Input Notify Broadcasts.
///
/// ID: `b1db7c7e`.
class InputNotifyBroadcasts extends InputNotifyPeerBase {
  /// Input Notify Broadcasts constructor.
  const InputNotifyBroadcasts() : super._();

  /// Deserialize.
  factory InputNotifyBroadcasts.deserialize(BinaryReader reader) {
    // Construct [InputNotifyBroadcasts] object.
    final returnValue = InputNotifyBroadcasts();

    // Now return the deserialized [InputNotifyBroadcasts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb1db7c7e.
    buffer.writeInt32(0xb1db7c7e);

    // Finished serialization.
  }
}

/// Input Notify Forum Topic.
///
/// ID: `5c467992`.
class InputNotifyForumTopic extends InputNotifyPeerBase {
  /// Input Notify Forum Topic constructor.
  const InputNotifyForumTopic({
    required this.peer,
    required this.topMsgId,
  }) : super._();

  /// Deserialize.
  factory InputNotifyForumTopic.deserialize(BinaryReader reader) {
    // Read [InputNotifyForumTopic] fields.
    final peer = reader.readObject() as InputPeerBase;
    final topMsgId = reader.readInt32();

    // Construct [InputNotifyForumTopic] object.
    final returnValue = InputNotifyForumTopic(
      peer: peer,
      topMsgId: topMsgId,
    );

    // Now return the deserialized [InputNotifyForumTopic].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Top Msg Id.
  ///
  /// Field type is Int32.
  final int topMsgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5c467992.
    buffer.writeInt32(0x5c467992);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(topMsgId);

    // Finished serialization.
  }
}

/// Input Peer Notify Settings.
///
/// ID: `cacb6ae2`.
class InputPeerNotifySettings extends InputPeerNotifySettingsBase {
  /// Input Peer Notify Settings constructor.
  const InputPeerNotifySettings({
    required this.showPreviews,
    required this.silent,
    this.muteUntil,
    this.sound,
    required this.storiesMuted,
    required this.storiesHideSender,
    this.storiesSound,
  }) : super._();

  /// Deserialize.
  factory InputPeerNotifySettings.deserialize(BinaryReader reader) {
    // Read [InputPeerNotifySettings] fields.
    final flags = reader.readInt32();
    final showPreviews = (flags & 1) != 0;
    final silent = (flags & 2) != 0;
    final hasMuteUntilField = (flags & 4) != 0;
    final muteUntil = hasMuteUntilField ? reader.readDateTime() : null;
    final hasSoundField = (flags & 8) != 0;
    final sound =
        hasSoundField ? reader.readObject() as NotificationSoundBase : null;
    final storiesMuted = (flags & 64) != 0;
    final storiesHideSender = (flags & 128) != 0;
    final hasStoriesSoundField = (flags & 256) != 0;
    final storiesSound = hasStoriesSoundField
        ? reader.readObject() as NotificationSoundBase
        : null;

    // Construct [InputPeerNotifySettings] object.
    final returnValue = InputPeerNotifySettings(
      showPreviews: showPreviews,
      silent: silent,
      muteUntil: muteUntil,
      sound: sound,
      storiesMuted: storiesMuted,
      storiesHideSender: storiesHideSender,
      storiesSound: storiesSound,
    );

    // Now return the deserialized [InputPeerNotifySettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: showPreviews,
      b01: silent,
      b02: muteUntil != null,
      b03: sound != null,
      b06: storiesMuted,
      b07: storiesHideSender,
      b08: storiesSound != null,
    );

    return v;
  }

  /// show_previews: bit 0 of flags.0?Bool
  final bool showPreviews;

  /// silent: bit 1 of flags.1?Bool
  final bool silent;

  /// Mute Until.
  final DateTime? muteUntil;

  /// Sound.
  final NotificationSoundBase? sound;

  /// stories_muted: bit 6 of flags.6?Bool
  final bool storiesMuted;

  /// stories_hide_sender: bit 7 of flags.7?Bool
  final bool storiesHideSender;

  /// Stories Sound.
  final NotificationSoundBase? storiesSound;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcacb6ae2.
    buffer.writeInt32(0xcacb6ae2);

    // Write fields.
    buffer.writeInt32(flags);
    final localMuteUntilCopy = muteUntil;
    if (localMuteUntilCopy != null) {
      buffer.writeDateTime(localMuteUntilCopy);
    }
    final localSoundCopy = sound;
    if (localSoundCopy != null) {
      buffer.writeObject(localSoundCopy);
    }
    final localStoriesSoundCopy = storiesSound;
    if (localStoriesSoundCopy != null) {
      buffer.writeObject(localStoriesSoundCopy);
    }

    // Finished serialization.
  }
}

/// Peer Notify Settings.
///
/// ID: `99622c0c`.
class PeerNotifySettings extends PeerNotifySettingsBase {
  /// Peer Notify Settings constructor.
  const PeerNotifySettings({
    required this.showPreviews,
    required this.silent,
    this.muteUntil,
    this.iosSound,
    this.androidSound,
    this.otherSound,
    required this.storiesMuted,
    required this.storiesHideSender,
    this.storiesIosSound,
    this.storiesAndroidSound,
    this.storiesOtherSound,
  }) : super._();

  /// Deserialize.
  factory PeerNotifySettings.deserialize(BinaryReader reader) {
    // Read [PeerNotifySettings] fields.
    final flags = reader.readInt32();
    final showPreviews = (flags & 1) != 0;
    final silent = (flags & 2) != 0;
    final hasMuteUntilField = (flags & 4) != 0;
    final muteUntil = hasMuteUntilField ? reader.readDateTime() : null;
    final hasIosSoundField = (flags & 8) != 0;
    final iosSound =
        hasIosSoundField ? reader.readObject() as NotificationSoundBase : null;
    final hasAndroidSoundField = (flags & 16) != 0;
    final androidSound = hasAndroidSoundField
        ? reader.readObject() as NotificationSoundBase
        : null;
    final hasOtherSoundField = (flags & 32) != 0;
    final otherSound = hasOtherSoundField
        ? reader.readObject() as NotificationSoundBase
        : null;
    final storiesMuted = (flags & 64) != 0;
    final storiesHideSender = (flags & 128) != 0;
    final hasStoriesIosSoundField = (flags & 256) != 0;
    final storiesIosSound = hasStoriesIosSoundField
        ? reader.readObject() as NotificationSoundBase
        : null;
    final hasStoriesAndroidSoundField = (flags & 512) != 0;
    final storiesAndroidSound = hasStoriesAndroidSoundField
        ? reader.readObject() as NotificationSoundBase
        : null;
    final hasStoriesOtherSoundField = (flags & 1024) != 0;
    final storiesOtherSound = hasStoriesOtherSoundField
        ? reader.readObject() as NotificationSoundBase
        : null;

    // Construct [PeerNotifySettings] object.
    final returnValue = PeerNotifySettings(
      showPreviews: showPreviews,
      silent: silent,
      muteUntil: muteUntil,
      iosSound: iosSound,
      androidSound: androidSound,
      otherSound: otherSound,
      storiesMuted: storiesMuted,
      storiesHideSender: storiesHideSender,
      storiesIosSound: storiesIosSound,
      storiesAndroidSound: storiesAndroidSound,
      storiesOtherSound: storiesOtherSound,
    );

    // Now return the deserialized [PeerNotifySettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: showPreviews,
      b01: silent,
      b02: muteUntil != null,
      b03: iosSound != null,
      b04: androidSound != null,
      b05: otherSound != null,
      b06: storiesMuted,
      b07: storiesHideSender,
      b08: storiesIosSound != null,
      b09: storiesAndroidSound != null,
      b10: storiesOtherSound != null,
    );

    return v;
  }

  /// show_previews: bit 0 of flags.0?Bool
  final bool showPreviews;

  /// silent: bit 1 of flags.1?Bool
  final bool silent;

  /// Mute Until.
  final DateTime? muteUntil;

  /// Ios Sound.
  final NotificationSoundBase? iosSound;

  /// Android Sound.
  final NotificationSoundBase? androidSound;

  /// Other Sound.
  final NotificationSoundBase? otherSound;

  /// stories_muted: bit 6 of flags.6?Bool
  final bool storiesMuted;

  /// stories_hide_sender: bit 7 of flags.7?Bool
  final bool storiesHideSender;

  /// Stories Ios Sound.
  final NotificationSoundBase? storiesIosSound;

  /// Stories Android Sound.
  final NotificationSoundBase? storiesAndroidSound;

  /// Stories Other Sound.
  final NotificationSoundBase? storiesOtherSound;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x99622c0c.
    buffer.writeInt32(0x99622c0c);

    // Write fields.
    buffer.writeInt32(flags);
    final localMuteUntilCopy = muteUntil;
    if (localMuteUntilCopy != null) {
      buffer.writeDateTime(localMuteUntilCopy);
    }
    final localIosSoundCopy = iosSound;
    if (localIosSoundCopy != null) {
      buffer.writeObject(localIosSoundCopy);
    }
    final localAndroidSoundCopy = androidSound;
    if (localAndroidSoundCopy != null) {
      buffer.writeObject(localAndroidSoundCopy);
    }
    final localOtherSoundCopy = otherSound;
    if (localOtherSoundCopy != null) {
      buffer.writeObject(localOtherSoundCopy);
    }
    final localStoriesIosSoundCopy = storiesIosSound;
    if (localStoriesIosSoundCopy != null) {
      buffer.writeObject(localStoriesIosSoundCopy);
    }
    final localStoriesAndroidSoundCopy = storiesAndroidSound;
    if (localStoriesAndroidSoundCopy != null) {
      buffer.writeObject(localStoriesAndroidSoundCopy);
    }
    final localStoriesOtherSoundCopy = storiesOtherSound;
    if (localStoriesOtherSoundCopy != null) {
      buffer.writeObject(localStoriesOtherSoundCopy);
    }

    // Finished serialization.
  }
}

/// Peer Settings.
///
/// ID: `a518110d`.
class PeerSettings extends PeerSettingsBase {
  /// Peer Settings constructor.
  const PeerSettings({
    required this.reportSpam,
    required this.addContact,
    required this.blockContact,
    required this.shareContact,
    required this.needContactsException,
    required this.reportGeo,
    required this.autoarchived,
    required this.inviteMembers,
    required this.requestChatBroadcast,
    this.geoDistance,
    this.requestChatTitle,
    this.requestChatDate,
  }) : super._();

  /// Deserialize.
  factory PeerSettings.deserialize(BinaryReader reader) {
    // Read [PeerSettings] fields.
    final flags = reader.readInt32();
    final reportSpam = (flags & 1) != 0;
    final addContact = (flags & 2) != 0;
    final blockContact = (flags & 4) != 0;
    final shareContact = (flags & 8) != 0;
    final needContactsException = (flags & 16) != 0;
    final reportGeo = (flags & 32) != 0;
    final autoarchived = (flags & 128) != 0;
    final inviteMembers = (flags & 256) != 0;
    final requestChatBroadcast = (flags & 1024) != 0;
    final hasGeoDistanceField = (flags & 64) != 0;
    final geoDistance = hasGeoDistanceField ? reader.readInt32() : null;
    final hasRequestChatTitleField = (flags & 512) != 0;
    final requestChatTitle =
        hasRequestChatTitleField ? reader.readString() : null;
    final hasRequestChatDateField = (flags & 512) != 0;
    final requestChatDate =
        hasRequestChatDateField ? reader.readDateTime() : null;

    // Construct [PeerSettings] object.
    final returnValue = PeerSettings(
      reportSpam: reportSpam,
      addContact: addContact,
      blockContact: blockContact,
      shareContact: shareContact,
      needContactsException: needContactsException,
      reportGeo: reportGeo,
      autoarchived: autoarchived,
      inviteMembers: inviteMembers,
      requestChatBroadcast: requestChatBroadcast,
      geoDistance: geoDistance,
      requestChatTitle: requestChatTitle,
      requestChatDate: requestChatDate,
    );

    // Now return the deserialized [PeerSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: reportSpam,
      b01: addContact,
      b02: blockContact,
      b03: shareContact,
      b04: needContactsException,
      b05: reportGeo,
      b07: autoarchived,
      b08: inviteMembers,
      b10: requestChatBroadcast,
      b06: geoDistance != null,
      b09: requestChatTitle != null || requestChatDate != null,
    );

    return v;
  }

  /// report_spam: bit 0 of flags.0?true
  final bool reportSpam;

  /// add_contact: bit 1 of flags.1?true
  final bool addContact;

  /// block_contact: bit 2 of flags.2?true
  final bool blockContact;

  /// share_contact: bit 3 of flags.3?true
  final bool shareContact;

  /// need_contacts_exception: bit 4 of flags.4?true
  final bool needContactsException;

  /// report_geo: bit 5 of flags.5?true
  final bool reportGeo;

  /// autoarchived: bit 7 of flags.7?true
  final bool autoarchived;

  /// invite_members: bit 8 of flags.8?true
  final bool inviteMembers;

  /// request_chat_broadcast: bit 10 of flags.10?true
  final bool requestChatBroadcast;

  /// Geo Distance.
  final int? geoDistance;

  /// Request Chat Title.
  final String? requestChatTitle;

  /// Request Chat Date.
  final DateTime? requestChatDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa518110d.
    buffer.writeInt32(0xa518110d);

    // Write fields.
    buffer.writeInt32(flags);
    final localGeoDistanceCopy = geoDistance;
    if (localGeoDistanceCopy != null) {
      buffer.writeInt32(localGeoDistanceCopy);
    }
    final localRequestChatTitleCopy = requestChatTitle;
    if (localRequestChatTitleCopy != null) {
      buffer.writeString(localRequestChatTitleCopy);
    }
    final localRequestChatDateCopy = requestChatDate;
    if (localRequestChatDateCopy != null) {
      buffer.writeDateTime(localRequestChatDateCopy);
    }

    // Finished serialization.
  }
}

/// Wall Paper.
///
/// ID: `a437c3ed`.
class WallPaper extends WallPaperBase {
  /// Wall Paper constructor.
  const WallPaper({
    required this.id,
    required this.creator,
    required this.ddefault,
    required this.pattern,
    required this.dark,
    required this.accessHash,
    required this.slug,
    required this.document,
    this.settings,
  }) : super._();

  /// Deserialize.
  factory WallPaper.deserialize(BinaryReader reader) {
    // Read [WallPaper] fields.
    final id = reader.readInt64();
    final flags = reader.readInt32();
    final creator = (flags & 1) != 0;
    final ddefault = (flags & 2) != 0;
    final pattern = (flags & 8) != 0;
    final dark = (flags & 16) != 0;
    final accessHash = reader.readInt64();
    final slug = reader.readString();
    final document = reader.readObject() as DocumentBase;
    final hasSettingsField = (flags & 4) != 0;
    final settings =
        hasSettingsField ? reader.readObject() as WallPaperSettingsBase : null;

    // Construct [WallPaper] object.
    final returnValue = WallPaper(
      id: id,
      creator: creator,
      ddefault: ddefault,
      pattern: pattern,
      dark: dark,
      accessHash: accessHash,
      slug: slug,
      document: document,
      settings: settings,
    );

    // Now return the deserialized [WallPaper].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: creator,
      b01: ddefault,
      b03: pattern,
      b04: dark,
      b02: settings != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// creator: bit 0 of flags.0?true
  final bool creator;

  /// default: bit 1 of flags.1?true
  final bool ddefault;

  /// pattern: bit 3 of flags.3?true
  final bool pattern;

  /// dark: bit 4 of flags.4?true
  final bool dark;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Slug.
  final String slug;

  /// Document.
  final DocumentBase document;

  /// Settings.
  final WallPaperSettingsBase? settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa437c3ed.
    buffer.writeInt32(0xa437c3ed);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt32(flags);
    buffer.writeInt64(accessHash);
    buffer.writeString(slug);
    buffer.writeObject(document);
    final localSettingsCopy = settings;
    if (localSettingsCopy != null) {
      buffer.writeObject(localSettingsCopy);
    }

    // Finished serialization.
  }
}

/// Wall Paper No File.
///
/// ID: `e0804116`.
class WallPaperNoFile extends WallPaperBase {
  /// Wall Paper No File constructor.
  const WallPaperNoFile({
    required this.id,
    required this.ddefault,
    required this.dark,
    this.settings,
  }) : super._();

  /// Deserialize.
  factory WallPaperNoFile.deserialize(BinaryReader reader) {
    // Read [WallPaperNoFile] fields.
    final id = reader.readInt64();
    final flags = reader.readInt32();
    final ddefault = (flags & 2) != 0;
    final dark = (flags & 16) != 0;
    final hasSettingsField = (flags & 4) != 0;
    final settings =
        hasSettingsField ? reader.readObject() as WallPaperSettingsBase : null;

    // Construct [WallPaperNoFile] object.
    final returnValue = WallPaperNoFile(
      id: id,
      ddefault: ddefault,
      dark: dark,
      settings: settings,
    );

    // Now return the deserialized [WallPaperNoFile].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: ddefault,
      b04: dark,
      b02: settings != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// default: bit 1 of flags.1?true
  final bool ddefault;

  /// dark: bit 4 of flags.4?true
  final bool dark;

  /// Settings.
  final WallPaperSettingsBase? settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe0804116.
    buffer.writeInt32(0xe0804116);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt32(flags);
    final localSettingsCopy = settings;
    if (localSettingsCopy != null) {
      buffer.writeObject(localSettingsCopy);
    }

    // Finished serialization.
  }
}

/// Input Report Reason Spam.
///
/// ID: `58dbcab8`.
class InputReportReasonSpam extends ReportReasonBase {
  /// Input Report Reason Spam constructor.
  const InputReportReasonSpam() : super._();

  /// Deserialize.
  factory InputReportReasonSpam.deserialize(BinaryReader reader) {
    // Construct [InputReportReasonSpam] object.
    final returnValue = InputReportReasonSpam();

    // Now return the deserialized [InputReportReasonSpam].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x58dbcab8.
    buffer.writeInt32(0x58dbcab8);

    // Finished serialization.
  }
}

/// Input Report Reason Violence.
///
/// ID: `1e22c78d`.
class InputReportReasonViolence extends ReportReasonBase {
  /// Input Report Reason Violence constructor.
  const InputReportReasonViolence() : super._();

  /// Deserialize.
  factory InputReportReasonViolence.deserialize(BinaryReader reader) {
    // Construct [InputReportReasonViolence] object.
    final returnValue = InputReportReasonViolence();

    // Now return the deserialized [InputReportReasonViolence].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1e22c78d.
    buffer.writeInt32(0x1e22c78d);

    // Finished serialization.
  }
}

/// Input Report Reason Pornography.
///
/// ID: `2e59d922`.
class InputReportReasonPornography extends ReportReasonBase {
  /// Input Report Reason Pornography constructor.
  const InputReportReasonPornography() : super._();

  /// Deserialize.
  factory InputReportReasonPornography.deserialize(BinaryReader reader) {
    // Construct [InputReportReasonPornography] object.
    final returnValue = InputReportReasonPornography();

    // Now return the deserialized [InputReportReasonPornography].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2e59d922.
    buffer.writeInt32(0x2e59d922);

    // Finished serialization.
  }
}

/// Input Report Reason Child Abuse.
///
/// ID: `adf44ee3`.
class InputReportReasonChildAbuse extends ReportReasonBase {
  /// Input Report Reason Child Abuse constructor.
  const InputReportReasonChildAbuse() : super._();

  /// Deserialize.
  factory InputReportReasonChildAbuse.deserialize(BinaryReader reader) {
    // Construct [InputReportReasonChildAbuse] object.
    final returnValue = InputReportReasonChildAbuse();

    // Now return the deserialized [InputReportReasonChildAbuse].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xadf44ee3.
    buffer.writeInt32(0xadf44ee3);

    // Finished serialization.
  }
}

/// Input Report Reason Other.
///
/// ID: `c1e4a2b1`.
class InputReportReasonOther extends ReportReasonBase {
  /// Input Report Reason Other constructor.
  const InputReportReasonOther() : super._();

  /// Deserialize.
  factory InputReportReasonOther.deserialize(BinaryReader reader) {
    // Construct [InputReportReasonOther] object.
    final returnValue = InputReportReasonOther();

    // Now return the deserialized [InputReportReasonOther].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc1e4a2b1.
    buffer.writeInt32(0xc1e4a2b1);

    // Finished serialization.
  }
}

/// Input Report Reason Copyright.
///
/// ID: `9b89f93a`.
class InputReportReasonCopyright extends ReportReasonBase {
  /// Input Report Reason Copyright constructor.
  const InputReportReasonCopyright() : super._();

  /// Deserialize.
  factory InputReportReasonCopyright.deserialize(BinaryReader reader) {
    // Construct [InputReportReasonCopyright] object.
    final returnValue = InputReportReasonCopyright();

    // Now return the deserialized [InputReportReasonCopyright].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9b89f93a.
    buffer.writeInt32(0x9b89f93a);

    // Finished serialization.
  }
}

/// Input Report Reason Geo Irrelevant.
///
/// ID: `dbd4feed`.
class InputReportReasonGeoIrrelevant extends ReportReasonBase {
  /// Input Report Reason Geo Irrelevant constructor.
  const InputReportReasonGeoIrrelevant() : super._();

  /// Deserialize.
  factory InputReportReasonGeoIrrelevant.deserialize(BinaryReader reader) {
    // Construct [InputReportReasonGeoIrrelevant] object.
    final returnValue = InputReportReasonGeoIrrelevant();

    // Now return the deserialized [InputReportReasonGeoIrrelevant].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdbd4feed.
    buffer.writeInt32(0xdbd4feed);

    // Finished serialization.
  }
}

/// Input Report Reason Fake.
///
/// ID: `f5ddd6e7`.
class InputReportReasonFake extends ReportReasonBase {
  /// Input Report Reason Fake constructor.
  const InputReportReasonFake() : super._();

  /// Deserialize.
  factory InputReportReasonFake.deserialize(BinaryReader reader) {
    // Construct [InputReportReasonFake] object.
    final returnValue = InputReportReasonFake();

    // Now return the deserialized [InputReportReasonFake].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf5ddd6e7.
    buffer.writeInt32(0xf5ddd6e7);

    // Finished serialization.
  }
}

/// Input Report Reason Illegal Drugs.
///
/// ID: `0a8eb2be`.
class InputReportReasonIllegalDrugs extends ReportReasonBase {
  /// Input Report Reason Illegal Drugs constructor.
  const InputReportReasonIllegalDrugs() : super._();

  /// Deserialize.
  factory InputReportReasonIllegalDrugs.deserialize(BinaryReader reader) {
    // Construct [InputReportReasonIllegalDrugs] object.
    final returnValue = InputReportReasonIllegalDrugs();

    // Now return the deserialized [InputReportReasonIllegalDrugs].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0a8eb2be.
    buffer.writeInt32(0x0a8eb2be);

    // Finished serialization.
  }
}

/// Input Report Reason Personal Details.
///
/// ID: `9ec7863d`.
class InputReportReasonPersonalDetails extends ReportReasonBase {
  /// Input Report Reason Personal Details constructor.
  const InputReportReasonPersonalDetails() : super._();

  /// Deserialize.
  factory InputReportReasonPersonalDetails.deserialize(BinaryReader reader) {
    // Construct [InputReportReasonPersonalDetails] object.
    final returnValue = InputReportReasonPersonalDetails();

    // Now return the deserialized [InputReportReasonPersonalDetails].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9ec7863d.
    buffer.writeInt32(0x9ec7863d);

    // Finished serialization.
  }
}

/// User Full.
///
/// ID: `b9b12c6c`.
class UserFull extends UserFullBase {
  /// User Full constructor.
  const UserFull({
    required this.blocked,
    required this.phoneCallsAvailable,
    required this.phoneCallsPrivate,
    required this.canPinMessage,
    required this.hasScheduled,
    required this.videoCallsAvailable,
    required this.voiceMessagesForbidden,
    required this.translationsDisabled,
    required this.storiesPinnedAvailable,
    required this.blockedMyStoriesFrom,
    required this.wallpaperOverridden,
    required this.id,
    this.about,
    required this.settings,
    this.personalPhoto,
    this.profilePhoto,
    this.fallbackPhoto,
    required this.notifySettings,
    this.botInfo,
    this.pinnedMsgId,
    required this.commonChatsCount,
    this.folderId,
    this.ttlPeriod,
    this.themeEmoticon,
    this.privateForwardName,
    this.botGroupAdminRights,
    this.botBroadcastAdminRights,
    this.premiumGifts,
    this.wallpaper,
    this.stories,
  }) : super._();

  /// Deserialize.
  factory UserFull.deserialize(BinaryReader reader) {
    // Read [UserFull] fields.
    final flags = reader.readInt32();
    final blocked = (flags & 1) != 0;
    final phoneCallsAvailable = (flags & 16) != 0;
    final phoneCallsPrivate = (flags & 32) != 0;
    final canPinMessage = (flags & 128) != 0;
    final hasScheduled = (flags & 4096) != 0;
    final videoCallsAvailable = (flags & 8192) != 0;
    final voiceMessagesForbidden = (flags & 1048576) != 0;
    final translationsDisabled = (flags & 8388608) != 0;
    final storiesPinnedAvailable = (flags & 67108864) != 0;
    final blockedMyStoriesFrom = (flags & 134217728) != 0;
    final wallpaperOverridden = (flags & 268435456) != 0;
    final id = reader.readInt64();
    final hasAboutField = (flags & 2) != 0;
    final about = hasAboutField ? reader.readString() : null;
    final settings = reader.readObject() as PeerSettingsBase;
    final hasPersonalPhotoField = (flags & 2097152) != 0;
    final personalPhoto =
        hasPersonalPhotoField ? reader.readObject() as PhotoBase : null;
    final hasProfilePhotoField = (flags & 4) != 0;
    final profilePhoto =
        hasProfilePhotoField ? reader.readObject() as PhotoBase : null;
    final hasFallbackPhotoField = (flags & 4194304) != 0;
    final fallbackPhoto =
        hasFallbackPhotoField ? reader.readObject() as PhotoBase : null;
    final notifySettings = reader.readObject() as PeerNotifySettingsBase;
    final hasBotInfoField = (flags & 8) != 0;
    final botInfo = hasBotInfoField ? reader.readObject() as BotInfoBase : null;
    final hasPinnedMsgIdField = (flags & 64) != 0;
    final pinnedMsgId = hasPinnedMsgIdField ? reader.readInt32() : null;
    final commonChatsCount = reader.readInt32();
    final hasFolderIdField = (flags & 2048) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final hasTtlPeriodField = (flags & 16384) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;
    final hasThemeEmoticonField = (flags & 32768) != 0;
    final themeEmoticon = hasThemeEmoticonField ? reader.readString() : null;
    final hasPrivateForwardNameField = (flags & 65536) != 0;
    final privateForwardName =
        hasPrivateForwardNameField ? reader.readString() : null;
    final hasBotGroupAdminRightsField = (flags & 131072) != 0;
    final botGroupAdminRights = hasBotGroupAdminRightsField
        ? reader.readObject() as ChatAdminRightsBase
        : null;
    final hasBotBroadcastAdminRightsField = (flags & 262144) != 0;
    final botBroadcastAdminRights = hasBotBroadcastAdminRightsField
        ? reader.readObject() as ChatAdminRightsBase
        : null;
    final hasPremiumGiftsField = (flags & 524288) != 0;
    final premiumGifts = hasPremiumGiftsField
        ? reader.readVectorObject<PremiumGiftOptionBase>()
        : null;
    final hasWallpaperField = (flags & 16777216) != 0;
    final wallpaper =
        hasWallpaperField ? reader.readObject() as WallPaperBase : null;
    final hasStoriesField = (flags & 33554432) != 0;
    final stories =
        hasStoriesField ? reader.readObject() as PeerStoriesBase : null;

    // Construct [UserFull] object.
    final returnValue = UserFull(
      blocked: blocked,
      phoneCallsAvailable: phoneCallsAvailable,
      phoneCallsPrivate: phoneCallsPrivate,
      canPinMessage: canPinMessage,
      hasScheduled: hasScheduled,
      videoCallsAvailable: videoCallsAvailable,
      voiceMessagesForbidden: voiceMessagesForbidden,
      translationsDisabled: translationsDisabled,
      storiesPinnedAvailable: storiesPinnedAvailable,
      blockedMyStoriesFrom: blockedMyStoriesFrom,
      wallpaperOverridden: wallpaperOverridden,
      id: id,
      about: about,
      settings: settings,
      personalPhoto: personalPhoto,
      profilePhoto: profilePhoto,
      fallbackPhoto: fallbackPhoto,
      notifySettings: notifySettings,
      botInfo: botInfo,
      pinnedMsgId: pinnedMsgId,
      commonChatsCount: commonChatsCount,
      folderId: folderId,
      ttlPeriod: ttlPeriod,
      themeEmoticon: themeEmoticon,
      privateForwardName: privateForwardName,
      botGroupAdminRights: botGroupAdminRights,
      botBroadcastAdminRights: botBroadcastAdminRights,
      premiumGifts: premiumGifts,
      wallpaper: wallpaper,
      stories: stories,
    );

    // Now return the deserialized [UserFull].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: blocked,
      b04: phoneCallsAvailable,
      b05: phoneCallsPrivate,
      b07: canPinMessage,
      b12: hasScheduled,
      b13: videoCallsAvailable,
      b20: voiceMessagesForbidden,
      b23: translationsDisabled,
      b26: storiesPinnedAvailable,
      b27: blockedMyStoriesFrom,
      b28: wallpaperOverridden,
      b01: about != null,
      b21: personalPhoto != null,
      b02: profilePhoto != null,
      b22: fallbackPhoto != null,
      b03: botInfo != null,
      b06: pinnedMsgId != null,
      b11: folderId != null,
      b14: ttlPeriod != null,
      b15: themeEmoticon != null,
      b16: privateForwardName != null,
      b17: botGroupAdminRights != null,
      b18: botBroadcastAdminRights != null,
      b19: premiumGifts != null,
      b24: wallpaper != null,
      b25: stories != null,
    );

    return v;
  }

  /// blocked: bit 0 of flags.0?true
  final bool blocked;

  /// phone_calls_available: bit 4 of flags.4?true
  final bool phoneCallsAvailable;

  /// phone_calls_private: bit 5 of flags.5?true
  final bool phoneCallsPrivate;

  /// can_pin_message: bit 7 of flags.7?true
  final bool canPinMessage;

  /// has_scheduled: bit 12 of flags.12?true
  final bool hasScheduled;

  /// video_calls_available: bit 13 of flags.13?true
  final bool videoCallsAvailable;

  /// voice_messages_forbidden: bit 20 of flags.20?true
  final bool voiceMessagesForbidden;

  /// translations_disabled: bit 23 of flags.23?true
  final bool translationsDisabled;

  /// stories_pinned_available: bit 26 of flags.26?true
  final bool storiesPinnedAvailable;

  /// blocked_my_stories_from: bit 27 of flags.27?true
  final bool blockedMyStoriesFrom;

  /// wallpaper_overridden: bit 28 of flags.28?true
  final bool wallpaperOverridden;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// About.
  final String? about;

  /// Settings.
  final PeerSettingsBase settings;

  /// Personal Photo.
  final PhotoBase? personalPhoto;

  /// Profile Photo.
  final PhotoBase? profilePhoto;

  /// Fallback Photo.
  final PhotoBase? fallbackPhoto;

  /// Notify Settings.
  final PeerNotifySettingsBase notifySettings;

  /// Bot Info.
  final BotInfoBase? botInfo;

  /// Pinned Msg Id.
  final int? pinnedMsgId;

  /// Common Chats Count.
  ///
  /// Field type is Int32.
  final int commonChatsCount;

  /// Folder Id.
  final int? folderId;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Theme Emoticon.
  final String? themeEmoticon;

  /// Private Forward Name.
  final String? privateForwardName;

  /// Bot Group Admin Rights.
  final ChatAdminRightsBase? botGroupAdminRights;

  /// Bot Broadcast Admin Rights.
  final ChatAdminRightsBase? botBroadcastAdminRights;

  /// Premium Gifts.
  final List<PremiumGiftOptionBase>? premiumGifts;

  /// Wallpaper.
  final WallPaperBase? wallpaper;

  /// Stories.
  final PeerStoriesBase? stories;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb9b12c6c.
    buffer.writeInt32(0xb9b12c6c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    final localAboutCopy = about;
    if (localAboutCopy != null) {
      buffer.writeString(localAboutCopy);
    }
    buffer.writeObject(settings);
    final localPersonalPhotoCopy = personalPhoto;
    if (localPersonalPhotoCopy != null) {
      buffer.writeObject(localPersonalPhotoCopy);
    }
    final localProfilePhotoCopy = profilePhoto;
    if (localProfilePhotoCopy != null) {
      buffer.writeObject(localProfilePhotoCopy);
    }
    final localFallbackPhotoCopy = fallbackPhoto;
    if (localFallbackPhotoCopy != null) {
      buffer.writeObject(localFallbackPhotoCopy);
    }
    buffer.writeObject(notifySettings);
    final localBotInfoCopy = botInfo;
    if (localBotInfoCopy != null) {
      buffer.writeObject(localBotInfoCopy);
    }
    final localPinnedMsgIdCopy = pinnedMsgId;
    if (localPinnedMsgIdCopy != null) {
      buffer.writeInt32(localPinnedMsgIdCopy);
    }
    buffer.writeInt32(commonChatsCount);
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }
    final localThemeEmoticonCopy = themeEmoticon;
    if (localThemeEmoticonCopy != null) {
      buffer.writeString(localThemeEmoticonCopy);
    }
    final localPrivateForwardNameCopy = privateForwardName;
    if (localPrivateForwardNameCopy != null) {
      buffer.writeString(localPrivateForwardNameCopy);
    }
    final localBotGroupAdminRightsCopy = botGroupAdminRights;
    if (localBotGroupAdminRightsCopy != null) {
      buffer.writeObject(localBotGroupAdminRightsCopy);
    }
    final localBotBroadcastAdminRightsCopy = botBroadcastAdminRights;
    if (localBotBroadcastAdminRightsCopy != null) {
      buffer.writeObject(localBotBroadcastAdminRightsCopy);
    }
    final localPremiumGiftsCopy = premiumGifts;
    if (localPremiumGiftsCopy != null) {
      buffer.writeVectorObject(localPremiumGiftsCopy);
    }
    final localWallpaperCopy = wallpaper;
    if (localWallpaperCopy != null) {
      buffer.writeObject(localWallpaperCopy);
    }
    final localStoriesCopy = stories;
    if (localStoriesCopy != null) {
      buffer.writeObject(localStoriesCopy);
    }

    // Finished serialization.
  }
}

/// Contact.
///
/// ID: `145ade0b`.
class Contact extends ContactBase {
  /// Contact constructor.
  const Contact({
    required this.userId,
    required this.mutual,
  }) : super._();

  /// Deserialize.
  factory Contact.deserialize(BinaryReader reader) {
    // Read [Contact] fields.
    final userId = reader.readInt64();
    final mutual = reader.readBool();

    // Construct [Contact] object.
    final returnValue = Contact(
      userId: userId,
      mutual: mutual,
    );

    // Now return the deserialized [Contact].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Mutual.
  final bool mutual;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x145ade0b.
    buffer.writeInt32(0x145ade0b);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeBool(mutual);

    // Finished serialization.
  }
}

/// Imported Contact.
///
/// ID: `c13e3c50`.
class ImportedContact extends ImportedContactBase {
  /// Imported Contact constructor.
  const ImportedContact({
    required this.userId,
    required this.clientId,
  }) : super._();

  /// Deserialize.
  factory ImportedContact.deserialize(BinaryReader reader) {
    // Read [ImportedContact] fields.
    final userId = reader.readInt64();
    final clientId = reader.readInt64();

    // Construct [ImportedContact] object.
    final returnValue = ImportedContact(
      userId: userId,
      clientId: clientId,
    );

    // Now return the deserialized [ImportedContact].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Client Id.
  ///
  /// Field type is Int64.
  final int clientId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc13e3c50.
    buffer.writeInt32(0xc13e3c50);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeInt64(clientId);

    // Finished serialization.
  }
}

/// Contact Status.
///
/// ID: `16d9703b`.
class ContactStatus extends ContactStatusBase {
  /// Contact Status constructor.
  const ContactStatus({
    required this.userId,
    required this.status,
  }) : super._();

  /// Deserialize.
  factory ContactStatus.deserialize(BinaryReader reader) {
    // Read [ContactStatus] fields.
    final userId = reader.readInt64();
    final status = reader.readObject() as UserStatusBase;

    // Construct [ContactStatus] object.
    final returnValue = ContactStatus(
      userId: userId,
      status: status,
    );

    // Now return the deserialized [ContactStatus].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Status.
  final UserStatusBase status;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x16d9703b.
    buffer.writeInt32(0x16d9703b);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeObject(status);

    // Finished serialization.
  }
}

/// Contacts Contacts Not Modified.
///
/// ID: `b74ba9d2`.
class ContactsContactsNotModified extends ContactsContactsBase {
  /// Contacts Contacts Not Modified constructor.
  const ContactsContactsNotModified() : super._();

  /// Deserialize.
  factory ContactsContactsNotModified.deserialize(BinaryReader reader) {
    // Construct [ContactsContactsNotModified] object.
    final returnValue = ContactsContactsNotModified();

    // Now return the deserialized [ContactsContactsNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb74ba9d2.
    buffer.writeInt32(0xb74ba9d2);

    // Finished serialization.
  }
}

/// Contacts Contacts.
///
/// ID: `eae87e42`.
class ContactsContacts extends ContactsContactsBase {
  /// Contacts Contacts constructor.
  const ContactsContacts({
    required this.contacts,
    required this.savedCount,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ContactsContacts.deserialize(BinaryReader reader) {
    // Read [ContactsContacts] fields.
    final contacts = reader.readVectorObject<ContactBase>();
    final savedCount = reader.readInt32();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ContactsContacts] object.
    final returnValue = ContactsContacts(
      contacts: contacts,
      savedCount: savedCount,
      users: users,
    );

    // Now return the deserialized [ContactsContacts].
    return returnValue;
  }

  /// Contacts.
  final List<ContactBase> contacts;

  /// Saved Count.
  ///
  /// Field type is Int32.
  final int savedCount;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeae87e42.
    buffer.writeInt32(0xeae87e42);

    // Write fields.
    buffer.writeVectorObject(contacts);
    buffer.writeInt32(savedCount);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Contacts Imported Contacts.
///
/// ID: `77d01c3b`.
class ContactsImportedContacts extends ContactsImportedContactsBase {
  /// Contacts Imported Contacts constructor.
  const ContactsImportedContacts({
    required this.imported,
    required this.popularInvites,
    required this.retryContacts,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ContactsImportedContacts.deserialize(BinaryReader reader) {
    // Read [ContactsImportedContacts] fields.
    final imported = reader.readVectorObject<ImportedContactBase>();
    final popularInvites = reader.readVectorObject<PopularContactBase>();
    final retryContacts = reader.readVectorInt64();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ContactsImportedContacts] object.
    final returnValue = ContactsImportedContacts(
      imported: imported,
      popularInvites: popularInvites,
      retryContacts: retryContacts,
      users: users,
    );

    // Now return the deserialized [ContactsImportedContacts].
    return returnValue;
  }

  /// Imported.
  final List<ImportedContactBase> imported;

  /// Popular Invites.
  final List<PopularContactBase> popularInvites;

  /// Retry Contacts.
  final List<int> retryContacts;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x77d01c3b.
    buffer.writeInt32(0x77d01c3b);

    // Write fields.
    buffer.writeVectorObject(imported);
    buffer.writeVectorObject(popularInvites);
    buffer.writeVectorInt64(retryContacts);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Contacts Blocked.
///
/// ID: `0ade1591`.
class ContactsBlocked extends ContactsBlockedBase {
  /// Contacts Blocked constructor.
  const ContactsBlocked({
    required this.blocked,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ContactsBlocked.deserialize(BinaryReader reader) {
    // Read [ContactsBlocked] fields.
    final blocked = reader.readVectorObject<PeerBlockedBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ContactsBlocked] object.
    final returnValue = ContactsBlocked(
      blocked: blocked,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ContactsBlocked].
    return returnValue;
  }

  /// Blocked.
  final List<PeerBlockedBase> blocked;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0ade1591.
    buffer.writeInt32(0x0ade1591);

    // Write fields.
    buffer.writeVectorObject(blocked);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Contacts Blocked Slice.
///
/// ID: `e1664194`.
class ContactsBlockedSlice extends ContactsBlockedBase {
  /// Contacts Blocked Slice constructor.
  const ContactsBlockedSlice({
    required this.count,
    required this.blocked,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ContactsBlockedSlice.deserialize(BinaryReader reader) {
    // Read [ContactsBlockedSlice] fields.
    final count = reader.readInt32();
    final blocked = reader.readVectorObject<PeerBlockedBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ContactsBlockedSlice] object.
    final returnValue = ContactsBlockedSlice(
      count: count,
      blocked: blocked,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ContactsBlockedSlice].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Blocked.
  final List<PeerBlockedBase> blocked;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe1664194.
    buffer.writeInt32(0xe1664194);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(blocked);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Dialogs.
///
/// ID: `15ba6c40`.
class MessagesDialogs extends MessagesDialogsBase {
  /// Messages Dialogs constructor.
  const MessagesDialogs({
    required this.dialogs,
    required this.messages,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesDialogs.deserialize(BinaryReader reader) {
    // Read [MessagesDialogs] fields.
    final dialogs = reader.readVectorObject<DialogBase>();
    final messages = reader.readVectorObject<MessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesDialogs] object.
    final returnValue = MessagesDialogs(
      dialogs: dialogs,
      messages: messages,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesDialogs].
    return returnValue;
  }

  /// Dialogs.
  final List<DialogBase> dialogs;

  /// Messages.
  final List<MessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x15ba6c40.
    buffer.writeInt32(0x15ba6c40);

    // Write fields.
    buffer.writeVectorObject(dialogs);
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Dialogs Slice.
///
/// ID: `71e094f3`.
class MessagesDialogsSlice extends MessagesDialogsBase {
  /// Messages Dialogs Slice constructor.
  const MessagesDialogsSlice({
    required this.count,
    required this.dialogs,
    required this.messages,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesDialogsSlice.deserialize(BinaryReader reader) {
    // Read [MessagesDialogsSlice] fields.
    final count = reader.readInt32();
    final dialogs = reader.readVectorObject<DialogBase>();
    final messages = reader.readVectorObject<MessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesDialogsSlice] object.
    final returnValue = MessagesDialogsSlice(
      count: count,
      dialogs: dialogs,
      messages: messages,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesDialogsSlice].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Dialogs.
  final List<DialogBase> dialogs;

  /// Messages.
  final List<MessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x71e094f3.
    buffer.writeInt32(0x71e094f3);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(dialogs);
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Dialogs Not Modified.
///
/// ID: `f0e3e596`.
class MessagesDialogsNotModified extends MessagesDialogsBase {
  /// Messages Dialogs Not Modified constructor.
  const MessagesDialogsNotModified({
    required this.count,
  }) : super._();

  /// Deserialize.
  factory MessagesDialogsNotModified.deserialize(BinaryReader reader) {
    // Read [MessagesDialogsNotModified] fields.
    final count = reader.readInt32();

    // Construct [MessagesDialogsNotModified] object.
    final returnValue = MessagesDialogsNotModified(
      count: count,
    );

    // Now return the deserialized [MessagesDialogsNotModified].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf0e3e596.
    buffer.writeInt32(0xf0e3e596);

    // Write fields.
    buffer.writeInt32(count);

    // Finished serialization.
  }
}

/// Messages Messages.
///
/// ID: `8c718e87`.
class MessagesMessages extends MessagesMessagesBase {
  /// Messages Messages constructor.
  const MessagesMessages({
    required this.messages,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesMessages.deserialize(BinaryReader reader) {
    // Read [MessagesMessages] fields.
    final messages = reader.readVectorObject<MessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesMessages] object.
    final returnValue = MessagesMessages(
      messages: messages,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesMessages].
    return returnValue;
  }

  /// Messages.
  final List<MessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8c718e87.
    buffer.writeInt32(0x8c718e87);

    // Write fields.
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Messages Slice.
///
/// ID: `3a54685e`.
class MessagesMessagesSlice extends MessagesMessagesBase {
  /// Messages Messages Slice constructor.
  const MessagesMessagesSlice({
    required this.inexact,
    required this.count,
    this.nextRate,
    this.offsetIdOffset,
    required this.messages,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesMessagesSlice.deserialize(BinaryReader reader) {
    // Read [MessagesMessagesSlice] fields.
    final flags = reader.readInt32();
    final inexact = (flags & 2) != 0;
    final count = reader.readInt32();
    final hasNextRateField = (flags & 1) != 0;
    final nextRate = hasNextRateField ? reader.readInt32() : null;
    final hasOffsetIdOffsetField = (flags & 4) != 0;
    final offsetIdOffset = hasOffsetIdOffsetField ? reader.readInt32() : null;
    final messages = reader.readVectorObject<MessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesMessagesSlice] object.
    final returnValue = MessagesMessagesSlice(
      inexact: inexact,
      count: count,
      nextRate: nextRate,
      offsetIdOffset: offsetIdOffset,
      messages: messages,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesMessagesSlice].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: inexact,
      b00: nextRate != null,
      b02: offsetIdOffset != null,
    );

    return v;
  }

  /// inexact: bit 1 of flags.1?true
  final bool inexact;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Next Rate.
  final int? nextRate;

  /// Offset Id Offset.
  final int? offsetIdOffset;

  /// Messages.
  final List<MessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3a54685e.
    buffer.writeInt32(0x3a54685e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(count);
    final localNextRateCopy = nextRate;
    if (localNextRateCopy != null) {
      buffer.writeInt32(localNextRateCopy);
    }
    final localOffsetIdOffsetCopy = offsetIdOffset;
    if (localOffsetIdOffsetCopy != null) {
      buffer.writeInt32(localOffsetIdOffsetCopy);
    }
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Channel Messages.
///
/// ID: `c776ba4e`.
class MessagesChannelMessages extends MessagesMessagesBase {
  /// Messages Channel Messages constructor.
  const MessagesChannelMessages({
    required this.inexact,
    required this.pts,
    required this.count,
    this.offsetIdOffset,
    required this.messages,
    required this.topics,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesChannelMessages.deserialize(BinaryReader reader) {
    // Read [MessagesChannelMessages] fields.
    final flags = reader.readInt32();
    final inexact = (flags & 2) != 0;
    final pts = reader.readInt32();
    final count = reader.readInt32();
    final hasOffsetIdOffsetField = (flags & 4) != 0;
    final offsetIdOffset = hasOffsetIdOffsetField ? reader.readInt32() : null;
    final messages = reader.readVectorObject<MessageBase>();
    final topics = reader.readVectorObject<ForumTopicBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesChannelMessages] object.
    final returnValue = MessagesChannelMessages(
      inexact: inexact,
      pts: pts,
      count: count,
      offsetIdOffset: offsetIdOffset,
      messages: messages,
      topics: topics,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesChannelMessages].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: inexact,
      b02: offsetIdOffset != null,
    );

    return v;
  }

  /// inexact: bit 1 of flags.1?true
  final bool inexact;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Offset Id Offset.
  final int? offsetIdOffset;

  /// Messages.
  final List<MessageBase> messages;

  /// Topics.
  final List<ForumTopicBase> topics;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc776ba4e.
    buffer.writeInt32(0xc776ba4e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(pts);
    buffer.writeInt32(count);
    final localOffsetIdOffsetCopy = offsetIdOffset;
    if (localOffsetIdOffsetCopy != null) {
      buffer.writeInt32(localOffsetIdOffsetCopy);
    }
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(topics);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Messages Not Modified.
///
/// ID: `74535f21`.
class MessagesMessagesNotModified extends MessagesMessagesBase {
  /// Messages Messages Not Modified constructor.
  const MessagesMessagesNotModified({
    required this.count,
  }) : super._();

  /// Deserialize.
  factory MessagesMessagesNotModified.deserialize(BinaryReader reader) {
    // Read [MessagesMessagesNotModified] fields.
    final count = reader.readInt32();

    // Construct [MessagesMessagesNotModified] object.
    final returnValue = MessagesMessagesNotModified(
      count: count,
    );

    // Now return the deserialized [MessagesMessagesNotModified].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x74535f21.
    buffer.writeInt32(0x74535f21);

    // Write fields.
    buffer.writeInt32(count);

    // Finished serialization.
  }
}

/// Messages Chats.
///
/// ID: `64ff9fd5`.
class MessagesChats extends MessagesChatsBase {
  /// Messages Chats constructor.
  const MessagesChats({
    required this.chats,
  }) : super._();

  /// Deserialize.
  factory MessagesChats.deserialize(BinaryReader reader) {
    // Read [MessagesChats] fields.
    final chats = reader.readVectorObject<ChatBase>();

    // Construct [MessagesChats] object.
    final returnValue = MessagesChats(
      chats: chats,
    );

    // Now return the deserialized [MessagesChats].
    return returnValue;
  }

  /// Chats.
  final List<ChatBase> chats;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x64ff9fd5.
    buffer.writeInt32(0x64ff9fd5);

    // Write fields.
    buffer.writeVectorObject(chats);

    // Finished serialization.
  }
}

/// Messages Chats Slice.
///
/// ID: `9cd81144`.
class MessagesChatsSlice extends MessagesChatsBase {
  /// Messages Chats Slice constructor.
  const MessagesChatsSlice({
    required this.count,
    required this.chats,
  }) : super._();

  /// Deserialize.
  factory MessagesChatsSlice.deserialize(BinaryReader reader) {
    // Read [MessagesChatsSlice] fields.
    final count = reader.readInt32();
    final chats = reader.readVectorObject<ChatBase>();

    // Construct [MessagesChatsSlice] object.
    final returnValue = MessagesChatsSlice(
      count: count,
      chats: chats,
    );

    // Now return the deserialized [MessagesChatsSlice].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Chats.
  final List<ChatBase> chats;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9cd81144.
    buffer.writeInt32(0x9cd81144);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(chats);

    // Finished serialization.
  }
}

/// Messages Chat Full.
///
/// ID: `e5d7d19c`.
class MessagesChatFull extends MessagesChatFullBase {
  /// Messages Chat Full constructor.
  const MessagesChatFull({
    required this.fullChat,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesChatFull.deserialize(BinaryReader reader) {
    // Read [MessagesChatFull] fields.
    final fullChat = reader.readObject() as ChatFullBase;
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesChatFull] object.
    final returnValue = MessagesChatFull(
      fullChat: fullChat,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesChatFull].
    return returnValue;
  }

  /// Full Chat.
  final ChatFullBase fullChat;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe5d7d19c.
    buffer.writeInt32(0xe5d7d19c);

    // Write fields.
    buffer.writeObject(fullChat);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Affected History.
///
/// ID: `b45c69d1`.
class MessagesAffectedHistory extends MessagesAffectedHistoryBase {
  /// Messages Affected History constructor.
  const MessagesAffectedHistory({
    required this.pts,
    required this.ptsCount,
    required this.offset,
  }) : super._();

  /// Deserialize.
  factory MessagesAffectedHistory.deserialize(BinaryReader reader) {
    // Read [MessagesAffectedHistory] fields.
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();
    final offset = reader.readInt32();

    // Construct [MessagesAffectedHistory] object.
    final returnValue = MessagesAffectedHistory(
      pts: pts,
      ptsCount: ptsCount,
      offset: offset,
    );

    // Now return the deserialized [MessagesAffectedHistory].
    return returnValue;
  }

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb45c69d1.
    buffer.writeInt32(0xb45c69d1);

    // Write fields.
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);
    buffer.writeInt32(offset);

    // Finished serialization.
  }
}

/// Input Messages Filter Empty.
///
/// ID: `57e2f66c`.
class InputMessagesFilterEmpty extends MessagesFilterBase {
  /// Input Messages Filter Empty constructor.
  const InputMessagesFilterEmpty() : super._();

  /// Deserialize.
  factory InputMessagesFilterEmpty.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterEmpty] object.
    final returnValue = InputMessagesFilterEmpty();

    // Now return the deserialized [InputMessagesFilterEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x57e2f66c.
    buffer.writeInt32(0x57e2f66c);

    // Finished serialization.
  }
}

/// Input Messages Filter Photos.
///
/// ID: `9609a51c`.
class InputMessagesFilterPhotos extends MessagesFilterBase {
  /// Input Messages Filter Photos constructor.
  const InputMessagesFilterPhotos() : super._();

  /// Deserialize.
  factory InputMessagesFilterPhotos.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterPhotos] object.
    final returnValue = InputMessagesFilterPhotos();

    // Now return the deserialized [InputMessagesFilterPhotos].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9609a51c.
    buffer.writeInt32(0x9609a51c);

    // Finished serialization.
  }
}

/// Input Messages Filter Video.
///
/// ID: `9fc00e65`.
class InputMessagesFilterVideo extends MessagesFilterBase {
  /// Input Messages Filter Video constructor.
  const InputMessagesFilterVideo() : super._();

  /// Deserialize.
  factory InputMessagesFilterVideo.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterVideo] object.
    final returnValue = InputMessagesFilterVideo();

    // Now return the deserialized [InputMessagesFilterVideo].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9fc00e65.
    buffer.writeInt32(0x9fc00e65);

    // Finished serialization.
  }
}

/// Input Messages Filter Photo Video.
///
/// ID: `56e9f0e4`.
class InputMessagesFilterPhotoVideo extends MessagesFilterBase {
  /// Input Messages Filter Photo Video constructor.
  const InputMessagesFilterPhotoVideo() : super._();

  /// Deserialize.
  factory InputMessagesFilterPhotoVideo.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterPhotoVideo] object.
    final returnValue = InputMessagesFilterPhotoVideo();

    // Now return the deserialized [InputMessagesFilterPhotoVideo].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x56e9f0e4.
    buffer.writeInt32(0x56e9f0e4);

    // Finished serialization.
  }
}

/// Input Messages Filter Document.
///
/// ID: `9eddf188`.
class InputMessagesFilterDocument extends MessagesFilterBase {
  /// Input Messages Filter Document constructor.
  const InputMessagesFilterDocument() : super._();

  /// Deserialize.
  factory InputMessagesFilterDocument.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterDocument] object.
    final returnValue = InputMessagesFilterDocument();

    // Now return the deserialized [InputMessagesFilterDocument].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9eddf188.
    buffer.writeInt32(0x9eddf188);

    // Finished serialization.
  }
}

/// Input Messages Filter Url.
///
/// ID: `7ef0dd87`.
class InputMessagesFilterUrl extends MessagesFilterBase {
  /// Input Messages Filter Url constructor.
  const InputMessagesFilterUrl() : super._();

  /// Deserialize.
  factory InputMessagesFilterUrl.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterUrl] object.
    final returnValue = InputMessagesFilterUrl();

    // Now return the deserialized [InputMessagesFilterUrl].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7ef0dd87.
    buffer.writeInt32(0x7ef0dd87);

    // Finished serialization.
  }
}

/// Input Messages Filter Gif.
///
/// ID: `ffc86587`.
class InputMessagesFilterGif extends MessagesFilterBase {
  /// Input Messages Filter Gif constructor.
  const InputMessagesFilterGif() : super._();

  /// Deserialize.
  factory InputMessagesFilterGif.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterGif] object.
    final returnValue = InputMessagesFilterGif();

    // Now return the deserialized [InputMessagesFilterGif].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xffc86587.
    buffer.writeInt32(0xffc86587);

    // Finished serialization.
  }
}

/// Input Messages Filter Voice.
///
/// ID: `50f5c392`.
class InputMessagesFilterVoice extends MessagesFilterBase {
  /// Input Messages Filter Voice constructor.
  const InputMessagesFilterVoice() : super._();

  /// Deserialize.
  factory InputMessagesFilterVoice.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterVoice] object.
    final returnValue = InputMessagesFilterVoice();

    // Now return the deserialized [InputMessagesFilterVoice].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x50f5c392.
    buffer.writeInt32(0x50f5c392);

    // Finished serialization.
  }
}

/// Input Messages Filter Music.
///
/// ID: `3751b49e`.
class InputMessagesFilterMusic extends MessagesFilterBase {
  /// Input Messages Filter Music constructor.
  const InputMessagesFilterMusic() : super._();

  /// Deserialize.
  factory InputMessagesFilterMusic.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterMusic] object.
    final returnValue = InputMessagesFilterMusic();

    // Now return the deserialized [InputMessagesFilterMusic].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3751b49e.
    buffer.writeInt32(0x3751b49e);

    // Finished serialization.
  }
}

/// Input Messages Filter Chat Photos.
///
/// ID: `3a20ecb8`.
class InputMessagesFilterChatPhotos extends MessagesFilterBase {
  /// Input Messages Filter Chat Photos constructor.
  const InputMessagesFilterChatPhotos() : super._();

  /// Deserialize.
  factory InputMessagesFilterChatPhotos.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterChatPhotos] object.
    final returnValue = InputMessagesFilterChatPhotos();

    // Now return the deserialized [InputMessagesFilterChatPhotos].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3a20ecb8.
    buffer.writeInt32(0x3a20ecb8);

    // Finished serialization.
  }
}

/// Input Messages Filter Phone Calls.
///
/// ID: `80c99768`.
class InputMessagesFilterPhoneCalls extends MessagesFilterBase {
  /// Input Messages Filter Phone Calls constructor.
  const InputMessagesFilterPhoneCalls({
    required this.missed,
  }) : super._();

  /// Deserialize.
  factory InputMessagesFilterPhoneCalls.deserialize(BinaryReader reader) {
    // Read [InputMessagesFilterPhoneCalls] fields.
    final flags = reader.readInt32();
    final missed = (flags & 1) != 0;

    // Construct [InputMessagesFilterPhoneCalls] object.
    final returnValue = InputMessagesFilterPhoneCalls(
      missed: missed,
    );

    // Now return the deserialized [InputMessagesFilterPhoneCalls].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: missed,
    );

    return v;
  }

  /// missed: bit 0 of flags.0?true
  final bool missed;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x80c99768.
    buffer.writeInt32(0x80c99768);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Input Messages Filter Round Voice.
///
/// ID: `7a7c17a4`.
class InputMessagesFilterRoundVoice extends MessagesFilterBase {
  /// Input Messages Filter Round Voice constructor.
  const InputMessagesFilterRoundVoice() : super._();

  /// Deserialize.
  factory InputMessagesFilterRoundVoice.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterRoundVoice] object.
    final returnValue = InputMessagesFilterRoundVoice();

    // Now return the deserialized [InputMessagesFilterRoundVoice].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7a7c17a4.
    buffer.writeInt32(0x7a7c17a4);

    // Finished serialization.
  }
}

/// Input Messages Filter Round Video.
///
/// ID: `b549da53`.
class InputMessagesFilterRoundVideo extends MessagesFilterBase {
  /// Input Messages Filter Round Video constructor.
  const InputMessagesFilterRoundVideo() : super._();

  /// Deserialize.
  factory InputMessagesFilterRoundVideo.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterRoundVideo] object.
    final returnValue = InputMessagesFilterRoundVideo();

    // Now return the deserialized [InputMessagesFilterRoundVideo].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb549da53.
    buffer.writeInt32(0xb549da53);

    // Finished serialization.
  }
}

/// Input Messages Filter My Mentions.
///
/// ID: `c1f8e69a`.
class InputMessagesFilterMyMentions extends MessagesFilterBase {
  /// Input Messages Filter My Mentions constructor.
  const InputMessagesFilterMyMentions() : super._();

  /// Deserialize.
  factory InputMessagesFilterMyMentions.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterMyMentions] object.
    final returnValue = InputMessagesFilterMyMentions();

    // Now return the deserialized [InputMessagesFilterMyMentions].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc1f8e69a.
    buffer.writeInt32(0xc1f8e69a);

    // Finished serialization.
  }
}

/// Input Messages Filter Geo.
///
/// ID: `e7026d0d`.
class InputMessagesFilterGeo extends MessagesFilterBase {
  /// Input Messages Filter Geo constructor.
  const InputMessagesFilterGeo() : super._();

  /// Deserialize.
  factory InputMessagesFilterGeo.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterGeo] object.
    final returnValue = InputMessagesFilterGeo();

    // Now return the deserialized [InputMessagesFilterGeo].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe7026d0d.
    buffer.writeInt32(0xe7026d0d);

    // Finished serialization.
  }
}

/// Input Messages Filter Contacts.
///
/// ID: `e062db83`.
class InputMessagesFilterContacts extends MessagesFilterBase {
  /// Input Messages Filter Contacts constructor.
  const InputMessagesFilterContacts() : super._();

  /// Deserialize.
  factory InputMessagesFilterContacts.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterContacts] object.
    final returnValue = InputMessagesFilterContacts();

    // Now return the deserialized [InputMessagesFilterContacts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe062db83.
    buffer.writeInt32(0xe062db83);

    // Finished serialization.
  }
}

/// Input Messages Filter Pinned.
///
/// ID: `1bb00451`.
class InputMessagesFilterPinned extends MessagesFilterBase {
  /// Input Messages Filter Pinned constructor.
  const InputMessagesFilterPinned() : super._();

  /// Deserialize.
  factory InputMessagesFilterPinned.deserialize(BinaryReader reader) {
    // Construct [InputMessagesFilterPinned] object.
    final returnValue = InputMessagesFilterPinned();

    // Now return the deserialized [InputMessagesFilterPinned].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1bb00451.
    buffer.writeInt32(0x1bb00451);

    // Finished serialization.
  }
}

/// Update New Message.
///
/// ID: `1f2b0afd`.
class UpdateNewMessage extends UpdateBase {
  /// Update New Message constructor.
  const UpdateNewMessage({
    required this.message,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateNewMessage.deserialize(BinaryReader reader) {
    // Read [UpdateNewMessage] fields.
    final message = reader.readObject() as MessageBase;
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateNewMessage] object.
    final returnValue = UpdateNewMessage(
      message: message,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateNewMessage].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1f2b0afd.
    buffer.writeInt32(0x1f2b0afd);

    // Write fields.
    buffer.writeObject(message);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Message I D.
///
/// ID: `4e90bfd6`.
class UpdateMessageID extends UpdateBase {
  /// Update Message I D constructor.
  const UpdateMessageID({
    required this.id,
    required this.randomId,
  }) : super._();

  /// Deserialize.
  factory UpdateMessageID.deserialize(BinaryReader reader) {
    // Read [UpdateMessageID] fields.
    final id = reader.readInt32();
    final randomId = reader.readInt64();

    // Construct [UpdateMessageID] object.
    final returnValue = UpdateMessageID(
      id: id,
      randomId: randomId,
    );

    // Now return the deserialized [UpdateMessageID].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4e90bfd6.
    buffer.writeInt32(0x4e90bfd6);

    // Write fields.
    buffer.writeInt32(id);
    buffer.writeInt64(randomId);

    // Finished serialization.
  }
}

/// Update Delete Messages.
///
/// ID: `a20db0e5`.
class UpdateDeleteMessages extends UpdateBase {
  /// Update Delete Messages constructor.
  const UpdateDeleteMessages({
    required this.messages,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateDeleteMessages.deserialize(BinaryReader reader) {
    // Read [UpdateDeleteMessages] fields.
    final messages = reader.readVectorInt32();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateDeleteMessages] object.
    final returnValue = UpdateDeleteMessages(
      messages: messages,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateDeleteMessages].
    return returnValue;
  }

  /// Messages.
  final List<int> messages;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa20db0e5.
    buffer.writeInt32(0xa20db0e5);

    // Write fields.
    buffer.writeVectorInt32(messages);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update User Typing.
///
/// ID: `c01e857f`.
class UpdateUserTyping extends UpdateBase {
  /// Update User Typing constructor.
  const UpdateUserTyping({
    required this.userId,
    required this.action,
  }) : super._();

  /// Deserialize.
  factory UpdateUserTyping.deserialize(BinaryReader reader) {
    // Read [UpdateUserTyping] fields.
    final userId = reader.readInt64();
    final action = reader.readObject() as SendMessageActionBase;

    // Construct [UpdateUserTyping] object.
    final returnValue = UpdateUserTyping(
      userId: userId,
      action: action,
    );

    // Now return the deserialized [UpdateUserTyping].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Action.
  final SendMessageActionBase action;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc01e857f.
    buffer.writeInt32(0xc01e857f);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeObject(action);

    // Finished serialization.
  }
}

/// Update Chat User Typing.
///
/// ID: `83487af0`.
class UpdateChatUserTyping extends UpdateBase {
  /// Update Chat User Typing constructor.
  const UpdateChatUserTyping({
    required this.chatId,
    required this.fromId,
    required this.action,
  }) : super._();

  /// Deserialize.
  factory UpdateChatUserTyping.deserialize(BinaryReader reader) {
    // Read [UpdateChatUserTyping] fields.
    final chatId = reader.readInt64();
    final fromId = reader.readObject() as PeerBase;
    final action = reader.readObject() as SendMessageActionBase;

    // Construct [UpdateChatUserTyping] object.
    final returnValue = UpdateChatUserTyping(
      chatId: chatId,
      fromId: fromId,
      action: action,
    );

    // Now return the deserialized [UpdateChatUserTyping].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// From Id.
  final PeerBase fromId;

  /// Action.
  final SendMessageActionBase action;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x83487af0.
    buffer.writeInt32(0x83487af0);

    // Write fields.
    buffer.writeInt64(chatId);
    buffer.writeObject(fromId);
    buffer.writeObject(action);

    // Finished serialization.
  }
}

/// Update Chat Participants.
///
/// ID: `07761198`.
class UpdateChatParticipants extends UpdateBase {
  /// Update Chat Participants constructor.
  const UpdateChatParticipants({
    required this.participants,
  }) : super._();

  /// Deserialize.
  factory UpdateChatParticipants.deserialize(BinaryReader reader) {
    // Read [UpdateChatParticipants] fields.
    final participants = reader.readObject() as ChatParticipantsBase;

    // Construct [UpdateChatParticipants] object.
    final returnValue = UpdateChatParticipants(
      participants: participants,
    );

    // Now return the deserialized [UpdateChatParticipants].
    return returnValue;
  }

  /// Participants.
  final ChatParticipantsBase participants;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x07761198.
    buffer.writeInt32(0x07761198);

    // Write fields.
    buffer.writeObject(participants);

    // Finished serialization.
  }
}

/// Update User Status.
///
/// ID: `e5bdf8de`.
class UpdateUserStatus extends UpdateBase {
  /// Update User Status constructor.
  const UpdateUserStatus({
    required this.userId,
    required this.status,
  }) : super._();

  /// Deserialize.
  factory UpdateUserStatus.deserialize(BinaryReader reader) {
    // Read [UpdateUserStatus] fields.
    final userId = reader.readInt64();
    final status = reader.readObject() as UserStatusBase;

    // Construct [UpdateUserStatus] object.
    final returnValue = UpdateUserStatus(
      userId: userId,
      status: status,
    );

    // Now return the deserialized [UpdateUserStatus].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Status.
  final UserStatusBase status;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe5bdf8de.
    buffer.writeInt32(0xe5bdf8de);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeObject(status);

    // Finished serialization.
  }
}

/// Update User Name.
///
/// ID: `a7848924`.
class UpdateUserName extends UpdateBase {
  /// Update User Name constructor.
  const UpdateUserName({
    required this.userId,
    required this.firstName,
    required this.lastName,
    required this.usernames,
  }) : super._();

  /// Deserialize.
  factory UpdateUserName.deserialize(BinaryReader reader) {
    // Read [UpdateUserName] fields.
    final userId = reader.readInt64();
    final firstName = reader.readString();
    final lastName = reader.readString();
    final usernames = reader.readVectorObject<UsernameBase>();

    // Construct [UpdateUserName] object.
    final returnValue = UpdateUserName(
      userId: userId,
      firstName: firstName,
      lastName: lastName,
      usernames: usernames,
    );

    // Now return the deserialized [UpdateUserName].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// First Name.
  final String firstName;

  /// Last Name.
  final String lastName;

  /// Usernames.
  final List<UsernameBase> usernames;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa7848924.
    buffer.writeInt32(0xa7848924);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeString(firstName);
    buffer.writeString(lastName);
    buffer.writeVectorObject(usernames);

    // Finished serialization.
  }
}

/// Update New Authorization.
///
/// ID: `8951abef`.
class UpdateNewAuthorization extends UpdateBase {
  /// Update New Authorization constructor.
  const UpdateNewAuthorization({
    required this.unconfirmed,
    required this.hash,
    this.date,
    this.device,
    this.location,
  }) : super._();

  /// Deserialize.
  factory UpdateNewAuthorization.deserialize(BinaryReader reader) {
    // Read [UpdateNewAuthorization] fields.
    final flags = reader.readInt32();
    final unconfirmed = (flags & 1) != 0;
    final hash = reader.readInt64();
    final hasDateField = (flags & 1) != 0;
    final date = hasDateField ? reader.readDateTime() : null;
    final hasDeviceField = (flags & 1) != 0;
    final device = hasDeviceField ? reader.readString() : null;
    final hasLocationField = (flags & 1) != 0;
    final location = hasLocationField ? reader.readString() : null;

    // Construct [UpdateNewAuthorization] object.
    final returnValue = UpdateNewAuthorization(
      unconfirmed: unconfirmed,
      hash: hash,
      date: date,
      device: device,
      location: location,
    );

    // Now return the deserialized [UpdateNewAuthorization].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: unconfirmed || date != null || device != null || location != null,
    );

    return v;
  }

  /// unconfirmed: bit 0 of flags.0?true
  final bool unconfirmed;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Date.
  final DateTime? date;

  /// Device.
  final String? device;

  /// Location.
  final String? location;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8951abef.
    buffer.writeInt32(0x8951abef);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(hash);
    final localDateCopy = date;
    if (localDateCopy != null) {
      buffer.writeDateTime(localDateCopy);
    }
    final localDeviceCopy = device;
    if (localDeviceCopy != null) {
      buffer.writeString(localDeviceCopy);
    }
    final localLocationCopy = location;
    if (localLocationCopy != null) {
      buffer.writeString(localLocationCopy);
    }

    // Finished serialization.
  }
}

/// Update New Encrypted Message.
///
/// ID: `12bcbd9a`.
class UpdateNewEncryptedMessage extends UpdateBase {
  /// Update New Encrypted Message constructor.
  const UpdateNewEncryptedMessage({
    required this.message,
    required this.qts,
  }) : super._();

  /// Deserialize.
  factory UpdateNewEncryptedMessage.deserialize(BinaryReader reader) {
    // Read [UpdateNewEncryptedMessage] fields.
    final message = reader.readObject() as EncryptedMessageBase;
    final qts = reader.readInt32();

    // Construct [UpdateNewEncryptedMessage] object.
    final returnValue = UpdateNewEncryptedMessage(
      message: message,
      qts: qts,
    );

    // Now return the deserialized [UpdateNewEncryptedMessage].
    return returnValue;
  }

  /// Message.
  final EncryptedMessageBase message;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x12bcbd9a.
    buffer.writeInt32(0x12bcbd9a);

    // Write fields.
    buffer.writeObject(message);
    buffer.writeInt32(qts);

    // Finished serialization.
  }
}

/// Update Encrypted Chat Typing.
///
/// ID: `1710f156`.
class UpdateEncryptedChatTyping extends UpdateBase {
  /// Update Encrypted Chat Typing constructor.
  const UpdateEncryptedChatTyping({
    required this.chatId,
  }) : super._();

  /// Deserialize.
  factory UpdateEncryptedChatTyping.deserialize(BinaryReader reader) {
    // Read [UpdateEncryptedChatTyping] fields.
    final chatId = reader.readInt32();

    // Construct [UpdateEncryptedChatTyping] object.
    final returnValue = UpdateEncryptedChatTyping(
      chatId: chatId,
    );

    // Now return the deserialized [UpdateEncryptedChatTyping].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int32.
  final int chatId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1710f156.
    buffer.writeInt32(0x1710f156);

    // Write fields.
    buffer.writeInt32(chatId);

    // Finished serialization.
  }
}

/// Update Encryption.
///
/// ID: `b4a2e88d`.
class UpdateEncryption extends UpdateBase {
  /// Update Encryption constructor.
  const UpdateEncryption({
    required this.chat,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory UpdateEncryption.deserialize(BinaryReader reader) {
    // Read [UpdateEncryption] fields.
    final chat = reader.readObject() as EncryptedChatBase;
    final date = reader.readDateTime();

    // Construct [UpdateEncryption] object.
    final returnValue = UpdateEncryption(
      chat: chat,
      date: date,
    );

    // Now return the deserialized [UpdateEncryption].
    return returnValue;
  }

  /// Chat.
  final EncryptedChatBase chat;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb4a2e88d.
    buffer.writeInt32(0xb4a2e88d);

    // Write fields.
    buffer.writeObject(chat);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Update Encrypted Messages Read.
///
/// ID: `38fe25b7`.
class UpdateEncryptedMessagesRead extends UpdateBase {
  /// Update Encrypted Messages Read constructor.
  const UpdateEncryptedMessagesRead({
    required this.chatId,
    required this.maxDate,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory UpdateEncryptedMessagesRead.deserialize(BinaryReader reader) {
    // Read [UpdateEncryptedMessagesRead] fields.
    final chatId = reader.readInt32();
    final maxDate = reader.readDateTime();
    final date = reader.readDateTime();

    // Construct [UpdateEncryptedMessagesRead] object.
    final returnValue = UpdateEncryptedMessagesRead(
      chatId: chatId,
      maxDate: maxDate,
      date: date,
    );

    // Now return the deserialized [UpdateEncryptedMessagesRead].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int32.
  final int chatId;

  /// Max Date.
  final DateTime maxDate;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x38fe25b7.
    buffer.writeInt32(0x38fe25b7);

    // Write fields.
    buffer.writeInt32(chatId);
    buffer.writeDateTime(maxDate);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Update Chat Participant Add.
///
/// ID: `3dda5451`.
class UpdateChatParticipantAdd extends UpdateBase {
  /// Update Chat Participant Add constructor.
  const UpdateChatParticipantAdd({
    required this.chatId,
    required this.userId,
    required this.inviterId,
    required this.date,
    required this.version,
  }) : super._();

  /// Deserialize.
  factory UpdateChatParticipantAdd.deserialize(BinaryReader reader) {
    // Read [UpdateChatParticipantAdd] fields.
    final chatId = reader.readInt64();
    final userId = reader.readInt64();
    final inviterId = reader.readInt64();
    final date = reader.readDateTime();
    final version = reader.readInt32();

    // Construct [UpdateChatParticipantAdd] object.
    final returnValue = UpdateChatParticipantAdd(
      chatId: chatId,
      userId: userId,
      inviterId: inviterId,
      date: date,
      version: version,
    );

    // Now return the deserialized [UpdateChatParticipantAdd].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Inviter Id.
  ///
  /// Field type is Int64.
  final int inviterId;

  /// Date.
  final DateTime date;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3dda5451.
    buffer.writeInt32(0x3dda5451);

    // Write fields.
    buffer.writeInt64(chatId);
    buffer.writeInt64(userId);
    buffer.writeInt64(inviterId);
    buffer.writeDateTime(date);
    buffer.writeInt32(version);

    // Finished serialization.
  }
}

/// Update Chat Participant Delete.
///
/// ID: `e32f3d77`.
class UpdateChatParticipantDelete extends UpdateBase {
  /// Update Chat Participant Delete constructor.
  const UpdateChatParticipantDelete({
    required this.chatId,
    required this.userId,
    required this.version,
  }) : super._();

  /// Deserialize.
  factory UpdateChatParticipantDelete.deserialize(BinaryReader reader) {
    // Read [UpdateChatParticipantDelete] fields.
    final chatId = reader.readInt64();
    final userId = reader.readInt64();
    final version = reader.readInt32();

    // Construct [UpdateChatParticipantDelete] object.
    final returnValue = UpdateChatParticipantDelete(
      chatId: chatId,
      userId: userId,
      version: version,
    );

    // Now return the deserialized [UpdateChatParticipantDelete].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe32f3d77.
    buffer.writeInt32(0xe32f3d77);

    // Write fields.
    buffer.writeInt64(chatId);
    buffer.writeInt64(userId);
    buffer.writeInt32(version);

    // Finished serialization.
  }
}

/// Update Dc Options.
///
/// ID: `8e5e9873`.
class UpdateDcOptions extends UpdateBase {
  /// Update Dc Options constructor.
  const UpdateDcOptions({
    required this.dcOptions,
  }) : super._();

  /// Deserialize.
  factory UpdateDcOptions.deserialize(BinaryReader reader) {
    // Read [UpdateDcOptions] fields.
    final dcOptions = reader.readVectorObject<DcOptionBase>();

    // Construct [UpdateDcOptions] object.
    final returnValue = UpdateDcOptions(
      dcOptions: dcOptions,
    );

    // Now return the deserialized [UpdateDcOptions].
    return returnValue;
  }

  /// Dc Options.
  final List<DcOptionBase> dcOptions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8e5e9873.
    buffer.writeInt32(0x8e5e9873);

    // Write fields.
    buffer.writeVectorObject(dcOptions);

    // Finished serialization.
  }
}

/// Update Notify Settings.
///
/// ID: `bec268ef`.
class UpdateNotifySettings extends UpdateBase {
  /// Update Notify Settings constructor.
  const UpdateNotifySettings({
    required this.peer,
    required this.notifySettings,
  }) : super._();

  /// Deserialize.
  factory UpdateNotifySettings.deserialize(BinaryReader reader) {
    // Read [UpdateNotifySettings] fields.
    final peer = reader.readObject() as NotifyPeerBase;
    final notifySettings = reader.readObject() as PeerNotifySettingsBase;

    // Construct [UpdateNotifySettings] object.
    final returnValue = UpdateNotifySettings(
      peer: peer,
      notifySettings: notifySettings,
    );

    // Now return the deserialized [UpdateNotifySettings].
    return returnValue;
  }

  /// Peer.
  final NotifyPeerBase peer;

  /// Notify Settings.
  final PeerNotifySettingsBase notifySettings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbec268ef.
    buffer.writeInt32(0xbec268ef);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(notifySettings);

    // Finished serialization.
  }
}

/// Update Service Notification.
///
/// ID: `ebe46819`.
class UpdateServiceNotification extends UpdateBase {
  /// Update Service Notification constructor.
  const UpdateServiceNotification({
    required this.popup,
    required this.invertMedia,
    this.inboxDate,
    required this.type,
    required this.message,
    required this.media,
    required this.entities,
  }) : super._();

  /// Deserialize.
  factory UpdateServiceNotification.deserialize(BinaryReader reader) {
    // Read [UpdateServiceNotification] fields.
    final flags = reader.readInt32();
    final popup = (flags & 1) != 0;
    final invertMedia = (flags & 4) != 0;
    final hasInboxDateField = (flags & 2) != 0;
    final inboxDate = hasInboxDateField ? reader.readDateTime() : null;
    final type = reader.readString();
    final message = reader.readString();
    final media = reader.readObject() as MessageMediaBase;
    final entities = reader.readVectorObject<MessageEntityBase>();

    // Construct [UpdateServiceNotification] object.
    final returnValue = UpdateServiceNotification(
      popup: popup,
      invertMedia: invertMedia,
      inboxDate: inboxDate,
      type: type,
      message: message,
      media: media,
      entities: entities,
    );

    // Now return the deserialized [UpdateServiceNotification].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: popup,
      b02: invertMedia,
      b01: inboxDate != null,
    );

    return v;
  }

  /// popup: bit 0 of flags.0?true
  final bool popup;

  /// invert_media: bit 2 of flags.2?true
  final bool invertMedia;

  /// Inbox Date.
  final DateTime? inboxDate;

  /// Type.
  final String type;

  /// Message.
  final String message;

  /// Media.
  final MessageMediaBase media;

  /// Entities.
  final List<MessageEntityBase> entities;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xebe46819.
    buffer.writeInt32(0xebe46819);

    // Write fields.
    buffer.writeInt32(flags);
    final localInboxDateCopy = inboxDate;
    if (localInboxDateCopy != null) {
      buffer.writeDateTime(localInboxDateCopy);
    }
    buffer.writeString(type);
    buffer.writeString(message);
    buffer.writeObject(media);
    buffer.writeVectorObject(entities);

    // Finished serialization.
  }
}

/// Update Privacy.
///
/// ID: `ee3b272a`.
class UpdatePrivacy extends UpdateBase {
  /// Update Privacy constructor.
  const UpdatePrivacy({
    required this.key,
    required this.rules,
  }) : super._();

  /// Deserialize.
  factory UpdatePrivacy.deserialize(BinaryReader reader) {
    // Read [UpdatePrivacy] fields.
    final key = reader.readObject() as PrivacyKeyBase;
    final rules = reader.readVectorObject<PrivacyRuleBase>();

    // Construct [UpdatePrivacy] object.
    final returnValue = UpdatePrivacy(
      key: key,
      rules: rules,
    );

    // Now return the deserialized [UpdatePrivacy].
    return returnValue;
  }

  /// Key.
  final PrivacyKeyBase key;

  /// Rules.
  final List<PrivacyRuleBase> rules;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xee3b272a.
    buffer.writeInt32(0xee3b272a);

    // Write fields.
    buffer.writeObject(key);
    buffer.writeVectorObject(rules);

    // Finished serialization.
  }
}

/// Update User Phone.
///
/// ID: `05492a13`.
class UpdateUserPhone extends UpdateBase {
  /// Update User Phone constructor.
  const UpdateUserPhone({
    required this.userId,
    required this.phone,
  }) : super._();

  /// Deserialize.
  factory UpdateUserPhone.deserialize(BinaryReader reader) {
    // Read [UpdateUserPhone] fields.
    final userId = reader.readInt64();
    final phone = reader.readString();

    // Construct [UpdateUserPhone] object.
    final returnValue = UpdateUserPhone(
      userId: userId,
      phone: phone,
    );

    // Now return the deserialized [UpdateUserPhone].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Phone.
  final String phone;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x05492a13.
    buffer.writeInt32(0x05492a13);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeString(phone);

    // Finished serialization.
  }
}

/// Update Read History Inbox.
///
/// ID: `9c974fdf`.
class UpdateReadHistoryInbox extends UpdateBase {
  /// Update Read History Inbox constructor.
  const UpdateReadHistoryInbox({
    this.folderId,
    required this.peer,
    required this.maxId,
    required this.stillUnreadCount,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateReadHistoryInbox.deserialize(BinaryReader reader) {
    // Read [UpdateReadHistoryInbox] fields.
    final flags = reader.readInt32();
    final hasFolderIdField = (flags & 1) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final peer = reader.readObject() as PeerBase;
    final maxId = reader.readInt32();
    final stillUnreadCount = reader.readInt32();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateReadHistoryInbox] object.
    final returnValue = UpdateReadHistoryInbox(
      folderId: folderId,
      peer: peer,
      maxId: maxId,
      stillUnreadCount: stillUnreadCount,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateReadHistoryInbox].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: folderId != null,
    );

    return v;
  }

  /// Folder Id.
  final int? folderId;

  /// Peer.
  final PeerBase peer;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Still Unread Count.
  ///
  /// Field type is Int32.
  final int stillUnreadCount;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9c974fdf.
    buffer.writeInt32(0x9c974fdf);

    // Write fields.
    buffer.writeInt32(flags);
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    buffer.writeObject(peer);
    buffer.writeInt32(maxId);
    buffer.writeInt32(stillUnreadCount);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Read History Outbox.
///
/// ID: `2f2f21bf`.
class UpdateReadHistoryOutbox extends UpdateBase {
  /// Update Read History Outbox constructor.
  const UpdateReadHistoryOutbox({
    required this.peer,
    required this.maxId,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateReadHistoryOutbox.deserialize(BinaryReader reader) {
    // Read [UpdateReadHistoryOutbox] fields.
    final peer = reader.readObject() as PeerBase;
    final maxId = reader.readInt32();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateReadHistoryOutbox] object.
    final returnValue = UpdateReadHistoryOutbox(
      peer: peer,
      maxId: maxId,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateReadHistoryOutbox].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2f2f21bf.
    buffer.writeInt32(0x2f2f21bf);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(maxId);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Web Page.
///
/// ID: `7f891213`.
class UpdateWebPage extends UpdateBase {
  /// Update Web Page constructor.
  const UpdateWebPage({
    required this.webpage,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateWebPage.deserialize(BinaryReader reader) {
    // Read [UpdateWebPage] fields.
    final webpage = reader.readObject() as WebPageBase;
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateWebPage] object.
    final returnValue = UpdateWebPage(
      webpage: webpage,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateWebPage].
    return returnValue;
  }

  /// Webpage.
  final WebPageBase webpage;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7f891213.
    buffer.writeInt32(0x7f891213);

    // Write fields.
    buffer.writeObject(webpage);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Read Messages Contents.
///
/// ID: `f8227181`.
class UpdateReadMessagesContents extends UpdateBase {
  /// Update Read Messages Contents constructor.
  const UpdateReadMessagesContents({
    required this.messages,
    required this.pts,
    required this.ptsCount,
    this.date,
  }) : super._();

  /// Deserialize.
  factory UpdateReadMessagesContents.deserialize(BinaryReader reader) {
    // Read [UpdateReadMessagesContents] fields.
    final flags = reader.readInt32();
    final messages = reader.readVectorInt32();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();
    final hasDateField = (flags & 1) != 0;
    final date = hasDateField ? reader.readDateTime() : null;

    // Construct [UpdateReadMessagesContents] object.
    final returnValue = UpdateReadMessagesContents(
      messages: messages,
      pts: pts,
      ptsCount: ptsCount,
      date: date,
    );

    // Now return the deserialized [UpdateReadMessagesContents].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: date != null,
    );

    return v;
  }

  /// Messages.
  final List<int> messages;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Date.
  final DateTime? date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf8227181.
    buffer.writeInt32(0xf8227181);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorInt32(messages);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);
    final localDateCopy = date;
    if (localDateCopy != null) {
      buffer.writeDateTime(localDateCopy);
    }

    // Finished serialization.
  }
}

/// Update Channel Too Long.
///
/// ID: `108d941f`.
class UpdateChannelTooLong extends UpdateBase {
  /// Update Channel Too Long constructor.
  const UpdateChannelTooLong({
    required this.channelId,
    this.pts,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelTooLong.deserialize(BinaryReader reader) {
    // Read [UpdateChannelTooLong] fields.
    final flags = reader.readInt32();
    final channelId = reader.readInt64();
    final hasPtsField = (flags & 1) != 0;
    final pts = hasPtsField ? reader.readInt32() : null;

    // Construct [UpdateChannelTooLong] object.
    final returnValue = UpdateChannelTooLong(
      channelId: channelId,
      pts: pts,
    );

    // Now return the deserialized [UpdateChannelTooLong].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pts != null,
    );

    return v;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Pts.
  final int? pts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x108d941f.
    buffer.writeInt32(0x108d941f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(channelId);
    final localPtsCopy = pts;
    if (localPtsCopy != null) {
      buffer.writeInt32(localPtsCopy);
    }

    // Finished serialization.
  }
}

/// Update Channel.
///
/// ID: `635b4c09`.
class UpdateChannel extends UpdateBase {
  /// Update Channel constructor.
  const UpdateChannel({
    required this.channelId,
  }) : super._();

  /// Deserialize.
  factory UpdateChannel.deserialize(BinaryReader reader) {
    // Read [UpdateChannel] fields.
    final channelId = reader.readInt64();

    // Construct [UpdateChannel] object.
    final returnValue = UpdateChannel(
      channelId: channelId,
    );

    // Now return the deserialized [UpdateChannel].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x635b4c09.
    buffer.writeInt32(0x635b4c09);

    // Write fields.
    buffer.writeInt64(channelId);

    // Finished serialization.
  }
}

/// Update New Channel Message.
///
/// ID: `62ba04d9`.
class UpdateNewChannelMessage extends UpdateBase {
  /// Update New Channel Message constructor.
  const UpdateNewChannelMessage({
    required this.message,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateNewChannelMessage.deserialize(BinaryReader reader) {
    // Read [UpdateNewChannelMessage] fields.
    final message = reader.readObject() as MessageBase;
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateNewChannelMessage] object.
    final returnValue = UpdateNewChannelMessage(
      message: message,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateNewChannelMessage].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x62ba04d9.
    buffer.writeInt32(0x62ba04d9);

    // Write fields.
    buffer.writeObject(message);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Read Channel Inbox.
///
/// ID: `922e6e10`.
class UpdateReadChannelInbox extends UpdateBase {
  /// Update Read Channel Inbox constructor.
  const UpdateReadChannelInbox({
    this.folderId,
    required this.channelId,
    required this.maxId,
    required this.stillUnreadCount,
    required this.pts,
  }) : super._();

  /// Deserialize.
  factory UpdateReadChannelInbox.deserialize(BinaryReader reader) {
    // Read [UpdateReadChannelInbox] fields.
    final flags = reader.readInt32();
    final hasFolderIdField = (flags & 1) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final channelId = reader.readInt64();
    final maxId = reader.readInt32();
    final stillUnreadCount = reader.readInt32();
    final pts = reader.readInt32();

    // Construct [UpdateReadChannelInbox] object.
    final returnValue = UpdateReadChannelInbox(
      folderId: folderId,
      channelId: channelId,
      maxId: maxId,
      stillUnreadCount: stillUnreadCount,
      pts: pts,
    );

    // Now return the deserialized [UpdateReadChannelInbox].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: folderId != null,
    );

    return v;
  }

  /// Folder Id.
  final int? folderId;

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Still Unread Count.
  ///
  /// Field type is Int32.
  final int stillUnreadCount;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x922e6e10.
    buffer.writeInt32(0x922e6e10);

    // Write fields.
    buffer.writeInt32(flags);
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    buffer.writeInt64(channelId);
    buffer.writeInt32(maxId);
    buffer.writeInt32(stillUnreadCount);
    buffer.writeInt32(pts);

    // Finished serialization.
  }
}

/// Update Delete Channel Messages.
///
/// ID: `c32d5b12`.
class UpdateDeleteChannelMessages extends UpdateBase {
  /// Update Delete Channel Messages constructor.
  const UpdateDeleteChannelMessages({
    required this.channelId,
    required this.messages,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateDeleteChannelMessages.deserialize(BinaryReader reader) {
    // Read [UpdateDeleteChannelMessages] fields.
    final channelId = reader.readInt64();
    final messages = reader.readVectorInt32();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateDeleteChannelMessages] object.
    final returnValue = UpdateDeleteChannelMessages(
      channelId: channelId,
      messages: messages,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateDeleteChannelMessages].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Messages.
  final List<int> messages;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc32d5b12.
    buffer.writeInt32(0xc32d5b12);

    // Write fields.
    buffer.writeInt64(channelId);
    buffer.writeVectorInt32(messages);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Channel Message Views.
///
/// ID: `f226ac08`.
class UpdateChannelMessageViews extends UpdateBase {
  /// Update Channel Message Views constructor.
  const UpdateChannelMessageViews({
    required this.channelId,
    required this.id,
    required this.views,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelMessageViews.deserialize(BinaryReader reader) {
    // Read [UpdateChannelMessageViews] fields.
    final channelId = reader.readInt64();
    final id = reader.readInt32();
    final views = reader.readInt32();

    // Construct [UpdateChannelMessageViews] object.
    final returnValue = UpdateChannelMessageViews(
      channelId: channelId,
      id: id,
      views: views,
    );

    // Now return the deserialized [UpdateChannelMessageViews].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Views.
  ///
  /// Field type is Int32.
  final int views;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf226ac08.
    buffer.writeInt32(0xf226ac08);

    // Write fields.
    buffer.writeInt64(channelId);
    buffer.writeInt32(id);
    buffer.writeInt32(views);

    // Finished serialization.
  }
}

/// Update Chat Participant Admin.
///
/// ID: `d7ca61a2`.
class UpdateChatParticipantAdmin extends UpdateBase {
  /// Update Chat Participant Admin constructor.
  const UpdateChatParticipantAdmin({
    required this.chatId,
    required this.userId,
    required this.isAdmin,
    required this.version,
  }) : super._();

  /// Deserialize.
  factory UpdateChatParticipantAdmin.deserialize(BinaryReader reader) {
    // Read [UpdateChatParticipantAdmin] fields.
    final chatId = reader.readInt64();
    final userId = reader.readInt64();
    final isAdmin = reader.readBool();
    final version = reader.readInt32();

    // Construct [UpdateChatParticipantAdmin] object.
    final returnValue = UpdateChatParticipantAdmin(
      chatId: chatId,
      userId: userId,
      isAdmin: isAdmin,
      version: version,
    );

    // Now return the deserialized [UpdateChatParticipantAdmin].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Is Admin.
  final bool isAdmin;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd7ca61a2.
    buffer.writeInt32(0xd7ca61a2);

    // Write fields.
    buffer.writeInt64(chatId);
    buffer.writeInt64(userId);
    buffer.writeBool(isAdmin);
    buffer.writeInt32(version);

    // Finished serialization.
  }
}

/// Update New Sticker Set.
///
/// ID: `688a30aa`.
class UpdateNewStickerSet extends UpdateBase {
  /// Update New Sticker Set constructor.
  const UpdateNewStickerSet({
    required this.stickerset,
  }) : super._();

  /// Deserialize.
  factory UpdateNewStickerSet.deserialize(BinaryReader reader) {
    // Read [UpdateNewStickerSet] fields.
    final stickerset = reader.readObject() as MessagesStickerSetBase;

    // Construct [UpdateNewStickerSet] object.
    final returnValue = UpdateNewStickerSet(
      stickerset: stickerset,
    );

    // Now return the deserialized [UpdateNewStickerSet].
    return returnValue;
  }

  /// Stickerset.
  final MessagesStickerSetBase stickerset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x688a30aa.
    buffer.writeInt32(0x688a30aa);

    // Write fields.
    buffer.writeObject(stickerset);

    // Finished serialization.
  }
}

/// Update Sticker Sets Order.
///
/// ID: `0bb2d201`.
class UpdateStickerSetsOrder extends UpdateBase {
  /// Update Sticker Sets Order constructor.
  const UpdateStickerSetsOrder({
    required this.masks,
    required this.emojis,
    required this.order,
  }) : super._();

  /// Deserialize.
  factory UpdateStickerSetsOrder.deserialize(BinaryReader reader) {
    // Read [UpdateStickerSetsOrder] fields.
    final flags = reader.readInt32();
    final masks = (flags & 1) != 0;
    final emojis = (flags & 2) != 0;
    final order = reader.readVectorInt64();

    // Construct [UpdateStickerSetsOrder] object.
    final returnValue = UpdateStickerSetsOrder(
      masks: masks,
      emojis: emojis,
      order: order,
    );

    // Now return the deserialized [UpdateStickerSetsOrder].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: masks,
      b01: emojis,
    );

    return v;
  }

  /// masks: bit 0 of flags.0?true
  final bool masks;

  /// emojis: bit 1 of flags.1?true
  final bool emojis;

  /// Order.
  final List<int> order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0bb2d201.
    buffer.writeInt32(0x0bb2d201);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorInt64(order);

    // Finished serialization.
  }
}

/// Update Sticker Sets.
///
/// ID: `31c24808`.
class UpdateStickerSets extends UpdateBase {
  /// Update Sticker Sets constructor.
  const UpdateStickerSets({
    required this.masks,
    required this.emojis,
  }) : super._();

  /// Deserialize.
  factory UpdateStickerSets.deserialize(BinaryReader reader) {
    // Read [UpdateStickerSets] fields.
    final flags = reader.readInt32();
    final masks = (flags & 1) != 0;
    final emojis = (flags & 2) != 0;

    // Construct [UpdateStickerSets] object.
    final returnValue = UpdateStickerSets(
      masks: masks,
      emojis: emojis,
    );

    // Now return the deserialized [UpdateStickerSets].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: masks,
      b01: emojis,
    );

    return v;
  }

  /// masks: bit 0 of flags.0?true
  final bool masks;

  /// emojis: bit 1 of flags.1?true
  final bool emojis;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x31c24808.
    buffer.writeInt32(0x31c24808);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Update Saved Gifs.
///
/// ID: `9375341e`.
class UpdateSavedGifs extends UpdateBase {
  /// Update Saved Gifs constructor.
  const UpdateSavedGifs() : super._();

  /// Deserialize.
  factory UpdateSavedGifs.deserialize(BinaryReader reader) {
    // Construct [UpdateSavedGifs] object.
    final returnValue = UpdateSavedGifs();

    // Now return the deserialized [UpdateSavedGifs].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9375341e.
    buffer.writeInt32(0x9375341e);

    // Finished serialization.
  }
}

/// Update Bot Inline Query.
///
/// ID: `496f379c`.
class UpdateBotInlineQuery extends UpdateBase {
  /// Update Bot Inline Query constructor.
  const UpdateBotInlineQuery({
    required this.queryId,
    required this.userId,
    required this.query,
    this.geo,
    this.peerType,
    required this.offset,
  }) : super._();

  /// Deserialize.
  factory UpdateBotInlineQuery.deserialize(BinaryReader reader) {
    // Read [UpdateBotInlineQuery] fields.
    final flags = reader.readInt32();
    final queryId = reader.readInt64();
    final userId = reader.readInt64();
    final query = reader.readString();
    final hasGeoField = (flags & 1) != 0;
    final geo = hasGeoField ? reader.readObject() as GeoPointBase : null;
    final hasPeerTypeField = (flags & 2) != 0;
    final peerType = hasPeerTypeField
        ? reader.readObject() as InlineQueryPeerTypeBase
        : null;
    final offset = reader.readString();

    // Construct [UpdateBotInlineQuery] object.
    final returnValue = UpdateBotInlineQuery(
      queryId: queryId,
      userId: userId,
      query: query,
      geo: geo,
      peerType: peerType,
      offset: offset,
    );

    // Now return the deserialized [UpdateBotInlineQuery].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: geo != null,
      b01: peerType != null,
    );

    return v;
  }

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Query.
  final String query;

  /// Geo.
  final GeoPointBase? geo;

  /// Peer Type.
  final InlineQueryPeerTypeBase? peerType;

  /// Offset.
  final String offset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x496f379c.
    buffer.writeInt32(0x496f379c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(queryId);
    buffer.writeInt64(userId);
    buffer.writeString(query);
    final localGeoCopy = geo;
    if (localGeoCopy != null) {
      buffer.writeObject(localGeoCopy);
    }
    final localPeerTypeCopy = peerType;
    if (localPeerTypeCopy != null) {
      buffer.writeObject(localPeerTypeCopy);
    }
    buffer.writeString(offset);

    // Finished serialization.
  }
}

/// Update Bot Inline Send.
///
/// ID: `12f12a07`.
class UpdateBotInlineSend extends UpdateBase {
  /// Update Bot Inline Send constructor.
  const UpdateBotInlineSend({
    required this.userId,
    required this.query,
    this.geo,
    required this.id,
    this.msgId,
  }) : super._();

  /// Deserialize.
  factory UpdateBotInlineSend.deserialize(BinaryReader reader) {
    // Read [UpdateBotInlineSend] fields.
    final flags = reader.readInt32();
    final userId = reader.readInt64();
    final query = reader.readString();
    final hasGeoField = (flags & 1) != 0;
    final geo = hasGeoField ? reader.readObject() as GeoPointBase : null;
    final id = reader.readString();
    final hasMsgIdField = (flags & 2) != 0;
    final msgId = hasMsgIdField
        ? reader.readObject() as InputBotInlineMessageIDBase
        : null;

    // Construct [UpdateBotInlineSend] object.
    final returnValue = UpdateBotInlineSend(
      userId: userId,
      query: query,
      geo: geo,
      id: id,
      msgId: msgId,
    );

    // Now return the deserialized [UpdateBotInlineSend].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: geo != null,
      b01: msgId != null,
    );

    return v;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Query.
  final String query;

  /// Geo.
  final GeoPointBase? geo;

  /// Id.
  final String id;

  /// Msg Id.
  final InputBotInlineMessageIDBase? msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x12f12a07.
    buffer.writeInt32(0x12f12a07);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(userId);
    buffer.writeString(query);
    final localGeoCopy = geo;
    if (localGeoCopy != null) {
      buffer.writeObject(localGeoCopy);
    }
    buffer.writeString(id);
    final localMsgIdCopy = msgId;
    if (localMsgIdCopy != null) {
      buffer.writeObject(localMsgIdCopy);
    }

    // Finished serialization.
  }
}

/// Update Edit Channel Message.
///
/// ID: `1b3f4df7`.
class UpdateEditChannelMessage extends UpdateBase {
  /// Update Edit Channel Message constructor.
  const UpdateEditChannelMessage({
    required this.message,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateEditChannelMessage.deserialize(BinaryReader reader) {
    // Read [UpdateEditChannelMessage] fields.
    final message = reader.readObject() as MessageBase;
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateEditChannelMessage] object.
    final returnValue = UpdateEditChannelMessage(
      message: message,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateEditChannelMessage].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1b3f4df7.
    buffer.writeInt32(0x1b3f4df7);

    // Write fields.
    buffer.writeObject(message);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Bot Callback Query.
///
/// ID: `b9cfc48d`.
class UpdateBotCallbackQuery extends UpdateBase {
  /// Update Bot Callback Query constructor.
  const UpdateBotCallbackQuery({
    required this.queryId,
    required this.userId,
    required this.peer,
    required this.msgId,
    required this.chatInstance,
    this.data,
    this.gameShortName,
  }) : super._();

  /// Deserialize.
  factory UpdateBotCallbackQuery.deserialize(BinaryReader reader) {
    // Read [UpdateBotCallbackQuery] fields.
    final flags = reader.readInt32();
    final queryId = reader.readInt64();
    final userId = reader.readInt64();
    final peer = reader.readObject() as PeerBase;
    final msgId = reader.readInt32();
    final chatInstance = reader.readInt64();
    final hasDataField = (flags & 1) != 0;
    final data = hasDataField ? reader.readBytes() : null;
    final hasGameShortNameField = (flags & 2) != 0;
    final gameShortName = hasGameShortNameField ? reader.readString() : null;

    // Construct [UpdateBotCallbackQuery] object.
    final returnValue = UpdateBotCallbackQuery(
      queryId: queryId,
      userId: userId,
      peer: peer,
      msgId: msgId,
      chatInstance: chatInstance,
      data: data,
      gameShortName: gameShortName,
    );

    // Now return the deserialized [UpdateBotCallbackQuery].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: data != null,
      b01: gameShortName != null,
    );

    return v;
  }

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Peer.
  final PeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Chat Instance.
  ///
  /// Field type is Int64.
  final int chatInstance;

  /// Data.
  final Uint8List? data;

  /// Game Short Name.
  final String? gameShortName;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb9cfc48d.
    buffer.writeInt32(0xb9cfc48d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(queryId);
    buffer.writeInt64(userId);
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeInt64(chatInstance);
    final localDataCopy = data;
    if (localDataCopy != null) {
      buffer.writeBytes(localDataCopy);
    }
    final localGameShortNameCopy = gameShortName;
    if (localGameShortNameCopy != null) {
      buffer.writeString(localGameShortNameCopy);
    }

    // Finished serialization.
  }
}

/// Update Edit Message.
///
/// ID: `e40370a3`.
class UpdateEditMessage extends UpdateBase {
  /// Update Edit Message constructor.
  const UpdateEditMessage({
    required this.message,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateEditMessage.deserialize(BinaryReader reader) {
    // Read [UpdateEditMessage] fields.
    final message = reader.readObject() as MessageBase;
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateEditMessage] object.
    final returnValue = UpdateEditMessage(
      message: message,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateEditMessage].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe40370a3.
    buffer.writeInt32(0xe40370a3);

    // Write fields.
    buffer.writeObject(message);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Inline Bot Callback Query.
///
/// ID: `691e9052`.
class UpdateInlineBotCallbackQuery extends UpdateBase {
  /// Update Inline Bot Callback Query constructor.
  const UpdateInlineBotCallbackQuery({
    required this.queryId,
    required this.userId,
    required this.msgId,
    required this.chatInstance,
    this.data,
    this.gameShortName,
  }) : super._();

  /// Deserialize.
  factory UpdateInlineBotCallbackQuery.deserialize(BinaryReader reader) {
    // Read [UpdateInlineBotCallbackQuery] fields.
    final flags = reader.readInt32();
    final queryId = reader.readInt64();
    final userId = reader.readInt64();
    final msgId = reader.readObject() as InputBotInlineMessageIDBase;
    final chatInstance = reader.readInt64();
    final hasDataField = (flags & 1) != 0;
    final data = hasDataField ? reader.readBytes() : null;
    final hasGameShortNameField = (flags & 2) != 0;
    final gameShortName = hasGameShortNameField ? reader.readString() : null;

    // Construct [UpdateInlineBotCallbackQuery] object.
    final returnValue = UpdateInlineBotCallbackQuery(
      queryId: queryId,
      userId: userId,
      msgId: msgId,
      chatInstance: chatInstance,
      data: data,
      gameShortName: gameShortName,
    );

    // Now return the deserialized [UpdateInlineBotCallbackQuery].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: data != null,
      b01: gameShortName != null,
    );

    return v;
  }

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Msg Id.
  final InputBotInlineMessageIDBase msgId;

  /// Chat Instance.
  ///
  /// Field type is Int64.
  final int chatInstance;

  /// Data.
  final Uint8List? data;

  /// Game Short Name.
  final String? gameShortName;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x691e9052.
    buffer.writeInt32(0x691e9052);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(queryId);
    buffer.writeInt64(userId);
    buffer.writeObject(msgId);
    buffer.writeInt64(chatInstance);
    final localDataCopy = data;
    if (localDataCopy != null) {
      buffer.writeBytes(localDataCopy);
    }
    final localGameShortNameCopy = gameShortName;
    if (localGameShortNameCopy != null) {
      buffer.writeString(localGameShortNameCopy);
    }

    // Finished serialization.
  }
}

/// Update Read Channel Outbox.
///
/// ID: `b75f99a9`.
class UpdateReadChannelOutbox extends UpdateBase {
  /// Update Read Channel Outbox constructor.
  const UpdateReadChannelOutbox({
    required this.channelId,
    required this.maxId,
  }) : super._();

  /// Deserialize.
  factory UpdateReadChannelOutbox.deserialize(BinaryReader reader) {
    // Read [UpdateReadChannelOutbox] fields.
    final channelId = reader.readInt64();
    final maxId = reader.readInt32();

    // Construct [UpdateReadChannelOutbox] object.
    final returnValue = UpdateReadChannelOutbox(
      channelId: channelId,
      maxId: maxId,
    );

    // Now return the deserialized [UpdateReadChannelOutbox].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb75f99a9.
    buffer.writeInt32(0xb75f99a9);

    // Write fields.
    buffer.writeInt64(channelId);
    buffer.writeInt32(maxId);

    // Finished serialization.
  }
}

/// Update Draft Message.
///
/// ID: `1b49ec6d`.
class UpdateDraftMessage extends UpdateBase {
  /// Update Draft Message constructor.
  const UpdateDraftMessage({
    required this.peer,
    this.topMsgId,
    required this.draft,
  }) : super._();

  /// Deserialize.
  factory UpdateDraftMessage.deserialize(BinaryReader reader) {
    // Read [UpdateDraftMessage] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as PeerBase;
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final draft = reader.readObject() as DraftMessageBase;

    // Construct [UpdateDraftMessage] object.
    final returnValue = UpdateDraftMessage(
      peer: peer,
      topMsgId: topMsgId,
      draft: draft,
    );

    // Now return the deserialized [UpdateDraftMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
    );

    return v;
  }

  /// Peer.
  final PeerBase peer;

  /// Top Msg Id.
  final int? topMsgId;

  /// Draft.
  final DraftMessageBase draft;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1b49ec6d.
    buffer.writeInt32(0x1b49ec6d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    buffer.writeObject(draft);

    // Finished serialization.
  }
}

/// Update Read Featured Stickers.
///
/// ID: `571d2742`.
class UpdateReadFeaturedStickers extends UpdateBase {
  /// Update Read Featured Stickers constructor.
  const UpdateReadFeaturedStickers() : super._();

  /// Deserialize.
  factory UpdateReadFeaturedStickers.deserialize(BinaryReader reader) {
    // Construct [UpdateReadFeaturedStickers] object.
    final returnValue = UpdateReadFeaturedStickers();

    // Now return the deserialized [UpdateReadFeaturedStickers].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x571d2742.
    buffer.writeInt32(0x571d2742);

    // Finished serialization.
  }
}

/// Update Recent Stickers.
///
/// ID: `9a422c20`.
class UpdateRecentStickers extends UpdateBase {
  /// Update Recent Stickers constructor.
  const UpdateRecentStickers() : super._();

  /// Deserialize.
  factory UpdateRecentStickers.deserialize(BinaryReader reader) {
    // Construct [UpdateRecentStickers] object.
    final returnValue = UpdateRecentStickers();

    // Now return the deserialized [UpdateRecentStickers].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9a422c20.
    buffer.writeInt32(0x9a422c20);

    // Finished serialization.
  }
}

/// Update Config.
///
/// ID: `a229dd06`.
class UpdateConfig extends UpdateBase {
  /// Update Config constructor.
  const UpdateConfig() : super._();

  /// Deserialize.
  factory UpdateConfig.deserialize(BinaryReader reader) {
    // Construct [UpdateConfig] object.
    final returnValue = UpdateConfig();

    // Now return the deserialized [UpdateConfig].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa229dd06.
    buffer.writeInt32(0xa229dd06);

    // Finished serialization.
  }
}

/// Update Pts Changed.
///
/// ID: `3354678f`.
class UpdatePtsChanged extends UpdateBase {
  /// Update Pts Changed constructor.
  const UpdatePtsChanged() : super._();

  /// Deserialize.
  factory UpdatePtsChanged.deserialize(BinaryReader reader) {
    // Construct [UpdatePtsChanged] object.
    final returnValue = UpdatePtsChanged();

    // Now return the deserialized [UpdatePtsChanged].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3354678f.
    buffer.writeInt32(0x3354678f);

    // Finished serialization.
  }
}

/// Update Channel Web Page.
///
/// ID: `2f2ba99f`.
class UpdateChannelWebPage extends UpdateBase {
  /// Update Channel Web Page constructor.
  const UpdateChannelWebPage({
    required this.channelId,
    required this.webpage,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelWebPage.deserialize(BinaryReader reader) {
    // Read [UpdateChannelWebPage] fields.
    final channelId = reader.readInt64();
    final webpage = reader.readObject() as WebPageBase;
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateChannelWebPage] object.
    final returnValue = UpdateChannelWebPage(
      channelId: channelId,
      webpage: webpage,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateChannelWebPage].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Webpage.
  final WebPageBase webpage;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2f2ba99f.
    buffer.writeInt32(0x2f2ba99f);

    // Write fields.
    buffer.writeInt64(channelId);
    buffer.writeObject(webpage);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Dialog Pinned.
///
/// ID: `6e6fe51c`.
class UpdateDialogPinned extends UpdateBase {
  /// Update Dialog Pinned constructor.
  const UpdateDialogPinned({
    required this.pinned,
    this.folderId,
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory UpdateDialogPinned.deserialize(BinaryReader reader) {
    // Read [UpdateDialogPinned] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 1) != 0;
    final hasFolderIdField = (flags & 2) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final peer = reader.readObject() as DialogPeerBase;

    // Construct [UpdateDialogPinned] object.
    final returnValue = UpdateDialogPinned(
      pinned: pinned,
      folderId: folderId,
      peer: peer,
    );

    // Now return the deserialized [UpdateDialogPinned].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pinned,
      b01: folderId != null,
    );

    return v;
  }

  /// pinned: bit 0 of flags.0?true
  final bool pinned;

  /// Folder Id.
  final int? folderId;

  /// Peer.
  final DialogPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6e6fe51c.
    buffer.writeInt32(0x6e6fe51c);

    // Write fields.
    buffer.writeInt32(flags);
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Update Pinned Dialogs.
///
/// ID: `fa0f3ca2`.
class UpdatePinnedDialogs extends UpdateBase {
  /// Update Pinned Dialogs constructor.
  const UpdatePinnedDialogs({
    this.folderId,
    this.order,
  }) : super._();

  /// Deserialize.
  factory UpdatePinnedDialogs.deserialize(BinaryReader reader) {
    // Read [UpdatePinnedDialogs] fields.
    final flags = reader.readInt32();
    final hasFolderIdField = (flags & 2) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final hasOrderField = (flags & 1) != 0;
    final order =
        hasOrderField ? reader.readVectorObject<DialogPeerBase>() : null;

    // Construct [UpdatePinnedDialogs] object.
    final returnValue = UpdatePinnedDialogs(
      folderId: folderId,
      order: order,
    );

    // Now return the deserialized [UpdatePinnedDialogs].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: folderId != null,
      b00: order != null,
    );

    return v;
  }

  /// Folder Id.
  final int? folderId;

  /// Order.
  final List<DialogPeerBase>? order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfa0f3ca2.
    buffer.writeInt32(0xfa0f3ca2);

    // Write fields.
    buffer.writeInt32(flags);
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    final localOrderCopy = order;
    if (localOrderCopy != null) {
      buffer.writeVectorObject(localOrderCopy);
    }

    // Finished serialization.
  }
}

/// Update Bot Webhook J S O N.
///
/// ID: `8317c0c3`.
class UpdateBotWebhookJSON extends UpdateBase {
  /// Update Bot Webhook J S O N constructor.
  const UpdateBotWebhookJSON({
    required this.data,
  }) : super._();

  /// Deserialize.
  factory UpdateBotWebhookJSON.deserialize(BinaryReader reader) {
    // Read [UpdateBotWebhookJSON] fields.
    final data = reader.readObject() as DataJSONBase;

    // Construct [UpdateBotWebhookJSON] object.
    final returnValue = UpdateBotWebhookJSON(
      data: data,
    );

    // Now return the deserialized [UpdateBotWebhookJSON].
    return returnValue;
  }

  /// Data.
  final DataJSONBase data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8317c0c3.
    buffer.writeInt32(0x8317c0c3);

    // Write fields.
    buffer.writeObject(data);

    // Finished serialization.
  }
}

/// Update Bot Webhook J S O N Query.
///
/// ID: `9b9240a6`.
class UpdateBotWebhookJSONQuery extends UpdateBase {
  /// Update Bot Webhook J S O N Query constructor.
  const UpdateBotWebhookJSONQuery({
    required this.queryId,
    required this.data,
    required this.timeout,
  }) : super._();

  /// Deserialize.
  factory UpdateBotWebhookJSONQuery.deserialize(BinaryReader reader) {
    // Read [UpdateBotWebhookJSONQuery] fields.
    final queryId = reader.readInt64();
    final data = reader.readObject() as DataJSONBase;
    final timeout = reader.readInt32();

    // Construct [UpdateBotWebhookJSONQuery] object.
    final returnValue = UpdateBotWebhookJSONQuery(
      queryId: queryId,
      data: data,
      timeout: timeout,
    );

    // Now return the deserialized [UpdateBotWebhookJSONQuery].
    return returnValue;
  }

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Data.
  final DataJSONBase data;

  /// Timeout.
  ///
  /// Field type is Int32.
  final int timeout;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9b9240a6.
    buffer.writeInt32(0x9b9240a6);

    // Write fields.
    buffer.writeInt64(queryId);
    buffer.writeObject(data);
    buffer.writeInt32(timeout);

    // Finished serialization.
  }
}

/// Update Bot Shipping Query.
///
/// ID: `b5aefd7d`.
class UpdateBotShippingQuery extends UpdateBase {
  /// Update Bot Shipping Query constructor.
  const UpdateBotShippingQuery({
    required this.queryId,
    required this.userId,
    required this.payload,
    required this.shippingAddress,
  }) : super._();

  /// Deserialize.
  factory UpdateBotShippingQuery.deserialize(BinaryReader reader) {
    // Read [UpdateBotShippingQuery] fields.
    final queryId = reader.readInt64();
    final userId = reader.readInt64();
    final payload = reader.readBytes();
    final shippingAddress = reader.readObject() as PostAddressBase;

    // Construct [UpdateBotShippingQuery] object.
    final returnValue = UpdateBotShippingQuery(
      queryId: queryId,
      userId: userId,
      payload: payload,
      shippingAddress: shippingAddress,
    );

    // Now return the deserialized [UpdateBotShippingQuery].
    return returnValue;
  }

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Payload.
  final Uint8List payload;

  /// Shipping Address.
  final PostAddressBase shippingAddress;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb5aefd7d.
    buffer.writeInt32(0xb5aefd7d);

    // Write fields.
    buffer.writeInt64(queryId);
    buffer.writeInt64(userId);
    buffer.writeBytes(payload);
    buffer.writeObject(shippingAddress);

    // Finished serialization.
  }
}

/// Update Bot Precheckout Query.
///
/// ID: `8caa9a96`.
class UpdateBotPrecheckoutQuery extends UpdateBase {
  /// Update Bot Precheckout Query constructor.
  const UpdateBotPrecheckoutQuery({
    required this.queryId,
    required this.userId,
    required this.payload,
    this.info,
    this.shippingOptionId,
    required this.currency,
    required this.totalAmount,
  }) : super._();

  /// Deserialize.
  factory UpdateBotPrecheckoutQuery.deserialize(BinaryReader reader) {
    // Read [UpdateBotPrecheckoutQuery] fields.
    final flags = reader.readInt32();
    final queryId = reader.readInt64();
    final userId = reader.readInt64();
    final payload = reader.readBytes();
    final hasInfoField = (flags & 1) != 0;
    final info =
        hasInfoField ? reader.readObject() as PaymentRequestedInfoBase : null;
    final hasShippingOptionIdField = (flags & 2) != 0;
    final shippingOptionId =
        hasShippingOptionIdField ? reader.readString() : null;
    final currency = reader.readString();
    final totalAmount = reader.readInt64();

    // Construct [UpdateBotPrecheckoutQuery] object.
    final returnValue = UpdateBotPrecheckoutQuery(
      queryId: queryId,
      userId: userId,
      payload: payload,
      info: info,
      shippingOptionId: shippingOptionId,
      currency: currency,
      totalAmount: totalAmount,
    );

    // Now return the deserialized [UpdateBotPrecheckoutQuery].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: info != null,
      b01: shippingOptionId != null,
    );

    return v;
  }

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Payload.
  final Uint8List payload;

  /// Info.
  final PaymentRequestedInfoBase? info;

  /// Shipping Option Id.
  final String? shippingOptionId;

  /// Currency.
  final String currency;

  /// Total Amount.
  ///
  /// Field type is Int64.
  final int totalAmount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8caa9a96.
    buffer.writeInt32(0x8caa9a96);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(queryId);
    buffer.writeInt64(userId);
    buffer.writeBytes(payload);
    final localInfoCopy = info;
    if (localInfoCopy != null) {
      buffer.writeObject(localInfoCopy);
    }
    final localShippingOptionIdCopy = shippingOptionId;
    if (localShippingOptionIdCopy != null) {
      buffer.writeString(localShippingOptionIdCopy);
    }
    buffer.writeString(currency);
    buffer.writeInt64(totalAmount);

    // Finished serialization.
  }
}

/// Update Phone Call.
///
/// ID: `ab0f6b1e`.
class UpdatePhoneCall extends UpdateBase {
  /// Update Phone Call constructor.
  const UpdatePhoneCall({
    required this.phoneCall,
  }) : super._();

  /// Deserialize.
  factory UpdatePhoneCall.deserialize(BinaryReader reader) {
    // Read [UpdatePhoneCall] fields.
    final phoneCall = reader.readObject() as PhoneCallBase;

    // Construct [UpdatePhoneCall] object.
    final returnValue = UpdatePhoneCall(
      phoneCall: phoneCall,
    );

    // Now return the deserialized [UpdatePhoneCall].
    return returnValue;
  }

  /// Phone Call.
  final PhoneCallBase phoneCall;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xab0f6b1e.
    buffer.writeInt32(0xab0f6b1e);

    // Write fields.
    buffer.writeObject(phoneCall);

    // Finished serialization.
  }
}

/// Update Lang Pack Too Long.
///
/// ID: `46560264`.
class UpdateLangPackTooLong extends UpdateBase {
  /// Update Lang Pack Too Long constructor.
  const UpdateLangPackTooLong({
    required this.langCode,
  }) : super._();

  /// Deserialize.
  factory UpdateLangPackTooLong.deserialize(BinaryReader reader) {
    // Read [UpdateLangPackTooLong] fields.
    final langCode = reader.readString();

    // Construct [UpdateLangPackTooLong] object.
    final returnValue = UpdateLangPackTooLong(
      langCode: langCode,
    );

    // Now return the deserialized [UpdateLangPackTooLong].
    return returnValue;
  }

  /// Lang Code.
  final String langCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x46560264.
    buffer.writeInt32(0x46560264);

    // Write fields.
    buffer.writeString(langCode);

    // Finished serialization.
  }
}

/// Update Lang Pack.
///
/// ID: `56022f4d`.
class UpdateLangPack extends UpdateBase {
  /// Update Lang Pack constructor.
  const UpdateLangPack({
    required this.difference,
  }) : super._();

  /// Deserialize.
  factory UpdateLangPack.deserialize(BinaryReader reader) {
    // Read [UpdateLangPack] fields.
    final difference = reader.readObject() as LangPackDifferenceBase;

    // Construct [UpdateLangPack] object.
    final returnValue = UpdateLangPack(
      difference: difference,
    );

    // Now return the deserialized [UpdateLangPack].
    return returnValue;
  }

  /// Difference.
  final LangPackDifferenceBase difference;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x56022f4d.
    buffer.writeInt32(0x56022f4d);

    // Write fields.
    buffer.writeObject(difference);

    // Finished serialization.
  }
}

/// Update Faved Stickers.
///
/// ID: `e511996d`.
class UpdateFavedStickers extends UpdateBase {
  /// Update Faved Stickers constructor.
  const UpdateFavedStickers() : super._();

  /// Deserialize.
  factory UpdateFavedStickers.deserialize(BinaryReader reader) {
    // Construct [UpdateFavedStickers] object.
    final returnValue = UpdateFavedStickers();

    // Now return the deserialized [UpdateFavedStickers].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe511996d.
    buffer.writeInt32(0xe511996d);

    // Finished serialization.
  }
}

/// Update Channel Read Messages Contents.
///
/// ID: `ea29055d`.
class UpdateChannelReadMessagesContents extends UpdateBase {
  /// Update Channel Read Messages Contents constructor.
  const UpdateChannelReadMessagesContents({
    required this.channelId,
    this.topMsgId,
    required this.messages,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelReadMessagesContents.deserialize(BinaryReader reader) {
    // Read [UpdateChannelReadMessagesContents] fields.
    final flags = reader.readInt32();
    final channelId = reader.readInt64();
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final messages = reader.readVectorInt32();

    // Construct [UpdateChannelReadMessagesContents] object.
    final returnValue = UpdateChannelReadMessagesContents(
      channelId: channelId,
      topMsgId: topMsgId,
      messages: messages,
    );

    // Now return the deserialized [UpdateChannelReadMessagesContents].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
    );

    return v;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Top Msg Id.
  final int? topMsgId;

  /// Messages.
  final List<int> messages;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xea29055d.
    buffer.writeInt32(0xea29055d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(channelId);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    buffer.writeVectorInt32(messages);

    // Finished serialization.
  }
}

/// Update Contacts Reset.
///
/// ID: `7084a7be`.
class UpdateContactsReset extends UpdateBase {
  /// Update Contacts Reset constructor.
  const UpdateContactsReset() : super._();

  /// Deserialize.
  factory UpdateContactsReset.deserialize(BinaryReader reader) {
    // Construct [UpdateContactsReset] object.
    final returnValue = UpdateContactsReset();

    // Now return the deserialized [UpdateContactsReset].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7084a7be.
    buffer.writeInt32(0x7084a7be);

    // Finished serialization.
  }
}

/// Update Channel Available Messages.
///
/// ID: `b23fc698`.
class UpdateChannelAvailableMessages extends UpdateBase {
  /// Update Channel Available Messages constructor.
  const UpdateChannelAvailableMessages({
    required this.channelId,
    required this.availableMinId,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelAvailableMessages.deserialize(BinaryReader reader) {
    // Read [UpdateChannelAvailableMessages] fields.
    final channelId = reader.readInt64();
    final availableMinId = reader.readInt32();

    // Construct [UpdateChannelAvailableMessages] object.
    final returnValue = UpdateChannelAvailableMessages(
      channelId: channelId,
      availableMinId: availableMinId,
    );

    // Now return the deserialized [UpdateChannelAvailableMessages].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Available Min Id.
  ///
  /// Field type is Int32.
  final int availableMinId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb23fc698.
    buffer.writeInt32(0xb23fc698);

    // Write fields.
    buffer.writeInt64(channelId);
    buffer.writeInt32(availableMinId);

    // Finished serialization.
  }
}

/// Update Dialog Unread Mark.
///
/// ID: `e16459c3`.
class UpdateDialogUnreadMark extends UpdateBase {
  /// Update Dialog Unread Mark constructor.
  const UpdateDialogUnreadMark({
    required this.unread,
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory UpdateDialogUnreadMark.deserialize(BinaryReader reader) {
    // Read [UpdateDialogUnreadMark] fields.
    final flags = reader.readInt32();
    final unread = (flags & 1) != 0;
    final peer = reader.readObject() as DialogPeerBase;

    // Construct [UpdateDialogUnreadMark] object.
    final returnValue = UpdateDialogUnreadMark(
      unread: unread,
      peer: peer,
    );

    // Now return the deserialized [UpdateDialogUnreadMark].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: unread,
    );

    return v;
  }

  /// unread: bit 0 of flags.0?true
  final bool unread;

  /// Peer.
  final DialogPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe16459c3.
    buffer.writeInt32(0xe16459c3);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Update Message Poll.
///
/// ID: `aca1657b`.
class UpdateMessagePoll extends UpdateBase {
  /// Update Message Poll constructor.
  const UpdateMessagePoll({
    required this.pollId,
    this.poll,
    required this.results,
  }) : super._();

  /// Deserialize.
  factory UpdateMessagePoll.deserialize(BinaryReader reader) {
    // Read [UpdateMessagePoll] fields.
    final flags = reader.readInt32();
    final pollId = reader.readInt64();
    final hasPollField = (flags & 1) != 0;
    final poll = hasPollField ? reader.readObject() as PollBase : null;
    final results = reader.readObject() as PollResultsBase;

    // Construct [UpdateMessagePoll] object.
    final returnValue = UpdateMessagePoll(
      pollId: pollId,
      poll: poll,
      results: results,
    );

    // Now return the deserialized [UpdateMessagePoll].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: poll != null,
    );

    return v;
  }

  /// Poll Id.
  ///
  /// Field type is Int64.
  final int pollId;

  /// Poll.
  final PollBase? poll;

  /// Results.
  final PollResultsBase results;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaca1657b.
    buffer.writeInt32(0xaca1657b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(pollId);
    final localPollCopy = poll;
    if (localPollCopy != null) {
      buffer.writeObject(localPollCopy);
    }
    buffer.writeObject(results);

    // Finished serialization.
  }
}

/// Update Chat Default Banned Rights.
///
/// ID: `54c01850`.
class UpdateChatDefaultBannedRights extends UpdateBase {
  /// Update Chat Default Banned Rights constructor.
  const UpdateChatDefaultBannedRights({
    required this.peer,
    required this.defaultBannedRights,
    required this.version,
  }) : super._();

  /// Deserialize.
  factory UpdateChatDefaultBannedRights.deserialize(BinaryReader reader) {
    // Read [UpdateChatDefaultBannedRights] fields.
    final peer = reader.readObject() as PeerBase;
    final defaultBannedRights = reader.readObject() as ChatBannedRightsBase;
    final version = reader.readInt32();

    // Construct [UpdateChatDefaultBannedRights] object.
    final returnValue = UpdateChatDefaultBannedRights(
      peer: peer,
      defaultBannedRights: defaultBannedRights,
      version: version,
    );

    // Now return the deserialized [UpdateChatDefaultBannedRights].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Default Banned Rights.
  final ChatBannedRightsBase defaultBannedRights;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x54c01850.
    buffer.writeInt32(0x54c01850);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(defaultBannedRights);
    buffer.writeInt32(version);

    // Finished serialization.
  }
}

/// Update Folder Peers.
///
/// ID: `19360dc0`.
class UpdateFolderPeers extends UpdateBase {
  /// Update Folder Peers constructor.
  const UpdateFolderPeers({
    required this.folderPeers,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdateFolderPeers.deserialize(BinaryReader reader) {
    // Read [UpdateFolderPeers] fields.
    final folderPeers = reader.readVectorObject<FolderPeerBase>();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdateFolderPeers] object.
    final returnValue = UpdateFolderPeers(
      folderPeers: folderPeers,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdateFolderPeers].
    return returnValue;
  }

  /// Folder Peers.
  final List<FolderPeerBase> folderPeers;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x19360dc0.
    buffer.writeInt32(0x19360dc0);

    // Write fields.
    buffer.writeVectorObject(folderPeers);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Peer Settings.
///
/// ID: `6a7e7366`.
class UpdatePeerSettings extends UpdateBase {
  /// Update Peer Settings constructor.
  const UpdatePeerSettings({
    required this.peer,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory UpdatePeerSettings.deserialize(BinaryReader reader) {
    // Read [UpdatePeerSettings] fields.
    final peer = reader.readObject() as PeerBase;
    final settings = reader.readObject() as PeerSettingsBase;

    // Construct [UpdatePeerSettings] object.
    final returnValue = UpdatePeerSettings(
      peer: peer,
      settings: settings,
    );

    // Now return the deserialized [UpdatePeerSettings].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Settings.
  final PeerSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6a7e7366.
    buffer.writeInt32(0x6a7e7366);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Update Peer Located.
///
/// ID: `b4afcfb0`.
class UpdatePeerLocated extends UpdateBase {
  /// Update Peer Located constructor.
  const UpdatePeerLocated({
    required this.peers,
  }) : super._();

  /// Deserialize.
  factory UpdatePeerLocated.deserialize(BinaryReader reader) {
    // Read [UpdatePeerLocated] fields.
    final peers = reader.readVectorObject<PeerLocatedBase>();

    // Construct [UpdatePeerLocated] object.
    final returnValue = UpdatePeerLocated(
      peers: peers,
    );

    // Now return the deserialized [UpdatePeerLocated].
    return returnValue;
  }

  /// Peers.
  final List<PeerLocatedBase> peers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb4afcfb0.
    buffer.writeInt32(0xb4afcfb0);

    // Write fields.
    buffer.writeVectorObject(peers);

    // Finished serialization.
  }
}

/// Update New Scheduled Message.
///
/// ID: `39a51dfb`.
class UpdateNewScheduledMessage extends UpdateBase {
  /// Update New Scheduled Message constructor.
  const UpdateNewScheduledMessage({
    required this.message,
  }) : super._();

  /// Deserialize.
  factory UpdateNewScheduledMessage.deserialize(BinaryReader reader) {
    // Read [UpdateNewScheduledMessage] fields.
    final message = reader.readObject() as MessageBase;

    // Construct [UpdateNewScheduledMessage] object.
    final returnValue = UpdateNewScheduledMessage(
      message: message,
    );

    // Now return the deserialized [UpdateNewScheduledMessage].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x39a51dfb.
    buffer.writeInt32(0x39a51dfb);

    // Write fields.
    buffer.writeObject(message);

    // Finished serialization.
  }
}

/// Update Delete Scheduled Messages.
///
/// ID: `90866cee`.
class UpdateDeleteScheduledMessages extends UpdateBase {
  /// Update Delete Scheduled Messages constructor.
  const UpdateDeleteScheduledMessages({
    required this.peer,
    required this.messages,
  }) : super._();

  /// Deserialize.
  factory UpdateDeleteScheduledMessages.deserialize(BinaryReader reader) {
    // Read [UpdateDeleteScheduledMessages] fields.
    final peer = reader.readObject() as PeerBase;
    final messages = reader.readVectorInt32();

    // Construct [UpdateDeleteScheduledMessages] object.
    final returnValue = UpdateDeleteScheduledMessages(
      peer: peer,
      messages: messages,
    );

    // Now return the deserialized [UpdateDeleteScheduledMessages].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Messages.
  final List<int> messages;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x90866cee.
    buffer.writeInt32(0x90866cee);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(messages);

    // Finished serialization.
  }
}

/// Update Theme.
///
/// ID: `8216fba3`.
class UpdateTheme extends UpdateBase {
  /// Update Theme constructor.
  const UpdateTheme({
    required this.theme,
  }) : super._();

  /// Deserialize.
  factory UpdateTheme.deserialize(BinaryReader reader) {
    // Read [UpdateTheme] fields.
    final theme = reader.readObject() as ThemeBase;

    // Construct [UpdateTheme] object.
    final returnValue = UpdateTheme(
      theme: theme,
    );

    // Now return the deserialized [UpdateTheme].
    return returnValue;
  }

  /// Theme.
  final ThemeBase theme;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8216fba3.
    buffer.writeInt32(0x8216fba3);

    // Write fields.
    buffer.writeObject(theme);

    // Finished serialization.
  }
}

/// Update Geo Live Viewed.
///
/// ID: `871fb939`.
class UpdateGeoLiveViewed extends UpdateBase {
  /// Update Geo Live Viewed constructor.
  const UpdateGeoLiveViewed({
    required this.peer,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory UpdateGeoLiveViewed.deserialize(BinaryReader reader) {
    // Read [UpdateGeoLiveViewed] fields.
    final peer = reader.readObject() as PeerBase;
    final msgId = reader.readInt32();

    // Construct [UpdateGeoLiveViewed] object.
    final returnValue = UpdateGeoLiveViewed(
      peer: peer,
      msgId: msgId,
    );

    // Now return the deserialized [UpdateGeoLiveViewed].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x871fb939.
    buffer.writeInt32(0x871fb939);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Update Login Token.
///
/// ID: `564fe691`.
class UpdateLoginToken extends UpdateBase {
  /// Update Login Token constructor.
  const UpdateLoginToken() : super._();

  /// Deserialize.
  factory UpdateLoginToken.deserialize(BinaryReader reader) {
    // Construct [UpdateLoginToken] object.
    final returnValue = UpdateLoginToken();

    // Now return the deserialized [UpdateLoginToken].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x564fe691.
    buffer.writeInt32(0x564fe691);

    // Finished serialization.
  }
}

/// Update Message Poll Vote.
///
/// ID: `24f40e77`.
class UpdateMessagePollVote extends UpdateBase {
  /// Update Message Poll Vote constructor.
  const UpdateMessagePollVote({
    required this.pollId,
    required this.peer,
    required this.options,
    required this.qts,
  }) : super._();

  /// Deserialize.
  factory UpdateMessagePollVote.deserialize(BinaryReader reader) {
    // Read [UpdateMessagePollVote] fields.
    final pollId = reader.readInt64();
    final peer = reader.readObject() as PeerBase;
    final options = reader.readVectorBytes();
    final qts = reader.readInt32();

    // Construct [UpdateMessagePollVote] object.
    final returnValue = UpdateMessagePollVote(
      pollId: pollId,
      peer: peer,
      options: options,
      qts: qts,
    );

    // Now return the deserialized [UpdateMessagePollVote].
    return returnValue;
  }

  /// Poll Id.
  ///
  /// Field type is Int64.
  final int pollId;

  /// Peer.
  final PeerBase peer;

  /// Options.
  final List<Uint8List> options;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x24f40e77.
    buffer.writeInt32(0x24f40e77);

    // Write fields.
    buffer.writeInt64(pollId);
    buffer.writeObject(peer);
    buffer.writeVectorBytes(options);
    buffer.writeInt32(qts);

    // Finished serialization.
  }
}

/// Update Dialog Filter.
///
/// ID: `26ffde7d`.
class UpdateDialogFilter extends UpdateBase {
  /// Update Dialog Filter constructor.
  const UpdateDialogFilter({
    required this.id,
    this.filter,
  }) : super._();

  /// Deserialize.
  factory UpdateDialogFilter.deserialize(BinaryReader reader) {
    // Read [UpdateDialogFilter] fields.
    final flags = reader.readInt32();
    final id = reader.readInt32();
    final hasFilterField = (flags & 1) != 0;
    final filter =
        hasFilterField ? reader.readObject() as DialogFilterBase : null;

    // Construct [UpdateDialogFilter] object.
    final returnValue = UpdateDialogFilter(
      id: id,
      filter: filter,
    );

    // Now return the deserialized [UpdateDialogFilter].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: filter != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Filter.
  final DialogFilterBase? filter;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x26ffde7d.
    buffer.writeInt32(0x26ffde7d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    final localFilterCopy = filter;
    if (localFilterCopy != null) {
      buffer.writeObject(localFilterCopy);
    }

    // Finished serialization.
  }
}

/// Update Dialog Filter Order.
///
/// ID: `a5d72105`.
class UpdateDialogFilterOrder extends UpdateBase {
  /// Update Dialog Filter Order constructor.
  const UpdateDialogFilterOrder({
    required this.order,
  }) : super._();

  /// Deserialize.
  factory UpdateDialogFilterOrder.deserialize(BinaryReader reader) {
    // Read [UpdateDialogFilterOrder] fields.
    final order = reader.readVectorInt32();

    // Construct [UpdateDialogFilterOrder] object.
    final returnValue = UpdateDialogFilterOrder(
      order: order,
    );

    // Now return the deserialized [UpdateDialogFilterOrder].
    return returnValue;
  }

  /// Order.
  final List<int> order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa5d72105.
    buffer.writeInt32(0xa5d72105);

    // Write fields.
    buffer.writeVectorInt32(order);

    // Finished serialization.
  }
}

/// Update Dialog Filters.
///
/// ID: `3504914f`.
class UpdateDialogFilters extends UpdateBase {
  /// Update Dialog Filters constructor.
  const UpdateDialogFilters() : super._();

  /// Deserialize.
  factory UpdateDialogFilters.deserialize(BinaryReader reader) {
    // Construct [UpdateDialogFilters] object.
    final returnValue = UpdateDialogFilters();

    // Now return the deserialized [UpdateDialogFilters].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3504914f.
    buffer.writeInt32(0x3504914f);

    // Finished serialization.
  }
}

/// Update Phone Call Signaling Data.
///
/// ID: `2661bf09`.
class UpdatePhoneCallSignalingData extends UpdateBase {
  /// Update Phone Call Signaling Data constructor.
  const UpdatePhoneCallSignalingData({
    required this.phoneCallId,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory UpdatePhoneCallSignalingData.deserialize(BinaryReader reader) {
    // Read [UpdatePhoneCallSignalingData] fields.
    final phoneCallId = reader.readInt64();
    final data = reader.readBytes();

    // Construct [UpdatePhoneCallSignalingData] object.
    final returnValue = UpdatePhoneCallSignalingData(
      phoneCallId: phoneCallId,
      data: data,
    );

    // Now return the deserialized [UpdatePhoneCallSignalingData].
    return returnValue;
  }

  /// Phone Call Id.
  ///
  /// Field type is Int64.
  final int phoneCallId;

  /// Data.
  final Uint8List data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2661bf09.
    buffer.writeInt32(0x2661bf09);

    // Write fields.
    buffer.writeInt64(phoneCallId);
    buffer.writeBytes(data);

    // Finished serialization.
  }
}

/// Update Channel Message Forwards.
///
/// ID: `d29a27f4`.
class UpdateChannelMessageForwards extends UpdateBase {
  /// Update Channel Message Forwards constructor.
  const UpdateChannelMessageForwards({
    required this.channelId,
    required this.id,
    required this.forwards,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelMessageForwards.deserialize(BinaryReader reader) {
    // Read [UpdateChannelMessageForwards] fields.
    final channelId = reader.readInt64();
    final id = reader.readInt32();
    final forwards = reader.readInt32();

    // Construct [UpdateChannelMessageForwards] object.
    final returnValue = UpdateChannelMessageForwards(
      channelId: channelId,
      id: id,
      forwards: forwards,
    );

    // Now return the deserialized [UpdateChannelMessageForwards].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Forwards.
  ///
  /// Field type is Int32.
  final int forwards;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd29a27f4.
    buffer.writeInt32(0xd29a27f4);

    // Write fields.
    buffer.writeInt64(channelId);
    buffer.writeInt32(id);
    buffer.writeInt32(forwards);

    // Finished serialization.
  }
}

/// Update Read Channel Discussion Inbox.
///
/// ID: `d6b19546`.
class UpdateReadChannelDiscussionInbox extends UpdateBase {
  /// Update Read Channel Discussion Inbox constructor.
  const UpdateReadChannelDiscussionInbox({
    required this.channelId,
    required this.topMsgId,
    required this.readMaxId,
    this.broadcastId,
    this.broadcastPost,
  }) : super._();

  /// Deserialize.
  factory UpdateReadChannelDiscussionInbox.deserialize(BinaryReader reader) {
    // Read [UpdateReadChannelDiscussionInbox] fields.
    final flags = reader.readInt32();
    final channelId = reader.readInt64();
    final topMsgId = reader.readInt32();
    final readMaxId = reader.readInt32();
    final hasBroadcastIdField = (flags & 1) != 0;
    final broadcastId = hasBroadcastIdField ? reader.readInt64() : null;
    final hasBroadcastPostField = (flags & 1) != 0;
    final broadcastPost = hasBroadcastPostField ? reader.readInt32() : null;

    // Construct [UpdateReadChannelDiscussionInbox] object.
    final returnValue = UpdateReadChannelDiscussionInbox(
      channelId: channelId,
      topMsgId: topMsgId,
      readMaxId: readMaxId,
      broadcastId: broadcastId,
      broadcastPost: broadcastPost,
    );

    // Now return the deserialized [UpdateReadChannelDiscussionInbox].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: broadcastId != null || broadcastPost != null,
    );

    return v;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Top Msg Id.
  ///
  /// Field type is Int32.
  final int topMsgId;

  /// Read Max Id.
  ///
  /// Field type is Int32.
  final int readMaxId;

  /// Broadcast Id.
  final int? broadcastId;

  /// Broadcast Post.
  final int? broadcastPost;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd6b19546.
    buffer.writeInt32(0xd6b19546);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(channelId);
    buffer.writeInt32(topMsgId);
    buffer.writeInt32(readMaxId);
    final localBroadcastIdCopy = broadcastId;
    if (localBroadcastIdCopy != null) {
      buffer.writeInt64(localBroadcastIdCopy);
    }
    final localBroadcastPostCopy = broadcastPost;
    if (localBroadcastPostCopy != null) {
      buffer.writeInt32(localBroadcastPostCopy);
    }

    // Finished serialization.
  }
}

/// Update Read Channel Discussion Outbox.
///
/// ID: `695c9e7c`.
class UpdateReadChannelDiscussionOutbox extends UpdateBase {
  /// Update Read Channel Discussion Outbox constructor.
  const UpdateReadChannelDiscussionOutbox({
    required this.channelId,
    required this.topMsgId,
    required this.readMaxId,
  }) : super._();

  /// Deserialize.
  factory UpdateReadChannelDiscussionOutbox.deserialize(BinaryReader reader) {
    // Read [UpdateReadChannelDiscussionOutbox] fields.
    final channelId = reader.readInt64();
    final topMsgId = reader.readInt32();
    final readMaxId = reader.readInt32();

    // Construct [UpdateReadChannelDiscussionOutbox] object.
    final returnValue = UpdateReadChannelDiscussionOutbox(
      channelId: channelId,
      topMsgId: topMsgId,
      readMaxId: readMaxId,
    );

    // Now return the deserialized [UpdateReadChannelDiscussionOutbox].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Top Msg Id.
  ///
  /// Field type is Int32.
  final int topMsgId;

  /// Read Max Id.
  ///
  /// Field type is Int32.
  final int readMaxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x695c9e7c.
    buffer.writeInt32(0x695c9e7c);

    // Write fields.
    buffer.writeInt64(channelId);
    buffer.writeInt32(topMsgId);
    buffer.writeInt32(readMaxId);

    // Finished serialization.
  }
}

/// Update Peer Blocked.
///
/// ID: `ebe07752`.
class UpdatePeerBlocked extends UpdateBase {
  /// Update Peer Blocked constructor.
  const UpdatePeerBlocked({
    required this.blocked,
    required this.blockedMyStoriesFrom,
    required this.peerId,
  }) : super._();

  /// Deserialize.
  factory UpdatePeerBlocked.deserialize(BinaryReader reader) {
    // Read [UpdatePeerBlocked] fields.
    final flags = reader.readInt32();
    final blocked = (flags & 1) != 0;
    final blockedMyStoriesFrom = (flags & 2) != 0;
    final peerId = reader.readObject() as PeerBase;

    // Construct [UpdatePeerBlocked] object.
    final returnValue = UpdatePeerBlocked(
      blocked: blocked,
      blockedMyStoriesFrom: blockedMyStoriesFrom,
      peerId: peerId,
    );

    // Now return the deserialized [UpdatePeerBlocked].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: blocked,
      b01: blockedMyStoriesFrom,
    );

    return v;
  }

  /// blocked: bit 0 of flags.0?true
  final bool blocked;

  /// blocked_my_stories_from: bit 1 of flags.1?true
  final bool blockedMyStoriesFrom;

  /// Peer Id.
  final PeerBase peerId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xebe07752.
    buffer.writeInt32(0xebe07752);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peerId);

    // Finished serialization.
  }
}

/// Update Channel User Typing.
///
/// ID: `8c88c923`.
class UpdateChannelUserTyping extends UpdateBase {
  /// Update Channel User Typing constructor.
  const UpdateChannelUserTyping({
    required this.channelId,
    this.topMsgId,
    required this.fromId,
    required this.action,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelUserTyping.deserialize(BinaryReader reader) {
    // Read [UpdateChannelUserTyping] fields.
    final flags = reader.readInt32();
    final channelId = reader.readInt64();
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final fromId = reader.readObject() as PeerBase;
    final action = reader.readObject() as SendMessageActionBase;

    // Construct [UpdateChannelUserTyping] object.
    final returnValue = UpdateChannelUserTyping(
      channelId: channelId,
      topMsgId: topMsgId,
      fromId: fromId,
      action: action,
    );

    // Now return the deserialized [UpdateChannelUserTyping].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
    );

    return v;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Top Msg Id.
  final int? topMsgId;

  /// From Id.
  final PeerBase fromId;

  /// Action.
  final SendMessageActionBase action;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8c88c923.
    buffer.writeInt32(0x8c88c923);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(channelId);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    buffer.writeObject(fromId);
    buffer.writeObject(action);

    // Finished serialization.
  }
}

/// Update Pinned Messages.
///
/// ID: `ed85eab5`.
class UpdatePinnedMessages extends UpdateBase {
  /// Update Pinned Messages constructor.
  const UpdatePinnedMessages({
    required this.pinned,
    required this.peer,
    required this.messages,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdatePinnedMessages.deserialize(BinaryReader reader) {
    // Read [UpdatePinnedMessages] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 1) != 0;
    final peer = reader.readObject() as PeerBase;
    final messages = reader.readVectorInt32();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdatePinnedMessages] object.
    final returnValue = UpdatePinnedMessages(
      pinned: pinned,
      peer: peer,
      messages: messages,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdatePinnedMessages].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pinned,
    );

    return v;
  }

  /// pinned: bit 0 of flags.0?true
  final bool pinned;

  /// Peer.
  final PeerBase peer;

  /// Messages.
  final List<int> messages;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xed85eab5.
    buffer.writeInt32(0xed85eab5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeVectorInt32(messages);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Pinned Channel Messages.
///
/// ID: `5bb98608`.
class UpdatePinnedChannelMessages extends UpdateBase {
  /// Update Pinned Channel Messages constructor.
  const UpdatePinnedChannelMessages({
    required this.pinned,
    required this.channelId,
    required this.messages,
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory UpdatePinnedChannelMessages.deserialize(BinaryReader reader) {
    // Read [UpdatePinnedChannelMessages] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 1) != 0;
    final channelId = reader.readInt64();
    final messages = reader.readVectorInt32();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [UpdatePinnedChannelMessages] object.
    final returnValue = UpdatePinnedChannelMessages(
      pinned: pinned,
      channelId: channelId,
      messages: messages,
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [UpdatePinnedChannelMessages].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pinned,
    );

    return v;
  }

  /// pinned: bit 0 of flags.0?true
  final bool pinned;

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Messages.
  final List<int> messages;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5bb98608.
    buffer.writeInt32(0x5bb98608);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(channelId);
    buffer.writeVectorInt32(messages);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Update Chat.
///
/// ID: `f89a6a4e`.
class UpdateChat extends UpdateBase {
  /// Update Chat constructor.
  const UpdateChat({
    required this.chatId,
  }) : super._();

  /// Deserialize.
  factory UpdateChat.deserialize(BinaryReader reader) {
    // Read [UpdateChat] fields.
    final chatId = reader.readInt64();

    // Construct [UpdateChat] object.
    final returnValue = UpdateChat(
      chatId: chatId,
    );

    // Now return the deserialized [UpdateChat].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf89a6a4e.
    buffer.writeInt32(0xf89a6a4e);

    // Write fields.
    buffer.writeInt64(chatId);

    // Finished serialization.
  }
}

/// Update Group Call Participants.
///
/// ID: `f2ebdb4e`.
class UpdateGroupCallParticipants extends UpdateBase {
  /// Update Group Call Participants constructor.
  const UpdateGroupCallParticipants({
    required this.call,
    required this.participants,
    required this.version,
  }) : super._();

  /// Deserialize.
  factory UpdateGroupCallParticipants.deserialize(BinaryReader reader) {
    // Read [UpdateGroupCallParticipants] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final participants = reader.readVectorObject<GroupCallParticipantBase>();
    final version = reader.readInt32();

    // Construct [UpdateGroupCallParticipants] object.
    final returnValue = UpdateGroupCallParticipants(
      call: call,
      participants: participants,
      version: version,
    );

    // Now return the deserialized [UpdateGroupCallParticipants].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Participants.
  final List<GroupCallParticipantBase> participants;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf2ebdb4e.
    buffer.writeInt32(0xf2ebdb4e);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeVectorObject(participants);
    buffer.writeInt32(version);

    // Finished serialization.
  }
}

/// Update Group Call.
///
/// ID: `14b24500`.
class UpdateGroupCall extends UpdateBase {
  /// Update Group Call constructor.
  const UpdateGroupCall({
    required this.chatId,
    required this.call,
  }) : super._();

  /// Deserialize.
  factory UpdateGroupCall.deserialize(BinaryReader reader) {
    // Read [UpdateGroupCall] fields.
    final chatId = reader.readInt64();
    final call = reader.readObject() as GroupCallBase;

    // Construct [UpdateGroupCall] object.
    final returnValue = UpdateGroupCall(
      chatId: chatId,
      call: call,
    );

    // Now return the deserialized [UpdateGroupCall].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Call.
  final GroupCallBase call;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x14b24500.
    buffer.writeInt32(0x14b24500);

    // Write fields.
    buffer.writeInt64(chatId);
    buffer.writeObject(call);

    // Finished serialization.
  }
}

/// Update Peer History T T L.
///
/// ID: `bb9bb9a5`.
class UpdatePeerHistoryTTL extends UpdateBase {
  /// Update Peer History T T L constructor.
  const UpdatePeerHistoryTTL({
    required this.peer,
    this.ttlPeriod,
  }) : super._();

  /// Deserialize.
  factory UpdatePeerHistoryTTL.deserialize(BinaryReader reader) {
    // Read [UpdatePeerHistoryTTL] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as PeerBase;
    final hasTtlPeriodField = (flags & 1) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;

    // Construct [UpdatePeerHistoryTTL] object.
    final returnValue = UpdatePeerHistoryTTL(
      peer: peer,
      ttlPeriod: ttlPeriod,
    );

    // Now return the deserialized [UpdatePeerHistoryTTL].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: ttlPeriod != null,
    );

    return v;
  }

  /// Peer.
  final PeerBase peer;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbb9bb9a5.
    buffer.writeInt32(0xbb9bb9a5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }

    // Finished serialization.
  }
}

/// Update Chat Participant.
///
/// ID: `d087663a`.
class UpdateChatParticipant extends UpdateBase {
  /// Update Chat Participant constructor.
  const UpdateChatParticipant({
    required this.chatId,
    required this.date,
    required this.actorId,
    required this.userId,
    this.prevParticipant,
    this.newParticipant,
    this.invite,
    required this.qts,
  }) : super._();

  /// Deserialize.
  factory UpdateChatParticipant.deserialize(BinaryReader reader) {
    // Read [UpdateChatParticipant] fields.
    final flags = reader.readInt32();
    final chatId = reader.readInt64();
    final date = reader.readDateTime();
    final actorId = reader.readInt64();
    final userId = reader.readInt64();
    final hasPrevParticipantField = (flags & 1) != 0;
    final prevParticipant = hasPrevParticipantField
        ? reader.readObject() as ChatParticipantBase
        : null;
    final hasNewParticipantField = (flags & 2) != 0;
    final newParticipant = hasNewParticipantField
        ? reader.readObject() as ChatParticipantBase
        : null;
    final hasInviteField = (flags & 4) != 0;
    final invite =
        hasInviteField ? reader.readObject() as ExportedChatInviteBase : null;
    final qts = reader.readInt32();

    // Construct [UpdateChatParticipant] object.
    final returnValue = UpdateChatParticipant(
      chatId: chatId,
      date: date,
      actorId: actorId,
      userId: userId,
      prevParticipant: prevParticipant,
      newParticipant: newParticipant,
      invite: invite,
      qts: qts,
    );

    // Now return the deserialized [UpdateChatParticipant].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: prevParticipant != null,
      b01: newParticipant != null,
      b02: invite != null,
    );

    return v;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Date.
  final DateTime date;

  /// Actor Id.
  ///
  /// Field type is Int64.
  final int actorId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Prev Participant.
  final ChatParticipantBase? prevParticipant;

  /// New Participant.
  final ChatParticipantBase? newParticipant;

  /// Invite.
  final ExportedChatInviteBase? invite;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd087663a.
    buffer.writeInt32(0xd087663a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(chatId);
    buffer.writeDateTime(date);
    buffer.writeInt64(actorId);
    buffer.writeInt64(userId);
    final localPrevParticipantCopy = prevParticipant;
    if (localPrevParticipantCopy != null) {
      buffer.writeObject(localPrevParticipantCopy);
    }
    final localNewParticipantCopy = newParticipant;
    if (localNewParticipantCopy != null) {
      buffer.writeObject(localNewParticipantCopy);
    }
    final localInviteCopy = invite;
    if (localInviteCopy != null) {
      buffer.writeObject(localInviteCopy);
    }
    buffer.writeInt32(qts);

    // Finished serialization.
  }
}

/// Update Channel Participant.
///
/// ID: `985d3abb`.
class UpdateChannelParticipant extends UpdateBase {
  /// Update Channel Participant constructor.
  const UpdateChannelParticipant({
    required this.viaChatlist,
    required this.channelId,
    required this.date,
    required this.actorId,
    required this.userId,
    this.prevParticipant,
    this.newParticipant,
    this.invite,
    required this.qts,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelParticipant.deserialize(BinaryReader reader) {
    // Read [UpdateChannelParticipant] fields.
    final flags = reader.readInt32();
    final viaChatlist = (flags & 8) != 0;
    final channelId = reader.readInt64();
    final date = reader.readDateTime();
    final actorId = reader.readInt64();
    final userId = reader.readInt64();
    final hasPrevParticipantField = (flags & 1) != 0;
    final prevParticipant = hasPrevParticipantField
        ? reader.readObject() as ChannelParticipantBase
        : null;
    final hasNewParticipantField = (flags & 2) != 0;
    final newParticipant = hasNewParticipantField
        ? reader.readObject() as ChannelParticipantBase
        : null;
    final hasInviteField = (flags & 4) != 0;
    final invite =
        hasInviteField ? reader.readObject() as ExportedChatInviteBase : null;
    final qts = reader.readInt32();

    // Construct [UpdateChannelParticipant] object.
    final returnValue = UpdateChannelParticipant(
      viaChatlist: viaChatlist,
      channelId: channelId,
      date: date,
      actorId: actorId,
      userId: userId,
      prevParticipant: prevParticipant,
      newParticipant: newParticipant,
      invite: invite,
      qts: qts,
    );

    // Now return the deserialized [UpdateChannelParticipant].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: viaChatlist,
      b00: prevParticipant != null,
      b01: newParticipant != null,
      b02: invite != null,
    );

    return v;
  }

  /// via_chatlist: bit 3 of flags.3?true
  final bool viaChatlist;

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Date.
  final DateTime date;

  /// Actor Id.
  ///
  /// Field type is Int64.
  final int actorId;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Prev Participant.
  final ChannelParticipantBase? prevParticipant;

  /// New Participant.
  final ChannelParticipantBase? newParticipant;

  /// Invite.
  final ExportedChatInviteBase? invite;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x985d3abb.
    buffer.writeInt32(0x985d3abb);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(channelId);
    buffer.writeDateTime(date);
    buffer.writeInt64(actorId);
    buffer.writeInt64(userId);
    final localPrevParticipantCopy = prevParticipant;
    if (localPrevParticipantCopy != null) {
      buffer.writeObject(localPrevParticipantCopy);
    }
    final localNewParticipantCopy = newParticipant;
    if (localNewParticipantCopy != null) {
      buffer.writeObject(localNewParticipantCopy);
    }
    final localInviteCopy = invite;
    if (localInviteCopy != null) {
      buffer.writeObject(localInviteCopy);
    }
    buffer.writeInt32(qts);

    // Finished serialization.
  }
}

/// Update Bot Stopped.
///
/// ID: `c4870a49`.
class UpdateBotStopped extends UpdateBase {
  /// Update Bot Stopped constructor.
  const UpdateBotStopped({
    required this.userId,
    required this.date,
    required this.stopped,
    required this.qts,
  }) : super._();

  /// Deserialize.
  factory UpdateBotStopped.deserialize(BinaryReader reader) {
    // Read [UpdateBotStopped] fields.
    final userId = reader.readInt64();
    final date = reader.readDateTime();
    final stopped = reader.readBool();
    final qts = reader.readInt32();

    // Construct [UpdateBotStopped] object.
    final returnValue = UpdateBotStopped(
      userId: userId,
      date: date,
      stopped: stopped,
      qts: qts,
    );

    // Now return the deserialized [UpdateBotStopped].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Date.
  final DateTime date;

  /// Stopped.
  final bool stopped;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc4870a49.
    buffer.writeInt32(0xc4870a49);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeDateTime(date);
    buffer.writeBool(stopped);
    buffer.writeInt32(qts);

    // Finished serialization.
  }
}

/// Update Group Call Connection.
///
/// ID: `0b783982`.
class UpdateGroupCallConnection extends UpdateBase {
  /// Update Group Call Connection constructor.
  const UpdateGroupCallConnection({
    required this.presentation,
    required this.params,
  }) : super._();

  /// Deserialize.
  factory UpdateGroupCallConnection.deserialize(BinaryReader reader) {
    // Read [UpdateGroupCallConnection] fields.
    final flags = reader.readInt32();
    final presentation = (flags & 1) != 0;
    final params = reader.readObject() as DataJSONBase;

    // Construct [UpdateGroupCallConnection] object.
    final returnValue = UpdateGroupCallConnection(
      presentation: presentation,
      params: params,
    );

    // Now return the deserialized [UpdateGroupCallConnection].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: presentation,
    );

    return v;
  }

  /// presentation: bit 0 of flags.0?true
  final bool presentation;

  /// Params.
  final DataJSONBase params;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0b783982.
    buffer.writeInt32(0x0b783982);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(params);

    // Finished serialization.
  }
}

/// Update Bot Commands.
///
/// ID: `4d712f2e`.
class UpdateBotCommands extends UpdateBase {
  /// Update Bot Commands constructor.
  const UpdateBotCommands({
    required this.peer,
    required this.botId,
    required this.commands,
  }) : super._();

  /// Deserialize.
  factory UpdateBotCommands.deserialize(BinaryReader reader) {
    // Read [UpdateBotCommands] fields.
    final peer = reader.readObject() as PeerBase;
    final botId = reader.readInt64();
    final commands = reader.readVectorObject<BotCommandBase>();

    // Construct [UpdateBotCommands] object.
    final returnValue = UpdateBotCommands(
      peer: peer,
      botId: botId,
      commands: commands,
    );

    // Now return the deserialized [UpdateBotCommands].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Bot Id.
  ///
  /// Field type is Int64.
  final int botId;

  /// Commands.
  final List<BotCommandBase> commands;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4d712f2e.
    buffer.writeInt32(0x4d712f2e);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt64(botId);
    buffer.writeVectorObject(commands);

    // Finished serialization.
  }
}

/// Update Pending Join Requests.
///
/// ID: `7063c3db`.
class UpdatePendingJoinRequests extends UpdateBase {
  /// Update Pending Join Requests constructor.
  const UpdatePendingJoinRequests({
    required this.peer,
    required this.requestsPending,
    required this.recentRequesters,
  }) : super._();

  /// Deserialize.
  factory UpdatePendingJoinRequests.deserialize(BinaryReader reader) {
    // Read [UpdatePendingJoinRequests] fields.
    final peer = reader.readObject() as PeerBase;
    final requestsPending = reader.readInt32();
    final recentRequesters = reader.readVectorInt64();

    // Construct [UpdatePendingJoinRequests] object.
    final returnValue = UpdatePendingJoinRequests(
      peer: peer,
      requestsPending: requestsPending,
      recentRequesters: recentRequesters,
    );

    // Now return the deserialized [UpdatePendingJoinRequests].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Requests Pending.
  ///
  /// Field type is Int32.
  final int requestsPending;

  /// Recent Requesters.
  final List<int> recentRequesters;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7063c3db.
    buffer.writeInt32(0x7063c3db);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(requestsPending);
    buffer.writeVectorInt64(recentRequesters);

    // Finished serialization.
  }
}

/// Update Bot Chat Invite Requester.
///
/// ID: `11dfa986`.
class UpdateBotChatInviteRequester extends UpdateBase {
  /// Update Bot Chat Invite Requester constructor.
  const UpdateBotChatInviteRequester({
    required this.peer,
    required this.date,
    required this.userId,
    required this.about,
    required this.invite,
    required this.qts,
  }) : super._();

  /// Deserialize.
  factory UpdateBotChatInviteRequester.deserialize(BinaryReader reader) {
    // Read [UpdateBotChatInviteRequester] fields.
    final peer = reader.readObject() as PeerBase;
    final date = reader.readDateTime();
    final userId = reader.readInt64();
    final about = reader.readString();
    final invite = reader.readObject() as ExportedChatInviteBase;
    final qts = reader.readInt32();

    // Construct [UpdateBotChatInviteRequester] object.
    final returnValue = UpdateBotChatInviteRequester(
      peer: peer,
      date: date,
      userId: userId,
      about: about,
      invite: invite,
      qts: qts,
    );

    // Now return the deserialized [UpdateBotChatInviteRequester].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Date.
  final DateTime date;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// About.
  final String about;

  /// Invite.
  final ExportedChatInviteBase invite;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x11dfa986.
    buffer.writeInt32(0x11dfa986);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeDateTime(date);
    buffer.writeInt64(userId);
    buffer.writeString(about);
    buffer.writeObject(invite);
    buffer.writeInt32(qts);

    // Finished serialization.
  }
}

/// Update Message Reactions.
///
/// ID: `5e1b3cb8`.
class UpdateMessageReactions extends UpdateBase {
  /// Update Message Reactions constructor.
  const UpdateMessageReactions({
    required this.peer,
    required this.msgId,
    this.topMsgId,
    required this.reactions,
  }) : super._();

  /// Deserialize.
  factory UpdateMessageReactions.deserialize(BinaryReader reader) {
    // Read [UpdateMessageReactions] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as PeerBase;
    final msgId = reader.readInt32();
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final reactions = reader.readObject() as MessageReactionsBase;

    // Construct [UpdateMessageReactions] object.
    final returnValue = UpdateMessageReactions(
      peer: peer,
      msgId: msgId,
      topMsgId: topMsgId,
      reactions: reactions,
    );

    // Now return the deserialized [UpdateMessageReactions].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
    );

    return v;
  }

  /// Peer.
  final PeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Top Msg Id.
  final int? topMsgId;

  /// Reactions.
  final MessageReactionsBase reactions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5e1b3cb8.
    buffer.writeInt32(0x5e1b3cb8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    buffer.writeObject(reactions);

    // Finished serialization.
  }
}

/// Update Attach Menu Bots.
///
/// ID: `17b7a20b`.
class UpdateAttachMenuBots extends UpdateBase {
  /// Update Attach Menu Bots constructor.
  const UpdateAttachMenuBots() : super._();

  /// Deserialize.
  factory UpdateAttachMenuBots.deserialize(BinaryReader reader) {
    // Construct [UpdateAttachMenuBots] object.
    final returnValue = UpdateAttachMenuBots();

    // Now return the deserialized [UpdateAttachMenuBots].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x17b7a20b.
    buffer.writeInt32(0x17b7a20b);

    // Finished serialization.
  }
}

/// Update Web View Result Sent.
///
/// ID: `1592b79d`.
class UpdateWebViewResultSent extends UpdateBase {
  /// Update Web View Result Sent constructor.
  const UpdateWebViewResultSent({
    required this.queryId,
  }) : super._();

  /// Deserialize.
  factory UpdateWebViewResultSent.deserialize(BinaryReader reader) {
    // Read [UpdateWebViewResultSent] fields.
    final queryId = reader.readInt64();

    // Construct [UpdateWebViewResultSent] object.
    final returnValue = UpdateWebViewResultSent(
      queryId: queryId,
    );

    // Now return the deserialized [UpdateWebViewResultSent].
    return returnValue;
  }

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1592b79d.
    buffer.writeInt32(0x1592b79d);

    // Write fields.
    buffer.writeInt64(queryId);

    // Finished serialization.
  }
}

/// Update Bot Menu Button.
///
/// ID: `14b85813`.
class UpdateBotMenuButton extends UpdateBase {
  /// Update Bot Menu Button constructor.
  const UpdateBotMenuButton({
    required this.botId,
    required this.button,
  }) : super._();

  /// Deserialize.
  factory UpdateBotMenuButton.deserialize(BinaryReader reader) {
    // Read [UpdateBotMenuButton] fields.
    final botId = reader.readInt64();
    final button = reader.readObject() as BotMenuButtonBase;

    // Construct [UpdateBotMenuButton] object.
    final returnValue = UpdateBotMenuButton(
      botId: botId,
      button: button,
    );

    // Now return the deserialized [UpdateBotMenuButton].
    return returnValue;
  }

  /// Bot Id.
  ///
  /// Field type is Int64.
  final int botId;

  /// Button.
  final BotMenuButtonBase button;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x14b85813.
    buffer.writeInt32(0x14b85813);

    // Write fields.
    buffer.writeInt64(botId);
    buffer.writeObject(button);

    // Finished serialization.
  }
}

/// Update Saved Ringtones.
///
/// ID: `74d8be99`.
class UpdateSavedRingtones extends UpdateBase {
  /// Update Saved Ringtones constructor.
  const UpdateSavedRingtones() : super._();

  /// Deserialize.
  factory UpdateSavedRingtones.deserialize(BinaryReader reader) {
    // Construct [UpdateSavedRingtones] object.
    final returnValue = UpdateSavedRingtones();

    // Now return the deserialized [UpdateSavedRingtones].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x74d8be99.
    buffer.writeInt32(0x74d8be99);

    // Finished serialization.
  }
}

/// Update Transcribed Audio.
///
/// ID: `0084cd5a`.
class UpdateTranscribedAudio extends UpdateBase {
  /// Update Transcribed Audio constructor.
  const UpdateTranscribedAudio({
    required this.pending,
    required this.peer,
    required this.msgId,
    required this.transcriptionId,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory UpdateTranscribedAudio.deserialize(BinaryReader reader) {
    // Read [UpdateTranscribedAudio] fields.
    final flags = reader.readInt32();
    final pending = (flags & 1) != 0;
    final peer = reader.readObject() as PeerBase;
    final msgId = reader.readInt32();
    final transcriptionId = reader.readInt64();
    final text = reader.readString();

    // Construct [UpdateTranscribedAudio] object.
    final returnValue = UpdateTranscribedAudio(
      pending: pending,
      peer: peer,
      msgId: msgId,
      transcriptionId: transcriptionId,
      text: text,
    );

    // Now return the deserialized [UpdateTranscribedAudio].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pending,
    );

    return v;
  }

  /// pending: bit 0 of flags.0?true
  final bool pending;

  /// Peer.
  final PeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Transcription Id.
  ///
  /// Field type is Int64.
  final int transcriptionId;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0084cd5a.
    buffer.writeInt32(0x0084cd5a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeInt64(transcriptionId);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Update Read Featured Emoji Stickers.
///
/// ID: `fb4c496c`.
class UpdateReadFeaturedEmojiStickers extends UpdateBase {
  /// Update Read Featured Emoji Stickers constructor.
  const UpdateReadFeaturedEmojiStickers() : super._();

  /// Deserialize.
  factory UpdateReadFeaturedEmojiStickers.deserialize(BinaryReader reader) {
    // Construct [UpdateReadFeaturedEmojiStickers] object.
    final returnValue = UpdateReadFeaturedEmojiStickers();

    // Now return the deserialized [UpdateReadFeaturedEmojiStickers].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfb4c496c.
    buffer.writeInt32(0xfb4c496c);

    // Finished serialization.
  }
}

/// Update User Emoji Status.
///
/// ID: `28373599`.
class UpdateUserEmojiStatus extends UpdateBase {
  /// Update User Emoji Status constructor.
  const UpdateUserEmojiStatus({
    required this.userId,
    required this.emojiStatus,
  }) : super._();

  /// Deserialize.
  factory UpdateUserEmojiStatus.deserialize(BinaryReader reader) {
    // Read [UpdateUserEmojiStatus] fields.
    final userId = reader.readInt64();
    final emojiStatus = reader.readObject() as EmojiStatusBase;

    // Construct [UpdateUserEmojiStatus] object.
    final returnValue = UpdateUserEmojiStatus(
      userId: userId,
      emojiStatus: emojiStatus,
    );

    // Now return the deserialized [UpdateUserEmojiStatus].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Emoji Status.
  final EmojiStatusBase emojiStatus;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x28373599.
    buffer.writeInt32(0x28373599);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeObject(emojiStatus);

    // Finished serialization.
  }
}

/// Update Recent Emoji Statuses.
///
/// ID: `30f443db`.
class UpdateRecentEmojiStatuses extends UpdateBase {
  /// Update Recent Emoji Statuses constructor.
  const UpdateRecentEmojiStatuses() : super._();

  /// Deserialize.
  factory UpdateRecentEmojiStatuses.deserialize(BinaryReader reader) {
    // Construct [UpdateRecentEmojiStatuses] object.
    final returnValue = UpdateRecentEmojiStatuses();

    // Now return the deserialized [UpdateRecentEmojiStatuses].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x30f443db.
    buffer.writeInt32(0x30f443db);

    // Finished serialization.
  }
}

/// Update Recent Reactions.
///
/// ID: `6f7863f4`.
class UpdateRecentReactions extends UpdateBase {
  /// Update Recent Reactions constructor.
  const UpdateRecentReactions() : super._();

  /// Deserialize.
  factory UpdateRecentReactions.deserialize(BinaryReader reader) {
    // Construct [UpdateRecentReactions] object.
    final returnValue = UpdateRecentReactions();

    // Now return the deserialized [UpdateRecentReactions].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6f7863f4.
    buffer.writeInt32(0x6f7863f4);

    // Finished serialization.
  }
}

/// Update Move Sticker Set To Top.
///
/// ID: `86fccf85`.
class UpdateMoveStickerSetToTop extends UpdateBase {
  /// Update Move Sticker Set To Top constructor.
  const UpdateMoveStickerSetToTop({
    required this.masks,
    required this.emojis,
    required this.stickerset,
  }) : super._();

  /// Deserialize.
  factory UpdateMoveStickerSetToTop.deserialize(BinaryReader reader) {
    // Read [UpdateMoveStickerSetToTop] fields.
    final flags = reader.readInt32();
    final masks = (flags & 1) != 0;
    final emojis = (flags & 2) != 0;
    final stickerset = reader.readInt64();

    // Construct [UpdateMoveStickerSetToTop] object.
    final returnValue = UpdateMoveStickerSetToTop(
      masks: masks,
      emojis: emojis,
      stickerset: stickerset,
    );

    // Now return the deserialized [UpdateMoveStickerSetToTop].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: masks,
      b01: emojis,
    );

    return v;
  }

  /// masks: bit 0 of flags.0?true
  final bool masks;

  /// emojis: bit 1 of flags.1?true
  final bool emojis;

  /// Stickerset.
  ///
  /// Field type is Int64.
  final int stickerset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x86fccf85.
    buffer.writeInt32(0x86fccf85);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(stickerset);

    // Finished serialization.
  }
}

/// Update Message Extended Media.
///
/// ID: `5a73a98c`.
class UpdateMessageExtendedMedia extends UpdateBase {
  /// Update Message Extended Media constructor.
  const UpdateMessageExtendedMedia({
    required this.peer,
    required this.msgId,
    required this.extendedMedia,
  }) : super._();

  /// Deserialize.
  factory UpdateMessageExtendedMedia.deserialize(BinaryReader reader) {
    // Read [UpdateMessageExtendedMedia] fields.
    final peer = reader.readObject() as PeerBase;
    final msgId = reader.readInt32();
    final extendedMedia = reader.readObject() as MessageExtendedMediaBase;

    // Construct [UpdateMessageExtendedMedia] object.
    final returnValue = UpdateMessageExtendedMedia(
      peer: peer,
      msgId: msgId,
      extendedMedia: extendedMedia,
    );

    // Now return the deserialized [UpdateMessageExtendedMedia].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Extended Media.
  final MessageExtendedMediaBase extendedMedia;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5a73a98c.
    buffer.writeInt32(0x5a73a98c);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeObject(extendedMedia);

    // Finished serialization.
  }
}

/// Update Channel Pinned Topic.
///
/// ID: `192efbe3`.
class UpdateChannelPinnedTopic extends UpdateBase {
  /// Update Channel Pinned Topic constructor.
  const UpdateChannelPinnedTopic({
    required this.pinned,
    required this.channelId,
    required this.topicId,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelPinnedTopic.deserialize(BinaryReader reader) {
    // Read [UpdateChannelPinnedTopic] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 1) != 0;
    final channelId = reader.readInt64();
    final topicId = reader.readInt32();

    // Construct [UpdateChannelPinnedTopic] object.
    final returnValue = UpdateChannelPinnedTopic(
      pinned: pinned,
      channelId: channelId,
      topicId: topicId,
    );

    // Now return the deserialized [UpdateChannelPinnedTopic].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pinned,
    );

    return v;
  }

  /// pinned: bit 0 of flags.0?true
  final bool pinned;

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Topic Id.
  ///
  /// Field type is Int32.
  final int topicId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x192efbe3.
    buffer.writeInt32(0x192efbe3);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(channelId);
    buffer.writeInt32(topicId);

    // Finished serialization.
  }
}

/// Update Channel Pinned Topics.
///
/// ID: `fe198602`.
class UpdateChannelPinnedTopics extends UpdateBase {
  /// Update Channel Pinned Topics constructor.
  const UpdateChannelPinnedTopics({
    required this.channelId,
    this.order,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelPinnedTopics.deserialize(BinaryReader reader) {
    // Read [UpdateChannelPinnedTopics] fields.
    final flags = reader.readInt32();
    final channelId = reader.readInt64();
    final hasOrderField = (flags & 1) != 0;
    final order = hasOrderField ? reader.readVectorInt32() : null;

    // Construct [UpdateChannelPinnedTopics] object.
    final returnValue = UpdateChannelPinnedTopics(
      channelId: channelId,
      order: order,
    );

    // Now return the deserialized [UpdateChannelPinnedTopics].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: order != null,
    );

    return v;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Order.
  final List<int>? order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfe198602.
    buffer.writeInt32(0xfe198602);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(channelId);
    final localOrderCopy = order;
    if (localOrderCopy != null) {
      buffer.writeVectorInt32(localOrderCopy);
    }

    // Finished serialization.
  }
}

/// Update User.
///
/// ID: `20529438`.
class UpdateUser extends UpdateBase {
  /// Update User constructor.
  const UpdateUser({
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory UpdateUser.deserialize(BinaryReader reader) {
    // Read [UpdateUser] fields.
    final userId = reader.readInt64();

    // Construct [UpdateUser] object.
    final returnValue = UpdateUser(
      userId: userId,
    );

    // Now return the deserialized [UpdateUser].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x20529438.
    buffer.writeInt32(0x20529438);

    // Write fields.
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Update Auto Save Settings.
///
/// ID: `ec05b097`.
class UpdateAutoSaveSettings extends UpdateBase {
  /// Update Auto Save Settings constructor.
  const UpdateAutoSaveSettings() : super._();

  /// Deserialize.
  factory UpdateAutoSaveSettings.deserialize(BinaryReader reader) {
    // Construct [UpdateAutoSaveSettings] object.
    final returnValue = UpdateAutoSaveSettings();

    // Now return the deserialized [UpdateAutoSaveSettings].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xec05b097.
    buffer.writeInt32(0xec05b097);

    // Finished serialization.
  }
}

/// Update Group Invite Privacy Forbidden.
///
/// ID: `ccf08ad6`.
class UpdateGroupInvitePrivacyForbidden extends UpdateBase {
  /// Update Group Invite Privacy Forbidden constructor.
  const UpdateGroupInvitePrivacyForbidden({
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory UpdateGroupInvitePrivacyForbidden.deserialize(BinaryReader reader) {
    // Read [UpdateGroupInvitePrivacyForbidden] fields.
    final userId = reader.readInt64();

    // Construct [UpdateGroupInvitePrivacyForbidden] object.
    final returnValue = UpdateGroupInvitePrivacyForbidden(
      userId: userId,
    );

    // Now return the deserialized [UpdateGroupInvitePrivacyForbidden].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xccf08ad6.
    buffer.writeInt32(0xccf08ad6);

    // Write fields.
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Update Story.
///
/// ID: `75b3b798`.
class UpdateStory extends UpdateBase {
  /// Update Story constructor.
  const UpdateStory({
    required this.peer,
    required this.story,
  }) : super._();

  /// Deserialize.
  factory UpdateStory.deserialize(BinaryReader reader) {
    // Read [UpdateStory] fields.
    final peer = reader.readObject() as PeerBase;
    final story = reader.readObject() as StoryItemBase;

    // Construct [UpdateStory] object.
    final returnValue = UpdateStory(
      peer: peer,
      story: story,
    );

    // Now return the deserialized [UpdateStory].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Story.
  final StoryItemBase story;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x75b3b798.
    buffer.writeInt32(0x75b3b798);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(story);

    // Finished serialization.
  }
}

/// Update Read Stories.
///
/// ID: `f74e932b`.
class UpdateReadStories extends UpdateBase {
  /// Update Read Stories constructor.
  const UpdateReadStories({
    required this.peer,
    required this.maxId,
  }) : super._();

  /// Deserialize.
  factory UpdateReadStories.deserialize(BinaryReader reader) {
    // Read [UpdateReadStories] fields.
    final peer = reader.readObject() as PeerBase;
    final maxId = reader.readInt32();

    // Construct [UpdateReadStories] object.
    final returnValue = UpdateReadStories(
      peer: peer,
      maxId: maxId,
    );

    // Now return the deserialized [UpdateReadStories].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf74e932b.
    buffer.writeInt32(0xf74e932b);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(maxId);

    // Finished serialization.
  }
}

/// Update Story I D.
///
/// ID: `1bf335b9`.
class UpdateStoryID extends UpdateBase {
  /// Update Story I D constructor.
  const UpdateStoryID({
    required this.id,
    required this.randomId,
  }) : super._();

  /// Deserialize.
  factory UpdateStoryID.deserialize(BinaryReader reader) {
    // Read [UpdateStoryID] fields.
    final id = reader.readInt32();
    final randomId = reader.readInt64();

    // Construct [UpdateStoryID] object.
    final returnValue = UpdateStoryID(
      id: id,
      randomId: randomId,
    );

    // Now return the deserialized [UpdateStoryID].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1bf335b9.
    buffer.writeInt32(0x1bf335b9);

    // Write fields.
    buffer.writeInt32(id);
    buffer.writeInt64(randomId);

    // Finished serialization.
  }
}

/// Update Stories Stealth Mode.
///
/// ID: `2c084dc1`.
class UpdateStoriesStealthMode extends UpdateBase {
  /// Update Stories Stealth Mode constructor.
  const UpdateStoriesStealthMode({
    required this.stealthMode,
  }) : super._();

  /// Deserialize.
  factory UpdateStoriesStealthMode.deserialize(BinaryReader reader) {
    // Read [UpdateStoriesStealthMode] fields.
    final stealthMode = reader.readObject() as StoriesStealthModeBase;

    // Construct [UpdateStoriesStealthMode] object.
    final returnValue = UpdateStoriesStealthMode(
      stealthMode: stealthMode,
    );

    // Now return the deserialized [UpdateStoriesStealthMode].
    return returnValue;
  }

  /// Stealth Mode.
  final StoriesStealthModeBase stealthMode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2c084dc1.
    buffer.writeInt32(0x2c084dc1);

    // Write fields.
    buffer.writeObject(stealthMode);

    // Finished serialization.
  }
}

/// Update Sent Story Reaction.
///
/// ID: `7d627683`.
class UpdateSentStoryReaction extends UpdateBase {
  /// Update Sent Story Reaction constructor.
  const UpdateSentStoryReaction({
    required this.peer,
    required this.storyId,
    required this.reaction,
  }) : super._();

  /// Deserialize.
  factory UpdateSentStoryReaction.deserialize(BinaryReader reader) {
    // Read [UpdateSentStoryReaction] fields.
    final peer = reader.readObject() as PeerBase;
    final storyId = reader.readInt32();
    final reaction = reader.readObject() as ReactionBase;

    // Construct [UpdateSentStoryReaction] object.
    final returnValue = UpdateSentStoryReaction(
      peer: peer,
      storyId: storyId,
      reaction: reaction,
    );

    // Now return the deserialized [UpdateSentStoryReaction].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Story Id.
  ///
  /// Field type is Int32.
  final int storyId;

  /// Reaction.
  final ReactionBase reaction;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7d627683.
    buffer.writeInt32(0x7d627683);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(storyId);
    buffer.writeObject(reaction);

    // Finished serialization.
  }
}

/// Update Bot Chat Boost.
///
/// ID: `904dd49c`.
class UpdateBotChatBoost extends UpdateBase {
  /// Update Bot Chat Boost constructor.
  const UpdateBotChatBoost({
    required this.peer,
    required this.boost,
    required this.qts,
  }) : super._();

  /// Deserialize.
  factory UpdateBotChatBoost.deserialize(BinaryReader reader) {
    // Read [UpdateBotChatBoost] fields.
    final peer = reader.readObject() as PeerBase;
    final boost = reader.readObject() as BoostBase;
    final qts = reader.readInt32();

    // Construct [UpdateBotChatBoost] object.
    final returnValue = UpdateBotChatBoost(
      peer: peer,
      boost: boost,
      qts: qts,
    );

    // Now return the deserialized [UpdateBotChatBoost].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Boost.
  final BoostBase boost;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x904dd49c.
    buffer.writeInt32(0x904dd49c);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(boost);
    buffer.writeInt32(qts);

    // Finished serialization.
  }
}

/// Update Channel View Forum As Messages.
///
/// ID: `07b68920`.
class UpdateChannelViewForumAsMessages extends UpdateBase {
  /// Update Channel View Forum As Messages constructor.
  const UpdateChannelViewForumAsMessages({
    required this.channelId,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory UpdateChannelViewForumAsMessages.deserialize(BinaryReader reader) {
    // Read [UpdateChannelViewForumAsMessages] fields.
    final channelId = reader.readInt64();
    final enabled = reader.readBool();

    // Construct [UpdateChannelViewForumAsMessages] object.
    final returnValue = UpdateChannelViewForumAsMessages(
      channelId: channelId,
      enabled: enabled,
    );

    // Now return the deserialized [UpdateChannelViewForumAsMessages].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x07b68920.
    buffer.writeInt32(0x07b68920);

    // Write fields.
    buffer.writeInt64(channelId);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Update Peer Wallpaper.
///
/// ID: `ae3f101d`.
class UpdatePeerWallpaper extends UpdateBase {
  /// Update Peer Wallpaper constructor.
  const UpdatePeerWallpaper({
    required this.wallpaperOverridden,
    required this.peer,
    this.wallpaper,
  }) : super._();

  /// Deserialize.
  factory UpdatePeerWallpaper.deserialize(BinaryReader reader) {
    // Read [UpdatePeerWallpaper] fields.
    final flags = reader.readInt32();
    final wallpaperOverridden = (flags & 2) != 0;
    final peer = reader.readObject() as PeerBase;
    final hasWallpaperField = (flags & 1) != 0;
    final wallpaper =
        hasWallpaperField ? reader.readObject() as WallPaperBase : null;

    // Construct [UpdatePeerWallpaper] object.
    final returnValue = UpdatePeerWallpaper(
      wallpaperOverridden: wallpaperOverridden,
      peer: peer,
      wallpaper: wallpaper,
    );

    // Now return the deserialized [UpdatePeerWallpaper].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: wallpaperOverridden,
      b00: wallpaper != null,
    );

    return v;
  }

  /// wallpaper_overridden: bit 1 of flags.1?true
  final bool wallpaperOverridden;

  /// Peer.
  final PeerBase peer;

  /// Wallpaper.
  final WallPaperBase? wallpaper;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xae3f101d.
    buffer.writeInt32(0xae3f101d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localWallpaperCopy = wallpaper;
    if (localWallpaperCopy != null) {
      buffer.writeObject(localWallpaperCopy);
    }

    // Finished serialization.
  }
}

/// Update Bot Message Reaction.
///
/// ID: `ac21d3ce`.
class UpdateBotMessageReaction extends UpdateBase {
  /// Update Bot Message Reaction constructor.
  const UpdateBotMessageReaction({
    required this.peer,
    required this.msgId,
    required this.date,
    required this.actor,
    required this.oldReactions,
    required this.newReactions,
    required this.qts,
  }) : super._();

  /// Deserialize.
  factory UpdateBotMessageReaction.deserialize(BinaryReader reader) {
    // Read [UpdateBotMessageReaction] fields.
    final peer = reader.readObject() as PeerBase;
    final msgId = reader.readInt32();
    final date = reader.readDateTime();
    final actor = reader.readObject() as PeerBase;
    final oldReactions = reader.readVectorObject<ReactionBase>();
    final newReactions = reader.readVectorObject<ReactionBase>();
    final qts = reader.readInt32();

    // Construct [UpdateBotMessageReaction] object.
    final returnValue = UpdateBotMessageReaction(
      peer: peer,
      msgId: msgId,
      date: date,
      actor: actor,
      oldReactions: oldReactions,
      newReactions: newReactions,
      qts: qts,
    );

    // Now return the deserialized [UpdateBotMessageReaction].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Date.
  final DateTime date;

  /// Actor.
  final PeerBase actor;

  /// Old Reactions.
  final List<ReactionBase> oldReactions;

  /// New Reactions.
  final List<ReactionBase> newReactions;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xac21d3ce.
    buffer.writeInt32(0xac21d3ce);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeDateTime(date);
    buffer.writeObject(actor);
    buffer.writeVectorObject(oldReactions);
    buffer.writeVectorObject(newReactions);
    buffer.writeInt32(qts);

    // Finished serialization.
  }
}

/// Update Bot Message Reactions.
///
/// ID: `09cb7759`.
class UpdateBotMessageReactions extends UpdateBase {
  /// Update Bot Message Reactions constructor.
  const UpdateBotMessageReactions({
    required this.peer,
    required this.msgId,
    required this.date,
    required this.reactions,
    required this.qts,
  }) : super._();

  /// Deserialize.
  factory UpdateBotMessageReactions.deserialize(BinaryReader reader) {
    // Read [UpdateBotMessageReactions] fields.
    final peer = reader.readObject() as PeerBase;
    final msgId = reader.readInt32();
    final date = reader.readDateTime();
    final reactions = reader.readVectorObject<ReactionCountBase>();
    final qts = reader.readInt32();

    // Construct [UpdateBotMessageReactions] object.
    final returnValue = UpdateBotMessageReactions(
      peer: peer,
      msgId: msgId,
      date: date,
      reactions: reactions,
      qts: qts,
    );

    // Now return the deserialized [UpdateBotMessageReactions].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Date.
  final DateTime date;

  /// Reactions.
  final List<ReactionCountBase> reactions;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x09cb7759.
    buffer.writeInt32(0x09cb7759);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeDateTime(date);
    buffer.writeVectorObject(reactions);
    buffer.writeInt32(qts);

    // Finished serialization.
  }
}

/// Update Saved Dialog Pinned.
///
/// ID: `aeaf9e74`.
class UpdateSavedDialogPinned extends UpdateBase {
  /// Update Saved Dialog Pinned constructor.
  const UpdateSavedDialogPinned({
    required this.pinned,
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory UpdateSavedDialogPinned.deserialize(BinaryReader reader) {
    // Read [UpdateSavedDialogPinned] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 1) != 0;
    final peer = reader.readObject() as DialogPeerBase;

    // Construct [UpdateSavedDialogPinned] object.
    final returnValue = UpdateSavedDialogPinned(
      pinned: pinned,
      peer: peer,
    );

    // Now return the deserialized [UpdateSavedDialogPinned].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pinned,
    );

    return v;
  }

  /// pinned: bit 0 of flags.0?true
  final bool pinned;

  /// Peer.
  final DialogPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaeaf9e74.
    buffer.writeInt32(0xaeaf9e74);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Update Pinned Saved Dialogs.
///
/// ID: `686c85a6`.
class UpdatePinnedSavedDialogs extends UpdateBase {
  /// Update Pinned Saved Dialogs constructor.
  const UpdatePinnedSavedDialogs({
    this.order,
  }) : super._();

  /// Deserialize.
  factory UpdatePinnedSavedDialogs.deserialize(BinaryReader reader) {
    // Read [UpdatePinnedSavedDialogs] fields.
    final flags = reader.readInt32();
    final hasOrderField = (flags & 1) != 0;
    final order =
        hasOrderField ? reader.readVectorObject<DialogPeerBase>() : null;

    // Construct [UpdatePinnedSavedDialogs] object.
    final returnValue = UpdatePinnedSavedDialogs(
      order: order,
    );

    // Now return the deserialized [UpdatePinnedSavedDialogs].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: order != null,
    );

    return v;
  }

  /// Order.
  final List<DialogPeerBase>? order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x686c85a6.
    buffer.writeInt32(0x686c85a6);

    // Write fields.
    buffer.writeInt32(flags);
    final localOrderCopy = order;
    if (localOrderCopy != null) {
      buffer.writeVectorObject(localOrderCopy);
    }

    // Finished serialization.
  }
}

/// Updates State.
///
/// ID: `a56c2a3e`.
class UpdatesState extends UpdatesStateBase {
  /// Updates State constructor.
  const UpdatesState({
    required this.pts,
    required this.qts,
    required this.date,
    required this.seq,
    required this.unreadCount,
  }) : super._();

  /// Deserialize.
  factory UpdatesState.deserialize(BinaryReader reader) {
    // Read [UpdatesState] fields.
    final pts = reader.readInt32();
    final qts = reader.readInt32();
    final date = reader.readDateTime();
    final seq = reader.readInt32();
    final unreadCount = reader.readInt32();

    // Construct [UpdatesState] object.
    final returnValue = UpdatesState(
      pts: pts,
      qts: qts,
      date: date,
      seq: seq,
      unreadCount: unreadCount,
    );

    // Now return the deserialized [UpdatesState].
    return returnValue;
  }

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Date.
  final DateTime date;

  /// Seq.
  ///
  /// Field type is Int32.
  final int seq;

  /// Unread Count.
  ///
  /// Field type is Int32.
  final int unreadCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa56c2a3e.
    buffer.writeInt32(0xa56c2a3e);

    // Write fields.
    buffer.writeInt32(pts);
    buffer.writeInt32(qts);
    buffer.writeDateTime(date);
    buffer.writeInt32(seq);
    buffer.writeInt32(unreadCount);

    // Finished serialization.
  }
}

/// Updates Difference Empty.
///
/// ID: `5d75a138`.
class UpdatesDifferenceEmpty extends UpdatesDifferenceBase {
  /// Updates Difference Empty constructor.
  const UpdatesDifferenceEmpty({
    required this.date,
    required this.seq,
  }) : super._();

  /// Deserialize.
  factory UpdatesDifferenceEmpty.deserialize(BinaryReader reader) {
    // Read [UpdatesDifferenceEmpty] fields.
    final date = reader.readDateTime();
    final seq = reader.readInt32();

    // Construct [UpdatesDifferenceEmpty] object.
    final returnValue = UpdatesDifferenceEmpty(
      date: date,
      seq: seq,
    );

    // Now return the deserialized [UpdatesDifferenceEmpty].
    return returnValue;
  }

  /// Date.
  final DateTime date;

  /// Seq.
  ///
  /// Field type is Int32.
  final int seq;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5d75a138.
    buffer.writeInt32(0x5d75a138);

    // Write fields.
    buffer.writeDateTime(date);
    buffer.writeInt32(seq);

    // Finished serialization.
  }
}

/// Updates Difference.
///
/// ID: `00f49ca0`.
class UpdatesDifference extends UpdatesDifferenceBase {
  /// Updates Difference constructor.
  const UpdatesDifference({
    required this.newMessages,
    required this.newEncryptedMessages,
    required this.otherUpdates,
    required this.chats,
    required this.users,
    required this.state,
  }) : super._();

  /// Deserialize.
  factory UpdatesDifference.deserialize(BinaryReader reader) {
    // Read [UpdatesDifference] fields.
    final newMessages = reader.readVectorObject<MessageBase>();
    final newEncryptedMessages =
        reader.readVectorObject<EncryptedMessageBase>();
    final otherUpdates = reader.readVectorObject<UpdateBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final state = reader.readObject() as UpdatesStateBase;

    // Construct [UpdatesDifference] object.
    final returnValue = UpdatesDifference(
      newMessages: newMessages,
      newEncryptedMessages: newEncryptedMessages,
      otherUpdates: otherUpdates,
      chats: chats,
      users: users,
      state: state,
    );

    // Now return the deserialized [UpdatesDifference].
    return returnValue;
  }

  /// New Messages.
  final List<MessageBase> newMessages;

  /// New Encrypted Messages.
  final List<EncryptedMessageBase> newEncryptedMessages;

  /// Other Updates.
  final List<UpdateBase> otherUpdates;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// State.
  final UpdatesStateBase state;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x00f49ca0.
    buffer.writeInt32(0x00f49ca0);

    // Write fields.
    buffer.writeVectorObject(newMessages);
    buffer.writeVectorObject(newEncryptedMessages);
    buffer.writeVectorObject(otherUpdates);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    buffer.writeObject(state);

    // Finished serialization.
  }
}

/// Updates Difference Slice.
///
/// ID: `a8fb1981`.
class UpdatesDifferenceSlice extends UpdatesDifferenceBase {
  /// Updates Difference Slice constructor.
  const UpdatesDifferenceSlice({
    required this.newMessages,
    required this.newEncryptedMessages,
    required this.otherUpdates,
    required this.chats,
    required this.users,
    required this.intermediateState,
  }) : super._();

  /// Deserialize.
  factory UpdatesDifferenceSlice.deserialize(BinaryReader reader) {
    // Read [UpdatesDifferenceSlice] fields.
    final newMessages = reader.readVectorObject<MessageBase>();
    final newEncryptedMessages =
        reader.readVectorObject<EncryptedMessageBase>();
    final otherUpdates = reader.readVectorObject<UpdateBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final intermediateState = reader.readObject() as UpdatesStateBase;

    // Construct [UpdatesDifferenceSlice] object.
    final returnValue = UpdatesDifferenceSlice(
      newMessages: newMessages,
      newEncryptedMessages: newEncryptedMessages,
      otherUpdates: otherUpdates,
      chats: chats,
      users: users,
      intermediateState: intermediateState,
    );

    // Now return the deserialized [UpdatesDifferenceSlice].
    return returnValue;
  }

  /// New Messages.
  final List<MessageBase> newMessages;

  /// New Encrypted Messages.
  final List<EncryptedMessageBase> newEncryptedMessages;

  /// Other Updates.
  final List<UpdateBase> otherUpdates;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Intermediate State.
  final UpdatesStateBase intermediateState;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa8fb1981.
    buffer.writeInt32(0xa8fb1981);

    // Write fields.
    buffer.writeVectorObject(newMessages);
    buffer.writeVectorObject(newEncryptedMessages);
    buffer.writeVectorObject(otherUpdates);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    buffer.writeObject(intermediateState);

    // Finished serialization.
  }
}

/// Updates Difference Too Long.
///
/// ID: `4afe8f6d`.
class UpdatesDifferenceTooLong extends UpdatesDifferenceBase {
  /// Updates Difference Too Long constructor.
  const UpdatesDifferenceTooLong({
    required this.pts,
  }) : super._();

  /// Deserialize.
  factory UpdatesDifferenceTooLong.deserialize(BinaryReader reader) {
    // Read [UpdatesDifferenceTooLong] fields.
    final pts = reader.readInt32();

    // Construct [UpdatesDifferenceTooLong] object.
    final returnValue = UpdatesDifferenceTooLong(
      pts: pts,
    );

    // Now return the deserialized [UpdatesDifferenceTooLong].
    return returnValue;
  }

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4afe8f6d.
    buffer.writeInt32(0x4afe8f6d);

    // Write fields.
    buffer.writeInt32(pts);

    // Finished serialization.
  }
}

/// Updates Too Long.
///
/// ID: `e317af7e`.
class UpdatesTooLong extends UpdatesBase {
  /// Updates Too Long constructor.
  const UpdatesTooLong() : super._();

  /// Deserialize.
  factory UpdatesTooLong.deserialize(BinaryReader reader) {
    // Construct [UpdatesTooLong] object.
    final returnValue = UpdatesTooLong();

    // Now return the deserialized [UpdatesTooLong].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe317af7e.
    buffer.writeInt32(0xe317af7e);

    // Finished serialization.
  }
}

/// Update Short Message.
///
/// ID: `313bc7f8`.
class UpdateShortMessage extends UpdatesBase {
  /// Update Short Message constructor.
  const UpdateShortMessage({
    required this.out,
    required this.mentioned,
    required this.mediaUnread,
    required this.silent,
    required this.id,
    required this.userId,
    required this.message,
    required this.pts,
    required this.ptsCount,
    required this.date,
    this.fwdFrom,
    this.viaBotId,
    this.replyTo,
    this.entities,
    this.ttlPeriod,
  }) : super._();

  /// Deserialize.
  factory UpdateShortMessage.deserialize(BinaryReader reader) {
    // Read [UpdateShortMessage] fields.
    final flags = reader.readInt32();
    final out = (flags & 2) != 0;
    final mentioned = (flags & 16) != 0;
    final mediaUnread = (flags & 32) != 0;
    final silent = (flags & 8192) != 0;
    final id = reader.readInt32();
    final userId = reader.readInt64();
    final message = reader.readString();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();
    final date = reader.readDateTime();
    final hasFwdFromField = (flags & 4) != 0;
    final fwdFrom =
        hasFwdFromField ? reader.readObject() as MessageFwdHeaderBase : null;
    final hasViaBotIdField = (flags & 2048) != 0;
    final viaBotId = hasViaBotIdField ? reader.readInt64() : null;
    final hasReplyToField = (flags & 8) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as MessageReplyHeaderBase : null;
    final hasEntitiesField = (flags & 128) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasTtlPeriodField = (flags & 33554432) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;

    // Construct [UpdateShortMessage] object.
    final returnValue = UpdateShortMessage(
      out: out,
      mentioned: mentioned,
      mediaUnread: mediaUnread,
      silent: silent,
      id: id,
      userId: userId,
      message: message,
      pts: pts,
      ptsCount: ptsCount,
      date: date,
      fwdFrom: fwdFrom,
      viaBotId: viaBotId,
      replyTo: replyTo,
      entities: entities,
      ttlPeriod: ttlPeriod,
    );

    // Now return the deserialized [UpdateShortMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: out,
      b04: mentioned,
      b05: mediaUnread,
      b13: silent,
      b02: fwdFrom != null,
      b11: viaBotId != null,
      b03: replyTo != null,
      b07: entities != null,
      b25: ttlPeriod != null,
    );

    return v;
  }

  /// out: bit 1 of flags.1?true
  final bool out;

  /// mentioned: bit 4 of flags.4?true
  final bool mentioned;

  /// media_unread: bit 5 of flags.5?true
  final bool mediaUnread;

  /// silent: bit 13 of flags.13?true
  final bool silent;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Message.
  final String message;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Date.
  final DateTime date;

  /// Fwd From.
  final MessageFwdHeaderBase? fwdFrom;

  /// Via Bot Id.
  final int? viaBotId;

  /// Reply To.
  final MessageReplyHeaderBase? replyTo;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x313bc7f8.
    buffer.writeInt32(0x313bc7f8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeInt64(userId);
    buffer.writeString(message);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);
    buffer.writeDateTime(date);
    final localFwdFromCopy = fwdFrom;
    if (localFwdFromCopy != null) {
      buffer.writeObject(localFwdFromCopy);
    }
    final localViaBotIdCopy = viaBotId;
    if (localViaBotIdCopy != null) {
      buffer.writeInt64(localViaBotIdCopy);
    }
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }

    // Finished serialization.
  }
}

/// Update Short Chat Message.
///
/// ID: `4d6deea5`.
class UpdateShortChatMessage extends UpdatesBase {
  /// Update Short Chat Message constructor.
  const UpdateShortChatMessage({
    required this.out,
    required this.mentioned,
    required this.mediaUnread,
    required this.silent,
    required this.id,
    required this.fromId,
    required this.chatId,
    required this.message,
    required this.pts,
    required this.ptsCount,
    required this.date,
    this.fwdFrom,
    this.viaBotId,
    this.replyTo,
    this.entities,
    this.ttlPeriod,
  }) : super._();

  /// Deserialize.
  factory UpdateShortChatMessage.deserialize(BinaryReader reader) {
    // Read [UpdateShortChatMessage] fields.
    final flags = reader.readInt32();
    final out = (flags & 2) != 0;
    final mentioned = (flags & 16) != 0;
    final mediaUnread = (flags & 32) != 0;
    final silent = (flags & 8192) != 0;
    final id = reader.readInt32();
    final fromId = reader.readInt64();
    final chatId = reader.readInt64();
    final message = reader.readString();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();
    final date = reader.readDateTime();
    final hasFwdFromField = (flags & 4) != 0;
    final fwdFrom =
        hasFwdFromField ? reader.readObject() as MessageFwdHeaderBase : null;
    final hasViaBotIdField = (flags & 2048) != 0;
    final viaBotId = hasViaBotIdField ? reader.readInt64() : null;
    final hasReplyToField = (flags & 8) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as MessageReplyHeaderBase : null;
    final hasEntitiesField = (flags & 128) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasTtlPeriodField = (flags & 33554432) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;

    // Construct [UpdateShortChatMessage] object.
    final returnValue = UpdateShortChatMessage(
      out: out,
      mentioned: mentioned,
      mediaUnread: mediaUnread,
      silent: silent,
      id: id,
      fromId: fromId,
      chatId: chatId,
      message: message,
      pts: pts,
      ptsCount: ptsCount,
      date: date,
      fwdFrom: fwdFrom,
      viaBotId: viaBotId,
      replyTo: replyTo,
      entities: entities,
      ttlPeriod: ttlPeriod,
    );

    // Now return the deserialized [UpdateShortChatMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: out,
      b04: mentioned,
      b05: mediaUnread,
      b13: silent,
      b02: fwdFrom != null,
      b11: viaBotId != null,
      b03: replyTo != null,
      b07: entities != null,
      b25: ttlPeriod != null,
    );

    return v;
  }

  /// out: bit 1 of flags.1?true
  final bool out;

  /// mentioned: bit 4 of flags.4?true
  final bool mentioned;

  /// media_unread: bit 5 of flags.5?true
  final bool mediaUnread;

  /// silent: bit 13 of flags.13?true
  final bool silent;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// From Id.
  ///
  /// Field type is Int64.
  final int fromId;

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Message.
  final String message;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Date.
  final DateTime date;

  /// Fwd From.
  final MessageFwdHeaderBase? fwdFrom;

  /// Via Bot Id.
  final int? viaBotId;

  /// Reply To.
  final MessageReplyHeaderBase? replyTo;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4d6deea5.
    buffer.writeInt32(0x4d6deea5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeInt64(fromId);
    buffer.writeInt64(chatId);
    buffer.writeString(message);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);
    buffer.writeDateTime(date);
    final localFwdFromCopy = fwdFrom;
    if (localFwdFromCopy != null) {
      buffer.writeObject(localFwdFromCopy);
    }
    final localViaBotIdCopy = viaBotId;
    if (localViaBotIdCopy != null) {
      buffer.writeInt64(localViaBotIdCopy);
    }
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }

    // Finished serialization.
  }
}

/// Update Short.
///
/// ID: `78d4dec1`.
class UpdateShort extends UpdatesBase {
  /// Update Short constructor.
  const UpdateShort({
    required this.update,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory UpdateShort.deserialize(BinaryReader reader) {
    // Read [UpdateShort] fields.
    final update = reader.readObject() as UpdateBase;
    final date = reader.readDateTime();

    // Construct [UpdateShort] object.
    final returnValue = UpdateShort(
      update: update,
      date: date,
    );

    // Now return the deserialized [UpdateShort].
    return returnValue;
  }

  /// Update.
  final UpdateBase update;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x78d4dec1.
    buffer.writeInt32(0x78d4dec1);

    // Write fields.
    buffer.writeObject(update);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Updates Combined.
///
/// ID: `725b04c3`.
class UpdatesCombined extends UpdatesBase {
  /// Updates Combined constructor.
  const UpdatesCombined({
    required this.updates,
    required this.users,
    required this.chats,
    required this.date,
    required this.seqStart,
    required this.seq,
  }) : super._();

  /// Deserialize.
  factory UpdatesCombined.deserialize(BinaryReader reader) {
    // Read [UpdatesCombined] fields.
    final updates = reader.readVectorObject<UpdateBase>();
    final users = reader.readVectorObject<UserBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final date = reader.readDateTime();
    final seqStart = reader.readInt32();
    final seq = reader.readInt32();

    // Construct [UpdatesCombined] object.
    final returnValue = UpdatesCombined(
      updates: updates,
      users: users,
      chats: chats,
      date: date,
      seqStart: seqStart,
      seq: seq,
    );

    // Now return the deserialized [UpdatesCombined].
    return returnValue;
  }

  /// Updates.
  final List<UpdateBase> updates;

  /// Users.
  final List<UserBase> users;

  /// Chats.
  final List<ChatBase> chats;

  /// Date.
  final DateTime date;

  /// Seq Start.
  ///
  /// Field type is Int32.
  final int seqStart;

  /// Seq.
  ///
  /// Field type is Int32.
  final int seq;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x725b04c3.
    buffer.writeInt32(0x725b04c3);

    // Write fields.
    buffer.writeVectorObject(updates);
    buffer.writeVectorObject(users);
    buffer.writeVectorObject(chats);
    buffer.writeDateTime(date);
    buffer.writeInt32(seqStart);
    buffer.writeInt32(seq);

    // Finished serialization.
  }
}

/// Updates.
///
/// ID: `74ae4240`.
class Updates extends UpdatesBase {
  /// Updates constructor.
  const Updates({
    required this.updates,
    required this.users,
    required this.chats,
    required this.date,
    required this.seq,
  }) : super._();

  /// Deserialize.
  factory Updates.deserialize(BinaryReader reader) {
    // Read [Updates] fields.
    final updates = reader.readVectorObject<UpdateBase>();
    final users = reader.readVectorObject<UserBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final date = reader.readDateTime();
    final seq = reader.readInt32();

    // Construct [Updates] object.
    final returnValue = Updates(
      updates: updates,
      users: users,
      chats: chats,
      date: date,
      seq: seq,
    );

    // Now return the deserialized [Updates].
    return returnValue;
  }

  /// Updates.
  final List<UpdateBase> updates;

  /// Users.
  final List<UserBase> users;

  /// Chats.
  final List<ChatBase> chats;

  /// Date.
  final DateTime date;

  /// Seq.
  ///
  /// Field type is Int32.
  final int seq;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x74ae4240.
    buffer.writeInt32(0x74ae4240);

    // Write fields.
    buffer.writeVectorObject(updates);
    buffer.writeVectorObject(users);
    buffer.writeVectorObject(chats);
    buffer.writeDateTime(date);
    buffer.writeInt32(seq);

    // Finished serialization.
  }
}

/// Update Short Sent Message.
///
/// ID: `9015e101`.
class UpdateShortSentMessage extends UpdatesBase {
  /// Update Short Sent Message constructor.
  const UpdateShortSentMessage({
    required this.out,
    required this.id,
    required this.pts,
    required this.ptsCount,
    required this.date,
    this.media,
    this.entities,
    this.ttlPeriod,
  }) : super._();

  /// Deserialize.
  factory UpdateShortSentMessage.deserialize(BinaryReader reader) {
    // Read [UpdateShortSentMessage] fields.
    final flags = reader.readInt32();
    final out = (flags & 2) != 0;
    final id = reader.readInt32();
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();
    final date = reader.readDateTime();
    final hasMediaField = (flags & 512) != 0;
    final media =
        hasMediaField ? reader.readObject() as MessageMediaBase : null;
    final hasEntitiesField = (flags & 128) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasTtlPeriodField = (flags & 33554432) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;

    // Construct [UpdateShortSentMessage] object.
    final returnValue = UpdateShortSentMessage(
      out: out,
      id: id,
      pts: pts,
      ptsCount: ptsCount,
      date: date,
      media: media,
      entities: entities,
      ttlPeriod: ttlPeriod,
    );

    // Now return the deserialized [UpdateShortSentMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: out,
      b09: media != null,
      b07: entities != null,
      b25: ttlPeriod != null,
    );

    return v;
  }

  /// out: bit 1 of flags.1?true
  final bool out;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Date.
  final DateTime date;

  /// Media.
  final MessageMediaBase? media;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9015e101.
    buffer.writeInt32(0x9015e101);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);
    buffer.writeDateTime(date);
    final localMediaCopy = media;
    if (localMediaCopy != null) {
      buffer.writeObject(localMediaCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }

    // Finished serialization.
  }
}

/// Photos Photos.
///
/// ID: `8dca6aa5`.
class PhotosPhotos extends PhotosPhotosBase {
  /// Photos Photos constructor.
  const PhotosPhotos({
    required this.photos,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PhotosPhotos.deserialize(BinaryReader reader) {
    // Read [PhotosPhotos] fields.
    final photos = reader.readVectorObject<PhotoBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [PhotosPhotos] object.
    final returnValue = PhotosPhotos(
      photos: photos,
      users: users,
    );

    // Now return the deserialized [PhotosPhotos].
    return returnValue;
  }

  /// Photos.
  final List<PhotoBase> photos;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8dca6aa5.
    buffer.writeInt32(0x8dca6aa5);

    // Write fields.
    buffer.writeVectorObject(photos);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Photos Photos Slice.
///
/// ID: `15051f54`.
class PhotosPhotosSlice extends PhotosPhotosBase {
  /// Photos Photos Slice constructor.
  const PhotosPhotosSlice({
    required this.count,
    required this.photos,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PhotosPhotosSlice.deserialize(BinaryReader reader) {
    // Read [PhotosPhotosSlice] fields.
    final count = reader.readInt32();
    final photos = reader.readVectorObject<PhotoBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [PhotosPhotosSlice] object.
    final returnValue = PhotosPhotosSlice(
      count: count,
      photos: photos,
      users: users,
    );

    // Now return the deserialized [PhotosPhotosSlice].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Photos.
  final List<PhotoBase> photos;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x15051f54.
    buffer.writeInt32(0x15051f54);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(photos);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Photos Photo.
///
/// ID: `20212ca8`.
class PhotosPhoto extends PhotosPhotoBase {
  /// Photos Photo constructor.
  const PhotosPhoto({
    required this.photo,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PhotosPhoto.deserialize(BinaryReader reader) {
    // Read [PhotosPhoto] fields.
    final photo = reader.readObject() as PhotoBase;
    final users = reader.readVectorObject<UserBase>();

    // Construct [PhotosPhoto] object.
    final returnValue = PhotosPhoto(
      photo: photo,
      users: users,
    );

    // Now return the deserialized [PhotosPhoto].
    return returnValue;
  }

  /// Photo.
  final PhotoBase photo;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x20212ca8.
    buffer.writeInt32(0x20212ca8);

    // Write fields.
    buffer.writeObject(photo);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Upload File.
///
/// ID: `096a18d5`.
class UploadFile extends UploadFileBase {
  /// Upload File constructor.
  const UploadFile({
    required this.type,
    required this.mtime,
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory UploadFile.deserialize(BinaryReader reader) {
    // Read [UploadFile] fields.
    final type = reader.readObject() as StorageFileTypeBase;
    final mtime = reader.readInt32();
    final bytes = reader.readBytes();

    // Construct [UploadFile] object.
    final returnValue = UploadFile(
      type: type,
      mtime: mtime,
      bytes: bytes,
    );

    // Now return the deserialized [UploadFile].
    return returnValue;
  }

  /// Type.
  final StorageFileTypeBase type;

  /// Mtime.
  ///
  /// Field type is Int32.
  final int mtime;

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x096a18d5.
    buffer.writeInt32(0x096a18d5);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeInt32(mtime);
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Upload File Cdn Redirect.
///
/// ID: `f18cda44`.
class UploadFileCdnRedirect extends UploadFileBase {
  /// Upload File Cdn Redirect constructor.
  const UploadFileCdnRedirect({
    required this.dcId,
    required this.fileToken,
    required this.encryptionKey,
    required this.encryptionIv,
    required this.fileHashes,
  }) : super._();

  /// Deserialize.
  factory UploadFileCdnRedirect.deserialize(BinaryReader reader) {
    // Read [UploadFileCdnRedirect] fields.
    final dcId = reader.readInt32();
    final fileToken = reader.readBytes();
    final encryptionKey = reader.readBytes();
    final encryptionIv = reader.readBytes();
    final fileHashes = reader.readVectorObject<FileHashBase>();

    // Construct [UploadFileCdnRedirect] object.
    final returnValue = UploadFileCdnRedirect(
      dcId: dcId,
      fileToken: fileToken,
      encryptionKey: encryptionKey,
      encryptionIv: encryptionIv,
      fileHashes: fileHashes,
    );

    // Now return the deserialized [UploadFileCdnRedirect].
    return returnValue;
  }

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// File Token.
  final Uint8List fileToken;

  /// Encryption Key.
  final Uint8List encryptionKey;

  /// Encryption Iv.
  final Uint8List encryptionIv;

  /// File Hashes.
  final List<FileHashBase> fileHashes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf18cda44.
    buffer.writeInt32(0xf18cda44);

    // Write fields.
    buffer.writeInt32(dcId);
    buffer.writeBytes(fileToken);
    buffer.writeBytes(encryptionKey);
    buffer.writeBytes(encryptionIv);
    buffer.writeVectorObject(fileHashes);

    // Finished serialization.
  }
}

/// Dc Option.
///
/// ID: `18b7a10d`.
class DcOption extends DcOptionBase {
  /// Dc Option constructor.
  const DcOption({
    required this.ipv6,
    required this.mediaOnly,
    required this.tcpoOnly,
    required this.cdn,
    required this.static,
    required this.thisPortOnly,
    required this.id,
    required this.ipAddress,
    required this.port,
    this.secret,
  }) : super._();

  /// Deserialize.
  factory DcOption.deserialize(BinaryReader reader) {
    // Read [DcOption] fields.
    final flags = reader.readInt32();
    final ipv6 = (flags & 1) != 0;
    final mediaOnly = (flags & 2) != 0;
    final tcpoOnly = (flags & 4) != 0;
    final cdn = (flags & 8) != 0;
    final static = (flags & 16) != 0;
    final thisPortOnly = (flags & 32) != 0;
    final id = reader.readInt32();
    final ipAddress = reader.readString();
    final port = reader.readInt32();
    final hasSecretField = (flags & 1024) != 0;
    final secret = hasSecretField ? reader.readBytes() : null;

    // Construct [DcOption] object.
    final returnValue = DcOption(
      ipv6: ipv6,
      mediaOnly: mediaOnly,
      tcpoOnly: tcpoOnly,
      cdn: cdn,
      static: static,
      thisPortOnly: thisPortOnly,
      id: id,
      ipAddress: ipAddress,
      port: port,
      secret: secret,
    );

    // Now return the deserialized [DcOption].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: ipv6,
      b01: mediaOnly,
      b02: tcpoOnly,
      b03: cdn,
      b04: static,
      b05: thisPortOnly,
      b10: secret != null,
    );

    return v;
  }

  /// ipv6: bit 0 of flags.0?true
  final bool ipv6;

  /// media_only: bit 1 of flags.1?true
  final bool mediaOnly;

  /// tcpo_only: bit 2 of flags.2?true
  final bool tcpoOnly;

  /// cdn: bit 3 of flags.3?true
  final bool cdn;

  /// static: bit 4 of flags.4?true
  final bool static;

  /// this_port_only: bit 5 of flags.5?true
  final bool thisPortOnly;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Ip Address.
  final String ipAddress;

  /// Port.
  ///
  /// Field type is Int32.
  final int port;

  /// Secret.
  final Uint8List? secret;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x18b7a10d.
    buffer.writeInt32(0x18b7a10d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeString(ipAddress);
    buffer.writeInt32(port);
    final localSecretCopy = secret;
    if (localSecretCopy != null) {
      buffer.writeBytes(localSecretCopy);
    }

    // Finished serialization.
  }
}

/// Config.
///
/// ID: `cc1a241e`.
class Config extends ConfigBase {
  /// Config constructor.
  const Config({
    required this.defaultP2pContacts,
    required this.preloadFeaturedStickers,
    required this.revokePmInbox,
    required this.blockedMode,
    required this.forceTryIpv6,
    required this.date,
    required this.expires,
    required this.testMode,
    required this.thisDc,
    required this.dcOptions,
    required this.dcTxtDomainName,
    required this.chatSizeMax,
    required this.megagroupSizeMax,
    required this.forwardedCountMax,
    required this.onlineUpdatePeriodMs,
    required this.offlineBlurTimeoutMs,
    required this.offlineIdleTimeoutMs,
    required this.onlineCloudTimeoutMs,
    required this.notifyCloudDelayMs,
    required this.notifyDefaultDelayMs,
    required this.pushChatPeriodMs,
    required this.pushChatLimit,
    required this.editTimeLimit,
    required this.revokeTimeLimit,
    required this.revokePmTimeLimit,
    required this.ratingEDecay,
    required this.stickersRecentLimit,
    required this.channelsReadMediaPeriod,
    this.tmpSessions,
    required this.callReceiveTimeoutMs,
    required this.callRingTimeoutMs,
    required this.callConnectTimeoutMs,
    required this.callPacketTimeoutMs,
    required this.meUrlPrefix,
    this.autoupdateUrlPrefix,
    this.gifSearchUsername,
    this.venueSearchUsername,
    this.imgSearchUsername,
    this.staticMapsProvider,
    required this.captionLengthMax,
    required this.messageLengthMax,
    required this.webfileDcId,
    this.suggestedLangCode,
    this.langPackVersion,
    this.baseLangPackVersion,
    this.reactionsDefault,
    this.autologinToken,
  }) : super._();

  /// Deserialize.
  factory Config.deserialize(BinaryReader reader) {
    // Read [Config] fields.
    final flags = reader.readInt32();
    final defaultP2pContacts = (flags & 8) != 0;
    final preloadFeaturedStickers = (flags & 16) != 0;
    final revokePmInbox = (flags & 64) != 0;
    final blockedMode = (flags & 256) != 0;
    final forceTryIpv6 = (flags & 16384) != 0;
    final date = reader.readDateTime();
    final expires = reader.readInt32();
    final testMode = reader.readBool();
    final thisDc = reader.readInt32();
    final dcOptions = reader.readVectorObject<DcOptionBase>();
    final dcTxtDomainName = reader.readString();
    final chatSizeMax = reader.readInt32();
    final megagroupSizeMax = reader.readInt32();
    final forwardedCountMax = reader.readInt32();
    final onlineUpdatePeriodMs = reader.readInt32();
    final offlineBlurTimeoutMs = reader.readInt32();
    final offlineIdleTimeoutMs = reader.readInt32();
    final onlineCloudTimeoutMs = reader.readInt32();
    final notifyCloudDelayMs = reader.readInt32();
    final notifyDefaultDelayMs = reader.readInt32();
    final pushChatPeriodMs = reader.readInt32();
    final pushChatLimit = reader.readInt32();
    final editTimeLimit = reader.readInt32();
    final revokeTimeLimit = reader.readInt32();
    final revokePmTimeLimit = reader.readInt32();
    final ratingEDecay = reader.readInt32();
    final stickersRecentLimit = reader.readInt32();
    final channelsReadMediaPeriod = reader.readInt32();
    final hasTmpSessionsField = (flags & 1) != 0;
    final tmpSessions = hasTmpSessionsField ? reader.readInt32() : null;
    final callReceiveTimeoutMs = reader.readInt32();
    final callRingTimeoutMs = reader.readInt32();
    final callConnectTimeoutMs = reader.readInt32();
    final callPacketTimeoutMs = reader.readInt32();
    final meUrlPrefix = reader.readString();
    final hasAutoupdateUrlPrefixField = (flags & 128) != 0;
    final autoupdateUrlPrefix =
        hasAutoupdateUrlPrefixField ? reader.readString() : null;
    final hasGifSearchUsernameField = (flags & 512) != 0;
    final gifSearchUsername =
        hasGifSearchUsernameField ? reader.readString() : null;
    final hasVenueSearchUsernameField = (flags & 1024) != 0;
    final venueSearchUsername =
        hasVenueSearchUsernameField ? reader.readString() : null;
    final hasImgSearchUsernameField = (flags & 2048) != 0;
    final imgSearchUsername =
        hasImgSearchUsernameField ? reader.readString() : null;
    final hasStaticMapsProviderField = (flags & 4096) != 0;
    final staticMapsProvider =
        hasStaticMapsProviderField ? reader.readString() : null;
    final captionLengthMax = reader.readInt32();
    final messageLengthMax = reader.readInt32();
    final webfileDcId = reader.readInt32();
    final hasSuggestedLangCodeField = (flags & 4) != 0;
    final suggestedLangCode =
        hasSuggestedLangCodeField ? reader.readString() : null;
    final hasLangPackVersionField = (flags & 4) != 0;
    final langPackVersion = hasLangPackVersionField ? reader.readInt32() : null;
    final hasBaseLangPackVersionField = (flags & 4) != 0;
    final baseLangPackVersion =
        hasBaseLangPackVersionField ? reader.readInt32() : null;
    final hasReactionsDefaultField = (flags & 32768) != 0;
    final reactionsDefault =
        hasReactionsDefaultField ? reader.readObject() as ReactionBase : null;
    final hasAutologinTokenField = (flags & 65536) != 0;
    final autologinToken = hasAutologinTokenField ? reader.readString() : null;

    // Construct [Config] object.
    final returnValue = Config(
      defaultP2pContacts: defaultP2pContacts,
      preloadFeaturedStickers: preloadFeaturedStickers,
      revokePmInbox: revokePmInbox,
      blockedMode: blockedMode,
      forceTryIpv6: forceTryIpv6,
      date: date,
      expires: expires,
      testMode: testMode,
      thisDc: thisDc,
      dcOptions: dcOptions,
      dcTxtDomainName: dcTxtDomainName,
      chatSizeMax: chatSizeMax,
      megagroupSizeMax: megagroupSizeMax,
      forwardedCountMax: forwardedCountMax,
      onlineUpdatePeriodMs: onlineUpdatePeriodMs,
      offlineBlurTimeoutMs: offlineBlurTimeoutMs,
      offlineIdleTimeoutMs: offlineIdleTimeoutMs,
      onlineCloudTimeoutMs: onlineCloudTimeoutMs,
      notifyCloudDelayMs: notifyCloudDelayMs,
      notifyDefaultDelayMs: notifyDefaultDelayMs,
      pushChatPeriodMs: pushChatPeriodMs,
      pushChatLimit: pushChatLimit,
      editTimeLimit: editTimeLimit,
      revokeTimeLimit: revokeTimeLimit,
      revokePmTimeLimit: revokePmTimeLimit,
      ratingEDecay: ratingEDecay,
      stickersRecentLimit: stickersRecentLimit,
      channelsReadMediaPeriod: channelsReadMediaPeriod,
      tmpSessions: tmpSessions,
      callReceiveTimeoutMs: callReceiveTimeoutMs,
      callRingTimeoutMs: callRingTimeoutMs,
      callConnectTimeoutMs: callConnectTimeoutMs,
      callPacketTimeoutMs: callPacketTimeoutMs,
      meUrlPrefix: meUrlPrefix,
      autoupdateUrlPrefix: autoupdateUrlPrefix,
      gifSearchUsername: gifSearchUsername,
      venueSearchUsername: venueSearchUsername,
      imgSearchUsername: imgSearchUsername,
      staticMapsProvider: staticMapsProvider,
      captionLengthMax: captionLengthMax,
      messageLengthMax: messageLengthMax,
      webfileDcId: webfileDcId,
      suggestedLangCode: suggestedLangCode,
      langPackVersion: langPackVersion,
      baseLangPackVersion: baseLangPackVersion,
      reactionsDefault: reactionsDefault,
      autologinToken: autologinToken,
    );

    // Now return the deserialized [Config].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: defaultP2pContacts,
      b04: preloadFeaturedStickers,
      b06: revokePmInbox,
      b08: blockedMode,
      b14: forceTryIpv6,
      b00: tmpSessions != null,
      b07: autoupdateUrlPrefix != null,
      b09: gifSearchUsername != null,
      b10: venueSearchUsername != null,
      b11: imgSearchUsername != null,
      b12: staticMapsProvider != null,
      b02: suggestedLangCode != null ||
          langPackVersion != null ||
          baseLangPackVersion != null,
      b15: reactionsDefault != null,
      b16: autologinToken != null,
    );

    return v;
  }

  /// default_p2p_contacts: bit 3 of flags.3?true
  final bool defaultP2pContacts;

  /// preload_featured_stickers: bit 4 of flags.4?true
  final bool preloadFeaturedStickers;

  /// revoke_pm_inbox: bit 6 of flags.6?true
  final bool revokePmInbox;

  /// blocked_mode: bit 8 of flags.8?true
  final bool blockedMode;

  /// force_try_ipv6: bit 14 of flags.14?true
  final bool forceTryIpv6;

  /// Date.
  final DateTime date;

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Test Mode.
  final bool testMode;

  /// This Dc.
  ///
  /// Field type is Int32.
  final int thisDc;

  /// Dc Options.
  final List<DcOptionBase> dcOptions;

  /// Dc Txt Domain Name.
  final String dcTxtDomainName;

  /// Chat Size Max.
  ///
  /// Field type is Int32.
  final int chatSizeMax;

  /// Megagroup Size Max.
  ///
  /// Field type is Int32.
  final int megagroupSizeMax;

  /// Forwarded Count Max.
  ///
  /// Field type is Int32.
  final int forwardedCountMax;

  /// Online Update Period Ms.
  ///
  /// Field type is Int32.
  final int onlineUpdatePeriodMs;

  /// Offline Blur Timeout Ms.
  ///
  /// Field type is Int32.
  final int offlineBlurTimeoutMs;

  /// Offline Idle Timeout Ms.
  ///
  /// Field type is Int32.
  final int offlineIdleTimeoutMs;

  /// Online Cloud Timeout Ms.
  ///
  /// Field type is Int32.
  final int onlineCloudTimeoutMs;

  /// Notify Cloud Delay Ms.
  ///
  /// Field type is Int32.
  final int notifyCloudDelayMs;

  /// Notify Default Delay Ms.
  ///
  /// Field type is Int32.
  final int notifyDefaultDelayMs;

  /// Push Chat Period Ms.
  ///
  /// Field type is Int32.
  final int pushChatPeriodMs;

  /// Push Chat Limit.
  ///
  /// Field type is Int32.
  final int pushChatLimit;

  /// Edit Time Limit.
  ///
  /// Field type is Int32.
  final int editTimeLimit;

  /// Revoke Time Limit.
  ///
  /// Field type is Int32.
  final int revokeTimeLimit;

  /// Revoke Pm Time Limit.
  ///
  /// Field type is Int32.
  final int revokePmTimeLimit;

  /// Rating E Decay.
  ///
  /// Field type is Int32.
  final int ratingEDecay;

  /// Stickers Recent Limit.
  ///
  /// Field type is Int32.
  final int stickersRecentLimit;

  /// Channels Read Media Period.
  ///
  /// Field type is Int32.
  final int channelsReadMediaPeriod;

  /// Tmp Sessions.
  final int? tmpSessions;

  /// Call Receive Timeout Ms.
  ///
  /// Field type is Int32.
  final int callReceiveTimeoutMs;

  /// Call Ring Timeout Ms.
  ///
  /// Field type is Int32.
  final int callRingTimeoutMs;

  /// Call Connect Timeout Ms.
  ///
  /// Field type is Int32.
  final int callConnectTimeoutMs;

  /// Call Packet Timeout Ms.
  ///
  /// Field type is Int32.
  final int callPacketTimeoutMs;

  /// Me Url Prefix.
  final String meUrlPrefix;

  /// Autoupdate Url Prefix.
  final String? autoupdateUrlPrefix;

  /// Gif Search Username.
  final String? gifSearchUsername;

  /// Venue Search Username.
  final String? venueSearchUsername;

  /// Img Search Username.
  final String? imgSearchUsername;

  /// Static Maps Provider.
  final String? staticMapsProvider;

  /// Caption Length Max.
  ///
  /// Field type is Int32.
  final int captionLengthMax;

  /// Message Length Max.
  ///
  /// Field type is Int32.
  final int messageLengthMax;

  /// Webfile Dc Id.
  ///
  /// Field type is Int32.
  final int webfileDcId;

  /// Suggested Lang Code.
  final String? suggestedLangCode;

  /// Lang Pack Version.
  final int? langPackVersion;

  /// Base Lang Pack Version.
  final int? baseLangPackVersion;

  /// Reactions Default.
  final ReactionBase? reactionsDefault;

  /// Autologin Token.
  final String? autologinToken;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcc1a241e.
    buffer.writeInt32(0xcc1a241e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeDateTime(date);
    buffer.writeInt32(expires);
    buffer.writeBool(testMode);
    buffer.writeInt32(thisDc);
    buffer.writeVectorObject(dcOptions);
    buffer.writeString(dcTxtDomainName);
    buffer.writeInt32(chatSizeMax);
    buffer.writeInt32(megagroupSizeMax);
    buffer.writeInt32(forwardedCountMax);
    buffer.writeInt32(onlineUpdatePeriodMs);
    buffer.writeInt32(offlineBlurTimeoutMs);
    buffer.writeInt32(offlineIdleTimeoutMs);
    buffer.writeInt32(onlineCloudTimeoutMs);
    buffer.writeInt32(notifyCloudDelayMs);
    buffer.writeInt32(notifyDefaultDelayMs);
    buffer.writeInt32(pushChatPeriodMs);
    buffer.writeInt32(pushChatLimit);
    buffer.writeInt32(editTimeLimit);
    buffer.writeInt32(revokeTimeLimit);
    buffer.writeInt32(revokePmTimeLimit);
    buffer.writeInt32(ratingEDecay);
    buffer.writeInt32(stickersRecentLimit);
    buffer.writeInt32(channelsReadMediaPeriod);
    final localTmpSessionsCopy = tmpSessions;
    if (localTmpSessionsCopy != null) {
      buffer.writeInt32(localTmpSessionsCopy);
    }
    buffer.writeInt32(callReceiveTimeoutMs);
    buffer.writeInt32(callRingTimeoutMs);
    buffer.writeInt32(callConnectTimeoutMs);
    buffer.writeInt32(callPacketTimeoutMs);
    buffer.writeString(meUrlPrefix);
    final localAutoupdateUrlPrefixCopy = autoupdateUrlPrefix;
    if (localAutoupdateUrlPrefixCopy != null) {
      buffer.writeString(localAutoupdateUrlPrefixCopy);
    }
    final localGifSearchUsernameCopy = gifSearchUsername;
    if (localGifSearchUsernameCopy != null) {
      buffer.writeString(localGifSearchUsernameCopy);
    }
    final localVenueSearchUsernameCopy = venueSearchUsername;
    if (localVenueSearchUsernameCopy != null) {
      buffer.writeString(localVenueSearchUsernameCopy);
    }
    final localImgSearchUsernameCopy = imgSearchUsername;
    if (localImgSearchUsernameCopy != null) {
      buffer.writeString(localImgSearchUsernameCopy);
    }
    final localStaticMapsProviderCopy = staticMapsProvider;
    if (localStaticMapsProviderCopy != null) {
      buffer.writeString(localStaticMapsProviderCopy);
    }
    buffer.writeInt32(captionLengthMax);
    buffer.writeInt32(messageLengthMax);
    buffer.writeInt32(webfileDcId);
    final localSuggestedLangCodeCopy = suggestedLangCode;
    if (localSuggestedLangCodeCopy != null) {
      buffer.writeString(localSuggestedLangCodeCopy);
    }
    final localLangPackVersionCopy = langPackVersion;
    if (localLangPackVersionCopy != null) {
      buffer.writeInt32(localLangPackVersionCopy);
    }
    final localBaseLangPackVersionCopy = baseLangPackVersion;
    if (localBaseLangPackVersionCopy != null) {
      buffer.writeInt32(localBaseLangPackVersionCopy);
    }
    final localReactionsDefaultCopy = reactionsDefault;
    if (localReactionsDefaultCopy != null) {
      buffer.writeObject(localReactionsDefaultCopy);
    }
    final localAutologinTokenCopy = autologinToken;
    if (localAutologinTokenCopy != null) {
      buffer.writeString(localAutologinTokenCopy);
    }

    // Finished serialization.
  }
}

/// Nearest Dc.
///
/// ID: `8e1a1775`.
class NearestDc extends NearestDcBase {
  /// Nearest Dc constructor.
  const NearestDc({
    required this.country,
    required this.thisDc,
    required this.nearestDc,
  }) : super._();

  /// Deserialize.
  factory NearestDc.deserialize(BinaryReader reader) {
    // Read [NearestDc] fields.
    final country = reader.readString();
    final thisDc = reader.readInt32();
    final nearestDc = reader.readInt32();

    // Construct [NearestDc] object.
    final returnValue = NearestDc(
      country: country,
      thisDc: thisDc,
      nearestDc: nearestDc,
    );

    // Now return the deserialized [NearestDc].
    return returnValue;
  }

  /// Country.
  final String country;

  /// This Dc.
  ///
  /// Field type is Int32.
  final int thisDc;

  /// Nearest Dc.
  ///
  /// Field type is Int32.
  final int nearestDc;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8e1a1775.
    buffer.writeInt32(0x8e1a1775);

    // Write fields.
    buffer.writeString(country);
    buffer.writeInt32(thisDc);
    buffer.writeInt32(nearestDc);

    // Finished serialization.
  }
}

/// Help App Update.
///
/// ID: `ccbbce30`.
class HelpAppUpdate extends HelpAppUpdateBase {
  /// Help App Update constructor.
  const HelpAppUpdate({
    required this.canNotSkip,
    required this.id,
    required this.version,
    required this.text,
    required this.entities,
    this.document,
    this.url,
    this.sticker,
  }) : super._();

  /// Deserialize.
  factory HelpAppUpdate.deserialize(BinaryReader reader) {
    // Read [HelpAppUpdate] fields.
    final flags = reader.readInt32();
    final canNotSkip = (flags & 1) != 0;
    final id = reader.readInt32();
    final version = reader.readString();
    final text = reader.readString();
    final entities = reader.readVectorObject<MessageEntityBase>();
    final hasDocumentField = (flags & 2) != 0;
    final document =
        hasDocumentField ? reader.readObject() as DocumentBase : null;
    final hasUrlField = (flags & 4) != 0;
    final url = hasUrlField ? reader.readString() : null;
    final hasStickerField = (flags & 8) != 0;
    final sticker =
        hasStickerField ? reader.readObject() as DocumentBase : null;

    // Construct [HelpAppUpdate] object.
    final returnValue = HelpAppUpdate(
      canNotSkip: canNotSkip,
      id: id,
      version: version,
      text: text,
      entities: entities,
      document: document,
      url: url,
      sticker: sticker,
    );

    // Now return the deserialized [HelpAppUpdate].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: canNotSkip,
      b01: document != null,
      b02: url != null,
      b03: sticker != null,
    );

    return v;
  }

  /// can_not_skip: bit 0 of flags.0?true
  final bool canNotSkip;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Version.
  final String version;

  /// Text.
  final String text;

  /// Entities.
  final List<MessageEntityBase> entities;

  /// Document.
  final DocumentBase? document;

  /// Url.
  final String? url;

  /// Sticker.
  final DocumentBase? sticker;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xccbbce30.
    buffer.writeInt32(0xccbbce30);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeString(version);
    buffer.writeString(text);
    buffer.writeVectorObject(entities);
    final localDocumentCopy = document;
    if (localDocumentCopy != null) {
      buffer.writeObject(localDocumentCopy);
    }
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }
    final localStickerCopy = sticker;
    if (localStickerCopy != null) {
      buffer.writeObject(localStickerCopy);
    }

    // Finished serialization.
  }
}

/// Help No App Update.
///
/// ID: `c45a6536`.
class HelpNoAppUpdate extends HelpAppUpdateBase {
  /// Help No App Update constructor.
  const HelpNoAppUpdate() : super._();

  /// Deserialize.
  factory HelpNoAppUpdate.deserialize(BinaryReader reader) {
    // Construct [HelpNoAppUpdate] object.
    final returnValue = HelpNoAppUpdate();

    // Now return the deserialized [HelpNoAppUpdate].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc45a6536.
    buffer.writeInt32(0xc45a6536);

    // Finished serialization.
  }
}

/// Help Invite Text.
///
/// ID: `18cb9f78`.
class HelpInviteText extends HelpInviteTextBase {
  /// Help Invite Text constructor.
  const HelpInviteText({
    required this.message,
  }) : super._();

  /// Deserialize.
  factory HelpInviteText.deserialize(BinaryReader reader) {
    // Read [HelpInviteText] fields.
    final message = reader.readString();

    // Construct [HelpInviteText] object.
    final returnValue = HelpInviteText(
      message: message,
    );

    // Now return the deserialized [HelpInviteText].
    return returnValue;
  }

  /// Message.
  final String message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x18cb9f78.
    buffer.writeInt32(0x18cb9f78);

    // Write fields.
    buffer.writeString(message);

    // Finished serialization.
  }
}

/// Encrypted Chat Empty.
///
/// ID: `ab7ec0a0`.
class EncryptedChatEmpty extends EncryptedChatBase {
  /// Encrypted Chat Empty constructor.
  const EncryptedChatEmpty({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory EncryptedChatEmpty.deserialize(BinaryReader reader) {
    // Read [EncryptedChatEmpty] fields.
    final id = reader.readInt32();

    // Construct [EncryptedChatEmpty] object.
    final returnValue = EncryptedChatEmpty(
      id: id,
    );

    // Now return the deserialized [EncryptedChatEmpty].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xab7ec0a0.
    buffer.writeInt32(0xab7ec0a0);

    // Write fields.
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Encrypted Chat Waiting.
///
/// ID: `66b25953`.
class EncryptedChatWaiting extends EncryptedChatBase {
  /// Encrypted Chat Waiting constructor.
  const EncryptedChatWaiting({
    required this.id,
    required this.accessHash,
    required this.date,
    required this.adminId,
    required this.participantId,
  }) : super._();

  /// Deserialize.
  factory EncryptedChatWaiting.deserialize(BinaryReader reader) {
    // Read [EncryptedChatWaiting] fields.
    final id = reader.readInt32();
    final accessHash = reader.readInt64();
    final date = reader.readDateTime();
    final adminId = reader.readInt64();
    final participantId = reader.readInt64();

    // Construct [EncryptedChatWaiting] object.
    final returnValue = EncryptedChatWaiting(
      id: id,
      accessHash: accessHash,
      date: date,
      adminId: adminId,
      participantId: participantId,
    );

    // Now return the deserialized [EncryptedChatWaiting].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Date.
  final DateTime date;

  /// Admin Id.
  ///
  /// Field type is Int64.
  final int adminId;

  /// Participant Id.
  ///
  /// Field type is Int64.
  final int participantId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x66b25953.
    buffer.writeInt32(0x66b25953);

    // Write fields.
    buffer.writeInt32(id);
    buffer.writeInt64(accessHash);
    buffer.writeDateTime(date);
    buffer.writeInt64(adminId);
    buffer.writeInt64(participantId);

    // Finished serialization.
  }
}

/// Encrypted Chat Requested.
///
/// ID: `48f1d94c`.
class EncryptedChatRequested extends EncryptedChatBase {
  /// Encrypted Chat Requested constructor.
  const EncryptedChatRequested({
    this.folderId,
    required this.id,
    required this.accessHash,
    required this.date,
    required this.adminId,
    required this.participantId,
    required this.gA,
  }) : super._();

  /// Deserialize.
  factory EncryptedChatRequested.deserialize(BinaryReader reader) {
    // Read [EncryptedChatRequested] fields.
    final flags = reader.readInt32();
    final hasFolderIdField = (flags & 1) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final id = reader.readInt32();
    final accessHash = reader.readInt64();
    final date = reader.readDateTime();
    final adminId = reader.readInt64();
    final participantId = reader.readInt64();
    final gA = reader.readBytes();

    // Construct [EncryptedChatRequested] object.
    final returnValue = EncryptedChatRequested(
      folderId: folderId,
      id: id,
      accessHash: accessHash,
      date: date,
      adminId: adminId,
      participantId: participantId,
      gA: gA,
    );

    // Now return the deserialized [EncryptedChatRequested].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: folderId != null,
    );

    return v;
  }

  /// Folder Id.
  final int? folderId;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Date.
  final DateTime date;

  /// Admin Id.
  ///
  /// Field type is Int64.
  final int adminId;

  /// Participant Id.
  ///
  /// Field type is Int64.
  final int participantId;

  /// G A.
  final Uint8List gA;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x48f1d94c.
    buffer.writeInt32(0x48f1d94c);

    // Write fields.
    buffer.writeInt32(flags);
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    buffer.writeInt32(id);
    buffer.writeInt64(accessHash);
    buffer.writeDateTime(date);
    buffer.writeInt64(adminId);
    buffer.writeInt64(participantId);
    buffer.writeBytes(gA);

    // Finished serialization.
  }
}

/// Encrypted Chat.
///
/// ID: `61f0d4c7`.
class EncryptedChat extends EncryptedChatBase {
  /// Encrypted Chat constructor.
  const EncryptedChat({
    required this.id,
    required this.accessHash,
    required this.date,
    required this.adminId,
    required this.participantId,
    required this.gAOrB,
    required this.keyFingerprint,
  }) : super._();

  /// Deserialize.
  factory EncryptedChat.deserialize(BinaryReader reader) {
    // Read [EncryptedChat] fields.
    final id = reader.readInt32();
    final accessHash = reader.readInt64();
    final date = reader.readDateTime();
    final adminId = reader.readInt64();
    final participantId = reader.readInt64();
    final gAOrB = reader.readBytes();
    final keyFingerprint = reader.readInt64();

    // Construct [EncryptedChat] object.
    final returnValue = EncryptedChat(
      id: id,
      accessHash: accessHash,
      date: date,
      adminId: adminId,
      participantId: participantId,
      gAOrB: gAOrB,
      keyFingerprint: keyFingerprint,
    );

    // Now return the deserialized [EncryptedChat].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Date.
  final DateTime date;

  /// Admin Id.
  ///
  /// Field type is Int64.
  final int adminId;

  /// Participant Id.
  ///
  /// Field type is Int64.
  final int participantId;

  /// G A Or B.
  final Uint8List gAOrB;

  /// Key Fingerprint.
  ///
  /// Field type is Int64.
  final int keyFingerprint;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x61f0d4c7.
    buffer.writeInt32(0x61f0d4c7);

    // Write fields.
    buffer.writeInt32(id);
    buffer.writeInt64(accessHash);
    buffer.writeDateTime(date);
    buffer.writeInt64(adminId);
    buffer.writeInt64(participantId);
    buffer.writeBytes(gAOrB);
    buffer.writeInt64(keyFingerprint);

    // Finished serialization.
  }
}

/// Encrypted Chat Discarded.
///
/// ID: `1e1c7c45`.
class EncryptedChatDiscarded extends EncryptedChatBase {
  /// Encrypted Chat Discarded constructor.
  const EncryptedChatDiscarded({
    required this.historyDeleted,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory EncryptedChatDiscarded.deserialize(BinaryReader reader) {
    // Read [EncryptedChatDiscarded] fields.
    final flags = reader.readInt32();
    final historyDeleted = (flags & 1) != 0;
    final id = reader.readInt32();

    // Construct [EncryptedChatDiscarded] object.
    final returnValue = EncryptedChatDiscarded(
      historyDeleted: historyDeleted,
      id: id,
    );

    // Now return the deserialized [EncryptedChatDiscarded].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: historyDeleted,
    );

    return v;
  }

  /// history_deleted: bit 0 of flags.0?true
  final bool historyDeleted;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1e1c7c45.
    buffer.writeInt32(0x1e1c7c45);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Input Encrypted Chat.
///
/// ID: `f141b5e1`.
class InputEncryptedChat extends InputEncryptedChatBase {
  /// Input Encrypted Chat constructor.
  const InputEncryptedChat({
    required this.chatId,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputEncryptedChat.deserialize(BinaryReader reader) {
    // Read [InputEncryptedChat] fields.
    final chatId = reader.readInt32();
    final accessHash = reader.readInt64();

    // Construct [InputEncryptedChat] object.
    final returnValue = InputEncryptedChat(
      chatId: chatId,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputEncryptedChat].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int32.
  final int chatId;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf141b5e1.
    buffer.writeInt32(0xf141b5e1);

    // Write fields.
    buffer.writeInt32(chatId);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Encrypted File Empty.
///
/// ID: `c21f497e`.
class EncryptedFileEmpty extends EncryptedFileBase {
  /// Encrypted File Empty constructor.
  const EncryptedFileEmpty() : super._();

  /// Deserialize.
  factory EncryptedFileEmpty.deserialize(BinaryReader reader) {
    // Construct [EncryptedFileEmpty] object.
    final returnValue = EncryptedFileEmpty();

    // Now return the deserialized [EncryptedFileEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc21f497e.
    buffer.writeInt32(0xc21f497e);

    // Finished serialization.
  }
}

/// Encrypted File.
///
/// ID: `a8008cd8`.
class EncryptedFile extends EncryptedFileBase {
  /// Encrypted File constructor.
  const EncryptedFile({
    required this.id,
    required this.accessHash,
    required this.size,
    required this.dcId,
    required this.keyFingerprint,
  }) : super._();

  /// Deserialize.
  factory EncryptedFile.deserialize(BinaryReader reader) {
    // Read [EncryptedFile] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final size = reader.readInt64();
    final dcId = reader.readInt32();
    final keyFingerprint = reader.readInt32();

    // Construct [EncryptedFile] object.
    final returnValue = EncryptedFile(
      id: id,
      accessHash: accessHash,
      size: size,
      dcId: dcId,
      keyFingerprint: keyFingerprint,
    );

    // Now return the deserialized [EncryptedFile].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Size.
  ///
  /// Field type is Int64.
  final int size;

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Key Fingerprint.
  ///
  /// Field type is Int32.
  final int keyFingerprint;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa8008cd8.
    buffer.writeInt32(0xa8008cd8);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeInt64(size);
    buffer.writeInt32(dcId);
    buffer.writeInt32(keyFingerprint);

    // Finished serialization.
  }
}

/// Input Encrypted File Empty.
///
/// ID: `1837c364`.
class InputEncryptedFileEmpty extends InputEncryptedFileBase {
  /// Input Encrypted File Empty constructor.
  const InputEncryptedFileEmpty() : super._();

  /// Deserialize.
  factory InputEncryptedFileEmpty.deserialize(BinaryReader reader) {
    // Construct [InputEncryptedFileEmpty] object.
    final returnValue = InputEncryptedFileEmpty();

    // Now return the deserialized [InputEncryptedFileEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1837c364.
    buffer.writeInt32(0x1837c364);

    // Finished serialization.
  }
}

/// Input Encrypted File Uploaded.
///
/// ID: `64bd0306`.
class InputEncryptedFileUploaded extends InputEncryptedFileBase {
  /// Input Encrypted File Uploaded constructor.
  const InputEncryptedFileUploaded({
    required this.id,
    required this.parts,
    required this.md5Checksum,
    required this.keyFingerprint,
  }) : super._();

  /// Deserialize.
  factory InputEncryptedFileUploaded.deserialize(BinaryReader reader) {
    // Read [InputEncryptedFileUploaded] fields.
    final id = reader.readInt64();
    final parts = reader.readInt32();
    final md5Checksum = reader.readString();
    final keyFingerprint = reader.readInt32();

    // Construct [InputEncryptedFileUploaded] object.
    final returnValue = InputEncryptedFileUploaded(
      id: id,
      parts: parts,
      md5Checksum: md5Checksum,
      keyFingerprint: keyFingerprint,
    );

    // Now return the deserialized [InputEncryptedFileUploaded].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Parts.
  ///
  /// Field type is Int32.
  final int parts;

  /// Md5 Checksum.
  final String md5Checksum;

  /// Key Fingerprint.
  ///
  /// Field type is Int32.
  final int keyFingerprint;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x64bd0306.
    buffer.writeInt32(0x64bd0306);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt32(parts);
    buffer.writeString(md5Checksum);
    buffer.writeInt32(keyFingerprint);

    // Finished serialization.
  }
}

/// Input Encrypted File.
///
/// ID: `5a17b5e5`.
class InputEncryptedFile extends InputEncryptedFileBase {
  /// Input Encrypted File constructor.
  const InputEncryptedFile({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputEncryptedFile.deserialize(BinaryReader reader) {
    // Read [InputEncryptedFile] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputEncryptedFile] object.
    final returnValue = InputEncryptedFile(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputEncryptedFile].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5a17b5e5.
    buffer.writeInt32(0x5a17b5e5);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Encrypted File Big Uploaded.
///
/// ID: `2dc173c8`.
class InputEncryptedFileBigUploaded extends InputEncryptedFileBase {
  /// Input Encrypted File Big Uploaded constructor.
  const InputEncryptedFileBigUploaded({
    required this.id,
    required this.parts,
    required this.keyFingerprint,
  }) : super._();

  /// Deserialize.
  factory InputEncryptedFileBigUploaded.deserialize(BinaryReader reader) {
    // Read [InputEncryptedFileBigUploaded] fields.
    final id = reader.readInt64();
    final parts = reader.readInt32();
    final keyFingerprint = reader.readInt32();

    // Construct [InputEncryptedFileBigUploaded] object.
    final returnValue = InputEncryptedFileBigUploaded(
      id: id,
      parts: parts,
      keyFingerprint: keyFingerprint,
    );

    // Now return the deserialized [InputEncryptedFileBigUploaded].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Parts.
  ///
  /// Field type is Int32.
  final int parts;

  /// Key Fingerprint.
  ///
  /// Field type is Int32.
  final int keyFingerprint;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2dc173c8.
    buffer.writeInt32(0x2dc173c8);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt32(parts);
    buffer.writeInt32(keyFingerprint);

    // Finished serialization.
  }
}

/// Encrypted Message.
///
/// ID: `ed18c118`.
class EncryptedMessage extends EncryptedMessageBase {
  /// Encrypted Message constructor.
  const EncryptedMessage({
    required this.randomId,
    required this.chatId,
    required this.date,
    required this.bytes,
    required this.file,
  }) : super._();

  /// Deserialize.
  factory EncryptedMessage.deserialize(BinaryReader reader) {
    // Read [EncryptedMessage] fields.
    final randomId = reader.readInt64();
    final chatId = reader.readInt32();
    final date = reader.readDateTime();
    final bytes = reader.readBytes();
    final file = reader.readObject() as EncryptedFileBase;

    // Construct [EncryptedMessage] object.
    final returnValue = EncryptedMessage(
      randomId: randomId,
      chatId: chatId,
      date: date,
      bytes: bytes,
      file: file,
    );

    // Now return the deserialized [EncryptedMessage].
    return returnValue;
  }

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Chat Id.
  ///
  /// Field type is Int32.
  final int chatId;

  /// Date.
  final DateTime date;

  /// Bytes.
  final Uint8List bytes;

  /// File.
  final EncryptedFileBase file;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xed18c118.
    buffer.writeInt32(0xed18c118);

    // Write fields.
    buffer.writeInt64(randomId);
    buffer.writeInt32(chatId);
    buffer.writeDateTime(date);
    buffer.writeBytes(bytes);
    buffer.writeObject(file);

    // Finished serialization.
  }
}

/// Encrypted Message Service.
///
/// ID: `23734b06`.
class EncryptedMessageService extends EncryptedMessageBase {
  /// Encrypted Message Service constructor.
  const EncryptedMessageService({
    required this.randomId,
    required this.chatId,
    required this.date,
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory EncryptedMessageService.deserialize(BinaryReader reader) {
    // Read [EncryptedMessageService] fields.
    final randomId = reader.readInt64();
    final chatId = reader.readInt32();
    final date = reader.readDateTime();
    final bytes = reader.readBytes();

    // Construct [EncryptedMessageService] object.
    final returnValue = EncryptedMessageService(
      randomId: randomId,
      chatId: chatId,
      date: date,
      bytes: bytes,
    );

    // Now return the deserialized [EncryptedMessageService].
    return returnValue;
  }

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Chat Id.
  ///
  /// Field type is Int32.
  final int chatId;

  /// Date.
  final DateTime date;

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x23734b06.
    buffer.writeInt32(0x23734b06);

    // Write fields.
    buffer.writeInt64(randomId);
    buffer.writeInt32(chatId);
    buffer.writeDateTime(date);
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Messages Dh Config Not Modified.
///
/// ID: `c0e24635`.
class MessagesDhConfigNotModified extends MessagesDhConfigBase {
  /// Messages Dh Config Not Modified constructor.
  const MessagesDhConfigNotModified({
    required this.random,
  }) : super._();

  /// Deserialize.
  factory MessagesDhConfigNotModified.deserialize(BinaryReader reader) {
    // Read [MessagesDhConfigNotModified] fields.
    final random = reader.readBytes();

    // Construct [MessagesDhConfigNotModified] object.
    final returnValue = MessagesDhConfigNotModified(
      random: random,
    );

    // Now return the deserialized [MessagesDhConfigNotModified].
    return returnValue;
  }

  /// Random.
  final Uint8List random;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc0e24635.
    buffer.writeInt32(0xc0e24635);

    // Write fields.
    buffer.writeBytes(random);

    // Finished serialization.
  }
}

/// Messages Dh Config.
///
/// ID: `2c221edd`.
class MessagesDhConfig extends MessagesDhConfigBase {
  /// Messages Dh Config constructor.
  const MessagesDhConfig({
    required this.g,
    required this.p,
    required this.version,
    required this.random,
  }) : super._();

  /// Deserialize.
  factory MessagesDhConfig.deserialize(BinaryReader reader) {
    // Read [MessagesDhConfig] fields.
    final g = reader.readInt32();
    final p = reader.readBytes();
    final version = reader.readInt32();
    final random = reader.readBytes();

    // Construct [MessagesDhConfig] object.
    final returnValue = MessagesDhConfig(
      g: g,
      p: p,
      version: version,
      random: random,
    );

    // Now return the deserialized [MessagesDhConfig].
    return returnValue;
  }

  /// G.
  ///
  /// Field type is Int32.
  final int g;

  /// P.
  final Uint8List p;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Random.
  final Uint8List random;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2c221edd.
    buffer.writeInt32(0x2c221edd);

    // Write fields.
    buffer.writeInt32(g);
    buffer.writeBytes(p);
    buffer.writeInt32(version);
    buffer.writeBytes(random);

    // Finished serialization.
  }
}

/// Messages Sent Encrypted Message.
///
/// ID: `560f8935`.
class MessagesSentEncryptedMessage extends MessagesSentEncryptedMessageBase {
  /// Messages Sent Encrypted Message constructor.
  const MessagesSentEncryptedMessage({
    required this.date,
  }) : super._();

  /// Deserialize.
  factory MessagesSentEncryptedMessage.deserialize(BinaryReader reader) {
    // Read [MessagesSentEncryptedMessage] fields.
    final date = reader.readDateTime();

    // Construct [MessagesSentEncryptedMessage] object.
    final returnValue = MessagesSentEncryptedMessage(
      date: date,
    );

    // Now return the deserialized [MessagesSentEncryptedMessage].
    return returnValue;
  }

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x560f8935.
    buffer.writeInt32(0x560f8935);

    // Write fields.
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Messages Sent Encrypted File.
///
/// ID: `9493ff32`.
class MessagesSentEncryptedFile extends MessagesSentEncryptedMessageBase {
  /// Messages Sent Encrypted File constructor.
  const MessagesSentEncryptedFile({
    required this.date,
    required this.file,
  }) : super._();

  /// Deserialize.
  factory MessagesSentEncryptedFile.deserialize(BinaryReader reader) {
    // Read [MessagesSentEncryptedFile] fields.
    final date = reader.readDateTime();
    final file = reader.readObject() as EncryptedFileBase;

    // Construct [MessagesSentEncryptedFile] object.
    final returnValue = MessagesSentEncryptedFile(
      date: date,
      file: file,
    );

    // Now return the deserialized [MessagesSentEncryptedFile].
    return returnValue;
  }

  /// Date.
  final DateTime date;

  /// File.
  final EncryptedFileBase file;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9493ff32.
    buffer.writeInt32(0x9493ff32);

    // Write fields.
    buffer.writeDateTime(date);
    buffer.writeObject(file);

    // Finished serialization.
  }
}

/// Input Document Empty.
///
/// ID: `72f0eaae`.
class InputDocumentEmpty extends InputDocumentBase {
  /// Input Document Empty constructor.
  const InputDocumentEmpty() : super._();

  /// Deserialize.
  factory InputDocumentEmpty.deserialize(BinaryReader reader) {
    // Construct [InputDocumentEmpty] object.
    final returnValue = InputDocumentEmpty();

    // Now return the deserialized [InputDocumentEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x72f0eaae.
    buffer.writeInt32(0x72f0eaae);

    // Finished serialization.
  }
}

/// Input Document.
///
/// ID: `1abfb575`.
class InputDocument extends InputDocumentBase {
  /// Input Document constructor.
  const InputDocument({
    required this.id,
    required this.accessHash,
    required this.fileReference,
  }) : super._();

  /// Deserialize.
  factory InputDocument.deserialize(BinaryReader reader) {
    // Read [InputDocument] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final fileReference = reader.readBytes();

    // Construct [InputDocument] object.
    final returnValue = InputDocument(
      id: id,
      accessHash: accessHash,
      fileReference: fileReference,
    );

    // Now return the deserialized [InputDocument].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// File Reference.
  final Uint8List fileReference;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1abfb575.
    buffer.writeInt32(0x1abfb575);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeBytes(fileReference);

    // Finished serialization.
  }
}

/// Document Empty.
///
/// ID: `36f8c871`.
class DocumentEmpty extends DocumentBase {
  /// Document Empty constructor.
  const DocumentEmpty({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory DocumentEmpty.deserialize(BinaryReader reader) {
    // Read [DocumentEmpty] fields.
    final id = reader.readInt64();

    // Construct [DocumentEmpty] object.
    final returnValue = DocumentEmpty(
      id: id,
    );

    // Now return the deserialized [DocumentEmpty].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x36f8c871.
    buffer.writeInt32(0x36f8c871);

    // Write fields.
    buffer.writeInt64(id);

    // Finished serialization.
  }
}

/// Document.
///
/// ID: `8fd4c4d8`.
class Document extends DocumentBase {
  /// Document constructor.
  const Document({
    required this.id,
    required this.accessHash,
    required this.fileReference,
    required this.date,
    required this.mimeType,
    required this.size,
    this.thumbs,
    this.videoThumbs,
    required this.dcId,
    required this.attributes,
  }) : super._();

  /// Deserialize.
  factory Document.deserialize(BinaryReader reader) {
    // Read [Document] fields.
    final flags = reader.readInt32();
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final fileReference = reader.readBytes();
    final date = reader.readDateTime();
    final mimeType = reader.readString();
    final size = reader.readInt64();
    final hasThumbsField = (flags & 1) != 0;
    final thumbs =
        hasThumbsField ? reader.readVectorObject<PhotoSizeBase>() : null;
    final hasVideoThumbsField = (flags & 2) != 0;
    final videoThumbs =
        hasVideoThumbsField ? reader.readVectorObject<VideoSizeBase>() : null;
    final dcId = reader.readInt32();
    final attributes = reader.readVectorObject<DocumentAttributeBase>();

    // Construct [Document] object.
    final returnValue = Document(
      id: id,
      accessHash: accessHash,
      fileReference: fileReference,
      date: date,
      mimeType: mimeType,
      size: size,
      thumbs: thumbs,
      videoThumbs: videoThumbs,
      dcId: dcId,
      attributes: attributes,
    );

    // Now return the deserialized [Document].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: thumbs != null,
      b01: videoThumbs != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// File Reference.
  final Uint8List fileReference;

  /// Date.
  final DateTime date;

  /// Mime Type.
  final String mimeType;

  /// Size.
  ///
  /// Field type is Int64.
  final int size;

  /// Thumbs.
  final List<PhotoSizeBase>? thumbs;

  /// Video Thumbs.
  final List<VideoSizeBase>? videoThumbs;

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Attributes.
  final List<DocumentAttributeBase> attributes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8fd4c4d8.
    buffer.writeInt32(0x8fd4c4d8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeBytes(fileReference);
    buffer.writeDateTime(date);
    buffer.writeString(mimeType);
    buffer.writeInt64(size);
    final localThumbsCopy = thumbs;
    if (localThumbsCopy != null) {
      buffer.writeVectorObject(localThumbsCopy);
    }
    final localVideoThumbsCopy = videoThumbs;
    if (localVideoThumbsCopy != null) {
      buffer.writeVectorObject(localVideoThumbsCopy);
    }
    buffer.writeInt32(dcId);
    buffer.writeVectorObject(attributes);

    // Finished serialization.
  }
}

/// Help Support.
///
/// ID: `17c6b5f6`.
class HelpSupport extends HelpSupportBase {
  /// Help Support constructor.
  const HelpSupport({
    required this.phoneNumber,
    required this.user,
  }) : super._();

  /// Deserialize.
  factory HelpSupport.deserialize(BinaryReader reader) {
    // Read [HelpSupport] fields.
    final phoneNumber = reader.readString();
    final user = reader.readObject() as UserBase;

    // Construct [HelpSupport] object.
    final returnValue = HelpSupport(
      phoneNumber: phoneNumber,
      user: user,
    );

    // Now return the deserialized [HelpSupport].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// User.
  final UserBase user;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x17c6b5f6.
    buffer.writeInt32(0x17c6b5f6);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeObject(user);

    // Finished serialization.
  }
}

/// Notify Peer.
///
/// ID: `9fd40bd8`.
class NotifyPeer extends NotifyPeerBase {
  /// Notify Peer constructor.
  const NotifyPeer({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory NotifyPeer.deserialize(BinaryReader reader) {
    // Read [NotifyPeer] fields.
    final peer = reader.readObject() as PeerBase;

    // Construct [NotifyPeer] object.
    final returnValue = NotifyPeer(
      peer: peer,
    );

    // Now return the deserialized [NotifyPeer].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9fd40bd8.
    buffer.writeInt32(0x9fd40bd8);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Notify Users.
///
/// ID: `b4c83b4c`.
class NotifyUsers extends NotifyPeerBase {
  /// Notify Users constructor.
  const NotifyUsers() : super._();

  /// Deserialize.
  factory NotifyUsers.deserialize(BinaryReader reader) {
    // Construct [NotifyUsers] object.
    final returnValue = NotifyUsers();

    // Now return the deserialized [NotifyUsers].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb4c83b4c.
    buffer.writeInt32(0xb4c83b4c);

    // Finished serialization.
  }
}

/// Notify Chats.
///
/// ID: `c007cec3`.
class NotifyChats extends NotifyPeerBase {
  /// Notify Chats constructor.
  const NotifyChats() : super._();

  /// Deserialize.
  factory NotifyChats.deserialize(BinaryReader reader) {
    // Construct [NotifyChats] object.
    final returnValue = NotifyChats();

    // Now return the deserialized [NotifyChats].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc007cec3.
    buffer.writeInt32(0xc007cec3);

    // Finished serialization.
  }
}

/// Notify Broadcasts.
///
/// ID: `d612e8ef`.
class NotifyBroadcasts extends NotifyPeerBase {
  /// Notify Broadcasts constructor.
  const NotifyBroadcasts() : super._();

  /// Deserialize.
  factory NotifyBroadcasts.deserialize(BinaryReader reader) {
    // Construct [NotifyBroadcasts] object.
    final returnValue = NotifyBroadcasts();

    // Now return the deserialized [NotifyBroadcasts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd612e8ef.
    buffer.writeInt32(0xd612e8ef);

    // Finished serialization.
  }
}

/// Notify Forum Topic.
///
/// ID: `226e6308`.
class NotifyForumTopic extends NotifyPeerBase {
  /// Notify Forum Topic constructor.
  const NotifyForumTopic({
    required this.peer,
    required this.topMsgId,
  }) : super._();

  /// Deserialize.
  factory NotifyForumTopic.deserialize(BinaryReader reader) {
    // Read [NotifyForumTopic] fields.
    final peer = reader.readObject() as PeerBase;
    final topMsgId = reader.readInt32();

    // Construct [NotifyForumTopic] object.
    final returnValue = NotifyForumTopic(
      peer: peer,
      topMsgId: topMsgId,
    );

    // Now return the deserialized [NotifyForumTopic].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Top Msg Id.
  ///
  /// Field type is Int32.
  final int topMsgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x226e6308.
    buffer.writeInt32(0x226e6308);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(topMsgId);

    // Finished serialization.
  }
}

/// Send Message Typing Action.
///
/// ID: `16bf744e`.
class SendMessageTypingAction extends SendMessageActionBase {
  /// Send Message Typing Action constructor.
  const SendMessageTypingAction() : super._();

  /// Deserialize.
  factory SendMessageTypingAction.deserialize(BinaryReader reader) {
    // Construct [SendMessageTypingAction] object.
    final returnValue = SendMessageTypingAction();

    // Now return the deserialized [SendMessageTypingAction].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x16bf744e.
    buffer.writeInt32(0x16bf744e);

    // Finished serialization.
  }
}

/// Send Message Cancel Action.
///
/// ID: `fd5ec8f5`.
class SendMessageCancelAction extends SendMessageActionBase {
  /// Send Message Cancel Action constructor.
  const SendMessageCancelAction() : super._();

  /// Deserialize.
  factory SendMessageCancelAction.deserialize(BinaryReader reader) {
    // Construct [SendMessageCancelAction] object.
    final returnValue = SendMessageCancelAction();

    // Now return the deserialized [SendMessageCancelAction].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfd5ec8f5.
    buffer.writeInt32(0xfd5ec8f5);

    // Finished serialization.
  }
}

/// Send Message Record Video Action.
///
/// ID: `a187d66f`.
class SendMessageRecordVideoAction extends SendMessageActionBase {
  /// Send Message Record Video Action constructor.
  const SendMessageRecordVideoAction() : super._();

  /// Deserialize.
  factory SendMessageRecordVideoAction.deserialize(BinaryReader reader) {
    // Construct [SendMessageRecordVideoAction] object.
    final returnValue = SendMessageRecordVideoAction();

    // Now return the deserialized [SendMessageRecordVideoAction].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa187d66f.
    buffer.writeInt32(0xa187d66f);

    // Finished serialization.
  }
}

/// Send Message Upload Video Action.
///
/// ID: `e9763aec`.
class SendMessageUploadVideoAction extends SendMessageActionBase {
  /// Send Message Upload Video Action constructor.
  const SendMessageUploadVideoAction({
    required this.progress,
  }) : super._();

  /// Deserialize.
  factory SendMessageUploadVideoAction.deserialize(BinaryReader reader) {
    // Read [SendMessageUploadVideoAction] fields.
    final progress = reader.readInt32();

    // Construct [SendMessageUploadVideoAction] object.
    final returnValue = SendMessageUploadVideoAction(
      progress: progress,
    );

    // Now return the deserialized [SendMessageUploadVideoAction].
    return returnValue;
  }

  /// Progress.
  ///
  /// Field type is Int32.
  final int progress;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe9763aec.
    buffer.writeInt32(0xe9763aec);

    // Write fields.
    buffer.writeInt32(progress);

    // Finished serialization.
  }
}

/// Send Message Record Audio Action.
///
/// ID: `d52f73f7`.
class SendMessageRecordAudioAction extends SendMessageActionBase {
  /// Send Message Record Audio Action constructor.
  const SendMessageRecordAudioAction() : super._();

  /// Deserialize.
  factory SendMessageRecordAudioAction.deserialize(BinaryReader reader) {
    // Construct [SendMessageRecordAudioAction] object.
    final returnValue = SendMessageRecordAudioAction();

    // Now return the deserialized [SendMessageRecordAudioAction].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd52f73f7.
    buffer.writeInt32(0xd52f73f7);

    // Finished serialization.
  }
}

/// Send Message Upload Audio Action.
///
/// ID: `f351d7ab`.
class SendMessageUploadAudioAction extends SendMessageActionBase {
  /// Send Message Upload Audio Action constructor.
  const SendMessageUploadAudioAction({
    required this.progress,
  }) : super._();

  /// Deserialize.
  factory SendMessageUploadAudioAction.deserialize(BinaryReader reader) {
    // Read [SendMessageUploadAudioAction] fields.
    final progress = reader.readInt32();

    // Construct [SendMessageUploadAudioAction] object.
    final returnValue = SendMessageUploadAudioAction(
      progress: progress,
    );

    // Now return the deserialized [SendMessageUploadAudioAction].
    return returnValue;
  }

  /// Progress.
  ///
  /// Field type is Int32.
  final int progress;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf351d7ab.
    buffer.writeInt32(0xf351d7ab);

    // Write fields.
    buffer.writeInt32(progress);

    // Finished serialization.
  }
}

/// Send Message Upload Photo Action.
///
/// ID: `d1d34a26`.
class SendMessageUploadPhotoAction extends SendMessageActionBase {
  /// Send Message Upload Photo Action constructor.
  const SendMessageUploadPhotoAction({
    required this.progress,
  }) : super._();

  /// Deserialize.
  factory SendMessageUploadPhotoAction.deserialize(BinaryReader reader) {
    // Read [SendMessageUploadPhotoAction] fields.
    final progress = reader.readInt32();

    // Construct [SendMessageUploadPhotoAction] object.
    final returnValue = SendMessageUploadPhotoAction(
      progress: progress,
    );

    // Now return the deserialized [SendMessageUploadPhotoAction].
    return returnValue;
  }

  /// Progress.
  ///
  /// Field type is Int32.
  final int progress;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd1d34a26.
    buffer.writeInt32(0xd1d34a26);

    // Write fields.
    buffer.writeInt32(progress);

    // Finished serialization.
  }
}

/// Send Message Upload Document Action.
///
/// ID: `aa0cd9e4`.
class SendMessageUploadDocumentAction extends SendMessageActionBase {
  /// Send Message Upload Document Action constructor.
  const SendMessageUploadDocumentAction({
    required this.progress,
  }) : super._();

  /// Deserialize.
  factory SendMessageUploadDocumentAction.deserialize(BinaryReader reader) {
    // Read [SendMessageUploadDocumentAction] fields.
    final progress = reader.readInt32();

    // Construct [SendMessageUploadDocumentAction] object.
    final returnValue = SendMessageUploadDocumentAction(
      progress: progress,
    );

    // Now return the deserialized [SendMessageUploadDocumentAction].
    return returnValue;
  }

  /// Progress.
  ///
  /// Field type is Int32.
  final int progress;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaa0cd9e4.
    buffer.writeInt32(0xaa0cd9e4);

    // Write fields.
    buffer.writeInt32(progress);

    // Finished serialization.
  }
}

/// Send Message Geo Location Action.
///
/// ID: `176f8ba1`.
class SendMessageGeoLocationAction extends SendMessageActionBase {
  /// Send Message Geo Location Action constructor.
  const SendMessageGeoLocationAction() : super._();

  /// Deserialize.
  factory SendMessageGeoLocationAction.deserialize(BinaryReader reader) {
    // Construct [SendMessageGeoLocationAction] object.
    final returnValue = SendMessageGeoLocationAction();

    // Now return the deserialized [SendMessageGeoLocationAction].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x176f8ba1.
    buffer.writeInt32(0x176f8ba1);

    // Finished serialization.
  }
}

/// Send Message Choose Contact Action.
///
/// ID: `628cbc6f`.
class SendMessageChooseContactAction extends SendMessageActionBase {
  /// Send Message Choose Contact Action constructor.
  const SendMessageChooseContactAction() : super._();

  /// Deserialize.
  factory SendMessageChooseContactAction.deserialize(BinaryReader reader) {
    // Construct [SendMessageChooseContactAction] object.
    final returnValue = SendMessageChooseContactAction();

    // Now return the deserialized [SendMessageChooseContactAction].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x628cbc6f.
    buffer.writeInt32(0x628cbc6f);

    // Finished serialization.
  }
}

/// Send Message Game Play Action.
///
/// ID: `dd6a8f48`.
class SendMessageGamePlayAction extends SendMessageActionBase {
  /// Send Message Game Play Action constructor.
  const SendMessageGamePlayAction() : super._();

  /// Deserialize.
  factory SendMessageGamePlayAction.deserialize(BinaryReader reader) {
    // Construct [SendMessageGamePlayAction] object.
    final returnValue = SendMessageGamePlayAction();

    // Now return the deserialized [SendMessageGamePlayAction].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdd6a8f48.
    buffer.writeInt32(0xdd6a8f48);

    // Finished serialization.
  }
}

/// Send Message Record Round Action.
///
/// ID: `88f27fbc`.
class SendMessageRecordRoundAction extends SendMessageActionBase {
  /// Send Message Record Round Action constructor.
  const SendMessageRecordRoundAction() : super._();

  /// Deserialize.
  factory SendMessageRecordRoundAction.deserialize(BinaryReader reader) {
    // Construct [SendMessageRecordRoundAction] object.
    final returnValue = SendMessageRecordRoundAction();

    // Now return the deserialized [SendMessageRecordRoundAction].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x88f27fbc.
    buffer.writeInt32(0x88f27fbc);

    // Finished serialization.
  }
}

/// Send Message Upload Round Action.
///
/// ID: `243e1c66`.
class SendMessageUploadRoundAction extends SendMessageActionBase {
  /// Send Message Upload Round Action constructor.
  const SendMessageUploadRoundAction({
    required this.progress,
  }) : super._();

  /// Deserialize.
  factory SendMessageUploadRoundAction.deserialize(BinaryReader reader) {
    // Read [SendMessageUploadRoundAction] fields.
    final progress = reader.readInt32();

    // Construct [SendMessageUploadRoundAction] object.
    final returnValue = SendMessageUploadRoundAction(
      progress: progress,
    );

    // Now return the deserialized [SendMessageUploadRoundAction].
    return returnValue;
  }

  /// Progress.
  ///
  /// Field type is Int32.
  final int progress;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x243e1c66.
    buffer.writeInt32(0x243e1c66);

    // Write fields.
    buffer.writeInt32(progress);

    // Finished serialization.
  }
}

/// Speaking In Group Call Action.
///
/// ID: `d92c2285`.
class SpeakingInGroupCallAction extends SendMessageActionBase {
  /// Speaking In Group Call Action constructor.
  const SpeakingInGroupCallAction() : super._();

  /// Deserialize.
  factory SpeakingInGroupCallAction.deserialize(BinaryReader reader) {
    // Construct [SpeakingInGroupCallAction] object.
    final returnValue = SpeakingInGroupCallAction();

    // Now return the deserialized [SpeakingInGroupCallAction].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd92c2285.
    buffer.writeInt32(0xd92c2285);

    // Finished serialization.
  }
}

/// Send Message History Import Action.
///
/// ID: `dbda9246`.
class SendMessageHistoryImportAction extends SendMessageActionBase {
  /// Send Message History Import Action constructor.
  const SendMessageHistoryImportAction({
    required this.progress,
  }) : super._();

  /// Deserialize.
  factory SendMessageHistoryImportAction.deserialize(BinaryReader reader) {
    // Read [SendMessageHistoryImportAction] fields.
    final progress = reader.readInt32();

    // Construct [SendMessageHistoryImportAction] object.
    final returnValue = SendMessageHistoryImportAction(
      progress: progress,
    );

    // Now return the deserialized [SendMessageHistoryImportAction].
    return returnValue;
  }

  /// Progress.
  ///
  /// Field type is Int32.
  final int progress;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdbda9246.
    buffer.writeInt32(0xdbda9246);

    // Write fields.
    buffer.writeInt32(progress);

    // Finished serialization.
  }
}

/// Send Message Choose Sticker Action.
///
/// ID: `b05ac6b1`.
class SendMessageChooseStickerAction extends SendMessageActionBase {
  /// Send Message Choose Sticker Action constructor.
  const SendMessageChooseStickerAction() : super._();

  /// Deserialize.
  factory SendMessageChooseStickerAction.deserialize(BinaryReader reader) {
    // Construct [SendMessageChooseStickerAction] object.
    final returnValue = SendMessageChooseStickerAction();

    // Now return the deserialized [SendMessageChooseStickerAction].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb05ac6b1.
    buffer.writeInt32(0xb05ac6b1);

    // Finished serialization.
  }
}

/// Send Message Emoji Interaction.
///
/// ID: `25972bcb`.
class SendMessageEmojiInteraction extends SendMessageActionBase {
  /// Send Message Emoji Interaction constructor.
  const SendMessageEmojiInteraction({
    required this.emoticon,
    required this.msgId,
    required this.interaction,
  }) : super._();

  /// Deserialize.
  factory SendMessageEmojiInteraction.deserialize(BinaryReader reader) {
    // Read [SendMessageEmojiInteraction] fields.
    final emoticon = reader.readString();
    final msgId = reader.readInt32();
    final interaction = reader.readObject() as DataJSONBase;

    // Construct [SendMessageEmojiInteraction] object.
    final returnValue = SendMessageEmojiInteraction(
      emoticon: emoticon,
      msgId: msgId,
      interaction: interaction,
    );

    // Now return the deserialized [SendMessageEmojiInteraction].
    return returnValue;
  }

  /// Emoticon.
  final String emoticon;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Interaction.
  final DataJSONBase interaction;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x25972bcb.
    buffer.writeInt32(0x25972bcb);

    // Write fields.
    buffer.writeString(emoticon);
    buffer.writeInt32(msgId);
    buffer.writeObject(interaction);

    // Finished serialization.
  }
}

/// Send Message Emoji Interaction Seen.
///
/// ID: `b665902e`.
class SendMessageEmojiInteractionSeen extends SendMessageActionBase {
  /// Send Message Emoji Interaction Seen constructor.
  const SendMessageEmojiInteractionSeen({
    required this.emoticon,
  }) : super._();

  /// Deserialize.
  factory SendMessageEmojiInteractionSeen.deserialize(BinaryReader reader) {
    // Read [SendMessageEmojiInteractionSeen] fields.
    final emoticon = reader.readString();

    // Construct [SendMessageEmojiInteractionSeen] object.
    final returnValue = SendMessageEmojiInteractionSeen(
      emoticon: emoticon,
    );

    // Now return the deserialized [SendMessageEmojiInteractionSeen].
    return returnValue;
  }

  /// Emoticon.
  final String emoticon;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb665902e.
    buffer.writeInt32(0xb665902e);

    // Write fields.
    buffer.writeString(emoticon);

    // Finished serialization.
  }
}

/// Contacts Found.
///
/// ID: `b3134d9d`.
class ContactsFound extends ContactsFoundBase {
  /// Contacts Found constructor.
  const ContactsFound({
    required this.myResults,
    required this.results,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ContactsFound.deserialize(BinaryReader reader) {
    // Read [ContactsFound] fields.
    final myResults = reader.readVectorObject<PeerBase>();
    final results = reader.readVectorObject<PeerBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ContactsFound] object.
    final returnValue = ContactsFound(
      myResults: myResults,
      results: results,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ContactsFound].
    return returnValue;
  }

  /// My Results.
  final List<PeerBase> myResults;

  /// Results.
  final List<PeerBase> results;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb3134d9d.
    buffer.writeInt32(0xb3134d9d);

    // Write fields.
    buffer.writeVectorObject(myResults);
    buffer.writeVectorObject(results);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Input Privacy Key Status Timestamp.
///
/// ID: `4f96cb18`.
class InputPrivacyKeyStatusTimestamp extends InputPrivacyKeyBase {
  /// Input Privacy Key Status Timestamp constructor.
  const InputPrivacyKeyStatusTimestamp() : super._();

  /// Deserialize.
  factory InputPrivacyKeyStatusTimestamp.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyKeyStatusTimestamp] object.
    final returnValue = InputPrivacyKeyStatusTimestamp();

    // Now return the deserialized [InputPrivacyKeyStatusTimestamp].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4f96cb18.
    buffer.writeInt32(0x4f96cb18);

    // Finished serialization.
  }
}

/// Input Privacy Key Chat Invite.
///
/// ID: `bdfb0426`.
class InputPrivacyKeyChatInvite extends InputPrivacyKeyBase {
  /// Input Privacy Key Chat Invite constructor.
  const InputPrivacyKeyChatInvite() : super._();

  /// Deserialize.
  factory InputPrivacyKeyChatInvite.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyKeyChatInvite] object.
    final returnValue = InputPrivacyKeyChatInvite();

    // Now return the deserialized [InputPrivacyKeyChatInvite].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbdfb0426.
    buffer.writeInt32(0xbdfb0426);

    // Finished serialization.
  }
}

/// Input Privacy Key Phone Call.
///
/// ID: `fabadc5f`.
class InputPrivacyKeyPhoneCall extends InputPrivacyKeyBase {
  /// Input Privacy Key Phone Call constructor.
  const InputPrivacyKeyPhoneCall() : super._();

  /// Deserialize.
  factory InputPrivacyKeyPhoneCall.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyKeyPhoneCall] object.
    final returnValue = InputPrivacyKeyPhoneCall();

    // Now return the deserialized [InputPrivacyKeyPhoneCall].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfabadc5f.
    buffer.writeInt32(0xfabadc5f);

    // Finished serialization.
  }
}

/// Input Privacy Key Phone P2 P.
///
/// ID: `db9e70d2`.
class InputPrivacyKeyPhoneP2P extends InputPrivacyKeyBase {
  /// Input Privacy Key Phone P2 P constructor.
  const InputPrivacyKeyPhoneP2P() : super._();

  /// Deserialize.
  factory InputPrivacyKeyPhoneP2P.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyKeyPhoneP2P] object.
    final returnValue = InputPrivacyKeyPhoneP2P();

    // Now return the deserialized [InputPrivacyKeyPhoneP2P].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdb9e70d2.
    buffer.writeInt32(0xdb9e70d2);

    // Finished serialization.
  }
}

/// Input Privacy Key Forwards.
///
/// ID: `a4dd4c08`.
class InputPrivacyKeyForwards extends InputPrivacyKeyBase {
  /// Input Privacy Key Forwards constructor.
  const InputPrivacyKeyForwards() : super._();

  /// Deserialize.
  factory InputPrivacyKeyForwards.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyKeyForwards] object.
    final returnValue = InputPrivacyKeyForwards();

    // Now return the deserialized [InputPrivacyKeyForwards].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa4dd4c08.
    buffer.writeInt32(0xa4dd4c08);

    // Finished serialization.
  }
}

/// Input Privacy Key Profile Photo.
///
/// ID: `5719bacc`.
class InputPrivacyKeyProfilePhoto extends InputPrivacyKeyBase {
  /// Input Privacy Key Profile Photo constructor.
  const InputPrivacyKeyProfilePhoto() : super._();

  /// Deserialize.
  factory InputPrivacyKeyProfilePhoto.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyKeyProfilePhoto] object.
    final returnValue = InputPrivacyKeyProfilePhoto();

    // Now return the deserialized [InputPrivacyKeyProfilePhoto].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5719bacc.
    buffer.writeInt32(0x5719bacc);

    // Finished serialization.
  }
}

/// Input Privacy Key Phone Number.
///
/// ID: `0352dafa`.
class InputPrivacyKeyPhoneNumber extends InputPrivacyKeyBase {
  /// Input Privacy Key Phone Number constructor.
  const InputPrivacyKeyPhoneNumber() : super._();

  /// Deserialize.
  factory InputPrivacyKeyPhoneNumber.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyKeyPhoneNumber] object.
    final returnValue = InputPrivacyKeyPhoneNumber();

    // Now return the deserialized [InputPrivacyKeyPhoneNumber].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0352dafa.
    buffer.writeInt32(0x0352dafa);

    // Finished serialization.
  }
}

/// Input Privacy Key Added By Phone.
///
/// ID: `d1219bdd`.
class InputPrivacyKeyAddedByPhone extends InputPrivacyKeyBase {
  /// Input Privacy Key Added By Phone constructor.
  const InputPrivacyKeyAddedByPhone() : super._();

  /// Deserialize.
  factory InputPrivacyKeyAddedByPhone.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyKeyAddedByPhone] object.
    final returnValue = InputPrivacyKeyAddedByPhone();

    // Now return the deserialized [InputPrivacyKeyAddedByPhone].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd1219bdd.
    buffer.writeInt32(0xd1219bdd);

    // Finished serialization.
  }
}

/// Input Privacy Key Voice Messages.
///
/// ID: `aee69d68`.
class InputPrivacyKeyVoiceMessages extends InputPrivacyKeyBase {
  /// Input Privacy Key Voice Messages constructor.
  const InputPrivacyKeyVoiceMessages() : super._();

  /// Deserialize.
  factory InputPrivacyKeyVoiceMessages.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyKeyVoiceMessages] object.
    final returnValue = InputPrivacyKeyVoiceMessages();

    // Now return the deserialized [InputPrivacyKeyVoiceMessages].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaee69d68.
    buffer.writeInt32(0xaee69d68);

    // Finished serialization.
  }
}

/// Input Privacy Key About.
///
/// ID: `3823cc40`.
class InputPrivacyKeyAbout extends InputPrivacyKeyBase {
  /// Input Privacy Key About constructor.
  const InputPrivacyKeyAbout() : super._();

  /// Deserialize.
  factory InputPrivacyKeyAbout.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyKeyAbout] object.
    final returnValue = InputPrivacyKeyAbout();

    // Now return the deserialized [InputPrivacyKeyAbout].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3823cc40.
    buffer.writeInt32(0x3823cc40);

    // Finished serialization.
  }
}

/// Privacy Key Status Timestamp.
///
/// ID: `bc2eab30`.
class PrivacyKeyStatusTimestamp extends PrivacyKeyBase {
  /// Privacy Key Status Timestamp constructor.
  const PrivacyKeyStatusTimestamp() : super._();

  /// Deserialize.
  factory PrivacyKeyStatusTimestamp.deserialize(BinaryReader reader) {
    // Construct [PrivacyKeyStatusTimestamp] object.
    final returnValue = PrivacyKeyStatusTimestamp();

    // Now return the deserialized [PrivacyKeyStatusTimestamp].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbc2eab30.
    buffer.writeInt32(0xbc2eab30);

    // Finished serialization.
  }
}

/// Privacy Key Chat Invite.
///
/// ID: `500e6dfa`.
class PrivacyKeyChatInvite extends PrivacyKeyBase {
  /// Privacy Key Chat Invite constructor.
  const PrivacyKeyChatInvite() : super._();

  /// Deserialize.
  factory PrivacyKeyChatInvite.deserialize(BinaryReader reader) {
    // Construct [PrivacyKeyChatInvite] object.
    final returnValue = PrivacyKeyChatInvite();

    // Now return the deserialized [PrivacyKeyChatInvite].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x500e6dfa.
    buffer.writeInt32(0x500e6dfa);

    // Finished serialization.
  }
}

/// Privacy Key Phone Call.
///
/// ID: `3d662b7b`.
class PrivacyKeyPhoneCall extends PrivacyKeyBase {
  /// Privacy Key Phone Call constructor.
  const PrivacyKeyPhoneCall() : super._();

  /// Deserialize.
  factory PrivacyKeyPhoneCall.deserialize(BinaryReader reader) {
    // Construct [PrivacyKeyPhoneCall] object.
    final returnValue = PrivacyKeyPhoneCall();

    // Now return the deserialized [PrivacyKeyPhoneCall].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3d662b7b.
    buffer.writeInt32(0x3d662b7b);

    // Finished serialization.
  }
}

/// Privacy Key Phone P2 P.
///
/// ID: `39491cc8`.
class PrivacyKeyPhoneP2P extends PrivacyKeyBase {
  /// Privacy Key Phone P2 P constructor.
  const PrivacyKeyPhoneP2P() : super._();

  /// Deserialize.
  factory PrivacyKeyPhoneP2P.deserialize(BinaryReader reader) {
    // Construct [PrivacyKeyPhoneP2P] object.
    final returnValue = PrivacyKeyPhoneP2P();

    // Now return the deserialized [PrivacyKeyPhoneP2P].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x39491cc8.
    buffer.writeInt32(0x39491cc8);

    // Finished serialization.
  }
}

/// Privacy Key Forwards.
///
/// ID: `69ec56a3`.
class PrivacyKeyForwards extends PrivacyKeyBase {
  /// Privacy Key Forwards constructor.
  const PrivacyKeyForwards() : super._();

  /// Deserialize.
  factory PrivacyKeyForwards.deserialize(BinaryReader reader) {
    // Construct [PrivacyKeyForwards] object.
    final returnValue = PrivacyKeyForwards();

    // Now return the deserialized [PrivacyKeyForwards].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x69ec56a3.
    buffer.writeInt32(0x69ec56a3);

    // Finished serialization.
  }
}

/// Privacy Key Profile Photo.
///
/// ID: `96151fed`.
class PrivacyKeyProfilePhoto extends PrivacyKeyBase {
  /// Privacy Key Profile Photo constructor.
  const PrivacyKeyProfilePhoto() : super._();

  /// Deserialize.
  factory PrivacyKeyProfilePhoto.deserialize(BinaryReader reader) {
    // Construct [PrivacyKeyProfilePhoto] object.
    final returnValue = PrivacyKeyProfilePhoto();

    // Now return the deserialized [PrivacyKeyProfilePhoto].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x96151fed.
    buffer.writeInt32(0x96151fed);

    // Finished serialization.
  }
}

/// Privacy Key Phone Number.
///
/// ID: `d19ae46d`.
class PrivacyKeyPhoneNumber extends PrivacyKeyBase {
  /// Privacy Key Phone Number constructor.
  const PrivacyKeyPhoneNumber() : super._();

  /// Deserialize.
  factory PrivacyKeyPhoneNumber.deserialize(BinaryReader reader) {
    // Construct [PrivacyKeyPhoneNumber] object.
    final returnValue = PrivacyKeyPhoneNumber();

    // Now return the deserialized [PrivacyKeyPhoneNumber].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd19ae46d.
    buffer.writeInt32(0xd19ae46d);

    // Finished serialization.
  }
}

/// Privacy Key Added By Phone.
///
/// ID: `42ffd42b`.
class PrivacyKeyAddedByPhone extends PrivacyKeyBase {
  /// Privacy Key Added By Phone constructor.
  const PrivacyKeyAddedByPhone() : super._();

  /// Deserialize.
  factory PrivacyKeyAddedByPhone.deserialize(BinaryReader reader) {
    // Construct [PrivacyKeyAddedByPhone] object.
    final returnValue = PrivacyKeyAddedByPhone();

    // Now return the deserialized [PrivacyKeyAddedByPhone].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x42ffd42b.
    buffer.writeInt32(0x42ffd42b);

    // Finished serialization.
  }
}

/// Privacy Key Voice Messages.
///
/// ID: `0697f414`.
class PrivacyKeyVoiceMessages extends PrivacyKeyBase {
  /// Privacy Key Voice Messages constructor.
  const PrivacyKeyVoiceMessages() : super._();

  /// Deserialize.
  factory PrivacyKeyVoiceMessages.deserialize(BinaryReader reader) {
    // Construct [PrivacyKeyVoiceMessages] object.
    final returnValue = PrivacyKeyVoiceMessages();

    // Now return the deserialized [PrivacyKeyVoiceMessages].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0697f414.
    buffer.writeInt32(0x0697f414);

    // Finished serialization.
  }
}

/// Privacy Key About.
///
/// ID: `a486b761`.
class PrivacyKeyAbout extends PrivacyKeyBase {
  /// Privacy Key About constructor.
  const PrivacyKeyAbout() : super._();

  /// Deserialize.
  factory PrivacyKeyAbout.deserialize(BinaryReader reader) {
    // Construct [PrivacyKeyAbout] object.
    final returnValue = PrivacyKeyAbout();

    // Now return the deserialized [PrivacyKeyAbout].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa486b761.
    buffer.writeInt32(0xa486b761);

    // Finished serialization.
  }
}

/// Input Privacy Value Allow Contacts.
///
/// ID: `0d09e07b`.
class InputPrivacyValueAllowContacts extends InputPrivacyRuleBase {
  /// Input Privacy Value Allow Contacts constructor.
  const InputPrivacyValueAllowContacts() : super._();

  /// Deserialize.
  factory InputPrivacyValueAllowContacts.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyValueAllowContacts] object.
    final returnValue = InputPrivacyValueAllowContacts();

    // Now return the deserialized [InputPrivacyValueAllowContacts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0d09e07b.
    buffer.writeInt32(0x0d09e07b);

    // Finished serialization.
  }
}

/// Input Privacy Value Allow All.
///
/// ID: `184b35ce`.
class InputPrivacyValueAllowAll extends InputPrivacyRuleBase {
  /// Input Privacy Value Allow All constructor.
  const InputPrivacyValueAllowAll() : super._();

  /// Deserialize.
  factory InputPrivacyValueAllowAll.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyValueAllowAll] object.
    final returnValue = InputPrivacyValueAllowAll();

    // Now return the deserialized [InputPrivacyValueAllowAll].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x184b35ce.
    buffer.writeInt32(0x184b35ce);

    // Finished serialization.
  }
}

/// Input Privacy Value Allow Users.
///
/// ID: `131cc67f`.
class InputPrivacyValueAllowUsers extends InputPrivacyRuleBase {
  /// Input Privacy Value Allow Users constructor.
  const InputPrivacyValueAllowUsers({
    required this.users,
  }) : super._();

  /// Deserialize.
  factory InputPrivacyValueAllowUsers.deserialize(BinaryReader reader) {
    // Read [InputPrivacyValueAllowUsers] fields.
    final users = reader.readVectorObject<InputUserBase>();

    // Construct [InputPrivacyValueAllowUsers] object.
    final returnValue = InputPrivacyValueAllowUsers(
      users: users,
    );

    // Now return the deserialized [InputPrivacyValueAllowUsers].
    return returnValue;
  }

  /// Users.
  final List<InputUserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x131cc67f.
    buffer.writeInt32(0x131cc67f);

    // Write fields.
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Input Privacy Value Disallow Contacts.
///
/// ID: `0ba52007`.
class InputPrivacyValueDisallowContacts extends InputPrivacyRuleBase {
  /// Input Privacy Value Disallow Contacts constructor.
  const InputPrivacyValueDisallowContacts() : super._();

  /// Deserialize.
  factory InputPrivacyValueDisallowContacts.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyValueDisallowContacts] object.
    final returnValue = InputPrivacyValueDisallowContacts();

    // Now return the deserialized [InputPrivacyValueDisallowContacts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0ba52007.
    buffer.writeInt32(0x0ba52007);

    // Finished serialization.
  }
}

/// Input Privacy Value Disallow All.
///
/// ID: `d66b66c9`.
class InputPrivacyValueDisallowAll extends InputPrivacyRuleBase {
  /// Input Privacy Value Disallow All constructor.
  const InputPrivacyValueDisallowAll() : super._();

  /// Deserialize.
  factory InputPrivacyValueDisallowAll.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyValueDisallowAll] object.
    final returnValue = InputPrivacyValueDisallowAll();

    // Now return the deserialized [InputPrivacyValueDisallowAll].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd66b66c9.
    buffer.writeInt32(0xd66b66c9);

    // Finished serialization.
  }
}

/// Input Privacy Value Disallow Users.
///
/// ID: `90110467`.
class InputPrivacyValueDisallowUsers extends InputPrivacyRuleBase {
  /// Input Privacy Value Disallow Users constructor.
  const InputPrivacyValueDisallowUsers({
    required this.users,
  }) : super._();

  /// Deserialize.
  factory InputPrivacyValueDisallowUsers.deserialize(BinaryReader reader) {
    // Read [InputPrivacyValueDisallowUsers] fields.
    final users = reader.readVectorObject<InputUserBase>();

    // Construct [InputPrivacyValueDisallowUsers] object.
    final returnValue = InputPrivacyValueDisallowUsers(
      users: users,
    );

    // Now return the deserialized [InputPrivacyValueDisallowUsers].
    return returnValue;
  }

  /// Users.
  final List<InputUserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x90110467.
    buffer.writeInt32(0x90110467);

    // Write fields.
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Input Privacy Value Allow Chat Participants.
///
/// ID: `840649cf`.
class InputPrivacyValueAllowChatParticipants extends InputPrivacyRuleBase {
  /// Input Privacy Value Allow Chat Participants constructor.
  const InputPrivacyValueAllowChatParticipants({
    required this.chats,
  }) : super._();

  /// Deserialize.
  factory InputPrivacyValueAllowChatParticipants.deserialize(
      BinaryReader reader) {
    // Read [InputPrivacyValueAllowChatParticipants] fields.
    final chats = reader.readVectorInt64();

    // Construct [InputPrivacyValueAllowChatParticipants] object.
    final returnValue = InputPrivacyValueAllowChatParticipants(
      chats: chats,
    );

    // Now return the deserialized [InputPrivacyValueAllowChatParticipants].
    return returnValue;
  }

  /// Chats.
  final List<int> chats;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x840649cf.
    buffer.writeInt32(0x840649cf);

    // Write fields.
    buffer.writeVectorInt64(chats);

    // Finished serialization.
  }
}

/// Input Privacy Value Disallow Chat Participants.
///
/// ID: `e94f0f86`.
class InputPrivacyValueDisallowChatParticipants extends InputPrivacyRuleBase {
  /// Input Privacy Value Disallow Chat Participants constructor.
  const InputPrivacyValueDisallowChatParticipants({
    required this.chats,
  }) : super._();

  /// Deserialize.
  factory InputPrivacyValueDisallowChatParticipants.deserialize(
      BinaryReader reader) {
    // Read [InputPrivacyValueDisallowChatParticipants] fields.
    final chats = reader.readVectorInt64();

    // Construct [InputPrivacyValueDisallowChatParticipants] object.
    final returnValue = InputPrivacyValueDisallowChatParticipants(
      chats: chats,
    );

    // Now return the deserialized [InputPrivacyValueDisallowChatParticipants].
    return returnValue;
  }

  /// Chats.
  final List<int> chats;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe94f0f86.
    buffer.writeInt32(0xe94f0f86);

    // Write fields.
    buffer.writeVectorInt64(chats);

    // Finished serialization.
  }
}

/// Input Privacy Value Allow Close Friends.
///
/// ID: `2f453e49`.
class InputPrivacyValueAllowCloseFriends extends InputPrivacyRuleBase {
  /// Input Privacy Value Allow Close Friends constructor.
  const InputPrivacyValueAllowCloseFriends() : super._();

  /// Deserialize.
  factory InputPrivacyValueAllowCloseFriends.deserialize(BinaryReader reader) {
    // Construct [InputPrivacyValueAllowCloseFriends] object.
    final returnValue = InputPrivacyValueAllowCloseFriends();

    // Now return the deserialized [InputPrivacyValueAllowCloseFriends].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2f453e49.
    buffer.writeInt32(0x2f453e49);

    // Finished serialization.
  }
}

/// Privacy Value Allow Contacts.
///
/// ID: `fffe1bac`.
class PrivacyValueAllowContacts extends PrivacyRuleBase {
  /// Privacy Value Allow Contacts constructor.
  const PrivacyValueAllowContacts() : super._();

  /// Deserialize.
  factory PrivacyValueAllowContacts.deserialize(BinaryReader reader) {
    // Construct [PrivacyValueAllowContacts] object.
    final returnValue = PrivacyValueAllowContacts();

    // Now return the deserialized [PrivacyValueAllowContacts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfffe1bac.
    buffer.writeInt32(0xfffe1bac);

    // Finished serialization.
  }
}

/// Privacy Value Allow All.
///
/// ID: `65427b82`.
class PrivacyValueAllowAll extends PrivacyRuleBase {
  /// Privacy Value Allow All constructor.
  const PrivacyValueAllowAll() : super._();

  /// Deserialize.
  factory PrivacyValueAllowAll.deserialize(BinaryReader reader) {
    // Construct [PrivacyValueAllowAll] object.
    final returnValue = PrivacyValueAllowAll();

    // Now return the deserialized [PrivacyValueAllowAll].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x65427b82.
    buffer.writeInt32(0x65427b82);

    // Finished serialization.
  }
}

/// Privacy Value Allow Users.
///
/// ID: `b8905fb2`.
class PrivacyValueAllowUsers extends PrivacyRuleBase {
  /// Privacy Value Allow Users constructor.
  const PrivacyValueAllowUsers({
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PrivacyValueAllowUsers.deserialize(BinaryReader reader) {
    // Read [PrivacyValueAllowUsers] fields.
    final users = reader.readVectorInt64();

    // Construct [PrivacyValueAllowUsers] object.
    final returnValue = PrivacyValueAllowUsers(
      users: users,
    );

    // Now return the deserialized [PrivacyValueAllowUsers].
    return returnValue;
  }

  /// Users.
  final List<int> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb8905fb2.
    buffer.writeInt32(0xb8905fb2);

    // Write fields.
    buffer.writeVectorInt64(users);

    // Finished serialization.
  }
}

/// Privacy Value Disallow Contacts.
///
/// ID: `f888fa1a`.
class PrivacyValueDisallowContacts extends PrivacyRuleBase {
  /// Privacy Value Disallow Contacts constructor.
  const PrivacyValueDisallowContacts() : super._();

  /// Deserialize.
  factory PrivacyValueDisallowContacts.deserialize(BinaryReader reader) {
    // Construct [PrivacyValueDisallowContacts] object.
    final returnValue = PrivacyValueDisallowContacts();

    // Now return the deserialized [PrivacyValueDisallowContacts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf888fa1a.
    buffer.writeInt32(0xf888fa1a);

    // Finished serialization.
  }
}

/// Privacy Value Disallow All.
///
/// ID: `8b73e763`.
class PrivacyValueDisallowAll extends PrivacyRuleBase {
  /// Privacy Value Disallow All constructor.
  const PrivacyValueDisallowAll() : super._();

  /// Deserialize.
  factory PrivacyValueDisallowAll.deserialize(BinaryReader reader) {
    // Construct [PrivacyValueDisallowAll] object.
    final returnValue = PrivacyValueDisallowAll();

    // Now return the deserialized [PrivacyValueDisallowAll].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8b73e763.
    buffer.writeInt32(0x8b73e763);

    // Finished serialization.
  }
}

/// Privacy Value Disallow Users.
///
/// ID: `e4621141`.
class PrivacyValueDisallowUsers extends PrivacyRuleBase {
  /// Privacy Value Disallow Users constructor.
  const PrivacyValueDisallowUsers({
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PrivacyValueDisallowUsers.deserialize(BinaryReader reader) {
    // Read [PrivacyValueDisallowUsers] fields.
    final users = reader.readVectorInt64();

    // Construct [PrivacyValueDisallowUsers] object.
    final returnValue = PrivacyValueDisallowUsers(
      users: users,
    );

    // Now return the deserialized [PrivacyValueDisallowUsers].
    return returnValue;
  }

  /// Users.
  final List<int> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe4621141.
    buffer.writeInt32(0xe4621141);

    // Write fields.
    buffer.writeVectorInt64(users);

    // Finished serialization.
  }
}

/// Privacy Value Allow Chat Participants.
///
/// ID: `6b134e8e`.
class PrivacyValueAllowChatParticipants extends PrivacyRuleBase {
  /// Privacy Value Allow Chat Participants constructor.
  const PrivacyValueAllowChatParticipants({
    required this.chats,
  }) : super._();

  /// Deserialize.
  factory PrivacyValueAllowChatParticipants.deserialize(BinaryReader reader) {
    // Read [PrivacyValueAllowChatParticipants] fields.
    final chats = reader.readVectorInt64();

    // Construct [PrivacyValueAllowChatParticipants] object.
    final returnValue = PrivacyValueAllowChatParticipants(
      chats: chats,
    );

    // Now return the deserialized [PrivacyValueAllowChatParticipants].
    return returnValue;
  }

  /// Chats.
  final List<int> chats;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6b134e8e.
    buffer.writeInt32(0x6b134e8e);

    // Write fields.
    buffer.writeVectorInt64(chats);

    // Finished serialization.
  }
}

/// Privacy Value Disallow Chat Participants.
///
/// ID: `41c87565`.
class PrivacyValueDisallowChatParticipants extends PrivacyRuleBase {
  /// Privacy Value Disallow Chat Participants constructor.
  const PrivacyValueDisallowChatParticipants({
    required this.chats,
  }) : super._();

  /// Deserialize.
  factory PrivacyValueDisallowChatParticipants.deserialize(
      BinaryReader reader) {
    // Read [PrivacyValueDisallowChatParticipants] fields.
    final chats = reader.readVectorInt64();

    // Construct [PrivacyValueDisallowChatParticipants] object.
    final returnValue = PrivacyValueDisallowChatParticipants(
      chats: chats,
    );

    // Now return the deserialized [PrivacyValueDisallowChatParticipants].
    return returnValue;
  }

  /// Chats.
  final List<int> chats;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x41c87565.
    buffer.writeInt32(0x41c87565);

    // Write fields.
    buffer.writeVectorInt64(chats);

    // Finished serialization.
  }
}

/// Privacy Value Allow Close Friends.
///
/// ID: `f7e8d89b`.
class PrivacyValueAllowCloseFriends extends PrivacyRuleBase {
  /// Privacy Value Allow Close Friends constructor.
  const PrivacyValueAllowCloseFriends() : super._();

  /// Deserialize.
  factory PrivacyValueAllowCloseFriends.deserialize(BinaryReader reader) {
    // Construct [PrivacyValueAllowCloseFriends] object.
    final returnValue = PrivacyValueAllowCloseFriends();

    // Now return the deserialized [PrivacyValueAllowCloseFriends].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf7e8d89b.
    buffer.writeInt32(0xf7e8d89b);

    // Finished serialization.
  }
}

/// Account Privacy Rules.
///
/// ID: `50a04e45`.
class AccountPrivacyRules extends AccountPrivacyRulesBase {
  /// Account Privacy Rules constructor.
  const AccountPrivacyRules({
    required this.rules,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory AccountPrivacyRules.deserialize(BinaryReader reader) {
    // Read [AccountPrivacyRules] fields.
    final rules = reader.readVectorObject<PrivacyRuleBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [AccountPrivacyRules] object.
    final returnValue = AccountPrivacyRules(
      rules: rules,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [AccountPrivacyRules].
    return returnValue;
  }

  /// Rules.
  final List<PrivacyRuleBase> rules;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x50a04e45.
    buffer.writeInt32(0x50a04e45);

    // Write fields.
    buffer.writeVectorObject(rules);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Account Days T T L.
///
/// ID: `b8d0afdf`.
class AccountDaysTTL extends AccountDaysTTLBase {
  /// Account Days T T L constructor.
  const AccountDaysTTL({
    required this.days,
  }) : super._();

  /// Deserialize.
  factory AccountDaysTTL.deserialize(BinaryReader reader) {
    // Read [AccountDaysTTL] fields.
    final days = reader.readInt32();

    // Construct [AccountDaysTTL] object.
    final returnValue = AccountDaysTTL(
      days: days,
    );

    // Now return the deserialized [AccountDaysTTL].
    return returnValue;
  }

  /// Days.
  ///
  /// Field type is Int32.
  final int days;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb8d0afdf.
    buffer.writeInt32(0xb8d0afdf);

    // Write fields.
    buffer.writeInt32(days);

    // Finished serialization.
  }
}

/// Document Attribute Image Size.
///
/// ID: `6c37c15c`.
class DocumentAttributeImageSize extends DocumentAttributeBase {
  /// Document Attribute Image Size constructor.
  const DocumentAttributeImageSize({
    required this.w,
    required this.h,
  }) : super._();

  /// Deserialize.
  factory DocumentAttributeImageSize.deserialize(BinaryReader reader) {
    // Read [DocumentAttributeImageSize] fields.
    final w = reader.readInt32();
    final h = reader.readInt32();

    // Construct [DocumentAttributeImageSize] object.
    final returnValue = DocumentAttributeImageSize(
      w: w,
      h: h,
    );

    // Now return the deserialized [DocumentAttributeImageSize].
    return returnValue;
  }

  /// W.
  ///
  /// Field type is Int32.
  final int w;

  /// H.
  ///
  /// Field type is Int32.
  final int h;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6c37c15c.
    buffer.writeInt32(0x6c37c15c);

    // Write fields.
    buffer.writeInt32(w);
    buffer.writeInt32(h);

    // Finished serialization.
  }
}

/// Document Attribute Animated.
///
/// ID: `11b58939`.
class DocumentAttributeAnimated extends DocumentAttributeBase {
  /// Document Attribute Animated constructor.
  const DocumentAttributeAnimated() : super._();

  /// Deserialize.
  factory DocumentAttributeAnimated.deserialize(BinaryReader reader) {
    // Construct [DocumentAttributeAnimated] object.
    final returnValue = DocumentAttributeAnimated();

    // Now return the deserialized [DocumentAttributeAnimated].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x11b58939.
    buffer.writeInt32(0x11b58939);

    // Finished serialization.
  }
}

/// Document Attribute Sticker.
///
/// ID: `6319d612`.
class DocumentAttributeSticker extends DocumentAttributeBase {
  /// Document Attribute Sticker constructor.
  const DocumentAttributeSticker({
    required this.mask,
    required this.alt,
    required this.stickerset,
    this.maskCoords,
  }) : super._();

  /// Deserialize.
  factory DocumentAttributeSticker.deserialize(BinaryReader reader) {
    // Read [DocumentAttributeSticker] fields.
    final flags = reader.readInt32();
    final mask = (flags & 2) != 0;
    final alt = reader.readString();
    final stickerset = reader.readObject() as InputStickerSetBase;
    final hasMaskCoordsField = (flags & 1) != 0;
    final maskCoords =
        hasMaskCoordsField ? reader.readObject() as MaskCoordsBase : null;

    // Construct [DocumentAttributeSticker] object.
    final returnValue = DocumentAttributeSticker(
      mask: mask,
      alt: alt,
      stickerset: stickerset,
      maskCoords: maskCoords,
    );

    // Now return the deserialized [DocumentAttributeSticker].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: mask,
      b00: maskCoords != null,
    );

    return v;
  }

  /// mask: bit 1 of flags.1?true
  final bool mask;

  /// Alt.
  final String alt;

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Mask Coords.
  final MaskCoordsBase? maskCoords;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6319d612.
    buffer.writeInt32(0x6319d612);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(alt);
    buffer.writeObject(stickerset);
    final localMaskCoordsCopy = maskCoords;
    if (localMaskCoordsCopy != null) {
      buffer.writeObject(localMaskCoordsCopy);
    }

    // Finished serialization.
  }
}

/// Document Attribute Video.
///
/// ID: `d38ff1c2`.
class DocumentAttributeVideo extends DocumentAttributeBase {
  /// Document Attribute Video constructor.
  const DocumentAttributeVideo({
    required this.roundMessage,
    required this.supportsStreaming,
    required this.nosound,
    required this.duration,
    required this.w,
    required this.h,
    this.preloadPrefixSize,
  }) : super._();

  /// Deserialize.
  factory DocumentAttributeVideo.deserialize(BinaryReader reader) {
    // Read [DocumentAttributeVideo] fields.
    final flags = reader.readInt32();
    final roundMessage = (flags & 1) != 0;
    final supportsStreaming = (flags & 2) != 0;
    final nosound = (flags & 8) != 0;
    final duration = reader.readFloat64();
    final w = reader.readInt32();
    final h = reader.readInt32();
    final hasPreloadPrefixSizeField = (flags & 4) != 0;
    final preloadPrefixSize =
        hasPreloadPrefixSizeField ? reader.readInt32() : null;

    // Construct [DocumentAttributeVideo] object.
    final returnValue = DocumentAttributeVideo(
      roundMessage: roundMessage,
      supportsStreaming: supportsStreaming,
      nosound: nosound,
      duration: duration,
      w: w,
      h: h,
      preloadPrefixSize: preloadPrefixSize,
    );

    // Now return the deserialized [DocumentAttributeVideo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: roundMessage,
      b01: supportsStreaming,
      b03: nosound,
      b02: preloadPrefixSize != null,
    );

    return v;
  }

  /// round_message: bit 0 of flags.0?true
  final bool roundMessage;

  /// supports_streaming: bit 1 of flags.1?true
  final bool supportsStreaming;

  /// nosound: bit 3 of flags.3?true
  final bool nosound;

  /// Duration.
  final double duration;

  /// W.
  ///
  /// Field type is Int32.
  final int w;

  /// H.
  ///
  /// Field type is Int32.
  final int h;

  /// Preload Prefix Size.
  final int? preloadPrefixSize;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd38ff1c2.
    buffer.writeInt32(0xd38ff1c2);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeDouble(duration);
    buffer.writeInt32(w);
    buffer.writeInt32(h);
    final localPreloadPrefixSizeCopy = preloadPrefixSize;
    if (localPreloadPrefixSizeCopy != null) {
      buffer.writeInt32(localPreloadPrefixSizeCopy);
    }

    // Finished serialization.
  }
}

/// Document Attribute Audio.
///
/// ID: `9852f9c6`.
class DocumentAttributeAudio extends DocumentAttributeBase {
  /// Document Attribute Audio constructor.
  const DocumentAttributeAudio({
    required this.voice,
    required this.duration,
    this.title,
    this.performer,
    this.waveform,
  }) : super._();

  /// Deserialize.
  factory DocumentAttributeAudio.deserialize(BinaryReader reader) {
    // Read [DocumentAttributeAudio] fields.
    final flags = reader.readInt32();
    final voice = (flags & 1024) != 0;
    final duration = reader.readInt32();
    final hasTitleField = (flags & 1) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasPerformerField = (flags & 2) != 0;
    final performer = hasPerformerField ? reader.readString() : null;
    final hasWaveformField = (flags & 4) != 0;
    final waveform = hasWaveformField ? reader.readBytes() : null;

    // Construct [DocumentAttributeAudio] object.
    final returnValue = DocumentAttributeAudio(
      voice: voice,
      duration: duration,
      title: title,
      performer: performer,
      waveform: waveform,
    );

    // Now return the deserialized [DocumentAttributeAudio].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b10: voice,
      b00: title != null,
      b01: performer != null,
      b02: waveform != null,
    );

    return v;
  }

  /// voice: bit 10 of flags.10?true
  final bool voice;

  /// Duration.
  ///
  /// Field type is Int32.
  final int duration;

  /// Title.
  final String? title;

  /// Performer.
  final String? performer;

  /// Waveform.
  final Uint8List? waveform;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9852f9c6.
    buffer.writeInt32(0x9852f9c6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(duration);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localPerformerCopy = performer;
    if (localPerformerCopy != null) {
      buffer.writeString(localPerformerCopy);
    }
    final localWaveformCopy = waveform;
    if (localWaveformCopy != null) {
      buffer.writeBytes(localWaveformCopy);
    }

    // Finished serialization.
  }
}

/// Document Attribute Filename.
///
/// ID: `15590068`.
class DocumentAttributeFilename extends DocumentAttributeBase {
  /// Document Attribute Filename constructor.
  const DocumentAttributeFilename({
    required this.fileName,
  }) : super._();

  /// Deserialize.
  factory DocumentAttributeFilename.deserialize(BinaryReader reader) {
    // Read [DocumentAttributeFilename] fields.
    final fileName = reader.readString();

    // Construct [DocumentAttributeFilename] object.
    final returnValue = DocumentAttributeFilename(
      fileName: fileName,
    );

    // Now return the deserialized [DocumentAttributeFilename].
    return returnValue;
  }

  /// File Name.
  final String fileName;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x15590068.
    buffer.writeInt32(0x15590068);

    // Write fields.
    buffer.writeString(fileName);

    // Finished serialization.
  }
}

/// Document Attribute Has Stickers.
///
/// ID: `9801d2f7`.
class DocumentAttributeHasStickers extends DocumentAttributeBase {
  /// Document Attribute Has Stickers constructor.
  const DocumentAttributeHasStickers() : super._();

  /// Deserialize.
  factory DocumentAttributeHasStickers.deserialize(BinaryReader reader) {
    // Construct [DocumentAttributeHasStickers] object.
    final returnValue = DocumentAttributeHasStickers();

    // Now return the deserialized [DocumentAttributeHasStickers].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9801d2f7.
    buffer.writeInt32(0x9801d2f7);

    // Finished serialization.
  }
}

/// Document Attribute Custom Emoji.
///
/// ID: `fd149899`.
class DocumentAttributeCustomEmoji extends DocumentAttributeBase {
  /// Document Attribute Custom Emoji constructor.
  const DocumentAttributeCustomEmoji({
    required this.free,
    required this.textColor,
    required this.alt,
    required this.stickerset,
  }) : super._();

  /// Deserialize.
  factory DocumentAttributeCustomEmoji.deserialize(BinaryReader reader) {
    // Read [DocumentAttributeCustomEmoji] fields.
    final flags = reader.readInt32();
    final free = (flags & 1) != 0;
    final textColor = (flags & 2) != 0;
    final alt = reader.readString();
    final stickerset = reader.readObject() as InputStickerSetBase;

    // Construct [DocumentAttributeCustomEmoji] object.
    final returnValue = DocumentAttributeCustomEmoji(
      free: free,
      textColor: textColor,
      alt: alt,
      stickerset: stickerset,
    );

    // Now return the deserialized [DocumentAttributeCustomEmoji].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: free,
      b01: textColor,
    );

    return v;
  }

  /// free: bit 0 of flags.0?true
  final bool free;

  /// text_color: bit 1 of flags.1?true
  final bool textColor;

  /// Alt.
  final String alt;

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfd149899.
    buffer.writeInt32(0xfd149899);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(alt);
    buffer.writeObject(stickerset);

    // Finished serialization.
  }
}

/// Messages Stickers Not Modified.
///
/// ID: `f1749a22`.
class MessagesStickersNotModified extends MessagesStickersBase {
  /// Messages Stickers Not Modified constructor.
  const MessagesStickersNotModified() : super._();

  /// Deserialize.
  factory MessagesStickersNotModified.deserialize(BinaryReader reader) {
    // Construct [MessagesStickersNotModified] object.
    final returnValue = MessagesStickersNotModified();

    // Now return the deserialized [MessagesStickersNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf1749a22.
    buffer.writeInt32(0xf1749a22);

    // Finished serialization.
  }
}

/// Messages Stickers.
///
/// ID: `30a6ec7e`.
class MessagesStickers extends MessagesStickersBase {
  /// Messages Stickers constructor.
  const MessagesStickers({
    required this.hash,
    required this.stickers,
  }) : super._();

  /// Deserialize.
  factory MessagesStickers.deserialize(BinaryReader reader) {
    // Read [MessagesStickers] fields.
    final hash = reader.readInt64();
    final stickers = reader.readVectorObject<DocumentBase>();

    // Construct [MessagesStickers] object.
    final returnValue = MessagesStickers(
      hash: hash,
      stickers: stickers,
    );

    // Now return the deserialized [MessagesStickers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Stickers.
  final List<DocumentBase> stickers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x30a6ec7e.
    buffer.writeInt32(0x30a6ec7e);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(stickers);

    // Finished serialization.
  }
}

/// Sticker Pack.
///
/// ID: `12b299d4`.
class StickerPack extends StickerPackBase {
  /// Sticker Pack constructor.
  const StickerPack({
    required this.emoticon,
    required this.documents,
  }) : super._();

  /// Deserialize.
  factory StickerPack.deserialize(BinaryReader reader) {
    // Read [StickerPack] fields.
    final emoticon = reader.readString();
    final documents = reader.readVectorInt64();

    // Construct [StickerPack] object.
    final returnValue = StickerPack(
      emoticon: emoticon,
      documents: documents,
    );

    // Now return the deserialized [StickerPack].
    return returnValue;
  }

  /// Emoticon.
  final String emoticon;

  /// Documents.
  final List<int> documents;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x12b299d4.
    buffer.writeInt32(0x12b299d4);

    // Write fields.
    buffer.writeString(emoticon);
    buffer.writeVectorInt64(documents);

    // Finished serialization.
  }
}

/// Messages All Stickers Not Modified.
///
/// ID: `e86602c3`.
class MessagesAllStickersNotModified extends MessagesAllStickersBase {
  /// Messages All Stickers Not Modified constructor.
  const MessagesAllStickersNotModified() : super._();

  /// Deserialize.
  factory MessagesAllStickersNotModified.deserialize(BinaryReader reader) {
    // Construct [MessagesAllStickersNotModified] object.
    final returnValue = MessagesAllStickersNotModified();

    // Now return the deserialized [MessagesAllStickersNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe86602c3.
    buffer.writeInt32(0xe86602c3);

    // Finished serialization.
  }
}

/// Messages All Stickers.
///
/// ID: `cdbbcebb`.
class MessagesAllStickers extends MessagesAllStickersBase {
  /// Messages All Stickers constructor.
  const MessagesAllStickers({
    required this.hash,
    required this.sets,
  }) : super._();

  /// Deserialize.
  factory MessagesAllStickers.deserialize(BinaryReader reader) {
    // Read [MessagesAllStickers] fields.
    final hash = reader.readInt64();
    final sets = reader.readVectorObject<StickerSetBase>();

    // Construct [MessagesAllStickers] object.
    final returnValue = MessagesAllStickers(
      hash: hash,
      sets: sets,
    );

    // Now return the deserialized [MessagesAllStickers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Sets.
  final List<StickerSetBase> sets;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcdbbcebb.
    buffer.writeInt32(0xcdbbcebb);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(sets);

    // Finished serialization.
  }
}

/// Messages Affected Messages.
///
/// ID: `84d19185`.
class MessagesAffectedMessages extends MessagesAffectedMessagesBase {
  /// Messages Affected Messages constructor.
  const MessagesAffectedMessages({
    required this.pts,
    required this.ptsCount,
  }) : super._();

  /// Deserialize.
  factory MessagesAffectedMessages.deserialize(BinaryReader reader) {
    // Read [MessagesAffectedMessages] fields.
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();

    // Construct [MessagesAffectedMessages] object.
    final returnValue = MessagesAffectedMessages(
      pts: pts,
      ptsCount: ptsCount,
    );

    // Now return the deserialized [MessagesAffectedMessages].
    return returnValue;
  }

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x84d19185.
    buffer.writeInt32(0x84d19185);

    // Write fields.
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);

    // Finished serialization.
  }
}

/// Web Page Empty.
///
/// ID: `211a1788`.
class WebPageEmpty extends WebPageBase {
  /// Web Page Empty constructor.
  const WebPageEmpty({
    required this.id,
    this.url,
  }) : super._();

  /// Deserialize.
  factory WebPageEmpty.deserialize(BinaryReader reader) {
    // Read [WebPageEmpty] fields.
    final flags = reader.readInt32();
    final id = reader.readInt64();
    final hasUrlField = (flags & 1) != 0;
    final url = hasUrlField ? reader.readString() : null;

    // Construct [WebPageEmpty] object.
    final returnValue = WebPageEmpty(
      id: id,
      url: url,
    );

    // Now return the deserialized [WebPageEmpty].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: url != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Url.
  final String? url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x211a1788.
    buffer.writeInt32(0x211a1788);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }

    // Finished serialization.
  }
}

/// Web Page Pending.
///
/// ID: `b0d13e47`.
class WebPagePending extends WebPageBase {
  /// Web Page Pending constructor.
  const WebPagePending({
    required this.id,
    this.url,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory WebPagePending.deserialize(BinaryReader reader) {
    // Read [WebPagePending] fields.
    final flags = reader.readInt32();
    final id = reader.readInt64();
    final hasUrlField = (flags & 1) != 0;
    final url = hasUrlField ? reader.readString() : null;
    final date = reader.readDateTime();

    // Construct [WebPagePending] object.
    final returnValue = WebPagePending(
      id: id,
      url: url,
      date: date,
    );

    // Now return the deserialized [WebPagePending].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: url != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Url.
  final String? url;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb0d13e47.
    buffer.writeInt32(0xb0d13e47);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Web Page.
///
/// ID: `e89c45b2`.
class WebPage extends WebPageBase {
  /// Web Page constructor.
  const WebPage({
    required this.hasLargeMedia,
    required this.id,
    required this.url,
    required this.displayUrl,
    required this.hash,
    this.type,
    this.siteName,
    this.title,
    this.description,
    this.photo,
    this.embedUrl,
    this.embedType,
    this.embedWidth,
    this.embedHeight,
    this.duration,
    this.author,
    this.document,
    this.cachedPage,
    this.attributes,
  }) : super._();

  /// Deserialize.
  factory WebPage.deserialize(BinaryReader reader) {
    // Read [WebPage] fields.
    final flags = reader.readInt32();
    final hasLargeMedia = (flags & 8192) != 0;
    final id = reader.readInt64();
    final url = reader.readString();
    final displayUrl = reader.readString();
    final hash = reader.readInt32();
    final hasTypeField = (flags & 1) != 0;
    final type = hasTypeField ? reader.readString() : null;
    final hasSiteNameField = (flags & 2) != 0;
    final siteName = hasSiteNameField ? reader.readString() : null;
    final hasTitleField = (flags & 4) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasDescriptionField = (flags & 8) != 0;
    final description = hasDescriptionField ? reader.readString() : null;
    final hasPhotoField = (flags & 16) != 0;
    final photo = hasPhotoField ? reader.readObject() as PhotoBase : null;
    final hasEmbedUrlField = (flags & 32) != 0;
    final embedUrl = hasEmbedUrlField ? reader.readString() : null;
    final hasEmbedTypeField = (flags & 32) != 0;
    final embedType = hasEmbedTypeField ? reader.readString() : null;
    final hasEmbedWidthField = (flags & 64) != 0;
    final embedWidth = hasEmbedWidthField ? reader.readInt32() : null;
    final hasEmbedHeightField = (flags & 64) != 0;
    final embedHeight = hasEmbedHeightField ? reader.readInt32() : null;
    final hasDurationField = (flags & 128) != 0;
    final duration = hasDurationField ? reader.readInt32() : null;
    final hasAuthorField = (flags & 256) != 0;
    final author = hasAuthorField ? reader.readString() : null;
    final hasDocumentField = (flags & 512) != 0;
    final document =
        hasDocumentField ? reader.readObject() as DocumentBase : null;
    final hasCachedPageField = (flags & 1024) != 0;
    final cachedPage =
        hasCachedPageField ? reader.readObject() as PageBase : null;
    final hasAttributesField = (flags & 4096) != 0;
    final attributes = hasAttributesField
        ? reader.readVectorObject<WebPageAttributeBase>()
        : null;

    // Construct [WebPage] object.
    final returnValue = WebPage(
      hasLargeMedia: hasLargeMedia,
      id: id,
      url: url,
      displayUrl: displayUrl,
      hash: hash,
      type: type,
      siteName: siteName,
      title: title,
      description: description,
      photo: photo,
      embedUrl: embedUrl,
      embedType: embedType,
      embedWidth: embedWidth,
      embedHeight: embedHeight,
      duration: duration,
      author: author,
      document: document,
      cachedPage: cachedPage,
      attributes: attributes,
    );

    // Now return the deserialized [WebPage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b13: hasLargeMedia,
      b00: type != null,
      b01: siteName != null,
      b02: title != null,
      b03: description != null,
      b04: photo != null,
      b05: embedUrl != null || embedType != null,
      b06: embedWidth != null || embedHeight != null,
      b07: duration != null,
      b08: author != null,
      b09: document != null,
      b10: cachedPage != null,
      b12: attributes != null,
    );

    return v;
  }

  /// has_large_media: bit 13 of flags.13?true
  final bool hasLargeMedia;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Url.
  final String url;

  /// Display Url.
  final String displayUrl;

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Type.
  final String? type;

  /// Site Name.
  final String? siteName;

  /// Title.
  final String? title;

  /// Description.
  final String? description;

  /// Photo.
  final PhotoBase? photo;

  /// Embed Url.
  final String? embedUrl;

  /// Embed Type.
  final String? embedType;

  /// Embed Width.
  final int? embedWidth;

  /// Embed Height.
  final int? embedHeight;

  /// Duration.
  final int? duration;

  /// Author.
  final String? author;

  /// Document.
  final DocumentBase? document;

  /// Cached Page.
  final PageBase? cachedPage;

  /// Attributes.
  final List<WebPageAttributeBase>? attributes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe89c45b2.
    buffer.writeInt32(0xe89c45b2);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeString(url);
    buffer.writeString(displayUrl);
    buffer.writeInt32(hash);
    final localTypeCopy = type;
    if (localTypeCopy != null) {
      buffer.writeString(localTypeCopy);
    }
    final localSiteNameCopy = siteName;
    if (localSiteNameCopy != null) {
      buffer.writeString(localSiteNameCopy);
    }
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localDescriptionCopy = description;
    if (localDescriptionCopy != null) {
      buffer.writeString(localDescriptionCopy);
    }
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }
    final localEmbedUrlCopy = embedUrl;
    if (localEmbedUrlCopy != null) {
      buffer.writeString(localEmbedUrlCopy);
    }
    final localEmbedTypeCopy = embedType;
    if (localEmbedTypeCopy != null) {
      buffer.writeString(localEmbedTypeCopy);
    }
    final localEmbedWidthCopy = embedWidth;
    if (localEmbedWidthCopy != null) {
      buffer.writeInt32(localEmbedWidthCopy);
    }
    final localEmbedHeightCopy = embedHeight;
    if (localEmbedHeightCopy != null) {
      buffer.writeInt32(localEmbedHeightCopy);
    }
    final localDurationCopy = duration;
    if (localDurationCopy != null) {
      buffer.writeInt32(localDurationCopy);
    }
    final localAuthorCopy = author;
    if (localAuthorCopy != null) {
      buffer.writeString(localAuthorCopy);
    }
    final localDocumentCopy = document;
    if (localDocumentCopy != null) {
      buffer.writeObject(localDocumentCopy);
    }
    final localCachedPageCopy = cachedPage;
    if (localCachedPageCopy != null) {
      buffer.writeObject(localCachedPageCopy);
    }
    final localAttributesCopy = attributes;
    if (localAttributesCopy != null) {
      buffer.writeVectorObject(localAttributesCopy);
    }

    // Finished serialization.
  }
}

/// Web Page Not Modified.
///
/// ID: `7311ca11`.
class WebPageNotModified extends WebPageBase {
  /// Web Page Not Modified constructor.
  const WebPageNotModified({
    this.cachedPageViews,
  }) : super._();

  /// Deserialize.
  factory WebPageNotModified.deserialize(BinaryReader reader) {
    // Read [WebPageNotModified] fields.
    final flags = reader.readInt32();
    final hasCachedPageViewsField = (flags & 1) != 0;
    final cachedPageViews = hasCachedPageViewsField ? reader.readInt32() : null;

    // Construct [WebPageNotModified] object.
    final returnValue = WebPageNotModified(
      cachedPageViews: cachedPageViews,
    );

    // Now return the deserialized [WebPageNotModified].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: cachedPageViews != null,
    );

    return v;
  }

  /// Cached Page Views.
  final int? cachedPageViews;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7311ca11.
    buffer.writeInt32(0x7311ca11);

    // Write fields.
    buffer.writeInt32(flags);
    final localCachedPageViewsCopy = cachedPageViews;
    if (localCachedPageViewsCopy != null) {
      buffer.writeInt32(localCachedPageViewsCopy);
    }

    // Finished serialization.
  }
}

/// Authorization.
///
/// ID: `ad01d61d`.
class Authorization extends AuthorizationBase {
  /// Authorization constructor.
  const Authorization({
    required this.current,
    required this.officialApp,
    required this.passwordPending,
    required this.encryptedRequestsDisabled,
    required this.callRequestsDisabled,
    required this.unconfirmed,
    required this.hash,
    required this.deviceModel,
    required this.platform,
    required this.systemVersion,
    required this.apiId,
    required this.appName,
    required this.appVersion,
    required this.dateCreated,
    required this.dateActive,
    required this.ip,
    required this.country,
    required this.region,
  }) : super._();

  /// Deserialize.
  factory Authorization.deserialize(BinaryReader reader) {
    // Read [Authorization] fields.
    final flags = reader.readInt32();
    final current = (flags & 1) != 0;
    final officialApp = (flags & 2) != 0;
    final passwordPending = (flags & 4) != 0;
    final encryptedRequestsDisabled = (flags & 8) != 0;
    final callRequestsDisabled = (flags & 16) != 0;
    final unconfirmed = (flags & 32) != 0;
    final hash = reader.readInt64();
    final deviceModel = reader.readString();
    final platform = reader.readString();
    final systemVersion = reader.readString();
    final apiId = reader.readInt32();
    final appName = reader.readString();
    final appVersion = reader.readString();
    final dateCreated = reader.readDateTime();
    final dateActive = reader.readDateTime();
    final ip = reader.readString();
    final country = reader.readString();
    final region = reader.readString();

    // Construct [Authorization] object.
    final returnValue = Authorization(
      current: current,
      officialApp: officialApp,
      passwordPending: passwordPending,
      encryptedRequestsDisabled: encryptedRequestsDisabled,
      callRequestsDisabled: callRequestsDisabled,
      unconfirmed: unconfirmed,
      hash: hash,
      deviceModel: deviceModel,
      platform: platform,
      systemVersion: systemVersion,
      apiId: apiId,
      appName: appName,
      appVersion: appVersion,
      dateCreated: dateCreated,
      dateActive: dateActive,
      ip: ip,
      country: country,
      region: region,
    );

    // Now return the deserialized [Authorization].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: current,
      b01: officialApp,
      b02: passwordPending,
      b03: encryptedRequestsDisabled,
      b04: callRequestsDisabled,
      b05: unconfirmed,
    );

    return v;
  }

  /// current: bit 0 of flags.0?true
  final bool current;

  /// official_app: bit 1 of flags.1?true
  final bool officialApp;

  /// password_pending: bit 2 of flags.2?true
  final bool passwordPending;

  /// encrypted_requests_disabled: bit 3 of flags.3?true
  final bool encryptedRequestsDisabled;

  /// call_requests_disabled: bit 4 of flags.4?true
  final bool callRequestsDisabled;

  /// unconfirmed: bit 5 of flags.5?true
  final bool unconfirmed;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Device Model.
  final String deviceModel;

  /// Platform.
  final String platform;

  /// System Version.
  final String systemVersion;

  /// Api Id.
  ///
  /// Field type is Int32.
  final int apiId;

  /// App Name.
  final String appName;

  /// App Version.
  final String appVersion;

  /// Date Created.
  final DateTime dateCreated;

  /// Date Active.
  final DateTime dateActive;

  /// Ip.
  final String ip;

  /// Country.
  final String country;

  /// Region.
  final String region;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xad01d61d.
    buffer.writeInt32(0xad01d61d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(hash);
    buffer.writeString(deviceModel);
    buffer.writeString(platform);
    buffer.writeString(systemVersion);
    buffer.writeInt32(apiId);
    buffer.writeString(appName);
    buffer.writeString(appVersion);
    buffer.writeDateTime(dateCreated);
    buffer.writeDateTime(dateActive);
    buffer.writeString(ip);
    buffer.writeString(country);
    buffer.writeString(region);

    // Finished serialization.
  }
}

/// Account Authorizations.
///
/// ID: `4bff8ea0`.
class AccountAuthorizations extends AccountAuthorizationsBase {
  /// Account Authorizations constructor.
  const AccountAuthorizations({
    required this.authorizationTtlDays,
    required this.authorizations,
  }) : super._();

  /// Deserialize.
  factory AccountAuthorizations.deserialize(BinaryReader reader) {
    // Read [AccountAuthorizations] fields.
    final authorizationTtlDays = reader.readInt32();
    final authorizations = reader.readVectorObject<AuthorizationBase>();

    // Construct [AccountAuthorizations] object.
    final returnValue = AccountAuthorizations(
      authorizationTtlDays: authorizationTtlDays,
      authorizations: authorizations,
    );

    // Now return the deserialized [AccountAuthorizations].
    return returnValue;
  }

  /// Authorization Ttl Days.
  ///
  /// Field type is Int32.
  final int authorizationTtlDays;

  /// Authorizations.
  final List<AuthorizationBase> authorizations;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4bff8ea0.
    buffer.writeInt32(0x4bff8ea0);

    // Write fields.
    buffer.writeInt32(authorizationTtlDays);
    buffer.writeVectorObject(authorizations);

    // Finished serialization.
  }
}

/// Account Password.
///
/// ID: `957b50fb`.
class AccountPassword extends AccountPasswordBase {
  /// Account Password constructor.
  const AccountPassword({
    required this.hasRecovery,
    required this.hasSecureValues,
    required this.hasPassword,
    this.currentAlgo,
    this.srpB,
    this.srpId,
    this.hint,
    this.emailUnconfirmedPattern,
    required this.newAlgo,
    required this.newSecureAlgo,
    required this.secureRandom,
    this.pendingResetDate,
    this.loginEmailPattern,
  }) : super._();

  /// Deserialize.
  factory AccountPassword.deserialize(BinaryReader reader) {
    // Read [AccountPassword] fields.
    final flags = reader.readInt32();
    final hasRecovery = (flags & 1) != 0;
    final hasSecureValues = (flags & 2) != 0;
    final hasPassword = (flags & 4) != 0;
    final hasCurrentAlgoField = (flags & 4) != 0;
    final currentAlgo =
        hasCurrentAlgoField ? reader.readObject() as PasswordKdfAlgoBase : null;
    final hasSrpBField = (flags & 4) != 0;
    final srpB = hasSrpBField ? reader.readBytes() : null;
    final hasSrpIdField = (flags & 4) != 0;
    final srpId = hasSrpIdField ? reader.readInt64() : null;
    final hasHintField = (flags & 8) != 0;
    final hint = hasHintField ? reader.readString() : null;
    final hasEmailUnconfirmedPatternField = (flags & 16) != 0;
    final emailUnconfirmedPattern =
        hasEmailUnconfirmedPatternField ? reader.readString() : null;
    final newAlgo = reader.readObject() as PasswordKdfAlgoBase;
    final newSecureAlgo = reader.readObject() as SecurePasswordKdfAlgoBase;
    final secureRandom = reader.readBytes();
    final hasPendingResetDateField = (flags & 32) != 0;
    final pendingResetDate =
        hasPendingResetDateField ? reader.readDateTime() : null;
    final hasLoginEmailPatternField = (flags & 64) != 0;
    final loginEmailPattern =
        hasLoginEmailPatternField ? reader.readString() : null;

    // Construct [AccountPassword] object.
    final returnValue = AccountPassword(
      hasRecovery: hasRecovery,
      hasSecureValues: hasSecureValues,
      hasPassword: hasPassword,
      currentAlgo: currentAlgo,
      srpB: srpB,
      srpId: srpId,
      hint: hint,
      emailUnconfirmedPattern: emailUnconfirmedPattern,
      newAlgo: newAlgo,
      newSecureAlgo: newSecureAlgo,
      secureRandom: secureRandom,
      pendingResetDate: pendingResetDate,
      loginEmailPattern: loginEmailPattern,
    );

    // Now return the deserialized [AccountPassword].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: hasRecovery,
      b01: hasSecureValues,
      b02: hasPassword || currentAlgo != null || srpB != null || srpId != null,
      b03: hint != null,
      b04: emailUnconfirmedPattern != null,
      b05: pendingResetDate != null,
      b06: loginEmailPattern != null,
    );

    return v;
  }

  /// has_recovery: bit 0 of flags.0?true
  final bool hasRecovery;

  /// has_secure_values: bit 1 of flags.1?true
  final bool hasSecureValues;

  /// has_password: bit 2 of flags.2?true
  final bool hasPassword;

  /// Current Algo.
  final PasswordKdfAlgoBase? currentAlgo;

  /// Srp B.
  final Uint8List? srpB;

  /// Srp Id.
  final int? srpId;

  /// Hint.
  final String? hint;

  /// Email Unconfirmed Pattern.
  final String? emailUnconfirmedPattern;

  /// New Algo.
  final PasswordKdfAlgoBase newAlgo;

  /// New Secure Algo.
  final SecurePasswordKdfAlgoBase newSecureAlgo;

  /// Secure Random.
  final Uint8List secureRandom;

  /// Pending Reset Date.
  final DateTime? pendingResetDate;

  /// Login Email Pattern.
  final String? loginEmailPattern;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x957b50fb.
    buffer.writeInt32(0x957b50fb);

    // Write fields.
    buffer.writeInt32(flags);
    final localCurrentAlgoCopy = currentAlgo;
    if (localCurrentAlgoCopy != null) {
      buffer.writeObject(localCurrentAlgoCopy);
    }
    final localSrpBCopy = srpB;
    if (localSrpBCopy != null) {
      buffer.writeBytes(localSrpBCopy);
    }
    final localSrpIdCopy = srpId;
    if (localSrpIdCopy != null) {
      buffer.writeInt64(localSrpIdCopy);
    }
    final localHintCopy = hint;
    if (localHintCopy != null) {
      buffer.writeString(localHintCopy);
    }
    final localEmailUnconfirmedPatternCopy = emailUnconfirmedPattern;
    if (localEmailUnconfirmedPatternCopy != null) {
      buffer.writeString(localEmailUnconfirmedPatternCopy);
    }
    buffer.writeObject(newAlgo);
    buffer.writeObject(newSecureAlgo);
    buffer.writeBytes(secureRandom);
    final localPendingResetDateCopy = pendingResetDate;
    if (localPendingResetDateCopy != null) {
      buffer.writeDateTime(localPendingResetDateCopy);
    }
    final localLoginEmailPatternCopy = loginEmailPattern;
    if (localLoginEmailPatternCopy != null) {
      buffer.writeString(localLoginEmailPatternCopy);
    }

    // Finished serialization.
  }
}

/// Account Password Settings.
///
/// ID: `9a5c33e5`.
class AccountPasswordSettings extends AccountPasswordSettingsBase {
  /// Account Password Settings constructor.
  const AccountPasswordSettings({
    this.email,
    this.secureSettings,
  }) : super._();

  /// Deserialize.
  factory AccountPasswordSettings.deserialize(BinaryReader reader) {
    // Read [AccountPasswordSettings] fields.
    final flags = reader.readInt32();
    final hasEmailField = (flags & 1) != 0;
    final email = hasEmailField ? reader.readString() : null;
    final hasSecureSettingsField = (flags & 2) != 0;
    final secureSettings = hasSecureSettingsField
        ? reader.readObject() as SecureSecretSettingsBase
        : null;

    // Construct [AccountPasswordSettings] object.
    final returnValue = AccountPasswordSettings(
      email: email,
      secureSettings: secureSettings,
    );

    // Now return the deserialized [AccountPasswordSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: email != null,
      b01: secureSettings != null,
    );

    return v;
  }

  /// Email.
  final String? email;

  /// Secure Settings.
  final SecureSecretSettingsBase? secureSettings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9a5c33e5.
    buffer.writeInt32(0x9a5c33e5);

    // Write fields.
    buffer.writeInt32(flags);
    final localEmailCopy = email;
    if (localEmailCopy != null) {
      buffer.writeString(localEmailCopy);
    }
    final localSecureSettingsCopy = secureSettings;
    if (localSecureSettingsCopy != null) {
      buffer.writeObject(localSecureSettingsCopy);
    }

    // Finished serialization.
  }
}

/// Account Password Input Settings.
///
/// ID: `c23727c9`.
class AccountPasswordInputSettings extends AccountPasswordInputSettingsBase {
  /// Account Password Input Settings constructor.
  const AccountPasswordInputSettings({
    this.newAlgo,
    this.newPasswordHash,
    this.hint,
    this.email,
    this.newSecureSettings,
  }) : super._();

  /// Deserialize.
  factory AccountPasswordInputSettings.deserialize(BinaryReader reader) {
    // Read [AccountPasswordInputSettings] fields.
    final flags = reader.readInt32();
    final hasNewAlgoField = (flags & 1) != 0;
    final newAlgo =
        hasNewAlgoField ? reader.readObject() as PasswordKdfAlgoBase : null;
    final hasNewPasswordHashField = (flags & 1) != 0;
    final newPasswordHash = hasNewPasswordHashField ? reader.readBytes() : null;
    final hasHintField = (flags & 1) != 0;
    final hint = hasHintField ? reader.readString() : null;
    final hasEmailField = (flags & 2) != 0;
    final email = hasEmailField ? reader.readString() : null;
    final hasNewSecureSettingsField = (flags & 4) != 0;
    final newSecureSettings = hasNewSecureSettingsField
        ? reader.readObject() as SecureSecretSettingsBase
        : null;

    // Construct [AccountPasswordInputSettings] object.
    final returnValue = AccountPasswordInputSettings(
      newAlgo: newAlgo,
      newPasswordHash: newPasswordHash,
      hint: hint,
      email: email,
      newSecureSettings: newSecureSettings,
    );

    // Now return the deserialized [AccountPasswordInputSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: newAlgo != null || newPasswordHash != null || hint != null,
      b01: email != null,
      b02: newSecureSettings != null,
    );

    return v;
  }

  /// New Algo.
  final PasswordKdfAlgoBase? newAlgo;

  /// New Password Hash.
  final Uint8List? newPasswordHash;

  /// Hint.
  final String? hint;

  /// Email.
  final String? email;

  /// New Secure Settings.
  final SecureSecretSettingsBase? newSecureSettings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc23727c9.
    buffer.writeInt32(0xc23727c9);

    // Write fields.
    buffer.writeInt32(flags);
    final localNewAlgoCopy = newAlgo;
    if (localNewAlgoCopy != null) {
      buffer.writeObject(localNewAlgoCopy);
    }
    final localNewPasswordHashCopy = newPasswordHash;
    if (localNewPasswordHashCopy != null) {
      buffer.writeBytes(localNewPasswordHashCopy);
    }
    final localHintCopy = hint;
    if (localHintCopy != null) {
      buffer.writeString(localHintCopy);
    }
    final localEmailCopy = email;
    if (localEmailCopy != null) {
      buffer.writeString(localEmailCopy);
    }
    final localNewSecureSettingsCopy = newSecureSettings;
    if (localNewSecureSettingsCopy != null) {
      buffer.writeObject(localNewSecureSettingsCopy);
    }

    // Finished serialization.
  }
}

/// Auth Password Recovery.
///
/// ID: `137948a5`.
class AuthPasswordRecovery extends AuthPasswordRecoveryBase {
  /// Auth Password Recovery constructor.
  const AuthPasswordRecovery({
    required this.emailPattern,
  }) : super._();

  /// Deserialize.
  factory AuthPasswordRecovery.deserialize(BinaryReader reader) {
    // Read [AuthPasswordRecovery] fields.
    final emailPattern = reader.readString();

    // Construct [AuthPasswordRecovery] object.
    final returnValue = AuthPasswordRecovery(
      emailPattern: emailPattern,
    );

    // Now return the deserialized [AuthPasswordRecovery].
    return returnValue;
  }

  /// Email Pattern.
  final String emailPattern;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x137948a5.
    buffer.writeInt32(0x137948a5);

    // Write fields.
    buffer.writeString(emailPattern);

    // Finished serialization.
  }
}

/// Received Notify Message.
///
/// ID: `a384b779`.
class ReceivedNotifyMessage extends ReceivedNotifyMessageBase {
  /// Received Notify Message constructor.
  const ReceivedNotifyMessage({
    required this.id,
    required this.flags,
  }) : super._();

  /// Deserialize.
  factory ReceivedNotifyMessage.deserialize(BinaryReader reader) {
    // Read [ReceivedNotifyMessage] fields.
    final id = reader.readInt32();
    final flags = reader.readInt32();

    // Construct [ReceivedNotifyMessage] object.
    final returnValue = ReceivedNotifyMessage(
      id: id,
      flags: flags,
    );

    // Now return the deserialized [ReceivedNotifyMessage].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Flags.
  ///
  /// Field type is Int32.
  final int flags;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa384b779.
    buffer.writeInt32(0xa384b779);

    // Write fields.
    buffer.writeInt32(id);
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Chat Invite Exported.
///
/// ID: `0ab4a819`.
class ChatInviteExported extends ExportedChatInviteBase {
  /// Chat Invite Exported constructor.
  const ChatInviteExported({
    required this.revoked,
    required this.permanent,
    required this.requestNeeded,
    required this.link,
    required this.adminId,
    required this.date,
    this.startDate,
    this.expireDate,
    this.usageLimit,
    this.usage,
    this.requested,
    this.title,
  }) : super._();

  /// Deserialize.
  factory ChatInviteExported.deserialize(BinaryReader reader) {
    // Read [ChatInviteExported] fields.
    final flags = reader.readInt32();
    final revoked = (flags & 1) != 0;
    final permanent = (flags & 32) != 0;
    final requestNeeded = (flags & 64) != 0;
    final link = reader.readString();
    final adminId = reader.readInt64();
    final date = reader.readDateTime();
    final hasStartDateField = (flags & 16) != 0;
    final startDate = hasStartDateField ? reader.readDateTime() : null;
    final hasExpireDateField = (flags & 2) != 0;
    final expireDate = hasExpireDateField ? reader.readDateTime() : null;
    final hasUsageLimitField = (flags & 4) != 0;
    final usageLimit = hasUsageLimitField ? reader.readInt32() : null;
    final hasUsageField = (flags & 8) != 0;
    final usage = hasUsageField ? reader.readInt32() : null;
    final hasRequestedField = (flags & 128) != 0;
    final requested = hasRequestedField ? reader.readInt32() : null;
    final hasTitleField = (flags & 256) != 0;
    final title = hasTitleField ? reader.readString() : null;

    // Construct [ChatInviteExported] object.
    final returnValue = ChatInviteExported(
      revoked: revoked,
      permanent: permanent,
      requestNeeded: requestNeeded,
      link: link,
      adminId: adminId,
      date: date,
      startDate: startDate,
      expireDate: expireDate,
      usageLimit: usageLimit,
      usage: usage,
      requested: requested,
      title: title,
    );

    // Now return the deserialized [ChatInviteExported].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: revoked,
      b05: permanent,
      b06: requestNeeded,
      b04: startDate != null,
      b01: expireDate != null,
      b02: usageLimit != null,
      b03: usage != null,
      b07: requested != null,
      b08: title != null,
    );

    return v;
  }

  /// revoked: bit 0 of flags.0?true
  final bool revoked;

  /// permanent: bit 5 of flags.5?true
  final bool permanent;

  /// request_needed: bit 6 of flags.6?true
  final bool requestNeeded;

  /// Link.
  final String link;

  /// Admin Id.
  ///
  /// Field type is Int64.
  final int adminId;

  /// Date.
  final DateTime date;

  /// Start Date.
  final DateTime? startDate;

  /// Expire Date.
  final DateTime? expireDate;

  /// Usage Limit.
  final int? usageLimit;

  /// Usage.
  final int? usage;

  /// Requested.
  final int? requested;

  /// Title.
  final String? title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0ab4a819.
    buffer.writeInt32(0x0ab4a819);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(link);
    buffer.writeInt64(adminId);
    buffer.writeDateTime(date);
    final localStartDateCopy = startDate;
    if (localStartDateCopy != null) {
      buffer.writeDateTime(localStartDateCopy);
    }
    final localExpireDateCopy = expireDate;
    if (localExpireDateCopy != null) {
      buffer.writeDateTime(localExpireDateCopy);
    }
    final localUsageLimitCopy = usageLimit;
    if (localUsageLimitCopy != null) {
      buffer.writeInt32(localUsageLimitCopy);
    }
    final localUsageCopy = usage;
    if (localUsageCopy != null) {
      buffer.writeInt32(localUsageCopy);
    }
    final localRequestedCopy = requested;
    if (localRequestedCopy != null) {
      buffer.writeInt32(localRequestedCopy);
    }
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }

    // Finished serialization.
  }
}

/// Chat Invite Public Join Requests.
///
/// ID: `ed107ab7`.
class ChatInvitePublicJoinRequests extends ExportedChatInviteBase {
  /// Chat Invite Public Join Requests constructor.
  const ChatInvitePublicJoinRequests() : super._();

  /// Deserialize.
  factory ChatInvitePublicJoinRequests.deserialize(BinaryReader reader) {
    // Construct [ChatInvitePublicJoinRequests] object.
    final returnValue = ChatInvitePublicJoinRequests();

    // Now return the deserialized [ChatInvitePublicJoinRequests].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xed107ab7.
    buffer.writeInt32(0xed107ab7);

    // Finished serialization.
  }
}

/// Chat Invite Already.
///
/// ID: `5a686d7c`.
class ChatInviteAlready extends ChatInviteBase {
  /// Chat Invite Already constructor.
  const ChatInviteAlready({
    required this.chat,
  }) : super._();

  /// Deserialize.
  factory ChatInviteAlready.deserialize(BinaryReader reader) {
    // Read [ChatInviteAlready] fields.
    final chat = reader.readObject() as ChatBase;

    // Construct [ChatInviteAlready] object.
    final returnValue = ChatInviteAlready(
      chat: chat,
    );

    // Now return the deserialized [ChatInviteAlready].
    return returnValue;
  }

  /// Chat.
  final ChatBase chat;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5a686d7c.
    buffer.writeInt32(0x5a686d7c);

    // Write fields.
    buffer.writeObject(chat);

    // Finished serialization.
  }
}

/// Chat Invite.
///
/// ID: `cde0ec40`.
class ChatInvite extends ChatInviteBase {
  /// Chat Invite constructor.
  const ChatInvite({
    required this.channel,
    required this.broadcast,
    required this.public,
    required this.megagroup,
    required this.requestNeeded,
    required this.verified,
    required this.scam,
    required this.fake,
    required this.title,
    this.about,
    required this.photo,
    required this.participantsCount,
    this.participants,
    required this.color,
  }) : super._();

  /// Deserialize.
  factory ChatInvite.deserialize(BinaryReader reader) {
    // Read [ChatInvite] fields.
    final flags = reader.readInt32();
    final channel = (flags & 1) != 0;
    final broadcast = (flags & 2) != 0;
    final public = (flags & 4) != 0;
    final megagroup = (flags & 8) != 0;
    final requestNeeded = (flags & 64) != 0;
    final verified = (flags & 128) != 0;
    final scam = (flags & 256) != 0;
    final fake = (flags & 512) != 0;
    final title = reader.readString();
    final hasAboutField = (flags & 32) != 0;
    final about = hasAboutField ? reader.readString() : null;
    final photo = reader.readObject() as PhotoBase;
    final participantsCount = reader.readInt32();
    final hasParticipantsField = (flags & 16) != 0;
    final participants =
        hasParticipantsField ? reader.readVectorObject<UserBase>() : null;
    final color = reader.readInt32();

    // Construct [ChatInvite] object.
    final returnValue = ChatInvite(
      channel: channel,
      broadcast: broadcast,
      public: public,
      megagroup: megagroup,
      requestNeeded: requestNeeded,
      verified: verified,
      scam: scam,
      fake: fake,
      title: title,
      about: about,
      photo: photo,
      participantsCount: participantsCount,
      participants: participants,
      color: color,
    );

    // Now return the deserialized [ChatInvite].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: channel,
      b01: broadcast,
      b02: public,
      b03: megagroup,
      b06: requestNeeded,
      b07: verified,
      b08: scam,
      b09: fake,
      b05: about != null,
      b04: participants != null,
    );

    return v;
  }

  /// channel: bit 0 of flags.0?true
  final bool channel;

  /// broadcast: bit 1 of flags.1?true
  final bool broadcast;

  /// public: bit 2 of flags.2?true
  final bool public;

  /// megagroup: bit 3 of flags.3?true
  final bool megagroup;

  /// request_needed: bit 6 of flags.6?true
  final bool requestNeeded;

  /// verified: bit 7 of flags.7?true
  final bool verified;

  /// scam: bit 8 of flags.8?true
  final bool scam;

  /// fake: bit 9 of flags.9?true
  final bool fake;

  /// Title.
  final String title;

  /// About.
  final String? about;

  /// Photo.
  final PhotoBase photo;

  /// Participants Count.
  ///
  /// Field type is Int32.
  final int participantsCount;

  /// Participants.
  final List<UserBase>? participants;

  /// Color.
  ///
  /// Field type is Int32.
  final int color;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcde0ec40.
    buffer.writeInt32(0xcde0ec40);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(title);
    final localAboutCopy = about;
    if (localAboutCopy != null) {
      buffer.writeString(localAboutCopy);
    }
    buffer.writeObject(photo);
    buffer.writeInt32(participantsCount);
    final localParticipantsCopy = participants;
    if (localParticipantsCopy != null) {
      buffer.writeVectorObject(localParticipantsCopy);
    }
    buffer.writeInt32(color);

    // Finished serialization.
  }
}

/// Chat Invite Peek.
///
/// ID: `61695cb0`.
class ChatInvitePeek extends ChatInviteBase {
  /// Chat Invite Peek constructor.
  const ChatInvitePeek({
    required this.chat,
    required this.expires,
  }) : super._();

  /// Deserialize.
  factory ChatInvitePeek.deserialize(BinaryReader reader) {
    // Read [ChatInvitePeek] fields.
    final chat = reader.readObject() as ChatBase;
    final expires = reader.readInt32();

    // Construct [ChatInvitePeek] object.
    final returnValue = ChatInvitePeek(
      chat: chat,
      expires: expires,
    );

    // Now return the deserialized [ChatInvitePeek].
    return returnValue;
  }

  /// Chat.
  final ChatBase chat;

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x61695cb0.
    buffer.writeInt32(0x61695cb0);

    // Write fields.
    buffer.writeObject(chat);
    buffer.writeInt32(expires);

    // Finished serialization.
  }
}

/// Input Sticker Set Empty.
///
/// ID: `ffb62b95`.
class InputStickerSetEmpty extends InputStickerSetBase {
  /// Input Sticker Set Empty constructor.
  const InputStickerSetEmpty() : super._();

  /// Deserialize.
  factory InputStickerSetEmpty.deserialize(BinaryReader reader) {
    // Construct [InputStickerSetEmpty] object.
    final returnValue = InputStickerSetEmpty();

    // Now return the deserialized [InputStickerSetEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xffb62b95.
    buffer.writeInt32(0xffb62b95);

    // Finished serialization.
  }
}

/// Input Sticker Set I D.
///
/// ID: `9de7a269`.
class InputStickerSetID extends InputStickerSetBase {
  /// Input Sticker Set I D constructor.
  const InputStickerSetID({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputStickerSetID.deserialize(BinaryReader reader) {
    // Read [InputStickerSetID] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputStickerSetID] object.
    final returnValue = InputStickerSetID(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputStickerSetID].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9de7a269.
    buffer.writeInt32(0x9de7a269);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Sticker Set Short Name.
///
/// ID: `861cc8a0`.
class InputStickerSetShortName extends InputStickerSetBase {
  /// Input Sticker Set Short Name constructor.
  const InputStickerSetShortName({
    required this.shortName,
  }) : super._();

  /// Deserialize.
  factory InputStickerSetShortName.deserialize(BinaryReader reader) {
    // Read [InputStickerSetShortName] fields.
    final shortName = reader.readString();

    // Construct [InputStickerSetShortName] object.
    final returnValue = InputStickerSetShortName(
      shortName: shortName,
    );

    // Now return the deserialized [InputStickerSetShortName].
    return returnValue;
  }

  /// Short Name.
  final String shortName;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x861cc8a0.
    buffer.writeInt32(0x861cc8a0);

    // Write fields.
    buffer.writeString(shortName);

    // Finished serialization.
  }
}

/// Input Sticker Set Animated Emoji.
///
/// ID: `028703c8`.
class InputStickerSetAnimatedEmoji extends InputStickerSetBase {
  /// Input Sticker Set Animated Emoji constructor.
  const InputStickerSetAnimatedEmoji() : super._();

  /// Deserialize.
  factory InputStickerSetAnimatedEmoji.deserialize(BinaryReader reader) {
    // Construct [InputStickerSetAnimatedEmoji] object.
    final returnValue = InputStickerSetAnimatedEmoji();

    // Now return the deserialized [InputStickerSetAnimatedEmoji].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x028703c8.
    buffer.writeInt32(0x028703c8);

    // Finished serialization.
  }
}

/// Input Sticker Set Dice.
///
/// ID: `e67f520e`.
class InputStickerSetDice extends InputStickerSetBase {
  /// Input Sticker Set Dice constructor.
  const InputStickerSetDice({
    required this.emoticon,
  }) : super._();

  /// Deserialize.
  factory InputStickerSetDice.deserialize(BinaryReader reader) {
    // Read [InputStickerSetDice] fields.
    final emoticon = reader.readString();

    // Construct [InputStickerSetDice] object.
    final returnValue = InputStickerSetDice(
      emoticon: emoticon,
    );

    // Now return the deserialized [InputStickerSetDice].
    return returnValue;
  }

  /// Emoticon.
  final String emoticon;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe67f520e.
    buffer.writeInt32(0xe67f520e);

    // Write fields.
    buffer.writeString(emoticon);

    // Finished serialization.
  }
}

/// Input Sticker Set Animated Emoji Animations.
///
/// ID: `0cde3739`.
class InputStickerSetAnimatedEmojiAnimations extends InputStickerSetBase {
  /// Input Sticker Set Animated Emoji Animations constructor.
  const InputStickerSetAnimatedEmojiAnimations() : super._();

  /// Deserialize.
  factory InputStickerSetAnimatedEmojiAnimations.deserialize(
      BinaryReader reader) {
    // Construct [InputStickerSetAnimatedEmojiAnimations] object.
    final returnValue = InputStickerSetAnimatedEmojiAnimations();

    // Now return the deserialized [InputStickerSetAnimatedEmojiAnimations].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0cde3739.
    buffer.writeInt32(0x0cde3739);

    // Finished serialization.
  }
}

/// Input Sticker Set Premium Gifts.
///
/// ID: `c88b3b02`.
class InputStickerSetPremiumGifts extends InputStickerSetBase {
  /// Input Sticker Set Premium Gifts constructor.
  const InputStickerSetPremiumGifts() : super._();

  /// Deserialize.
  factory InputStickerSetPremiumGifts.deserialize(BinaryReader reader) {
    // Construct [InputStickerSetPremiumGifts] object.
    final returnValue = InputStickerSetPremiumGifts();

    // Now return the deserialized [InputStickerSetPremiumGifts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc88b3b02.
    buffer.writeInt32(0xc88b3b02);

    // Finished serialization.
  }
}

/// Input Sticker Set Emoji Generic Animations.
///
/// ID: `04c4d4ce`.
class InputStickerSetEmojiGenericAnimations extends InputStickerSetBase {
  /// Input Sticker Set Emoji Generic Animations constructor.
  const InputStickerSetEmojiGenericAnimations() : super._();

  /// Deserialize.
  factory InputStickerSetEmojiGenericAnimations.deserialize(
      BinaryReader reader) {
    // Construct [InputStickerSetEmojiGenericAnimations] object.
    final returnValue = InputStickerSetEmojiGenericAnimations();

    // Now return the deserialized [InputStickerSetEmojiGenericAnimations].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x04c4d4ce.
    buffer.writeInt32(0x04c4d4ce);

    // Finished serialization.
  }
}

/// Input Sticker Set Emoji Default Statuses.
///
/// ID: `29d0f5ee`.
class InputStickerSetEmojiDefaultStatuses extends InputStickerSetBase {
  /// Input Sticker Set Emoji Default Statuses constructor.
  const InputStickerSetEmojiDefaultStatuses() : super._();

  /// Deserialize.
  factory InputStickerSetEmojiDefaultStatuses.deserialize(BinaryReader reader) {
    // Construct [InputStickerSetEmojiDefaultStatuses] object.
    final returnValue = InputStickerSetEmojiDefaultStatuses();

    // Now return the deserialized [InputStickerSetEmojiDefaultStatuses].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x29d0f5ee.
    buffer.writeInt32(0x29d0f5ee);

    // Finished serialization.
  }
}

/// Input Sticker Set Emoji Default Topic Icons.
///
/// ID: `44c1f8e9`.
class InputStickerSetEmojiDefaultTopicIcons extends InputStickerSetBase {
  /// Input Sticker Set Emoji Default Topic Icons constructor.
  const InputStickerSetEmojiDefaultTopicIcons() : super._();

  /// Deserialize.
  factory InputStickerSetEmojiDefaultTopicIcons.deserialize(
      BinaryReader reader) {
    // Construct [InputStickerSetEmojiDefaultTopicIcons] object.
    final returnValue = InputStickerSetEmojiDefaultTopicIcons();

    // Now return the deserialized [InputStickerSetEmojiDefaultTopicIcons].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x44c1f8e9.
    buffer.writeInt32(0x44c1f8e9);

    // Finished serialization.
  }
}

/// Input Sticker Set Emoji Channel Default Statuses.
///
/// ID: `49748553`.
class InputStickerSetEmojiChannelDefaultStatuses extends InputStickerSetBase {
  /// Input Sticker Set Emoji Channel Default Statuses constructor.
  const InputStickerSetEmojiChannelDefaultStatuses() : super._();

  /// Deserialize.
  factory InputStickerSetEmojiChannelDefaultStatuses.deserialize(
      BinaryReader reader) {
    // Construct [InputStickerSetEmojiChannelDefaultStatuses] object.
    final returnValue = InputStickerSetEmojiChannelDefaultStatuses();

    // Now return the deserialized [InputStickerSetEmojiChannelDefaultStatuses].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x49748553.
    buffer.writeInt32(0x49748553);

    // Finished serialization.
  }
}

/// Sticker Set.
///
/// ID: `2dd14edc`.
class StickerSet extends StickerSetBase {
  /// Sticker Set constructor.
  const StickerSet({
    required this.archived,
    required this.official,
    required this.masks,
    required this.emojis,
    required this.textColor,
    required this.channelEmojiStatus,
    this.installedDate,
    required this.id,
    required this.accessHash,
    required this.title,
    required this.shortName,
    this.thumbs,
    this.thumbDcId,
    this.thumbVersion,
    this.thumbDocumentId,
    required this.count,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory StickerSet.deserialize(BinaryReader reader) {
    // Read [StickerSet] fields.
    final flags = reader.readInt32();
    final archived = (flags & 2) != 0;
    final official = (flags & 4) != 0;
    final masks = (flags & 8) != 0;
    final emojis = (flags & 128) != 0;
    final textColor = (flags & 512) != 0;
    final channelEmojiStatus = (flags & 1024) != 0;
    final hasInstalledDateField = (flags & 1) != 0;
    final installedDate = hasInstalledDateField ? reader.readDateTime() : null;
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final title = reader.readString();
    final shortName = reader.readString();
    final hasThumbsField = (flags & 16) != 0;
    final thumbs =
        hasThumbsField ? reader.readVectorObject<PhotoSizeBase>() : null;
    final hasThumbDcIdField = (flags & 16) != 0;
    final thumbDcId = hasThumbDcIdField ? reader.readInt32() : null;
    final hasThumbVersionField = (flags & 16) != 0;
    final thumbVersion = hasThumbVersionField ? reader.readInt32() : null;
    final hasThumbDocumentIdField = (flags & 256) != 0;
    final thumbDocumentId = hasThumbDocumentIdField ? reader.readInt64() : null;
    final count = reader.readInt32();
    final hash = reader.readInt32();

    // Construct [StickerSet] object.
    final returnValue = StickerSet(
      archived: archived,
      official: official,
      masks: masks,
      emojis: emojis,
      textColor: textColor,
      channelEmojiStatus: channelEmojiStatus,
      installedDate: installedDate,
      id: id,
      accessHash: accessHash,
      title: title,
      shortName: shortName,
      thumbs: thumbs,
      thumbDcId: thumbDcId,
      thumbVersion: thumbVersion,
      thumbDocumentId: thumbDocumentId,
      count: count,
      hash: hash,
    );

    // Now return the deserialized [StickerSet].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: archived,
      b02: official,
      b03: masks,
      b07: emojis,
      b09: textColor,
      b10: channelEmojiStatus,
      b00: installedDate != null,
      b04: thumbs != null || thumbDcId != null || thumbVersion != null,
      b08: thumbDocumentId != null,
    );

    return v;
  }

  /// archived: bit 1 of flags.1?true
  final bool archived;

  /// official: bit 2 of flags.2?true
  final bool official;

  /// masks: bit 3 of flags.3?true
  final bool masks;

  /// emojis: bit 7 of flags.7?true
  final bool emojis;

  /// text_color: bit 9 of flags.9?true
  final bool textColor;

  /// channel_emoji_status: bit 10 of flags.10?true
  final bool channelEmojiStatus;

  /// Installed Date.
  final DateTime? installedDate;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Title.
  final String title;

  /// Short Name.
  final String shortName;

  /// Thumbs.
  final List<PhotoSizeBase>? thumbs;

  /// Thumb Dc Id.
  final int? thumbDcId;

  /// Thumb Version.
  final int? thumbVersion;

  /// Thumb Document Id.
  final int? thumbDocumentId;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2dd14edc.
    buffer.writeInt32(0x2dd14edc);

    // Write fields.
    buffer.writeInt32(flags);
    final localInstalledDateCopy = installedDate;
    if (localInstalledDateCopy != null) {
      buffer.writeDateTime(localInstalledDateCopy);
    }
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeString(title);
    buffer.writeString(shortName);
    final localThumbsCopy = thumbs;
    if (localThumbsCopy != null) {
      buffer.writeVectorObject(localThumbsCopy);
    }
    final localThumbDcIdCopy = thumbDcId;
    if (localThumbDcIdCopy != null) {
      buffer.writeInt32(localThumbDcIdCopy);
    }
    final localThumbVersionCopy = thumbVersion;
    if (localThumbVersionCopy != null) {
      buffer.writeInt32(localThumbVersionCopy);
    }
    final localThumbDocumentIdCopy = thumbDocumentId;
    if (localThumbDocumentIdCopy != null) {
      buffer.writeInt64(localThumbDocumentIdCopy);
    }
    buffer.writeInt32(count);
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Messages Sticker Set.
///
/// ID: `6e153f16`.
class MessagesStickerSet extends MessagesStickerSetBase {
  /// Messages Sticker Set constructor.
  const MessagesStickerSet({
    required this.set,
    required this.packs,
    required this.keywords,
    required this.documents,
  }) : super._();

  /// Deserialize.
  factory MessagesStickerSet.deserialize(BinaryReader reader) {
    // Read [MessagesStickerSet] fields.
    final set = reader.readObject() as StickerSetBase;
    final packs = reader.readVectorObject<StickerPackBase>();
    final keywords = reader.readVectorObject<StickerKeywordBase>();
    final documents = reader.readVectorObject<DocumentBase>();

    // Construct [MessagesStickerSet] object.
    final returnValue = MessagesStickerSet(
      set: set,
      packs: packs,
      keywords: keywords,
      documents: documents,
    );

    // Now return the deserialized [MessagesStickerSet].
    return returnValue;
  }

  /// Set.
  final StickerSetBase set;

  /// Packs.
  final List<StickerPackBase> packs;

  /// Keywords.
  final List<StickerKeywordBase> keywords;

  /// Documents.
  final List<DocumentBase> documents;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6e153f16.
    buffer.writeInt32(0x6e153f16);

    // Write fields.
    buffer.writeObject(set);
    buffer.writeVectorObject(packs);
    buffer.writeVectorObject(keywords);
    buffer.writeVectorObject(documents);

    // Finished serialization.
  }
}

/// Messages Sticker Set Not Modified.
///
/// ID: `d3f924eb`.
class MessagesStickerSetNotModified extends MessagesStickerSetBase {
  /// Messages Sticker Set Not Modified constructor.
  const MessagesStickerSetNotModified() : super._();

  /// Deserialize.
  factory MessagesStickerSetNotModified.deserialize(BinaryReader reader) {
    // Construct [MessagesStickerSetNotModified] object.
    final returnValue = MessagesStickerSetNotModified();

    // Now return the deserialized [MessagesStickerSetNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd3f924eb.
    buffer.writeInt32(0xd3f924eb);

    // Finished serialization.
  }
}

/// Bot Command.
///
/// ID: `c27ac8c7`.
class BotCommand extends BotCommandBase {
  /// Bot Command constructor.
  const BotCommand({
    required this.command,
    required this.description,
  }) : super._();

  /// Deserialize.
  factory BotCommand.deserialize(BinaryReader reader) {
    // Read [BotCommand] fields.
    final command = reader.readString();
    final description = reader.readString();

    // Construct [BotCommand] object.
    final returnValue = BotCommand(
      command: command,
      description: description,
    );

    // Now return the deserialized [BotCommand].
    return returnValue;
  }

  /// Command.
  final String command;

  /// Description.
  final String description;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc27ac8c7.
    buffer.writeInt32(0xc27ac8c7);

    // Write fields.
    buffer.writeString(command);
    buffer.writeString(description);

    // Finished serialization.
  }
}

/// Bot Info.
///
/// ID: `8f300b57`.
class BotInfo extends BotInfoBase {
  /// Bot Info constructor.
  const BotInfo({
    this.userId,
    this.description,
    this.descriptionPhoto,
    this.descriptionDocument,
    this.commands,
    this.menuButton,
  }) : super._();

  /// Deserialize.
  factory BotInfo.deserialize(BinaryReader reader) {
    // Read [BotInfo] fields.
    final flags = reader.readInt32();
    final hasUserIdField = (flags & 1) != 0;
    final userId = hasUserIdField ? reader.readInt64() : null;
    final hasDescriptionField = (flags & 2) != 0;
    final description = hasDescriptionField ? reader.readString() : null;
    final hasDescriptionPhotoField = (flags & 16) != 0;
    final descriptionPhoto =
        hasDescriptionPhotoField ? reader.readObject() as PhotoBase : null;
    final hasDescriptionDocumentField = (flags & 32) != 0;
    final descriptionDocument = hasDescriptionDocumentField
        ? reader.readObject() as DocumentBase
        : null;
    final hasCommandsField = (flags & 4) != 0;
    final commands =
        hasCommandsField ? reader.readVectorObject<BotCommandBase>() : null;
    final hasMenuButtonField = (flags & 8) != 0;
    final menuButton =
        hasMenuButtonField ? reader.readObject() as BotMenuButtonBase : null;

    // Construct [BotInfo] object.
    final returnValue = BotInfo(
      userId: userId,
      description: description,
      descriptionPhoto: descriptionPhoto,
      descriptionDocument: descriptionDocument,
      commands: commands,
      menuButton: menuButton,
    );

    // Now return the deserialized [BotInfo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: userId != null,
      b01: description != null,
      b04: descriptionPhoto != null,
      b05: descriptionDocument != null,
      b02: commands != null,
      b03: menuButton != null,
    );

    return v;
  }

  /// User Id.
  final int? userId;

  /// Description.
  final String? description;

  /// Description Photo.
  final PhotoBase? descriptionPhoto;

  /// Description Document.
  final DocumentBase? descriptionDocument;

  /// Commands.
  final List<BotCommandBase>? commands;

  /// Menu Button.
  final BotMenuButtonBase? menuButton;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8f300b57.
    buffer.writeInt32(0x8f300b57);

    // Write fields.
    buffer.writeInt32(flags);
    final localUserIdCopy = userId;
    if (localUserIdCopy != null) {
      buffer.writeInt64(localUserIdCopy);
    }
    final localDescriptionCopy = description;
    if (localDescriptionCopy != null) {
      buffer.writeString(localDescriptionCopy);
    }
    final localDescriptionPhotoCopy = descriptionPhoto;
    if (localDescriptionPhotoCopy != null) {
      buffer.writeObject(localDescriptionPhotoCopy);
    }
    final localDescriptionDocumentCopy = descriptionDocument;
    if (localDescriptionDocumentCopy != null) {
      buffer.writeObject(localDescriptionDocumentCopy);
    }
    final localCommandsCopy = commands;
    if (localCommandsCopy != null) {
      buffer.writeVectorObject(localCommandsCopy);
    }
    final localMenuButtonCopy = menuButton;
    if (localMenuButtonCopy != null) {
      buffer.writeObject(localMenuButtonCopy);
    }

    // Finished serialization.
  }
}

/// Keyboard Button.
///
/// ID: `a2fa4880`.
class KeyboardButton extends KeyboardButtonBase {
  /// Keyboard Button constructor.
  const KeyboardButton({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory KeyboardButton.deserialize(BinaryReader reader) {
    // Read [KeyboardButton] fields.
    final text = reader.readString();

    // Construct [KeyboardButton] object.
    final returnValue = KeyboardButton(
      text: text,
    );

    // Now return the deserialized [KeyboardButton].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa2fa4880.
    buffer.writeInt32(0xa2fa4880);

    // Write fields.
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Keyboard Button Url.
///
/// ID: `258aff05`.
class KeyboardButtonUrl extends KeyboardButtonBase {
  /// Keyboard Button Url constructor.
  const KeyboardButtonUrl({
    required this.text,
    required this.url,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonUrl.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonUrl] fields.
    final text = reader.readString();
    final url = reader.readString();

    // Construct [KeyboardButtonUrl] object.
    final returnValue = KeyboardButtonUrl(
      text: text,
      url: url,
    );

    // Now return the deserialized [KeyboardButtonUrl].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x258aff05.
    buffer.writeInt32(0x258aff05);

    // Write fields.
    buffer.writeString(text);
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Keyboard Button Callback.
///
/// ID: `35bbdb6b`.
class KeyboardButtonCallback extends KeyboardButtonBase {
  /// Keyboard Button Callback constructor.
  const KeyboardButtonCallback({
    required this.requiresPassword,
    required this.text,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonCallback.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonCallback] fields.
    final flags = reader.readInt32();
    final requiresPassword = (flags & 1) != 0;
    final text = reader.readString();
    final data = reader.readBytes();

    // Construct [KeyboardButtonCallback] object.
    final returnValue = KeyboardButtonCallback(
      requiresPassword: requiresPassword,
      text: text,
      data: data,
    );

    // Now return the deserialized [KeyboardButtonCallback].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: requiresPassword,
    );

    return v;
  }

  /// requires_password: bit 0 of flags.0?true
  final bool requiresPassword;

  /// Text.
  final String text;

  /// Data.
  final Uint8List data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x35bbdb6b.
    buffer.writeInt32(0x35bbdb6b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(text);
    buffer.writeBytes(data);

    // Finished serialization.
  }
}

/// Keyboard Button Request Phone.
///
/// ID: `b16a6c29`.
class KeyboardButtonRequestPhone extends KeyboardButtonBase {
  /// Keyboard Button Request Phone constructor.
  const KeyboardButtonRequestPhone({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonRequestPhone.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonRequestPhone] fields.
    final text = reader.readString();

    // Construct [KeyboardButtonRequestPhone] object.
    final returnValue = KeyboardButtonRequestPhone(
      text: text,
    );

    // Now return the deserialized [KeyboardButtonRequestPhone].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb16a6c29.
    buffer.writeInt32(0xb16a6c29);

    // Write fields.
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Keyboard Button Request Geo Location.
///
/// ID: `fc796b3f`.
class KeyboardButtonRequestGeoLocation extends KeyboardButtonBase {
  /// Keyboard Button Request Geo Location constructor.
  const KeyboardButtonRequestGeoLocation({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonRequestGeoLocation.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonRequestGeoLocation] fields.
    final text = reader.readString();

    // Construct [KeyboardButtonRequestGeoLocation] object.
    final returnValue = KeyboardButtonRequestGeoLocation(
      text: text,
    );

    // Now return the deserialized [KeyboardButtonRequestGeoLocation].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfc796b3f.
    buffer.writeInt32(0xfc796b3f);

    // Write fields.
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Keyboard Button Switch Inline.
///
/// ID: `93b9fbb5`.
class KeyboardButtonSwitchInline extends KeyboardButtonBase {
  /// Keyboard Button Switch Inline constructor.
  const KeyboardButtonSwitchInline({
    required this.samePeer,
    required this.text,
    required this.query,
    this.peerTypes,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonSwitchInline.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonSwitchInline] fields.
    final flags = reader.readInt32();
    final samePeer = (flags & 1) != 0;
    final text = reader.readString();
    final query = reader.readString();
    final hasPeerTypesField = (flags & 2) != 0;
    final peerTypes = hasPeerTypesField
        ? reader.readVectorObject<InlineQueryPeerTypeBase>()
        : null;

    // Construct [KeyboardButtonSwitchInline] object.
    final returnValue = KeyboardButtonSwitchInline(
      samePeer: samePeer,
      text: text,
      query: query,
      peerTypes: peerTypes,
    );

    // Now return the deserialized [KeyboardButtonSwitchInline].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: samePeer,
      b01: peerTypes != null,
    );

    return v;
  }

  /// same_peer: bit 0 of flags.0?true
  final bool samePeer;

  /// Text.
  final String text;

  /// Query.
  final String query;

  /// Peer Types.
  final List<InlineQueryPeerTypeBase>? peerTypes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x93b9fbb5.
    buffer.writeInt32(0x93b9fbb5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(text);
    buffer.writeString(query);
    final localPeerTypesCopy = peerTypes;
    if (localPeerTypesCopy != null) {
      buffer.writeVectorObject(localPeerTypesCopy);
    }

    // Finished serialization.
  }
}

/// Keyboard Button Game.
///
/// ID: `50f41ccf`.
class KeyboardButtonGame extends KeyboardButtonBase {
  /// Keyboard Button Game constructor.
  const KeyboardButtonGame({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonGame.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonGame] fields.
    final text = reader.readString();

    // Construct [KeyboardButtonGame] object.
    final returnValue = KeyboardButtonGame(
      text: text,
    );

    // Now return the deserialized [KeyboardButtonGame].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x50f41ccf.
    buffer.writeInt32(0x50f41ccf);

    // Write fields.
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Keyboard Button Buy.
///
/// ID: `afd93fbb`.
class KeyboardButtonBuy extends KeyboardButtonBase {
  /// Keyboard Button Buy constructor.
  const KeyboardButtonBuy({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonBuy.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonBuy] fields.
    final text = reader.readString();

    // Construct [KeyboardButtonBuy] object.
    final returnValue = KeyboardButtonBuy(
      text: text,
    );

    // Now return the deserialized [KeyboardButtonBuy].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xafd93fbb.
    buffer.writeInt32(0xafd93fbb);

    // Write fields.
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Keyboard Button Url Auth.
///
/// ID: `10b78d29`.
class KeyboardButtonUrlAuth extends KeyboardButtonBase {
  /// Keyboard Button Url Auth constructor.
  const KeyboardButtonUrlAuth({
    required this.text,
    this.fwdText,
    required this.url,
    required this.buttonId,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonUrlAuth.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonUrlAuth] fields.
    final flags = reader.readInt32();
    final text = reader.readString();
    final hasFwdTextField = (flags & 1) != 0;
    final fwdText = hasFwdTextField ? reader.readString() : null;
    final url = reader.readString();
    final buttonId = reader.readInt32();

    // Construct [KeyboardButtonUrlAuth] object.
    final returnValue = KeyboardButtonUrlAuth(
      text: text,
      fwdText: fwdText,
      url: url,
      buttonId: buttonId,
    );

    // Now return the deserialized [KeyboardButtonUrlAuth].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: fwdText != null,
    );

    return v;
  }

  /// Text.
  final String text;

  /// Fwd Text.
  final String? fwdText;

  /// Url.
  final String url;

  /// Button Id.
  ///
  /// Field type is Int32.
  final int buttonId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x10b78d29.
    buffer.writeInt32(0x10b78d29);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(text);
    final localFwdTextCopy = fwdText;
    if (localFwdTextCopy != null) {
      buffer.writeString(localFwdTextCopy);
    }
    buffer.writeString(url);
    buffer.writeInt32(buttonId);

    // Finished serialization.
  }
}

/// Input Keyboard Button Url Auth.
///
/// ID: `d02e7fd4`.
class InputKeyboardButtonUrlAuth extends KeyboardButtonBase {
  /// Input Keyboard Button Url Auth constructor.
  const InputKeyboardButtonUrlAuth({
    required this.requestWriteAccess,
    required this.text,
    this.fwdText,
    required this.url,
    required this.bot,
  }) : super._();

  /// Deserialize.
  factory InputKeyboardButtonUrlAuth.deserialize(BinaryReader reader) {
    // Read [InputKeyboardButtonUrlAuth] fields.
    final flags = reader.readInt32();
    final requestWriteAccess = (flags & 1) != 0;
    final text = reader.readString();
    final hasFwdTextField = (flags & 2) != 0;
    final fwdText = hasFwdTextField ? reader.readString() : null;
    final url = reader.readString();
    final bot = reader.readObject() as InputUserBase;

    // Construct [InputKeyboardButtonUrlAuth] object.
    final returnValue = InputKeyboardButtonUrlAuth(
      requestWriteAccess: requestWriteAccess,
      text: text,
      fwdText: fwdText,
      url: url,
      bot: bot,
    );

    // Now return the deserialized [InputKeyboardButtonUrlAuth].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: requestWriteAccess,
      b01: fwdText != null,
    );

    return v;
  }

  /// request_write_access: bit 0 of flags.0?true
  final bool requestWriteAccess;

  /// Text.
  final String text;

  /// Fwd Text.
  final String? fwdText;

  /// Url.
  final String url;

  /// Bot.
  final InputUserBase bot;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd02e7fd4.
    buffer.writeInt32(0xd02e7fd4);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(text);
    final localFwdTextCopy = fwdText;
    if (localFwdTextCopy != null) {
      buffer.writeString(localFwdTextCopy);
    }
    buffer.writeString(url);
    buffer.writeObject(bot);

    // Finished serialization.
  }
}

/// Keyboard Button Request Poll.
///
/// ID: `bbc7515d`.
class KeyboardButtonRequestPoll extends KeyboardButtonBase {
  /// Keyboard Button Request Poll constructor.
  const KeyboardButtonRequestPoll({
    required this.quiz,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonRequestPoll.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonRequestPoll] fields.
    final flags = reader.readInt32();
    final quiz = (flags & 1) != 0;
    final text = reader.readString();

    // Construct [KeyboardButtonRequestPoll] object.
    final returnValue = KeyboardButtonRequestPoll(
      quiz: quiz,
      text: text,
    );

    // Now return the deserialized [KeyboardButtonRequestPoll].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: quiz,
    );

    return v;
  }

  /// quiz: bit 0 of flags.0?Bool
  final bool quiz;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbbc7515d.
    buffer.writeInt32(0xbbc7515d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Input Keyboard Button User Profile.
///
/// ID: `e988037b`.
class InputKeyboardButtonUserProfile extends KeyboardButtonBase {
  /// Input Keyboard Button User Profile constructor.
  const InputKeyboardButtonUserProfile({
    required this.text,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory InputKeyboardButtonUserProfile.deserialize(BinaryReader reader) {
    // Read [InputKeyboardButtonUserProfile] fields.
    final text = reader.readString();
    final userId = reader.readObject() as InputUserBase;

    // Construct [InputKeyboardButtonUserProfile] object.
    final returnValue = InputKeyboardButtonUserProfile(
      text: text,
      userId: userId,
    );

    // Now return the deserialized [InputKeyboardButtonUserProfile].
    return returnValue;
  }

  /// Text.
  final String text;

  /// User Id.
  final InputUserBase userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe988037b.
    buffer.writeInt32(0xe988037b);

    // Write fields.
    buffer.writeString(text);
    buffer.writeObject(userId);

    // Finished serialization.
  }
}

/// Keyboard Button User Profile.
///
/// ID: `308660c1`.
class KeyboardButtonUserProfile extends KeyboardButtonBase {
  /// Keyboard Button User Profile constructor.
  const KeyboardButtonUserProfile({
    required this.text,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonUserProfile.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonUserProfile] fields.
    final text = reader.readString();
    final userId = reader.readInt64();

    // Construct [KeyboardButtonUserProfile] object.
    final returnValue = KeyboardButtonUserProfile(
      text: text,
      userId: userId,
    );

    // Now return the deserialized [KeyboardButtonUserProfile].
    return returnValue;
  }

  /// Text.
  final String text;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x308660c1.
    buffer.writeInt32(0x308660c1);

    // Write fields.
    buffer.writeString(text);
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Keyboard Button Web View.
///
/// ID: `13767230`.
class KeyboardButtonWebView extends KeyboardButtonBase {
  /// Keyboard Button Web View constructor.
  const KeyboardButtonWebView({
    required this.text,
    required this.url,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonWebView.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonWebView] fields.
    final text = reader.readString();
    final url = reader.readString();

    // Construct [KeyboardButtonWebView] object.
    final returnValue = KeyboardButtonWebView(
      text: text,
      url: url,
    );

    // Now return the deserialized [KeyboardButtonWebView].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x13767230.
    buffer.writeInt32(0x13767230);

    // Write fields.
    buffer.writeString(text);
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Keyboard Button Simple Web View.
///
/// ID: `a0c0505c`.
class KeyboardButtonSimpleWebView extends KeyboardButtonBase {
  /// Keyboard Button Simple Web View constructor.
  const KeyboardButtonSimpleWebView({
    required this.text,
    required this.url,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonSimpleWebView.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonSimpleWebView] fields.
    final text = reader.readString();
    final url = reader.readString();

    // Construct [KeyboardButtonSimpleWebView] object.
    final returnValue = KeyboardButtonSimpleWebView(
      text: text,
      url: url,
    );

    // Now return the deserialized [KeyboardButtonSimpleWebView].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa0c0505c.
    buffer.writeInt32(0xa0c0505c);

    // Write fields.
    buffer.writeString(text);
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Keyboard Button Request Peer.
///
/// ID: `53d7bfd8`.
class KeyboardButtonRequestPeer extends KeyboardButtonBase {
  /// Keyboard Button Request Peer constructor.
  const KeyboardButtonRequestPeer({
    required this.text,
    required this.buttonId,
    required this.peerType,
    required this.maxQuantity,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonRequestPeer.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonRequestPeer] fields.
    final text = reader.readString();
    final buttonId = reader.readInt32();
    final peerType = reader.readObject() as RequestPeerTypeBase;
    final maxQuantity = reader.readInt32();

    // Construct [KeyboardButtonRequestPeer] object.
    final returnValue = KeyboardButtonRequestPeer(
      text: text,
      buttonId: buttonId,
      peerType: peerType,
      maxQuantity: maxQuantity,
    );

    // Now return the deserialized [KeyboardButtonRequestPeer].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Button Id.
  ///
  /// Field type is Int32.
  final int buttonId;

  /// Peer Type.
  final RequestPeerTypeBase peerType;

  /// Max Quantity.
  ///
  /// Field type is Int32.
  final int maxQuantity;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x53d7bfd8.
    buffer.writeInt32(0x53d7bfd8);

    // Write fields.
    buffer.writeString(text);
    buffer.writeInt32(buttonId);
    buffer.writeObject(peerType);
    buffer.writeInt32(maxQuantity);

    // Finished serialization.
  }
}

/// Keyboard Button Row.
///
/// ID: `77608b83`.
class KeyboardButtonRow extends KeyboardButtonRowBase {
  /// Keyboard Button Row constructor.
  const KeyboardButtonRow({
    required this.buttons,
  }) : super._();

  /// Deserialize.
  factory KeyboardButtonRow.deserialize(BinaryReader reader) {
    // Read [KeyboardButtonRow] fields.
    final buttons = reader.readVectorObject<KeyboardButtonBase>();

    // Construct [KeyboardButtonRow] object.
    final returnValue = KeyboardButtonRow(
      buttons: buttons,
    );

    // Now return the deserialized [KeyboardButtonRow].
    return returnValue;
  }

  /// Buttons.
  final List<KeyboardButtonBase> buttons;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x77608b83.
    buffer.writeInt32(0x77608b83);

    // Write fields.
    buffer.writeVectorObject(buttons);

    // Finished serialization.
  }
}

/// Reply Keyboard Hide.
///
/// ID: `a03e5b85`.
class ReplyKeyboardHide extends ReplyMarkupBase {
  /// Reply Keyboard Hide constructor.
  const ReplyKeyboardHide({
    required this.selective,
  }) : super._();

  /// Deserialize.
  factory ReplyKeyboardHide.deserialize(BinaryReader reader) {
    // Read [ReplyKeyboardHide] fields.
    final flags = reader.readInt32();
    final selective = (flags & 4) != 0;

    // Construct [ReplyKeyboardHide] object.
    final returnValue = ReplyKeyboardHide(
      selective: selective,
    );

    // Now return the deserialized [ReplyKeyboardHide].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: selective,
    );

    return v;
  }

  /// selective: bit 2 of flags.2?true
  final bool selective;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa03e5b85.
    buffer.writeInt32(0xa03e5b85);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Reply Keyboard Force Reply.
///
/// ID: `86b40b08`.
class ReplyKeyboardForceReply extends ReplyMarkupBase {
  /// Reply Keyboard Force Reply constructor.
  const ReplyKeyboardForceReply({
    required this.singleUse,
    required this.selective,
    this.placeholder,
  }) : super._();

  /// Deserialize.
  factory ReplyKeyboardForceReply.deserialize(BinaryReader reader) {
    // Read [ReplyKeyboardForceReply] fields.
    final flags = reader.readInt32();
    final singleUse = (flags & 2) != 0;
    final selective = (flags & 4) != 0;
    final hasPlaceholderField = (flags & 8) != 0;
    final placeholder = hasPlaceholderField ? reader.readString() : null;

    // Construct [ReplyKeyboardForceReply] object.
    final returnValue = ReplyKeyboardForceReply(
      singleUse: singleUse,
      selective: selective,
      placeholder: placeholder,
    );

    // Now return the deserialized [ReplyKeyboardForceReply].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: singleUse,
      b02: selective,
      b03: placeholder != null,
    );

    return v;
  }

  /// single_use: bit 1 of flags.1?true
  final bool singleUse;

  /// selective: bit 2 of flags.2?true
  final bool selective;

  /// Placeholder.
  final String? placeholder;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x86b40b08.
    buffer.writeInt32(0x86b40b08);

    // Write fields.
    buffer.writeInt32(flags);
    final localPlaceholderCopy = placeholder;
    if (localPlaceholderCopy != null) {
      buffer.writeString(localPlaceholderCopy);
    }

    // Finished serialization.
  }
}

/// Reply Keyboard Markup.
///
/// ID: `85dd99d1`.
class ReplyKeyboardMarkup extends ReplyMarkupBase {
  /// Reply Keyboard Markup constructor.
  const ReplyKeyboardMarkup({
    required this.resize,
    required this.singleUse,
    required this.selective,
    required this.persistent,
    required this.rows,
    this.placeholder,
  }) : super._();

  /// Deserialize.
  factory ReplyKeyboardMarkup.deserialize(BinaryReader reader) {
    // Read [ReplyKeyboardMarkup] fields.
    final flags = reader.readInt32();
    final resize = (flags & 1) != 0;
    final singleUse = (flags & 2) != 0;
    final selective = (flags & 4) != 0;
    final persistent = (flags & 16) != 0;
    final rows = reader.readVectorObject<KeyboardButtonRowBase>();
    final hasPlaceholderField = (flags & 8) != 0;
    final placeholder = hasPlaceholderField ? reader.readString() : null;

    // Construct [ReplyKeyboardMarkup] object.
    final returnValue = ReplyKeyboardMarkup(
      resize: resize,
      singleUse: singleUse,
      selective: selective,
      persistent: persistent,
      rows: rows,
      placeholder: placeholder,
    );

    // Now return the deserialized [ReplyKeyboardMarkup].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: resize,
      b01: singleUse,
      b02: selective,
      b04: persistent,
      b03: placeholder != null,
    );

    return v;
  }

  /// resize: bit 0 of flags.0?true
  final bool resize;

  /// single_use: bit 1 of flags.1?true
  final bool singleUse;

  /// selective: bit 2 of flags.2?true
  final bool selective;

  /// persistent: bit 4 of flags.4?true
  final bool persistent;

  /// Rows.
  final List<KeyboardButtonRowBase> rows;

  /// Placeholder.
  final String? placeholder;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x85dd99d1.
    buffer.writeInt32(0x85dd99d1);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(rows);
    final localPlaceholderCopy = placeholder;
    if (localPlaceholderCopy != null) {
      buffer.writeString(localPlaceholderCopy);
    }

    // Finished serialization.
  }
}

/// Reply Inline Markup.
///
/// ID: `48a30254`.
class ReplyInlineMarkup extends ReplyMarkupBase {
  /// Reply Inline Markup constructor.
  const ReplyInlineMarkup({
    required this.rows,
  }) : super._();

  /// Deserialize.
  factory ReplyInlineMarkup.deserialize(BinaryReader reader) {
    // Read [ReplyInlineMarkup] fields.
    final rows = reader.readVectorObject<KeyboardButtonRowBase>();

    // Construct [ReplyInlineMarkup] object.
    final returnValue = ReplyInlineMarkup(
      rows: rows,
    );

    // Now return the deserialized [ReplyInlineMarkup].
    return returnValue;
  }

  /// Rows.
  final List<KeyboardButtonRowBase> rows;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x48a30254.
    buffer.writeInt32(0x48a30254);

    // Write fields.
    buffer.writeVectorObject(rows);

    // Finished serialization.
  }
}

/// Message Entity Unknown.
///
/// ID: `bb92ba95`.
class MessageEntityUnknown extends MessageEntityBase {
  /// Message Entity Unknown constructor.
  const MessageEntityUnknown({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityUnknown.deserialize(BinaryReader reader) {
    // Read [MessageEntityUnknown] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityUnknown] object.
    final returnValue = MessageEntityUnknown(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityUnknown].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbb92ba95.
    buffer.writeInt32(0xbb92ba95);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Mention.
///
/// ID: `fa04579d`.
class MessageEntityMention extends MessageEntityBase {
  /// Message Entity Mention constructor.
  const MessageEntityMention({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityMention.deserialize(BinaryReader reader) {
    // Read [MessageEntityMention] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityMention] object.
    final returnValue = MessageEntityMention(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityMention].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfa04579d.
    buffer.writeInt32(0xfa04579d);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Hashtag.
///
/// ID: `6f635b0d`.
class MessageEntityHashtag extends MessageEntityBase {
  /// Message Entity Hashtag constructor.
  const MessageEntityHashtag({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityHashtag.deserialize(BinaryReader reader) {
    // Read [MessageEntityHashtag] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityHashtag] object.
    final returnValue = MessageEntityHashtag(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityHashtag].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6f635b0d.
    buffer.writeInt32(0x6f635b0d);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Bot Command.
///
/// ID: `6cef8ac7`.
class MessageEntityBotCommand extends MessageEntityBase {
  /// Message Entity Bot Command constructor.
  const MessageEntityBotCommand({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityBotCommand.deserialize(BinaryReader reader) {
    // Read [MessageEntityBotCommand] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityBotCommand] object.
    final returnValue = MessageEntityBotCommand(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityBotCommand].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6cef8ac7.
    buffer.writeInt32(0x6cef8ac7);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Url.
///
/// ID: `6ed02538`.
class MessageEntityUrl extends MessageEntityBase {
  /// Message Entity Url constructor.
  const MessageEntityUrl({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityUrl.deserialize(BinaryReader reader) {
    // Read [MessageEntityUrl] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityUrl] object.
    final returnValue = MessageEntityUrl(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityUrl].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6ed02538.
    buffer.writeInt32(0x6ed02538);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Email.
///
/// ID: `64e475c2`.
class MessageEntityEmail extends MessageEntityBase {
  /// Message Entity Email constructor.
  const MessageEntityEmail({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityEmail.deserialize(BinaryReader reader) {
    // Read [MessageEntityEmail] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityEmail] object.
    final returnValue = MessageEntityEmail(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityEmail].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x64e475c2.
    buffer.writeInt32(0x64e475c2);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Bold.
///
/// ID: `bd610bc9`.
class MessageEntityBold extends MessageEntityBase {
  /// Message Entity Bold constructor.
  const MessageEntityBold({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityBold.deserialize(BinaryReader reader) {
    // Read [MessageEntityBold] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityBold] object.
    final returnValue = MessageEntityBold(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityBold].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbd610bc9.
    buffer.writeInt32(0xbd610bc9);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Italic.
///
/// ID: `826f8b60`.
class MessageEntityItalic extends MessageEntityBase {
  /// Message Entity Italic constructor.
  const MessageEntityItalic({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityItalic.deserialize(BinaryReader reader) {
    // Read [MessageEntityItalic] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityItalic] object.
    final returnValue = MessageEntityItalic(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityItalic].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x826f8b60.
    buffer.writeInt32(0x826f8b60);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Code.
///
/// ID: `28a20571`.
class MessageEntityCode extends MessageEntityBase {
  /// Message Entity Code constructor.
  const MessageEntityCode({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityCode.deserialize(BinaryReader reader) {
    // Read [MessageEntityCode] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityCode] object.
    final returnValue = MessageEntityCode(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityCode].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x28a20571.
    buffer.writeInt32(0x28a20571);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Pre.
///
/// ID: `73924be0`.
class MessageEntityPre extends MessageEntityBase {
  /// Message Entity Pre constructor.
  const MessageEntityPre({
    required this.offset,
    required this.length,
    required this.language,
  }) : super._();

  /// Deserialize.
  factory MessageEntityPre.deserialize(BinaryReader reader) {
    // Read [MessageEntityPre] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();
    final language = reader.readString();

    // Construct [MessageEntityPre] object.
    final returnValue = MessageEntityPre(
      offset: offset,
      length: length,
      language: language,
    );

    // Now return the deserialized [MessageEntityPre].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Language.
  final String language;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x73924be0.
    buffer.writeInt32(0x73924be0);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);
    buffer.writeString(language);

    // Finished serialization.
  }
}

/// Message Entity Text Url.
///
/// ID: `76a6d327`.
class MessageEntityTextUrl extends MessageEntityBase {
  /// Message Entity Text Url constructor.
  const MessageEntityTextUrl({
    required this.offset,
    required this.length,
    required this.url,
  }) : super._();

  /// Deserialize.
  factory MessageEntityTextUrl.deserialize(BinaryReader reader) {
    // Read [MessageEntityTextUrl] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();
    final url = reader.readString();

    // Construct [MessageEntityTextUrl] object.
    final returnValue = MessageEntityTextUrl(
      offset: offset,
      length: length,
      url: url,
    );

    // Now return the deserialized [MessageEntityTextUrl].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x76a6d327.
    buffer.writeInt32(0x76a6d327);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Message Entity Mention Name.
///
/// ID: `dc7b1140`.
class MessageEntityMentionName extends MessageEntityBase {
  /// Message Entity Mention Name constructor.
  const MessageEntityMentionName({
    required this.offset,
    required this.length,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory MessageEntityMentionName.deserialize(BinaryReader reader) {
    // Read [MessageEntityMentionName] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();
    final userId = reader.readInt64();

    // Construct [MessageEntityMentionName] object.
    final returnValue = MessageEntityMentionName(
      offset: offset,
      length: length,
      userId: userId,
    );

    // Now return the deserialized [MessageEntityMentionName].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdc7b1140.
    buffer.writeInt32(0xdc7b1140);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Input Message Entity Mention Name.
///
/// ID: `208e68c9`.
class InputMessageEntityMentionName extends MessageEntityBase {
  /// Input Message Entity Mention Name constructor.
  const InputMessageEntityMentionName({
    required this.offset,
    required this.length,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory InputMessageEntityMentionName.deserialize(BinaryReader reader) {
    // Read [InputMessageEntityMentionName] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();
    final userId = reader.readObject() as InputUserBase;

    // Construct [InputMessageEntityMentionName] object.
    final returnValue = InputMessageEntityMentionName(
      offset: offset,
      length: length,
      userId: userId,
    );

    // Now return the deserialized [InputMessageEntityMentionName].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// User Id.
  final InputUserBase userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x208e68c9.
    buffer.writeInt32(0x208e68c9);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);
    buffer.writeObject(userId);

    // Finished serialization.
  }
}

/// Message Entity Phone.
///
/// ID: `9b69e34b`.
class MessageEntityPhone extends MessageEntityBase {
  /// Message Entity Phone constructor.
  const MessageEntityPhone({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityPhone.deserialize(BinaryReader reader) {
    // Read [MessageEntityPhone] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityPhone] object.
    final returnValue = MessageEntityPhone(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityPhone].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9b69e34b.
    buffer.writeInt32(0x9b69e34b);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Cashtag.
///
/// ID: `4c4e743f`.
class MessageEntityCashtag extends MessageEntityBase {
  /// Message Entity Cashtag constructor.
  const MessageEntityCashtag({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityCashtag.deserialize(BinaryReader reader) {
    // Read [MessageEntityCashtag] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityCashtag] object.
    final returnValue = MessageEntityCashtag(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityCashtag].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4c4e743f.
    buffer.writeInt32(0x4c4e743f);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Underline.
///
/// ID: `9c4e7e8b`.
class MessageEntityUnderline extends MessageEntityBase {
  /// Message Entity Underline constructor.
  const MessageEntityUnderline({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityUnderline.deserialize(BinaryReader reader) {
    // Read [MessageEntityUnderline] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityUnderline] object.
    final returnValue = MessageEntityUnderline(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityUnderline].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9c4e7e8b.
    buffer.writeInt32(0x9c4e7e8b);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Strike.
///
/// ID: `bf0693d4`.
class MessageEntityStrike extends MessageEntityBase {
  /// Message Entity Strike constructor.
  const MessageEntityStrike({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityStrike.deserialize(BinaryReader reader) {
    // Read [MessageEntityStrike] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityStrike] object.
    final returnValue = MessageEntityStrike(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityStrike].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbf0693d4.
    buffer.writeInt32(0xbf0693d4);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Bank Card.
///
/// ID: `761e6af4`.
class MessageEntityBankCard extends MessageEntityBase {
  /// Message Entity Bank Card constructor.
  const MessageEntityBankCard({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityBankCard.deserialize(BinaryReader reader) {
    // Read [MessageEntityBankCard] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityBankCard] object.
    final returnValue = MessageEntityBankCard(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityBankCard].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x761e6af4.
    buffer.writeInt32(0x761e6af4);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Spoiler.
///
/// ID: `32ca960f`.
class MessageEntitySpoiler extends MessageEntityBase {
  /// Message Entity Spoiler constructor.
  const MessageEntitySpoiler({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntitySpoiler.deserialize(BinaryReader reader) {
    // Read [MessageEntitySpoiler] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntitySpoiler] object.
    final returnValue = MessageEntitySpoiler(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntitySpoiler].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x32ca960f.
    buffer.writeInt32(0x32ca960f);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Message Entity Custom Emoji.
///
/// ID: `c8cf05f8`.
class MessageEntityCustomEmoji extends MessageEntityBase {
  /// Message Entity Custom Emoji constructor.
  const MessageEntityCustomEmoji({
    required this.offset,
    required this.length,
    required this.documentId,
  }) : super._();

  /// Deserialize.
  factory MessageEntityCustomEmoji.deserialize(BinaryReader reader) {
    // Read [MessageEntityCustomEmoji] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();
    final documentId = reader.readInt64();

    // Construct [MessageEntityCustomEmoji] object.
    final returnValue = MessageEntityCustomEmoji(
      offset: offset,
      length: length,
      documentId: documentId,
    );

    // Now return the deserialized [MessageEntityCustomEmoji].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Document Id.
  ///
  /// Field type is Int64.
  final int documentId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc8cf05f8.
    buffer.writeInt32(0xc8cf05f8);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);
    buffer.writeInt64(documentId);

    // Finished serialization.
  }
}

/// Message Entity Blockquote.
///
/// ID: `020df5d0`.
class MessageEntityBlockquote extends MessageEntityBase {
  /// Message Entity Blockquote constructor.
  const MessageEntityBlockquote({
    required this.offset,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory MessageEntityBlockquote.deserialize(BinaryReader reader) {
    // Read [MessageEntityBlockquote] fields.
    final offset = reader.readInt32();
    final length = reader.readInt32();

    // Construct [MessageEntityBlockquote] object.
    final returnValue = MessageEntityBlockquote(
      offset: offset,
      length: length,
    );

    // Now return the deserialized [MessageEntityBlockquote].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x020df5d0.
    buffer.writeInt32(0x020df5d0);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Input Channel Empty.
///
/// ID: `ee8c1e86`.
class InputChannelEmpty extends InputChannelBase {
  /// Input Channel Empty constructor.
  const InputChannelEmpty() : super._();

  /// Deserialize.
  factory InputChannelEmpty.deserialize(BinaryReader reader) {
    // Construct [InputChannelEmpty] object.
    final returnValue = InputChannelEmpty();

    // Now return the deserialized [InputChannelEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xee8c1e86.
    buffer.writeInt32(0xee8c1e86);

    // Finished serialization.
  }
}

/// Input Channel.
///
/// ID: `f35aec28`.
class InputChannel extends InputChannelBase {
  /// Input Channel constructor.
  const InputChannel({
    required this.channelId,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputChannel.deserialize(BinaryReader reader) {
    // Read [InputChannel] fields.
    final channelId = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputChannel] object.
    final returnValue = InputChannel(
      channelId: channelId,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputChannel].
    return returnValue;
  }

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf35aec28.
    buffer.writeInt32(0xf35aec28);

    // Write fields.
    buffer.writeInt64(channelId);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Channel From Message.
///
/// ID: `5b934f9d`.
class InputChannelFromMessage extends InputChannelBase {
  /// Input Channel From Message constructor.
  const InputChannelFromMessage({
    required this.peer,
    required this.msgId,
    required this.channelId,
  }) : super._();

  /// Deserialize.
  factory InputChannelFromMessage.deserialize(BinaryReader reader) {
    // Read [InputChannelFromMessage] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final channelId = reader.readInt64();

    // Construct [InputChannelFromMessage] object.
    final returnValue = InputChannelFromMessage(
      peer: peer,
      msgId: msgId,
      channelId: channelId,
    );

    // Now return the deserialized [InputChannelFromMessage].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5b934f9d.
    buffer.writeInt32(0x5b934f9d);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeInt64(channelId);

    // Finished serialization.
  }
}

/// Contacts Resolved Peer.
///
/// ID: `7f077ad9`.
class ContactsResolvedPeer extends ContactsResolvedPeerBase {
  /// Contacts Resolved Peer constructor.
  const ContactsResolvedPeer({
    required this.peer,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ContactsResolvedPeer.deserialize(BinaryReader reader) {
    // Read [ContactsResolvedPeer] fields.
    final peer = reader.readObject() as PeerBase;
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ContactsResolvedPeer] object.
    final returnValue = ContactsResolvedPeer(
      peer: peer,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ContactsResolvedPeer].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7f077ad9.
    buffer.writeInt32(0x7f077ad9);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Message Range.
///
/// ID: `0ae30253`.
class MessageRange extends MessageRangeBase {
  /// Message Range constructor.
  const MessageRange({
    required this.minId,
    required this.maxId,
  }) : super._();

  /// Deserialize.
  factory MessageRange.deserialize(BinaryReader reader) {
    // Read [MessageRange] fields.
    final minId = reader.readInt32();
    final maxId = reader.readInt32();

    // Construct [MessageRange] object.
    final returnValue = MessageRange(
      minId: minId,
      maxId: maxId,
    );

    // Now return the deserialized [MessageRange].
    return returnValue;
  }

  /// Min Id.
  ///
  /// Field type is Int32.
  final int minId;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0ae30253.
    buffer.writeInt32(0x0ae30253);

    // Write fields.
    buffer.writeInt32(minId);
    buffer.writeInt32(maxId);

    // Finished serialization.
  }
}

/// Updates Channel Difference Empty.
///
/// ID: `3e11affb`.
class UpdatesChannelDifferenceEmpty extends UpdatesChannelDifferenceBase {
  /// Updates Channel Difference Empty constructor.
  const UpdatesChannelDifferenceEmpty({
    required this.ffinal,
    required this.pts,
    this.timeout,
  }) : super._();

  /// Deserialize.
  factory UpdatesChannelDifferenceEmpty.deserialize(BinaryReader reader) {
    // Read [UpdatesChannelDifferenceEmpty] fields.
    final flags = reader.readInt32();
    final ffinal = (flags & 1) != 0;
    final pts = reader.readInt32();
    final hasTimeoutField = (flags & 2) != 0;
    final timeout = hasTimeoutField ? reader.readInt32() : null;

    // Construct [UpdatesChannelDifferenceEmpty] object.
    final returnValue = UpdatesChannelDifferenceEmpty(
      ffinal: ffinal,
      pts: pts,
      timeout: timeout,
    );

    // Now return the deserialized [UpdatesChannelDifferenceEmpty].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: ffinal,
      b01: timeout != null,
    );

    return v;
  }

  /// final: bit 0 of flags.0?true
  final bool ffinal;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Timeout.
  final int? timeout;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3e11affb.
    buffer.writeInt32(0x3e11affb);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(pts);
    final localTimeoutCopy = timeout;
    if (localTimeoutCopy != null) {
      buffer.writeInt32(localTimeoutCopy);
    }

    // Finished serialization.
  }
}

/// Updates Channel Difference Too Long.
///
/// ID: `a4bcc6fe`.
class UpdatesChannelDifferenceTooLong extends UpdatesChannelDifferenceBase {
  /// Updates Channel Difference Too Long constructor.
  const UpdatesChannelDifferenceTooLong({
    required this.ffinal,
    this.timeout,
    required this.dialog,
    required this.messages,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory UpdatesChannelDifferenceTooLong.deserialize(BinaryReader reader) {
    // Read [UpdatesChannelDifferenceTooLong] fields.
    final flags = reader.readInt32();
    final ffinal = (flags & 1) != 0;
    final hasTimeoutField = (flags & 2) != 0;
    final timeout = hasTimeoutField ? reader.readInt32() : null;
    final dialog = reader.readObject() as DialogBase;
    final messages = reader.readVectorObject<MessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [UpdatesChannelDifferenceTooLong] object.
    final returnValue = UpdatesChannelDifferenceTooLong(
      ffinal: ffinal,
      timeout: timeout,
      dialog: dialog,
      messages: messages,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [UpdatesChannelDifferenceTooLong].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: ffinal,
      b01: timeout != null,
    );

    return v;
  }

  /// final: bit 0 of flags.0?true
  final bool ffinal;

  /// Timeout.
  final int? timeout;

  /// Dialog.
  final DialogBase dialog;

  /// Messages.
  final List<MessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa4bcc6fe.
    buffer.writeInt32(0xa4bcc6fe);

    // Write fields.
    buffer.writeInt32(flags);
    final localTimeoutCopy = timeout;
    if (localTimeoutCopy != null) {
      buffer.writeInt32(localTimeoutCopy);
    }
    buffer.writeObject(dialog);
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Updates Channel Difference.
///
/// ID: `2064674e`.
class UpdatesChannelDifference extends UpdatesChannelDifferenceBase {
  /// Updates Channel Difference constructor.
  const UpdatesChannelDifference({
    required this.ffinal,
    required this.pts,
    this.timeout,
    required this.newMessages,
    required this.otherUpdates,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory UpdatesChannelDifference.deserialize(BinaryReader reader) {
    // Read [UpdatesChannelDifference] fields.
    final flags = reader.readInt32();
    final ffinal = (flags & 1) != 0;
    final pts = reader.readInt32();
    final hasTimeoutField = (flags & 2) != 0;
    final timeout = hasTimeoutField ? reader.readInt32() : null;
    final newMessages = reader.readVectorObject<MessageBase>();
    final otherUpdates = reader.readVectorObject<UpdateBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [UpdatesChannelDifference] object.
    final returnValue = UpdatesChannelDifference(
      ffinal: ffinal,
      pts: pts,
      timeout: timeout,
      newMessages: newMessages,
      otherUpdates: otherUpdates,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [UpdatesChannelDifference].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: ffinal,
      b01: timeout != null,
    );

    return v;
  }

  /// final: bit 0 of flags.0?true
  final bool ffinal;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Timeout.
  final int? timeout;

  /// New Messages.
  final List<MessageBase> newMessages;

  /// Other Updates.
  final List<UpdateBase> otherUpdates;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2064674e.
    buffer.writeInt32(0x2064674e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(pts);
    final localTimeoutCopy = timeout;
    if (localTimeoutCopy != null) {
      buffer.writeInt32(localTimeoutCopy);
    }
    buffer.writeVectorObject(newMessages);
    buffer.writeVectorObject(otherUpdates);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Channel Messages Filter Empty.
///
/// ID: `94d42ee7`.
class ChannelMessagesFilterEmpty extends ChannelMessagesFilterBase {
  /// Channel Messages Filter Empty constructor.
  const ChannelMessagesFilterEmpty() : super._();

  /// Deserialize.
  factory ChannelMessagesFilterEmpty.deserialize(BinaryReader reader) {
    // Construct [ChannelMessagesFilterEmpty] object.
    final returnValue = ChannelMessagesFilterEmpty();

    // Now return the deserialized [ChannelMessagesFilterEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x94d42ee7.
    buffer.writeInt32(0x94d42ee7);

    // Finished serialization.
  }
}

/// Channel Messages Filter.
///
/// ID: `cd77d957`.
class ChannelMessagesFilter extends ChannelMessagesFilterBase {
  /// Channel Messages Filter constructor.
  const ChannelMessagesFilter({
    required this.excludeNewMessages,
    required this.ranges,
  }) : super._();

  /// Deserialize.
  factory ChannelMessagesFilter.deserialize(BinaryReader reader) {
    // Read [ChannelMessagesFilter] fields.
    final flags = reader.readInt32();
    final excludeNewMessages = (flags & 2) != 0;
    final ranges = reader.readVectorObject<MessageRangeBase>();

    // Construct [ChannelMessagesFilter] object.
    final returnValue = ChannelMessagesFilter(
      excludeNewMessages: excludeNewMessages,
      ranges: ranges,
    );

    // Now return the deserialized [ChannelMessagesFilter].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: excludeNewMessages,
    );

    return v;
  }

  /// exclude_new_messages: bit 1 of flags.1?true
  final bool excludeNewMessages;

  /// Ranges.
  final List<MessageRangeBase> ranges;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcd77d957.
    buffer.writeInt32(0xcd77d957);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(ranges);

    // Finished serialization.
  }
}

/// Channel Participant.
///
/// ID: `c00c07c0`.
class ChannelParticipant extends ChannelParticipantBase {
  /// Channel Participant constructor.
  const ChannelParticipant({
    required this.userId,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipant.deserialize(BinaryReader reader) {
    // Read [ChannelParticipant] fields.
    final userId = reader.readInt64();
    final date = reader.readDateTime();

    // Construct [ChannelParticipant] object.
    final returnValue = ChannelParticipant(
      userId: userId,
      date: date,
    );

    // Now return the deserialized [ChannelParticipant].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc00c07c0.
    buffer.writeInt32(0xc00c07c0);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Channel Participant Self.
///
/// ID: `35a8bfa7`.
class ChannelParticipantSelf extends ChannelParticipantBase {
  /// Channel Participant Self constructor.
  const ChannelParticipantSelf({
    required this.viaRequest,
    required this.userId,
    required this.inviterId,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipantSelf.deserialize(BinaryReader reader) {
    // Read [ChannelParticipantSelf] fields.
    final flags = reader.readInt32();
    final viaRequest = (flags & 1) != 0;
    final userId = reader.readInt64();
    final inviterId = reader.readInt64();
    final date = reader.readDateTime();

    // Construct [ChannelParticipantSelf] object.
    final returnValue = ChannelParticipantSelf(
      viaRequest: viaRequest,
      userId: userId,
      inviterId: inviterId,
      date: date,
    );

    // Now return the deserialized [ChannelParticipantSelf].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: viaRequest,
    );

    return v;
  }

  /// via_request: bit 0 of flags.0?true
  final bool viaRequest;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Inviter Id.
  ///
  /// Field type is Int64.
  final int inviterId;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x35a8bfa7.
    buffer.writeInt32(0x35a8bfa7);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(userId);
    buffer.writeInt64(inviterId);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Channel Participant Creator.
///
/// ID: `2fe601d3`.
class ChannelParticipantCreator extends ChannelParticipantBase {
  /// Channel Participant Creator constructor.
  const ChannelParticipantCreator({
    required this.userId,
    required this.adminRights,
    this.rank,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipantCreator.deserialize(BinaryReader reader) {
    // Read [ChannelParticipantCreator] fields.
    final flags = reader.readInt32();
    final userId = reader.readInt64();
    final adminRights = reader.readObject() as ChatAdminRightsBase;
    final hasRankField = (flags & 1) != 0;
    final rank = hasRankField ? reader.readString() : null;

    // Construct [ChannelParticipantCreator] object.
    final returnValue = ChannelParticipantCreator(
      userId: userId,
      adminRights: adminRights,
      rank: rank,
    );

    // Now return the deserialized [ChannelParticipantCreator].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: rank != null,
    );

    return v;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Admin Rights.
  final ChatAdminRightsBase adminRights;

  /// Rank.
  final String? rank;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2fe601d3.
    buffer.writeInt32(0x2fe601d3);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(userId);
    buffer.writeObject(adminRights);
    final localRankCopy = rank;
    if (localRankCopy != null) {
      buffer.writeString(localRankCopy);
    }

    // Finished serialization.
  }
}

/// Channel Participant Admin.
///
/// ID: `34c3bb53`.
class ChannelParticipantAdmin extends ChannelParticipantBase {
  /// Channel Participant Admin constructor.
  const ChannelParticipantAdmin({
    required this.canEdit,
    required this.self,
    required this.userId,
    this.inviterId,
    required this.promotedBy,
    required this.date,
    required this.adminRights,
    this.rank,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipantAdmin.deserialize(BinaryReader reader) {
    // Read [ChannelParticipantAdmin] fields.
    final flags = reader.readInt32();
    final canEdit = (flags & 1) != 0;
    final self = (flags & 2) != 0;
    final userId = reader.readInt64();
    final hasInviterIdField = (flags & 2) != 0;
    final inviterId = hasInviterIdField ? reader.readInt64() : null;
    final promotedBy = reader.readInt64();
    final date = reader.readDateTime();
    final adminRights = reader.readObject() as ChatAdminRightsBase;
    final hasRankField = (flags & 4) != 0;
    final rank = hasRankField ? reader.readString() : null;

    // Construct [ChannelParticipantAdmin] object.
    final returnValue = ChannelParticipantAdmin(
      canEdit: canEdit,
      self: self,
      userId: userId,
      inviterId: inviterId,
      promotedBy: promotedBy,
      date: date,
      adminRights: adminRights,
      rank: rank,
    );

    // Now return the deserialized [ChannelParticipantAdmin].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: canEdit,
      b01: self || inviterId != null,
      b02: rank != null,
    );

    return v;
  }

  /// can_edit: bit 0 of flags.0?true
  final bool canEdit;

  /// self: bit 1 of flags.1?true
  final bool self;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Inviter Id.
  final int? inviterId;

  /// Promoted By.
  ///
  /// Field type is Int64.
  final int promotedBy;

  /// Date.
  final DateTime date;

  /// Admin Rights.
  final ChatAdminRightsBase adminRights;

  /// Rank.
  final String? rank;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x34c3bb53.
    buffer.writeInt32(0x34c3bb53);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(userId);
    final localInviterIdCopy = inviterId;
    if (localInviterIdCopy != null) {
      buffer.writeInt64(localInviterIdCopy);
    }
    buffer.writeInt64(promotedBy);
    buffer.writeDateTime(date);
    buffer.writeObject(adminRights);
    final localRankCopy = rank;
    if (localRankCopy != null) {
      buffer.writeString(localRankCopy);
    }

    // Finished serialization.
  }
}

/// Channel Participant Banned.
///
/// ID: `6df8014e`.
class ChannelParticipantBanned extends ChannelParticipantBase {
  /// Channel Participant Banned constructor.
  const ChannelParticipantBanned({
    required this.left,
    required this.peer,
    required this.kickedBy,
    required this.date,
    required this.bannedRights,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipantBanned.deserialize(BinaryReader reader) {
    // Read [ChannelParticipantBanned] fields.
    final flags = reader.readInt32();
    final left = (flags & 1) != 0;
    final peer = reader.readObject() as PeerBase;
    final kickedBy = reader.readInt64();
    final date = reader.readDateTime();
    final bannedRights = reader.readObject() as ChatBannedRightsBase;

    // Construct [ChannelParticipantBanned] object.
    final returnValue = ChannelParticipantBanned(
      left: left,
      peer: peer,
      kickedBy: kickedBy,
      date: date,
      bannedRights: bannedRights,
    );

    // Now return the deserialized [ChannelParticipantBanned].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: left,
    );

    return v;
  }

  /// left: bit 0 of flags.0?true
  final bool left;

  /// Peer.
  final PeerBase peer;

  /// Kicked By.
  ///
  /// Field type is Int64.
  final int kickedBy;

  /// Date.
  final DateTime date;

  /// Banned Rights.
  final ChatBannedRightsBase bannedRights;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6df8014e.
    buffer.writeInt32(0x6df8014e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt64(kickedBy);
    buffer.writeDateTime(date);
    buffer.writeObject(bannedRights);

    // Finished serialization.
  }
}

/// Channel Participant Left.
///
/// ID: `1b03f006`.
class ChannelParticipantLeft extends ChannelParticipantBase {
  /// Channel Participant Left constructor.
  const ChannelParticipantLeft({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipantLeft.deserialize(BinaryReader reader) {
    // Read [ChannelParticipantLeft] fields.
    final peer = reader.readObject() as PeerBase;

    // Construct [ChannelParticipantLeft] object.
    final returnValue = ChannelParticipantLeft(
      peer: peer,
    );

    // Now return the deserialized [ChannelParticipantLeft].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1b03f006.
    buffer.writeInt32(0x1b03f006);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Channel Participants Recent.
///
/// ID: `de3f3c79`.
class ChannelParticipantsRecent extends ChannelParticipantsFilterBase {
  /// Channel Participants Recent constructor.
  const ChannelParticipantsRecent() : super._();

  /// Deserialize.
  factory ChannelParticipantsRecent.deserialize(BinaryReader reader) {
    // Construct [ChannelParticipantsRecent] object.
    final returnValue = ChannelParticipantsRecent();

    // Now return the deserialized [ChannelParticipantsRecent].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xde3f3c79.
    buffer.writeInt32(0xde3f3c79);

    // Finished serialization.
  }
}

/// Channel Participants Admins.
///
/// ID: `b4608969`.
class ChannelParticipantsAdmins extends ChannelParticipantsFilterBase {
  /// Channel Participants Admins constructor.
  const ChannelParticipantsAdmins() : super._();

  /// Deserialize.
  factory ChannelParticipantsAdmins.deserialize(BinaryReader reader) {
    // Construct [ChannelParticipantsAdmins] object.
    final returnValue = ChannelParticipantsAdmins();

    // Now return the deserialized [ChannelParticipantsAdmins].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb4608969.
    buffer.writeInt32(0xb4608969);

    // Finished serialization.
  }
}

/// Channel Participants Kicked.
///
/// ID: `a3b54985`.
class ChannelParticipantsKicked extends ChannelParticipantsFilterBase {
  /// Channel Participants Kicked constructor.
  const ChannelParticipantsKicked({
    required this.q,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipantsKicked.deserialize(BinaryReader reader) {
    // Read [ChannelParticipantsKicked] fields.
    final q = reader.readString();

    // Construct [ChannelParticipantsKicked] object.
    final returnValue = ChannelParticipantsKicked(
      q: q,
    );

    // Now return the deserialized [ChannelParticipantsKicked].
    return returnValue;
  }

  /// Q.
  final String q;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa3b54985.
    buffer.writeInt32(0xa3b54985);

    // Write fields.
    buffer.writeString(q);

    // Finished serialization.
  }
}

/// Channel Participants Bots.
///
/// ID: `b0d1865b`.
class ChannelParticipantsBots extends ChannelParticipantsFilterBase {
  /// Channel Participants Bots constructor.
  const ChannelParticipantsBots() : super._();

  /// Deserialize.
  factory ChannelParticipantsBots.deserialize(BinaryReader reader) {
    // Construct [ChannelParticipantsBots] object.
    final returnValue = ChannelParticipantsBots();

    // Now return the deserialized [ChannelParticipantsBots].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb0d1865b.
    buffer.writeInt32(0xb0d1865b);

    // Finished serialization.
  }
}

/// Channel Participants Banned.
///
/// ID: `1427a5e1`.
class ChannelParticipantsBanned extends ChannelParticipantsFilterBase {
  /// Channel Participants Banned constructor.
  const ChannelParticipantsBanned({
    required this.q,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipantsBanned.deserialize(BinaryReader reader) {
    // Read [ChannelParticipantsBanned] fields.
    final q = reader.readString();

    // Construct [ChannelParticipantsBanned] object.
    final returnValue = ChannelParticipantsBanned(
      q: q,
    );

    // Now return the deserialized [ChannelParticipantsBanned].
    return returnValue;
  }

  /// Q.
  final String q;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1427a5e1.
    buffer.writeInt32(0x1427a5e1);

    // Write fields.
    buffer.writeString(q);

    // Finished serialization.
  }
}

/// Channel Participants Search.
///
/// ID: `0656ac4b`.
class ChannelParticipantsSearch extends ChannelParticipantsFilterBase {
  /// Channel Participants Search constructor.
  const ChannelParticipantsSearch({
    required this.q,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipantsSearch.deserialize(BinaryReader reader) {
    // Read [ChannelParticipantsSearch] fields.
    final q = reader.readString();

    // Construct [ChannelParticipantsSearch] object.
    final returnValue = ChannelParticipantsSearch(
      q: q,
    );

    // Now return the deserialized [ChannelParticipantsSearch].
    return returnValue;
  }

  /// Q.
  final String q;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0656ac4b.
    buffer.writeInt32(0x0656ac4b);

    // Write fields.
    buffer.writeString(q);

    // Finished serialization.
  }
}

/// Channel Participants Contacts.
///
/// ID: `bb6ae88d`.
class ChannelParticipantsContacts extends ChannelParticipantsFilterBase {
  /// Channel Participants Contacts constructor.
  const ChannelParticipantsContacts({
    required this.q,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipantsContacts.deserialize(BinaryReader reader) {
    // Read [ChannelParticipantsContacts] fields.
    final q = reader.readString();

    // Construct [ChannelParticipantsContacts] object.
    final returnValue = ChannelParticipantsContacts(
      q: q,
    );

    // Now return the deserialized [ChannelParticipantsContacts].
    return returnValue;
  }

  /// Q.
  final String q;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbb6ae88d.
    buffer.writeInt32(0xbb6ae88d);

    // Write fields.
    buffer.writeString(q);

    // Finished serialization.
  }
}

/// Channel Participants Mentions.
///
/// ID: `e04b5ceb`.
class ChannelParticipantsMentions extends ChannelParticipantsFilterBase {
  /// Channel Participants Mentions constructor.
  const ChannelParticipantsMentions({
    this.q,
    this.topMsgId,
  }) : super._();

  /// Deserialize.
  factory ChannelParticipantsMentions.deserialize(BinaryReader reader) {
    // Read [ChannelParticipantsMentions] fields.
    final flags = reader.readInt32();
    final hasQField = (flags & 1) != 0;
    final q = hasQField ? reader.readString() : null;
    final hasTopMsgIdField = (flags & 2) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;

    // Construct [ChannelParticipantsMentions] object.
    final returnValue = ChannelParticipantsMentions(
      q: q,
      topMsgId: topMsgId,
    );

    // Now return the deserialized [ChannelParticipantsMentions].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: q != null,
      b01: topMsgId != null,
    );

    return v;
  }

  /// Q.
  final String? q;

  /// Top Msg Id.
  final int? topMsgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe04b5ceb.
    buffer.writeInt32(0xe04b5ceb);

    // Write fields.
    buffer.writeInt32(flags);
    final localQCopy = q;
    if (localQCopy != null) {
      buffer.writeString(localQCopy);
    }
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }

    // Finished serialization.
  }
}

/// Channels Channel Participants.
///
/// ID: `9ab0feaf`.
class ChannelsChannelParticipants extends ChannelsChannelParticipantsBase {
  /// Channels Channel Participants constructor.
  const ChannelsChannelParticipants({
    required this.count,
    required this.participants,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ChannelsChannelParticipants.deserialize(BinaryReader reader) {
    // Read [ChannelsChannelParticipants] fields.
    final count = reader.readInt32();
    final participants = reader.readVectorObject<ChannelParticipantBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ChannelsChannelParticipants] object.
    final returnValue = ChannelsChannelParticipants(
      count: count,
      participants: participants,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ChannelsChannelParticipants].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Participants.
  final List<ChannelParticipantBase> participants;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9ab0feaf.
    buffer.writeInt32(0x9ab0feaf);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(participants);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Channels Channel Participants Not Modified.
///
/// ID: `f0173fe9`.
class ChannelsChannelParticipantsNotModified
    extends ChannelsChannelParticipantsBase {
  /// Channels Channel Participants Not Modified constructor.
  const ChannelsChannelParticipantsNotModified() : super._();

  /// Deserialize.
  factory ChannelsChannelParticipantsNotModified.deserialize(
      BinaryReader reader) {
    // Construct [ChannelsChannelParticipantsNotModified] object.
    final returnValue = ChannelsChannelParticipantsNotModified();

    // Now return the deserialized [ChannelsChannelParticipantsNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf0173fe9.
    buffer.writeInt32(0xf0173fe9);

    // Finished serialization.
  }
}

/// Channels Channel Participant.
///
/// ID: `dfb80317`.
class ChannelsChannelParticipant extends ChannelsChannelParticipantBase {
  /// Channels Channel Participant constructor.
  const ChannelsChannelParticipant({
    required this.participant,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ChannelsChannelParticipant.deserialize(BinaryReader reader) {
    // Read [ChannelsChannelParticipant] fields.
    final participant = reader.readObject() as ChannelParticipantBase;
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ChannelsChannelParticipant] object.
    final returnValue = ChannelsChannelParticipant(
      participant: participant,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ChannelsChannelParticipant].
    return returnValue;
  }

  /// Participant.
  final ChannelParticipantBase participant;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdfb80317.
    buffer.writeInt32(0xdfb80317);

    // Write fields.
    buffer.writeObject(participant);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Help Terms Of Service.
///
/// ID: `780a0310`.
class HelpTermsOfService extends HelpTermsOfServiceBase {
  /// Help Terms Of Service constructor.
  const HelpTermsOfService({
    required this.popup,
    required this.id,
    required this.text,
    required this.entities,
    this.minAgeConfirm,
  }) : super._();

  /// Deserialize.
  factory HelpTermsOfService.deserialize(BinaryReader reader) {
    // Read [HelpTermsOfService] fields.
    final flags = reader.readInt32();
    final popup = (flags & 1) != 0;
    final id = reader.readObject() as DataJSONBase;
    final text = reader.readString();
    final entities = reader.readVectorObject<MessageEntityBase>();
    final hasMinAgeConfirmField = (flags & 2) != 0;
    final minAgeConfirm = hasMinAgeConfirmField ? reader.readInt32() : null;

    // Construct [HelpTermsOfService] object.
    final returnValue = HelpTermsOfService(
      popup: popup,
      id: id,
      text: text,
      entities: entities,
      minAgeConfirm: minAgeConfirm,
    );

    // Now return the deserialized [HelpTermsOfService].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: popup,
      b01: minAgeConfirm != null,
    );

    return v;
  }

  /// popup: bit 0 of flags.0?true
  final bool popup;

  /// Id.
  final DataJSONBase id;

  /// Text.
  final String text;

  /// Entities.
  final List<MessageEntityBase> entities;

  /// Min Age Confirm.
  final int? minAgeConfirm;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x780a0310.
    buffer.writeInt32(0x780a0310);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(id);
    buffer.writeString(text);
    buffer.writeVectorObject(entities);
    final localMinAgeConfirmCopy = minAgeConfirm;
    if (localMinAgeConfirmCopy != null) {
      buffer.writeInt32(localMinAgeConfirmCopy);
    }

    // Finished serialization.
  }
}

/// Messages Saved Gifs Not Modified.
///
/// ID: `e8025ca2`.
class MessagesSavedGifsNotModified extends MessagesSavedGifsBase {
  /// Messages Saved Gifs Not Modified constructor.
  const MessagesSavedGifsNotModified() : super._();

  /// Deserialize.
  factory MessagesSavedGifsNotModified.deserialize(BinaryReader reader) {
    // Construct [MessagesSavedGifsNotModified] object.
    final returnValue = MessagesSavedGifsNotModified();

    // Now return the deserialized [MessagesSavedGifsNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe8025ca2.
    buffer.writeInt32(0xe8025ca2);

    // Finished serialization.
  }
}

/// Messages Saved Gifs.
///
/// ID: `84a02a0d`.
class MessagesSavedGifs extends MessagesSavedGifsBase {
  /// Messages Saved Gifs constructor.
  const MessagesSavedGifs({
    required this.hash,
    required this.gifs,
  }) : super._();

  /// Deserialize.
  factory MessagesSavedGifs.deserialize(BinaryReader reader) {
    // Read [MessagesSavedGifs] fields.
    final hash = reader.readInt64();
    final gifs = reader.readVectorObject<DocumentBase>();

    // Construct [MessagesSavedGifs] object.
    final returnValue = MessagesSavedGifs(
      hash: hash,
      gifs: gifs,
    );

    // Now return the deserialized [MessagesSavedGifs].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Gifs.
  final List<DocumentBase> gifs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x84a02a0d.
    buffer.writeInt32(0x84a02a0d);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(gifs);

    // Finished serialization.
  }
}

/// Input Bot Inline Message Media Auto.
///
/// ID: `3380c786`.
class InputBotInlineMessageMediaAuto extends InputBotInlineMessageBase {
  /// Input Bot Inline Message Media Auto constructor.
  const InputBotInlineMessageMediaAuto({
    required this.invertMedia,
    required this.message,
    this.entities,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineMessageMediaAuto.deserialize(BinaryReader reader) {
    // Read [InputBotInlineMessageMediaAuto] fields.
    final flags = reader.readInt32();
    final invertMedia = (flags & 8) != 0;
    final message = reader.readString();
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [InputBotInlineMessageMediaAuto] object.
    final returnValue = InputBotInlineMessageMediaAuto(
      invertMedia: invertMedia,
      message: message,
      entities: entities,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [InputBotInlineMessageMediaAuto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: invertMedia,
      b01: entities != null,
      b02: replyMarkup != null,
    );

    return v;
  }

  /// invert_media: bit 3 of flags.3?true
  final bool invertMedia;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3380c786.
    buffer.writeInt32(0x3380c786);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Input Bot Inline Message Text.
///
/// ID: `3dcd7a87`.
class InputBotInlineMessageText extends InputBotInlineMessageBase {
  /// Input Bot Inline Message Text constructor.
  const InputBotInlineMessageText({
    required this.noWebpage,
    required this.invertMedia,
    required this.message,
    this.entities,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineMessageText.deserialize(BinaryReader reader) {
    // Read [InputBotInlineMessageText] fields.
    final flags = reader.readInt32();
    final noWebpage = (flags & 1) != 0;
    final invertMedia = (flags & 8) != 0;
    final message = reader.readString();
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [InputBotInlineMessageText] object.
    final returnValue = InputBotInlineMessageText(
      noWebpage: noWebpage,
      invertMedia: invertMedia,
      message: message,
      entities: entities,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [InputBotInlineMessageText].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: noWebpage,
      b03: invertMedia,
      b01: entities != null,
      b02: replyMarkup != null,
    );

    return v;
  }

  /// no_webpage: bit 0 of flags.0?true
  final bool noWebpage;

  /// invert_media: bit 3 of flags.3?true
  final bool invertMedia;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3dcd7a87.
    buffer.writeInt32(0x3dcd7a87);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Input Bot Inline Message Media Geo.
///
/// ID: `96929a85`.
class InputBotInlineMessageMediaGeo extends InputBotInlineMessageBase {
  /// Input Bot Inline Message Media Geo constructor.
  const InputBotInlineMessageMediaGeo({
    required this.geoPoint,
    this.heading,
    this.period,
    this.proximityNotificationRadius,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineMessageMediaGeo.deserialize(BinaryReader reader) {
    // Read [InputBotInlineMessageMediaGeo] fields.
    final flags = reader.readInt32();
    final geoPoint = reader.readObject() as InputGeoPointBase;
    final hasHeadingField = (flags & 1) != 0;
    final heading = hasHeadingField ? reader.readInt32() : null;
    final hasPeriodField = (flags & 2) != 0;
    final period = hasPeriodField ? reader.readInt32() : null;
    final hasProximityNotificationRadiusField = (flags & 8) != 0;
    final proximityNotificationRadius =
        hasProximityNotificationRadiusField ? reader.readInt32() : null;
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [InputBotInlineMessageMediaGeo] object.
    final returnValue = InputBotInlineMessageMediaGeo(
      geoPoint: geoPoint,
      heading: heading,
      period: period,
      proximityNotificationRadius: proximityNotificationRadius,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [InputBotInlineMessageMediaGeo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: heading != null,
      b01: period != null,
      b03: proximityNotificationRadius != null,
      b02: replyMarkup != null,
    );

    return v;
  }

  /// Geo Point.
  final InputGeoPointBase geoPoint;

  /// Heading.
  final int? heading;

  /// Period.
  final int? period;

  /// Proximity Notification Radius.
  final int? proximityNotificationRadius;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x96929a85.
    buffer.writeInt32(0x96929a85);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(geoPoint);
    final localHeadingCopy = heading;
    if (localHeadingCopy != null) {
      buffer.writeInt32(localHeadingCopy);
    }
    final localPeriodCopy = period;
    if (localPeriodCopy != null) {
      buffer.writeInt32(localPeriodCopy);
    }
    final localProximityNotificationRadiusCopy = proximityNotificationRadius;
    if (localProximityNotificationRadiusCopy != null) {
      buffer.writeInt32(localProximityNotificationRadiusCopy);
    }
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Input Bot Inline Message Media Venue.
///
/// ID: `417bbf11`.
class InputBotInlineMessageMediaVenue extends InputBotInlineMessageBase {
  /// Input Bot Inline Message Media Venue constructor.
  const InputBotInlineMessageMediaVenue({
    required this.geoPoint,
    required this.title,
    required this.address,
    required this.provider,
    required this.venueId,
    required this.venueType,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineMessageMediaVenue.deserialize(BinaryReader reader) {
    // Read [InputBotInlineMessageMediaVenue] fields.
    final flags = reader.readInt32();
    final geoPoint = reader.readObject() as InputGeoPointBase;
    final title = reader.readString();
    final address = reader.readString();
    final provider = reader.readString();
    final venueId = reader.readString();
    final venueType = reader.readString();
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [InputBotInlineMessageMediaVenue] object.
    final returnValue = InputBotInlineMessageMediaVenue(
      geoPoint: geoPoint,
      title: title,
      address: address,
      provider: provider,
      venueId: venueId,
      venueType: venueType,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [InputBotInlineMessageMediaVenue].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: replyMarkup != null,
    );

    return v;
  }

  /// Geo Point.
  final InputGeoPointBase geoPoint;

  /// Title.
  final String title;

  /// Address.
  final String address;

  /// Provider.
  final String provider;

  /// Venue Id.
  final String venueId;

  /// Venue Type.
  final String venueType;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x417bbf11.
    buffer.writeInt32(0x417bbf11);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(geoPoint);
    buffer.writeString(title);
    buffer.writeString(address);
    buffer.writeString(provider);
    buffer.writeString(venueId);
    buffer.writeString(venueType);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Input Bot Inline Message Media Contact.
///
/// ID: `a6edbffd`.
class InputBotInlineMessageMediaContact extends InputBotInlineMessageBase {
  /// Input Bot Inline Message Media Contact constructor.
  const InputBotInlineMessageMediaContact({
    required this.phoneNumber,
    required this.firstName,
    required this.lastName,
    required this.vcard,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineMessageMediaContact.deserialize(BinaryReader reader) {
    // Read [InputBotInlineMessageMediaContact] fields.
    final flags = reader.readInt32();
    final phoneNumber = reader.readString();
    final firstName = reader.readString();
    final lastName = reader.readString();
    final vcard = reader.readString();
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [InputBotInlineMessageMediaContact] object.
    final returnValue = InputBotInlineMessageMediaContact(
      phoneNumber: phoneNumber,
      firstName: firstName,
      lastName: lastName,
      vcard: vcard,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [InputBotInlineMessageMediaContact].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: replyMarkup != null,
    );

    return v;
  }

  /// Phone Number.
  final String phoneNumber;

  /// First Name.
  final String firstName;

  /// Last Name.
  final String lastName;

  /// Vcard.
  final String vcard;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa6edbffd.
    buffer.writeInt32(0xa6edbffd);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(phoneNumber);
    buffer.writeString(firstName);
    buffer.writeString(lastName);
    buffer.writeString(vcard);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Input Bot Inline Message Game.
///
/// ID: `4b425864`.
class InputBotInlineMessageGame extends InputBotInlineMessageBase {
  /// Input Bot Inline Message Game constructor.
  const InputBotInlineMessageGame({
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineMessageGame.deserialize(BinaryReader reader) {
    // Read [InputBotInlineMessageGame] fields.
    final flags = reader.readInt32();
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [InputBotInlineMessageGame] object.
    final returnValue = InputBotInlineMessageGame(
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [InputBotInlineMessageGame].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: replyMarkup != null,
    );

    return v;
  }

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4b425864.
    buffer.writeInt32(0x4b425864);

    // Write fields.
    buffer.writeInt32(flags);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Input Bot Inline Message Media Invoice.
///
/// ID: `d7e78225`.
class InputBotInlineMessageMediaInvoice extends InputBotInlineMessageBase {
  /// Input Bot Inline Message Media Invoice constructor.
  const InputBotInlineMessageMediaInvoice({
    required this.title,
    required this.description,
    this.photo,
    required this.invoice,
    required this.payload,
    required this.provider,
    required this.providerData,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineMessageMediaInvoice.deserialize(BinaryReader reader) {
    // Read [InputBotInlineMessageMediaInvoice] fields.
    final flags = reader.readInt32();
    final title = reader.readString();
    final description = reader.readString();
    final hasPhotoField = (flags & 1) != 0;
    final photo =
        hasPhotoField ? reader.readObject() as InputWebDocumentBase : null;
    final invoice = reader.readObject() as InvoiceBase;
    final payload = reader.readBytes();
    final provider = reader.readString();
    final providerData = reader.readObject() as DataJSONBase;
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [InputBotInlineMessageMediaInvoice] object.
    final returnValue = InputBotInlineMessageMediaInvoice(
      title: title,
      description: description,
      photo: photo,
      invoice: invoice,
      payload: payload,
      provider: provider,
      providerData: providerData,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [InputBotInlineMessageMediaInvoice].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: photo != null,
      b02: replyMarkup != null,
    );

    return v;
  }

  /// Title.
  final String title;

  /// Description.
  final String description;

  /// Photo.
  final InputWebDocumentBase? photo;

  /// Invoice.
  final InvoiceBase invoice;

  /// Payload.
  final Uint8List payload;

  /// Provider.
  final String provider;

  /// Provider Data.
  final DataJSONBase providerData;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd7e78225.
    buffer.writeInt32(0xd7e78225);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(title);
    buffer.writeString(description);
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }
    buffer.writeObject(invoice);
    buffer.writeBytes(payload);
    buffer.writeString(provider);
    buffer.writeObject(providerData);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Input Bot Inline Message Media Web Page.
///
/// ID: `bddcc510`.
class InputBotInlineMessageMediaWebPage extends InputBotInlineMessageBase {
  /// Input Bot Inline Message Media Web Page constructor.
  const InputBotInlineMessageMediaWebPage({
    required this.invertMedia,
    required this.forceLargeMedia,
    required this.forceSmallMedia,
    required this.optional,
    required this.message,
    this.entities,
    required this.url,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineMessageMediaWebPage.deserialize(BinaryReader reader) {
    // Read [InputBotInlineMessageMediaWebPage] fields.
    final flags = reader.readInt32();
    final invertMedia = (flags & 8) != 0;
    final forceLargeMedia = (flags & 16) != 0;
    final forceSmallMedia = (flags & 32) != 0;
    final optional = (flags & 64) != 0;
    final message = reader.readString();
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final url = reader.readString();
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [InputBotInlineMessageMediaWebPage] object.
    final returnValue = InputBotInlineMessageMediaWebPage(
      invertMedia: invertMedia,
      forceLargeMedia: forceLargeMedia,
      forceSmallMedia: forceSmallMedia,
      optional: optional,
      message: message,
      entities: entities,
      url: url,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [InputBotInlineMessageMediaWebPage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: invertMedia,
      b04: forceLargeMedia,
      b05: forceSmallMedia,
      b06: optional,
      b01: entities != null,
      b02: replyMarkup != null,
    );

    return v;
  }

  /// invert_media: bit 3 of flags.3?true
  final bool invertMedia;

  /// force_large_media: bit 4 of flags.4?true
  final bool forceLargeMedia;

  /// force_small_media: bit 5 of flags.5?true
  final bool forceSmallMedia;

  /// optional: bit 6 of flags.6?true
  final bool optional;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Url.
  final String url;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbddcc510.
    buffer.writeInt32(0xbddcc510);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    buffer.writeString(url);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Input Bot Inline Result.
///
/// ID: `88bf9319`.
class InputBotInlineResult extends InputBotInlineResultBase {
  /// Input Bot Inline Result constructor.
  const InputBotInlineResult({
    required this.id,
    required this.type,
    this.title,
    this.description,
    this.url,
    this.thumb,
    this.content,
    required this.sendMessage,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineResult.deserialize(BinaryReader reader) {
    // Read [InputBotInlineResult] fields.
    final flags = reader.readInt32();
    final id = reader.readString();
    final type = reader.readString();
    final hasTitleField = (flags & 2) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasDescriptionField = (flags & 4) != 0;
    final description = hasDescriptionField ? reader.readString() : null;
    final hasUrlField = (flags & 8) != 0;
    final url = hasUrlField ? reader.readString() : null;
    final hasThumbField = (flags & 16) != 0;
    final thumb =
        hasThumbField ? reader.readObject() as InputWebDocumentBase : null;
    final hasContentField = (flags & 32) != 0;
    final content =
        hasContentField ? reader.readObject() as InputWebDocumentBase : null;
    final sendMessage = reader.readObject() as InputBotInlineMessageBase;

    // Construct [InputBotInlineResult] object.
    final returnValue = InputBotInlineResult(
      id: id,
      type: type,
      title: title,
      description: description,
      url: url,
      thumb: thumb,
      content: content,
      sendMessage: sendMessage,
    );

    // Now return the deserialized [InputBotInlineResult].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: title != null,
      b02: description != null,
      b03: url != null,
      b04: thumb != null,
      b05: content != null,
    );

    return v;
  }

  /// Id.
  final String id;

  /// Type.
  final String type;

  /// Title.
  final String? title;

  /// Description.
  final String? description;

  /// Url.
  final String? url;

  /// Thumb.
  final InputWebDocumentBase? thumb;

  /// Content.
  final InputWebDocumentBase? content;

  /// Send Message.
  final InputBotInlineMessageBase sendMessage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x88bf9319.
    buffer.writeInt32(0x88bf9319);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(id);
    buffer.writeString(type);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localDescriptionCopy = description;
    if (localDescriptionCopy != null) {
      buffer.writeString(localDescriptionCopy);
    }
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }
    final localThumbCopy = thumb;
    if (localThumbCopy != null) {
      buffer.writeObject(localThumbCopy);
    }
    final localContentCopy = content;
    if (localContentCopy != null) {
      buffer.writeObject(localContentCopy);
    }
    buffer.writeObject(sendMessage);

    // Finished serialization.
  }
}

/// Input Bot Inline Result Photo.
///
/// ID: `a8d864a7`.
class InputBotInlineResultPhoto extends InputBotInlineResultBase {
  /// Input Bot Inline Result Photo constructor.
  const InputBotInlineResultPhoto({
    required this.id,
    required this.type,
    required this.photo,
    required this.sendMessage,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineResultPhoto.deserialize(BinaryReader reader) {
    // Read [InputBotInlineResultPhoto] fields.
    final id = reader.readString();
    final type = reader.readString();
    final photo = reader.readObject() as InputPhotoBase;
    final sendMessage = reader.readObject() as InputBotInlineMessageBase;

    // Construct [InputBotInlineResultPhoto] object.
    final returnValue = InputBotInlineResultPhoto(
      id: id,
      type: type,
      photo: photo,
      sendMessage: sendMessage,
    );

    // Now return the deserialized [InputBotInlineResultPhoto].
    return returnValue;
  }

  /// Id.
  final String id;

  /// Type.
  final String type;

  /// Photo.
  final InputPhotoBase photo;

  /// Send Message.
  final InputBotInlineMessageBase sendMessage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa8d864a7.
    buffer.writeInt32(0xa8d864a7);

    // Write fields.
    buffer.writeString(id);
    buffer.writeString(type);
    buffer.writeObject(photo);
    buffer.writeObject(sendMessage);

    // Finished serialization.
  }
}

/// Input Bot Inline Result Document.
///
/// ID: `fff8fdc4`.
class InputBotInlineResultDocument extends InputBotInlineResultBase {
  /// Input Bot Inline Result Document constructor.
  const InputBotInlineResultDocument({
    required this.id,
    required this.type,
    this.title,
    this.description,
    required this.document,
    required this.sendMessage,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineResultDocument.deserialize(BinaryReader reader) {
    // Read [InputBotInlineResultDocument] fields.
    final flags = reader.readInt32();
    final id = reader.readString();
    final type = reader.readString();
    final hasTitleField = (flags & 2) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasDescriptionField = (flags & 4) != 0;
    final description = hasDescriptionField ? reader.readString() : null;
    final document = reader.readObject() as InputDocumentBase;
    final sendMessage = reader.readObject() as InputBotInlineMessageBase;

    // Construct [InputBotInlineResultDocument] object.
    final returnValue = InputBotInlineResultDocument(
      id: id,
      type: type,
      title: title,
      description: description,
      document: document,
      sendMessage: sendMessage,
    );

    // Now return the deserialized [InputBotInlineResultDocument].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: title != null,
      b02: description != null,
    );

    return v;
  }

  /// Id.
  final String id;

  /// Type.
  final String type;

  /// Title.
  final String? title;

  /// Description.
  final String? description;

  /// Document.
  final InputDocumentBase document;

  /// Send Message.
  final InputBotInlineMessageBase sendMessage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfff8fdc4.
    buffer.writeInt32(0xfff8fdc4);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(id);
    buffer.writeString(type);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localDescriptionCopy = description;
    if (localDescriptionCopy != null) {
      buffer.writeString(localDescriptionCopy);
    }
    buffer.writeObject(document);
    buffer.writeObject(sendMessage);

    // Finished serialization.
  }
}

/// Input Bot Inline Result Game.
///
/// ID: `4fa417f2`.
class InputBotInlineResultGame extends InputBotInlineResultBase {
  /// Input Bot Inline Result Game constructor.
  const InputBotInlineResultGame({
    required this.id,
    required this.shortName,
    required this.sendMessage,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineResultGame.deserialize(BinaryReader reader) {
    // Read [InputBotInlineResultGame] fields.
    final id = reader.readString();
    final shortName = reader.readString();
    final sendMessage = reader.readObject() as InputBotInlineMessageBase;

    // Construct [InputBotInlineResultGame] object.
    final returnValue = InputBotInlineResultGame(
      id: id,
      shortName: shortName,
      sendMessage: sendMessage,
    );

    // Now return the deserialized [InputBotInlineResultGame].
    return returnValue;
  }

  /// Id.
  final String id;

  /// Short Name.
  final String shortName;

  /// Send Message.
  final InputBotInlineMessageBase sendMessage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4fa417f2.
    buffer.writeInt32(0x4fa417f2);

    // Write fields.
    buffer.writeString(id);
    buffer.writeString(shortName);
    buffer.writeObject(sendMessage);

    // Finished serialization.
  }
}

/// Bot Inline Message Media Auto.
///
/// ID: `764cf810`.
class BotInlineMessageMediaAuto extends BotInlineMessageBase {
  /// Bot Inline Message Media Auto constructor.
  const BotInlineMessageMediaAuto({
    required this.invertMedia,
    required this.message,
    this.entities,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory BotInlineMessageMediaAuto.deserialize(BinaryReader reader) {
    // Read [BotInlineMessageMediaAuto] fields.
    final flags = reader.readInt32();
    final invertMedia = (flags & 8) != 0;
    final message = reader.readString();
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [BotInlineMessageMediaAuto] object.
    final returnValue = BotInlineMessageMediaAuto(
      invertMedia: invertMedia,
      message: message,
      entities: entities,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [BotInlineMessageMediaAuto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: invertMedia,
      b01: entities != null,
      b02: replyMarkup != null,
    );

    return v;
  }

  /// invert_media: bit 3 of flags.3?true
  final bool invertMedia;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x764cf810.
    buffer.writeInt32(0x764cf810);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Bot Inline Message Text.
///
/// ID: `8c7f65e2`.
class BotInlineMessageText extends BotInlineMessageBase {
  /// Bot Inline Message Text constructor.
  const BotInlineMessageText({
    required this.noWebpage,
    required this.invertMedia,
    required this.message,
    this.entities,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory BotInlineMessageText.deserialize(BinaryReader reader) {
    // Read [BotInlineMessageText] fields.
    final flags = reader.readInt32();
    final noWebpage = (flags & 1) != 0;
    final invertMedia = (flags & 8) != 0;
    final message = reader.readString();
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [BotInlineMessageText] object.
    final returnValue = BotInlineMessageText(
      noWebpage: noWebpage,
      invertMedia: invertMedia,
      message: message,
      entities: entities,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [BotInlineMessageText].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: noWebpage,
      b03: invertMedia,
      b01: entities != null,
      b02: replyMarkup != null,
    );

    return v;
  }

  /// no_webpage: bit 0 of flags.0?true
  final bool noWebpage;

  /// invert_media: bit 3 of flags.3?true
  final bool invertMedia;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8c7f65e2.
    buffer.writeInt32(0x8c7f65e2);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Bot Inline Message Media Geo.
///
/// ID: `051846fd`.
class BotInlineMessageMediaGeo extends BotInlineMessageBase {
  /// Bot Inline Message Media Geo constructor.
  const BotInlineMessageMediaGeo({
    required this.geo,
    this.heading,
    this.period,
    this.proximityNotificationRadius,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory BotInlineMessageMediaGeo.deserialize(BinaryReader reader) {
    // Read [BotInlineMessageMediaGeo] fields.
    final flags = reader.readInt32();
    final geo = reader.readObject() as GeoPointBase;
    final hasHeadingField = (flags & 1) != 0;
    final heading = hasHeadingField ? reader.readInt32() : null;
    final hasPeriodField = (flags & 2) != 0;
    final period = hasPeriodField ? reader.readInt32() : null;
    final hasProximityNotificationRadiusField = (flags & 8) != 0;
    final proximityNotificationRadius =
        hasProximityNotificationRadiusField ? reader.readInt32() : null;
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [BotInlineMessageMediaGeo] object.
    final returnValue = BotInlineMessageMediaGeo(
      geo: geo,
      heading: heading,
      period: period,
      proximityNotificationRadius: proximityNotificationRadius,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [BotInlineMessageMediaGeo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: heading != null,
      b01: period != null,
      b03: proximityNotificationRadius != null,
      b02: replyMarkup != null,
    );

    return v;
  }

  /// Geo.
  final GeoPointBase geo;

  /// Heading.
  final int? heading;

  /// Period.
  final int? period;

  /// Proximity Notification Radius.
  final int? proximityNotificationRadius;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x051846fd.
    buffer.writeInt32(0x051846fd);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(geo);
    final localHeadingCopy = heading;
    if (localHeadingCopy != null) {
      buffer.writeInt32(localHeadingCopy);
    }
    final localPeriodCopy = period;
    if (localPeriodCopy != null) {
      buffer.writeInt32(localPeriodCopy);
    }
    final localProximityNotificationRadiusCopy = proximityNotificationRadius;
    if (localProximityNotificationRadiusCopy != null) {
      buffer.writeInt32(localProximityNotificationRadiusCopy);
    }
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Bot Inline Message Media Venue.
///
/// ID: `8a86659c`.
class BotInlineMessageMediaVenue extends BotInlineMessageBase {
  /// Bot Inline Message Media Venue constructor.
  const BotInlineMessageMediaVenue({
    required this.geo,
    required this.title,
    required this.address,
    required this.provider,
    required this.venueId,
    required this.venueType,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory BotInlineMessageMediaVenue.deserialize(BinaryReader reader) {
    // Read [BotInlineMessageMediaVenue] fields.
    final flags = reader.readInt32();
    final geo = reader.readObject() as GeoPointBase;
    final title = reader.readString();
    final address = reader.readString();
    final provider = reader.readString();
    final venueId = reader.readString();
    final venueType = reader.readString();
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [BotInlineMessageMediaVenue] object.
    final returnValue = BotInlineMessageMediaVenue(
      geo: geo,
      title: title,
      address: address,
      provider: provider,
      venueId: venueId,
      venueType: venueType,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [BotInlineMessageMediaVenue].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: replyMarkup != null,
    );

    return v;
  }

  /// Geo.
  final GeoPointBase geo;

  /// Title.
  final String title;

  /// Address.
  final String address;

  /// Provider.
  final String provider;

  /// Venue Id.
  final String venueId;

  /// Venue Type.
  final String venueType;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8a86659c.
    buffer.writeInt32(0x8a86659c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(geo);
    buffer.writeString(title);
    buffer.writeString(address);
    buffer.writeString(provider);
    buffer.writeString(venueId);
    buffer.writeString(venueType);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Bot Inline Message Media Contact.
///
/// ID: `18d1cdc2`.
class BotInlineMessageMediaContact extends BotInlineMessageBase {
  /// Bot Inline Message Media Contact constructor.
  const BotInlineMessageMediaContact({
    required this.phoneNumber,
    required this.firstName,
    required this.lastName,
    required this.vcard,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory BotInlineMessageMediaContact.deserialize(BinaryReader reader) {
    // Read [BotInlineMessageMediaContact] fields.
    final flags = reader.readInt32();
    final phoneNumber = reader.readString();
    final firstName = reader.readString();
    final lastName = reader.readString();
    final vcard = reader.readString();
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [BotInlineMessageMediaContact] object.
    final returnValue = BotInlineMessageMediaContact(
      phoneNumber: phoneNumber,
      firstName: firstName,
      lastName: lastName,
      vcard: vcard,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [BotInlineMessageMediaContact].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: replyMarkup != null,
    );

    return v;
  }

  /// Phone Number.
  final String phoneNumber;

  /// First Name.
  final String firstName;

  /// Last Name.
  final String lastName;

  /// Vcard.
  final String vcard;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x18d1cdc2.
    buffer.writeInt32(0x18d1cdc2);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(phoneNumber);
    buffer.writeString(firstName);
    buffer.writeString(lastName);
    buffer.writeString(vcard);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Bot Inline Message Media Invoice.
///
/// ID: `354a9b09`.
class BotInlineMessageMediaInvoice extends BotInlineMessageBase {
  /// Bot Inline Message Media Invoice constructor.
  const BotInlineMessageMediaInvoice({
    required this.shippingAddressRequested,
    required this.test,
    required this.title,
    required this.description,
    this.photo,
    required this.currency,
    required this.totalAmount,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory BotInlineMessageMediaInvoice.deserialize(BinaryReader reader) {
    // Read [BotInlineMessageMediaInvoice] fields.
    final flags = reader.readInt32();
    final shippingAddressRequested = (flags & 2) != 0;
    final test = (flags & 8) != 0;
    final title = reader.readString();
    final description = reader.readString();
    final hasPhotoField = (flags & 1) != 0;
    final photo = hasPhotoField ? reader.readObject() as WebDocumentBase : null;
    final currency = reader.readString();
    final totalAmount = reader.readInt64();
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [BotInlineMessageMediaInvoice] object.
    final returnValue = BotInlineMessageMediaInvoice(
      shippingAddressRequested: shippingAddressRequested,
      test: test,
      title: title,
      description: description,
      photo: photo,
      currency: currency,
      totalAmount: totalAmount,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [BotInlineMessageMediaInvoice].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: shippingAddressRequested,
      b03: test,
      b00: photo != null,
      b02: replyMarkup != null,
    );

    return v;
  }

  /// shipping_address_requested: bit 1 of flags.1?true
  final bool shippingAddressRequested;

  /// test: bit 3 of flags.3?true
  final bool test;

  /// Title.
  final String title;

  /// Description.
  final String description;

  /// Photo.
  final WebDocumentBase? photo;

  /// Currency.
  final String currency;

  /// Total Amount.
  ///
  /// Field type is Int64.
  final int totalAmount;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x354a9b09.
    buffer.writeInt32(0x354a9b09);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(title);
    buffer.writeString(description);
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }
    buffer.writeString(currency);
    buffer.writeInt64(totalAmount);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Bot Inline Message Media Web Page.
///
/// ID: `809ad9a6`.
class BotInlineMessageMediaWebPage extends BotInlineMessageBase {
  /// Bot Inline Message Media Web Page constructor.
  const BotInlineMessageMediaWebPage({
    required this.invertMedia,
    required this.forceLargeMedia,
    required this.forceSmallMedia,
    required this.manual,
    required this.safe,
    required this.message,
    this.entities,
    required this.url,
    this.replyMarkup,
  }) : super._();

  /// Deserialize.
  factory BotInlineMessageMediaWebPage.deserialize(BinaryReader reader) {
    // Read [BotInlineMessageMediaWebPage] fields.
    final flags = reader.readInt32();
    final invertMedia = (flags & 8) != 0;
    final forceLargeMedia = (flags & 16) != 0;
    final forceSmallMedia = (flags & 32) != 0;
    final manual = (flags & 128) != 0;
    final safe = (flags & 256) != 0;
    final message = reader.readString();
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final url = reader.readString();
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;

    // Construct [BotInlineMessageMediaWebPage] object.
    final returnValue = BotInlineMessageMediaWebPage(
      invertMedia: invertMedia,
      forceLargeMedia: forceLargeMedia,
      forceSmallMedia: forceSmallMedia,
      manual: manual,
      safe: safe,
      message: message,
      entities: entities,
      url: url,
      replyMarkup: replyMarkup,
    );

    // Now return the deserialized [BotInlineMessageMediaWebPage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: invertMedia,
      b04: forceLargeMedia,
      b05: forceSmallMedia,
      b07: manual,
      b08: safe,
      b01: entities != null,
      b02: replyMarkup != null,
    );

    return v;
  }

  /// invert_media: bit 3 of flags.3?true
  final bool invertMedia;

  /// force_large_media: bit 4 of flags.4?true
  final bool forceLargeMedia;

  /// force_small_media: bit 5 of flags.5?true
  final bool forceSmallMedia;

  /// manual: bit 7 of flags.7?true
  final bool manual;

  /// safe: bit 8 of flags.8?true
  final bool safe;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Url.
  final String url;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x809ad9a6.
    buffer.writeInt32(0x809ad9a6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    buffer.writeString(url);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Bot Inline Result.
///
/// ID: `11965f3a`.
class BotInlineResult extends BotInlineResultBase {
  /// Bot Inline Result constructor.
  const BotInlineResult({
    required this.id,
    required this.type,
    this.title,
    this.description,
    this.url,
    this.thumb,
    this.content,
    required this.sendMessage,
  }) : super._();

  /// Deserialize.
  factory BotInlineResult.deserialize(BinaryReader reader) {
    // Read [BotInlineResult] fields.
    final flags = reader.readInt32();
    final id = reader.readString();
    final type = reader.readString();
    final hasTitleField = (flags & 2) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasDescriptionField = (flags & 4) != 0;
    final description = hasDescriptionField ? reader.readString() : null;
    final hasUrlField = (flags & 8) != 0;
    final url = hasUrlField ? reader.readString() : null;
    final hasThumbField = (flags & 16) != 0;
    final thumb = hasThumbField ? reader.readObject() as WebDocumentBase : null;
    final hasContentField = (flags & 32) != 0;
    final content =
        hasContentField ? reader.readObject() as WebDocumentBase : null;
    final sendMessage = reader.readObject() as BotInlineMessageBase;

    // Construct [BotInlineResult] object.
    final returnValue = BotInlineResult(
      id: id,
      type: type,
      title: title,
      description: description,
      url: url,
      thumb: thumb,
      content: content,
      sendMessage: sendMessage,
    );

    // Now return the deserialized [BotInlineResult].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: title != null,
      b02: description != null,
      b03: url != null,
      b04: thumb != null,
      b05: content != null,
    );

    return v;
  }

  /// Id.
  final String id;

  /// Type.
  final String type;

  /// Title.
  final String? title;

  /// Description.
  final String? description;

  /// Url.
  final String? url;

  /// Thumb.
  final WebDocumentBase? thumb;

  /// Content.
  final WebDocumentBase? content;

  /// Send Message.
  final BotInlineMessageBase sendMessage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x11965f3a.
    buffer.writeInt32(0x11965f3a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(id);
    buffer.writeString(type);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localDescriptionCopy = description;
    if (localDescriptionCopy != null) {
      buffer.writeString(localDescriptionCopy);
    }
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }
    final localThumbCopy = thumb;
    if (localThumbCopy != null) {
      buffer.writeObject(localThumbCopy);
    }
    final localContentCopy = content;
    if (localContentCopy != null) {
      buffer.writeObject(localContentCopy);
    }
    buffer.writeObject(sendMessage);

    // Finished serialization.
  }
}

/// Bot Inline Media Result.
///
/// ID: `17db940b`.
class BotInlineMediaResult extends BotInlineResultBase {
  /// Bot Inline Media Result constructor.
  const BotInlineMediaResult({
    required this.id,
    required this.type,
    this.photo,
    this.document,
    this.title,
    this.description,
    required this.sendMessage,
  }) : super._();

  /// Deserialize.
  factory BotInlineMediaResult.deserialize(BinaryReader reader) {
    // Read [BotInlineMediaResult] fields.
    final flags = reader.readInt32();
    final id = reader.readString();
    final type = reader.readString();
    final hasPhotoField = (flags & 1) != 0;
    final photo = hasPhotoField ? reader.readObject() as PhotoBase : null;
    final hasDocumentField = (flags & 2) != 0;
    final document =
        hasDocumentField ? reader.readObject() as DocumentBase : null;
    final hasTitleField = (flags & 4) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasDescriptionField = (flags & 8) != 0;
    final description = hasDescriptionField ? reader.readString() : null;
    final sendMessage = reader.readObject() as BotInlineMessageBase;

    // Construct [BotInlineMediaResult] object.
    final returnValue = BotInlineMediaResult(
      id: id,
      type: type,
      photo: photo,
      document: document,
      title: title,
      description: description,
      sendMessage: sendMessage,
    );

    // Now return the deserialized [BotInlineMediaResult].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: photo != null,
      b01: document != null,
      b02: title != null,
      b03: description != null,
    );

    return v;
  }

  /// Id.
  final String id;

  /// Type.
  final String type;

  /// Photo.
  final PhotoBase? photo;

  /// Document.
  final DocumentBase? document;

  /// Title.
  final String? title;

  /// Description.
  final String? description;

  /// Send Message.
  final BotInlineMessageBase sendMessage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x17db940b.
    buffer.writeInt32(0x17db940b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(id);
    buffer.writeString(type);
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }
    final localDocumentCopy = document;
    if (localDocumentCopy != null) {
      buffer.writeObject(localDocumentCopy);
    }
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localDescriptionCopy = description;
    if (localDescriptionCopy != null) {
      buffer.writeString(localDescriptionCopy);
    }
    buffer.writeObject(sendMessage);

    // Finished serialization.
  }
}

/// Messages Bot Results.
///
/// ID: `e021f2f6`.
class MessagesBotResults extends MessagesBotResultsBase {
  /// Messages Bot Results constructor.
  const MessagesBotResults({
    required this.gallery,
    required this.queryId,
    this.nextOffset,
    this.switchPm,
    this.switchWebview,
    required this.results,
    required this.cacheTime,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesBotResults.deserialize(BinaryReader reader) {
    // Read [MessagesBotResults] fields.
    final flags = reader.readInt32();
    final gallery = (flags & 1) != 0;
    final queryId = reader.readInt64();
    final hasNextOffsetField = (flags & 2) != 0;
    final nextOffset = hasNextOffsetField ? reader.readString() : null;
    final hasSwitchPmField = (flags & 4) != 0;
    final switchPm =
        hasSwitchPmField ? reader.readObject() as InlineBotSwitchPMBase : null;
    final hasSwitchWebviewField = (flags & 8) != 0;
    final switchWebview = hasSwitchWebviewField
        ? reader.readObject() as InlineBotWebViewBase
        : null;
    final results = reader.readVectorObject<BotInlineResultBase>();
    final cacheTime = reader.readInt32();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesBotResults] object.
    final returnValue = MessagesBotResults(
      gallery: gallery,
      queryId: queryId,
      nextOffset: nextOffset,
      switchPm: switchPm,
      switchWebview: switchWebview,
      results: results,
      cacheTime: cacheTime,
      users: users,
    );

    // Now return the deserialized [MessagesBotResults].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: gallery,
      b01: nextOffset != null,
      b02: switchPm != null,
      b03: switchWebview != null,
    );

    return v;
  }

  /// gallery: bit 0 of flags.0?true
  final bool gallery;

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Next Offset.
  final String? nextOffset;

  /// Switch Pm.
  final InlineBotSwitchPMBase? switchPm;

  /// Switch Webview.
  final InlineBotWebViewBase? switchWebview;

  /// Results.
  final List<BotInlineResultBase> results;

  /// Cache Time.
  ///
  /// Field type is Int32.
  final int cacheTime;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe021f2f6.
    buffer.writeInt32(0xe021f2f6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(queryId);
    final localNextOffsetCopy = nextOffset;
    if (localNextOffsetCopy != null) {
      buffer.writeString(localNextOffsetCopy);
    }
    final localSwitchPmCopy = switchPm;
    if (localSwitchPmCopy != null) {
      buffer.writeObject(localSwitchPmCopy);
    }
    final localSwitchWebviewCopy = switchWebview;
    if (localSwitchWebviewCopy != null) {
      buffer.writeObject(localSwitchWebviewCopy);
    }
    buffer.writeVectorObject(results);
    buffer.writeInt32(cacheTime);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Exported Message Link.
///
/// ID: `5dab1af4`.
class ExportedMessageLink extends ExportedMessageLinkBase {
  /// Exported Message Link constructor.
  const ExportedMessageLink({
    required this.link,
    required this.html,
  }) : super._();

  /// Deserialize.
  factory ExportedMessageLink.deserialize(BinaryReader reader) {
    // Read [ExportedMessageLink] fields.
    final link = reader.readString();
    final html = reader.readString();

    // Construct [ExportedMessageLink] object.
    final returnValue = ExportedMessageLink(
      link: link,
      html: html,
    );

    // Now return the deserialized [ExportedMessageLink].
    return returnValue;
  }

  /// Link.
  final String link;

  /// Html.
  final String html;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5dab1af4.
    buffer.writeInt32(0x5dab1af4);

    // Write fields.
    buffer.writeString(link);
    buffer.writeString(html);

    // Finished serialization.
  }
}

/// Message Fwd Header.
///
/// ID: `4e4df4bb`.
class MessageFwdHeader extends MessageFwdHeaderBase {
  /// Message Fwd Header constructor.
  const MessageFwdHeader({
    required this.imported,
    required this.savedOut,
    this.fromId,
    this.fromName,
    required this.date,
    this.channelPost,
    this.postAuthor,
    this.savedFromPeer,
    this.savedFromMsgId,
    this.savedFromId,
    this.savedFromName,
    this.savedDate,
    this.psaType,
  }) : super._();

  /// Deserialize.
  factory MessageFwdHeader.deserialize(BinaryReader reader) {
    // Read [MessageFwdHeader] fields.
    final flags = reader.readInt32();
    final imported = (flags & 128) != 0;
    final savedOut = (flags & 2048) != 0;
    final hasFromIdField = (flags & 1) != 0;
    final fromId = hasFromIdField ? reader.readObject() as PeerBase : null;
    final hasFromNameField = (flags & 32) != 0;
    final fromName = hasFromNameField ? reader.readString() : null;
    final date = reader.readDateTime();
    final hasChannelPostField = (flags & 4) != 0;
    final channelPost = hasChannelPostField ? reader.readInt32() : null;
    final hasPostAuthorField = (flags & 8) != 0;
    final postAuthor = hasPostAuthorField ? reader.readString() : null;
    final hasSavedFromPeerField = (flags & 16) != 0;
    final savedFromPeer =
        hasSavedFromPeerField ? reader.readObject() as PeerBase : null;
    final hasSavedFromMsgIdField = (flags & 16) != 0;
    final savedFromMsgId = hasSavedFromMsgIdField ? reader.readInt32() : null;
    final hasSavedFromIdField = (flags & 256) != 0;
    final savedFromId =
        hasSavedFromIdField ? reader.readObject() as PeerBase : null;
    final hasSavedFromNameField = (flags & 512) != 0;
    final savedFromName = hasSavedFromNameField ? reader.readString() : null;
    final hasSavedDateField = (flags & 1024) != 0;
    final savedDate = hasSavedDateField ? reader.readDateTime() : null;
    final hasPsaTypeField = (flags & 64) != 0;
    final psaType = hasPsaTypeField ? reader.readString() : null;

    // Construct [MessageFwdHeader] object.
    final returnValue = MessageFwdHeader(
      imported: imported,
      savedOut: savedOut,
      fromId: fromId,
      fromName: fromName,
      date: date,
      channelPost: channelPost,
      postAuthor: postAuthor,
      savedFromPeer: savedFromPeer,
      savedFromMsgId: savedFromMsgId,
      savedFromId: savedFromId,
      savedFromName: savedFromName,
      savedDate: savedDate,
      psaType: psaType,
    );

    // Now return the deserialized [MessageFwdHeader].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b07: imported,
      b11: savedOut,
      b00: fromId != null,
      b05: fromName != null,
      b02: channelPost != null,
      b03: postAuthor != null,
      b04: savedFromPeer != null || savedFromMsgId != null,
      b08: savedFromId != null,
      b09: savedFromName != null,
      b10: savedDate != null,
      b06: psaType != null,
    );

    return v;
  }

  /// imported: bit 7 of flags.7?true
  final bool imported;

  /// saved_out: bit 11 of flags.11?true
  final bool savedOut;

  /// From Id.
  final PeerBase? fromId;

  /// From Name.
  final String? fromName;

  /// Date.
  final DateTime date;

  /// Channel Post.
  final int? channelPost;

  /// Post Author.
  final String? postAuthor;

  /// Saved From Peer.
  final PeerBase? savedFromPeer;

  /// Saved From Msg Id.
  final int? savedFromMsgId;

  /// Saved From Id.
  final PeerBase? savedFromId;

  /// Saved From Name.
  final String? savedFromName;

  /// Saved Date.
  final DateTime? savedDate;

  /// Psa Type.
  final String? psaType;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4e4df4bb.
    buffer.writeInt32(0x4e4df4bb);

    // Write fields.
    buffer.writeInt32(flags);
    final localFromIdCopy = fromId;
    if (localFromIdCopy != null) {
      buffer.writeObject(localFromIdCopy);
    }
    final localFromNameCopy = fromName;
    if (localFromNameCopy != null) {
      buffer.writeString(localFromNameCopy);
    }
    buffer.writeDateTime(date);
    final localChannelPostCopy = channelPost;
    if (localChannelPostCopy != null) {
      buffer.writeInt32(localChannelPostCopy);
    }
    final localPostAuthorCopy = postAuthor;
    if (localPostAuthorCopy != null) {
      buffer.writeString(localPostAuthorCopy);
    }
    final localSavedFromPeerCopy = savedFromPeer;
    if (localSavedFromPeerCopy != null) {
      buffer.writeObject(localSavedFromPeerCopy);
    }
    final localSavedFromMsgIdCopy = savedFromMsgId;
    if (localSavedFromMsgIdCopy != null) {
      buffer.writeInt32(localSavedFromMsgIdCopy);
    }
    final localSavedFromIdCopy = savedFromId;
    if (localSavedFromIdCopy != null) {
      buffer.writeObject(localSavedFromIdCopy);
    }
    final localSavedFromNameCopy = savedFromName;
    if (localSavedFromNameCopy != null) {
      buffer.writeString(localSavedFromNameCopy);
    }
    final localSavedDateCopy = savedDate;
    if (localSavedDateCopy != null) {
      buffer.writeDateTime(localSavedDateCopy);
    }
    final localPsaTypeCopy = psaType;
    if (localPsaTypeCopy != null) {
      buffer.writeString(localPsaTypeCopy);
    }

    // Finished serialization.
  }
}

/// Auth Code Type Sms.
///
/// ID: `72a3158c`.
class AuthCodeTypeSms extends AuthCodeTypeBase {
  /// Auth Code Type Sms constructor.
  const AuthCodeTypeSms() : super._();

  /// Deserialize.
  factory AuthCodeTypeSms.deserialize(BinaryReader reader) {
    // Construct [AuthCodeTypeSms] object.
    final returnValue = AuthCodeTypeSms();

    // Now return the deserialized [AuthCodeTypeSms].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x72a3158c.
    buffer.writeInt32(0x72a3158c);

    // Finished serialization.
  }
}

/// Auth Code Type Call.
///
/// ID: `741cd3e3`.
class AuthCodeTypeCall extends AuthCodeTypeBase {
  /// Auth Code Type Call constructor.
  const AuthCodeTypeCall() : super._();

  /// Deserialize.
  factory AuthCodeTypeCall.deserialize(BinaryReader reader) {
    // Construct [AuthCodeTypeCall] object.
    final returnValue = AuthCodeTypeCall();

    // Now return the deserialized [AuthCodeTypeCall].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x741cd3e3.
    buffer.writeInt32(0x741cd3e3);

    // Finished serialization.
  }
}

/// Auth Code Type Flash Call.
///
/// ID: `226ccefb`.
class AuthCodeTypeFlashCall extends AuthCodeTypeBase {
  /// Auth Code Type Flash Call constructor.
  const AuthCodeTypeFlashCall() : super._();

  /// Deserialize.
  factory AuthCodeTypeFlashCall.deserialize(BinaryReader reader) {
    // Construct [AuthCodeTypeFlashCall] object.
    final returnValue = AuthCodeTypeFlashCall();

    // Now return the deserialized [AuthCodeTypeFlashCall].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x226ccefb.
    buffer.writeInt32(0x226ccefb);

    // Finished serialization.
  }
}

/// Auth Code Type Missed Call.
///
/// ID: `d61ad6ee`.
class AuthCodeTypeMissedCall extends AuthCodeTypeBase {
  /// Auth Code Type Missed Call constructor.
  const AuthCodeTypeMissedCall() : super._();

  /// Deserialize.
  factory AuthCodeTypeMissedCall.deserialize(BinaryReader reader) {
    // Construct [AuthCodeTypeMissedCall] object.
    final returnValue = AuthCodeTypeMissedCall();

    // Now return the deserialized [AuthCodeTypeMissedCall].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd61ad6ee.
    buffer.writeInt32(0xd61ad6ee);

    // Finished serialization.
  }
}

/// Auth Code Type Fragment Sms.
///
/// ID: `06ed998c`.
class AuthCodeTypeFragmentSms extends AuthCodeTypeBase {
  /// Auth Code Type Fragment Sms constructor.
  const AuthCodeTypeFragmentSms() : super._();

  /// Deserialize.
  factory AuthCodeTypeFragmentSms.deserialize(BinaryReader reader) {
    // Construct [AuthCodeTypeFragmentSms] object.
    final returnValue = AuthCodeTypeFragmentSms();

    // Now return the deserialized [AuthCodeTypeFragmentSms].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x06ed998c.
    buffer.writeInt32(0x06ed998c);

    // Finished serialization.
  }
}

/// Auth Sent Code Type App.
///
/// ID: `3dbb5986`.
class AuthSentCodeTypeApp extends AuthSentCodeTypeBase {
  /// Auth Sent Code Type App constructor.
  const AuthSentCodeTypeApp({
    required this.length,
  }) : super._();

  /// Deserialize.
  factory AuthSentCodeTypeApp.deserialize(BinaryReader reader) {
    // Read [AuthSentCodeTypeApp] fields.
    final length = reader.readInt32();

    // Construct [AuthSentCodeTypeApp] object.
    final returnValue = AuthSentCodeTypeApp(
      length: length,
    );

    // Now return the deserialized [AuthSentCodeTypeApp].
    return returnValue;
  }

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3dbb5986.
    buffer.writeInt32(0x3dbb5986);

    // Write fields.
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Auth Sent Code Type Sms.
///
/// ID: `c000bba2`.
class AuthSentCodeTypeSms extends AuthSentCodeTypeBase {
  /// Auth Sent Code Type Sms constructor.
  const AuthSentCodeTypeSms({
    required this.length,
  }) : super._();

  /// Deserialize.
  factory AuthSentCodeTypeSms.deserialize(BinaryReader reader) {
    // Read [AuthSentCodeTypeSms] fields.
    final length = reader.readInt32();

    // Construct [AuthSentCodeTypeSms] object.
    final returnValue = AuthSentCodeTypeSms(
      length: length,
    );

    // Now return the deserialized [AuthSentCodeTypeSms].
    return returnValue;
  }

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc000bba2.
    buffer.writeInt32(0xc000bba2);

    // Write fields.
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Auth Sent Code Type Call.
///
/// ID: `5353e5a7`.
class AuthSentCodeTypeCall extends AuthSentCodeTypeBase {
  /// Auth Sent Code Type Call constructor.
  const AuthSentCodeTypeCall({
    required this.length,
  }) : super._();

  /// Deserialize.
  factory AuthSentCodeTypeCall.deserialize(BinaryReader reader) {
    // Read [AuthSentCodeTypeCall] fields.
    final length = reader.readInt32();

    // Construct [AuthSentCodeTypeCall] object.
    final returnValue = AuthSentCodeTypeCall(
      length: length,
    );

    // Now return the deserialized [AuthSentCodeTypeCall].
    return returnValue;
  }

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5353e5a7.
    buffer.writeInt32(0x5353e5a7);

    // Write fields.
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Auth Sent Code Type Flash Call.
///
/// ID: `ab03c6d9`.
class AuthSentCodeTypeFlashCall extends AuthSentCodeTypeBase {
  /// Auth Sent Code Type Flash Call constructor.
  const AuthSentCodeTypeFlashCall({
    required this.pattern,
  }) : super._();

  /// Deserialize.
  factory AuthSentCodeTypeFlashCall.deserialize(BinaryReader reader) {
    // Read [AuthSentCodeTypeFlashCall] fields.
    final pattern = reader.readString();

    // Construct [AuthSentCodeTypeFlashCall] object.
    final returnValue = AuthSentCodeTypeFlashCall(
      pattern: pattern,
    );

    // Now return the deserialized [AuthSentCodeTypeFlashCall].
    return returnValue;
  }

  /// Pattern.
  final String pattern;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xab03c6d9.
    buffer.writeInt32(0xab03c6d9);

    // Write fields.
    buffer.writeString(pattern);

    // Finished serialization.
  }
}

/// Auth Sent Code Type Missed Call.
///
/// ID: `82006484`.
class AuthSentCodeTypeMissedCall extends AuthSentCodeTypeBase {
  /// Auth Sent Code Type Missed Call constructor.
  const AuthSentCodeTypeMissedCall({
    required this.prefix,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory AuthSentCodeTypeMissedCall.deserialize(BinaryReader reader) {
    // Read [AuthSentCodeTypeMissedCall] fields.
    final prefix = reader.readString();
    final length = reader.readInt32();

    // Construct [AuthSentCodeTypeMissedCall] object.
    final returnValue = AuthSentCodeTypeMissedCall(
      prefix: prefix,
      length: length,
    );

    // Now return the deserialized [AuthSentCodeTypeMissedCall].
    return returnValue;
  }

  /// Prefix.
  final String prefix;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x82006484.
    buffer.writeInt32(0x82006484);

    // Write fields.
    buffer.writeString(prefix);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Auth Sent Code Type Email Code.
///
/// ID: `f450f59b`.
class AuthSentCodeTypeEmailCode extends AuthSentCodeTypeBase {
  /// Auth Sent Code Type Email Code constructor.
  const AuthSentCodeTypeEmailCode({
    required this.appleSigninAllowed,
    required this.googleSigninAllowed,
    required this.emailPattern,
    required this.length,
    this.resetAvailablePeriod,
    this.resetPendingDate,
  }) : super._();

  /// Deserialize.
  factory AuthSentCodeTypeEmailCode.deserialize(BinaryReader reader) {
    // Read [AuthSentCodeTypeEmailCode] fields.
    final flags = reader.readInt32();
    final appleSigninAllowed = (flags & 1) != 0;
    final googleSigninAllowed = (flags & 2) != 0;
    final emailPattern = reader.readString();
    final length = reader.readInt32();
    final hasResetAvailablePeriodField = (flags & 8) != 0;
    final resetAvailablePeriod =
        hasResetAvailablePeriodField ? reader.readInt32() : null;
    final hasResetPendingDateField = (flags & 16) != 0;
    final resetPendingDate =
        hasResetPendingDateField ? reader.readDateTime() : null;

    // Construct [AuthSentCodeTypeEmailCode] object.
    final returnValue = AuthSentCodeTypeEmailCode(
      appleSigninAllowed: appleSigninAllowed,
      googleSigninAllowed: googleSigninAllowed,
      emailPattern: emailPattern,
      length: length,
      resetAvailablePeriod: resetAvailablePeriod,
      resetPendingDate: resetPendingDate,
    );

    // Now return the deserialized [AuthSentCodeTypeEmailCode].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: appleSigninAllowed,
      b01: googleSigninAllowed,
      b03: resetAvailablePeriod != null,
      b04: resetPendingDate != null,
    );

    return v;
  }

  /// apple_signin_allowed: bit 0 of flags.0?true
  final bool appleSigninAllowed;

  /// google_signin_allowed: bit 1 of flags.1?true
  final bool googleSigninAllowed;

  /// Email Pattern.
  final String emailPattern;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Reset Available Period.
  final int? resetAvailablePeriod;

  /// Reset Pending Date.
  final DateTime? resetPendingDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf450f59b.
    buffer.writeInt32(0xf450f59b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(emailPattern);
    buffer.writeInt32(length);
    final localResetAvailablePeriodCopy = resetAvailablePeriod;
    if (localResetAvailablePeriodCopy != null) {
      buffer.writeInt32(localResetAvailablePeriodCopy);
    }
    final localResetPendingDateCopy = resetPendingDate;
    if (localResetPendingDateCopy != null) {
      buffer.writeDateTime(localResetPendingDateCopy);
    }

    // Finished serialization.
  }
}

/// Auth Sent Code Type Set Up Email Required.
///
/// ID: `a5491dea`.
class AuthSentCodeTypeSetUpEmailRequired extends AuthSentCodeTypeBase {
  /// Auth Sent Code Type Set Up Email Required constructor.
  const AuthSentCodeTypeSetUpEmailRequired({
    required this.appleSigninAllowed,
    required this.googleSigninAllowed,
  }) : super._();

  /// Deserialize.
  factory AuthSentCodeTypeSetUpEmailRequired.deserialize(BinaryReader reader) {
    // Read [AuthSentCodeTypeSetUpEmailRequired] fields.
    final flags = reader.readInt32();
    final appleSigninAllowed = (flags & 1) != 0;
    final googleSigninAllowed = (flags & 2) != 0;

    // Construct [AuthSentCodeTypeSetUpEmailRequired] object.
    final returnValue = AuthSentCodeTypeSetUpEmailRequired(
      appleSigninAllowed: appleSigninAllowed,
      googleSigninAllowed: googleSigninAllowed,
    );

    // Now return the deserialized [AuthSentCodeTypeSetUpEmailRequired].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: appleSigninAllowed,
      b01: googleSigninAllowed,
    );

    return v;
  }

  /// apple_signin_allowed: bit 0 of flags.0?true
  final bool appleSigninAllowed;

  /// google_signin_allowed: bit 1 of flags.1?true
  final bool googleSigninAllowed;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa5491dea.
    buffer.writeInt32(0xa5491dea);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Auth Sent Code Type Fragment Sms.
///
/// ID: `d9565c39`.
class AuthSentCodeTypeFragmentSms extends AuthSentCodeTypeBase {
  /// Auth Sent Code Type Fragment Sms constructor.
  const AuthSentCodeTypeFragmentSms({
    required this.url,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory AuthSentCodeTypeFragmentSms.deserialize(BinaryReader reader) {
    // Read [AuthSentCodeTypeFragmentSms] fields.
    final url = reader.readString();
    final length = reader.readInt32();

    // Construct [AuthSentCodeTypeFragmentSms] object.
    final returnValue = AuthSentCodeTypeFragmentSms(
      url: url,
      length: length,
    );

    // Now return the deserialized [AuthSentCodeTypeFragmentSms].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd9565c39.
    buffer.writeInt32(0xd9565c39);

    // Write fields.
    buffer.writeString(url);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Auth Sent Code Type Firebase Sms.
///
/// ID: `e57b1432`.
class AuthSentCodeTypeFirebaseSms extends AuthSentCodeTypeBase {
  /// Auth Sent Code Type Firebase Sms constructor.
  const AuthSentCodeTypeFirebaseSms({
    this.nonce,
    this.receipt,
    this.pushTimeout,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory AuthSentCodeTypeFirebaseSms.deserialize(BinaryReader reader) {
    // Read [AuthSentCodeTypeFirebaseSms] fields.
    final flags = reader.readInt32();
    final hasNonceField = (flags & 1) != 0;
    final nonce = hasNonceField ? reader.readBytes() : null;
    final hasReceiptField = (flags & 2) != 0;
    final receipt = hasReceiptField ? reader.readString() : null;
    final hasPushTimeoutField = (flags & 2) != 0;
    final pushTimeout = hasPushTimeoutField ? reader.readInt32() : null;
    final length = reader.readInt32();

    // Construct [AuthSentCodeTypeFirebaseSms] object.
    final returnValue = AuthSentCodeTypeFirebaseSms(
      nonce: nonce,
      receipt: receipt,
      pushTimeout: pushTimeout,
      length: length,
    );

    // Now return the deserialized [AuthSentCodeTypeFirebaseSms].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: nonce != null,
      b01: receipt != null || pushTimeout != null,
    );

    return v;
  }

  /// Nonce.
  final Uint8List? nonce;

  /// Receipt.
  final String? receipt;

  /// Push Timeout.
  final int? pushTimeout;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe57b1432.
    buffer.writeInt32(0xe57b1432);

    // Write fields.
    buffer.writeInt32(flags);
    final localNonceCopy = nonce;
    if (localNonceCopy != null) {
      buffer.writeBytes(localNonceCopy);
    }
    final localReceiptCopy = receipt;
    if (localReceiptCopy != null) {
      buffer.writeString(localReceiptCopy);
    }
    final localPushTimeoutCopy = pushTimeout;
    if (localPushTimeoutCopy != null) {
      buffer.writeInt32(localPushTimeoutCopy);
    }
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Messages Bot Callback Answer.
///
/// ID: `36585ea4`.
class MessagesBotCallbackAnswer extends MessagesBotCallbackAnswerBase {
  /// Messages Bot Callback Answer constructor.
  const MessagesBotCallbackAnswer({
    required this.alert,
    required this.hasUrl,
    required this.nativeUi,
    this.message,
    this.url,
    required this.cacheTime,
  }) : super._();

  /// Deserialize.
  factory MessagesBotCallbackAnswer.deserialize(BinaryReader reader) {
    // Read [MessagesBotCallbackAnswer] fields.
    final flags = reader.readInt32();
    final alert = (flags & 2) != 0;
    final hasUrl = (flags & 8) != 0;
    final nativeUi = (flags & 16) != 0;
    final hasMessageField = (flags & 1) != 0;
    final message = hasMessageField ? reader.readString() : null;
    final hasUrlField = (flags & 4) != 0;
    final url = hasUrlField ? reader.readString() : null;
    final cacheTime = reader.readInt32();

    // Construct [MessagesBotCallbackAnswer] object.
    final returnValue = MessagesBotCallbackAnswer(
      alert: alert,
      hasUrl: hasUrl,
      nativeUi: nativeUi,
      message: message,
      url: url,
      cacheTime: cacheTime,
    );

    // Now return the deserialized [MessagesBotCallbackAnswer].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: alert,
      b03: hasUrl,
      b04: nativeUi,
      b00: message != null,
      b02: url != null,
    );

    return v;
  }

  /// alert: bit 1 of flags.1?true
  final bool alert;

  /// has_url: bit 3 of flags.3?true
  final bool hasUrl;

  /// native_ui: bit 4 of flags.4?true
  final bool nativeUi;

  /// Message.
  final String? message;

  /// Url.
  final String? url;

  /// Cache Time.
  ///
  /// Field type is Int32.
  final int cacheTime;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x36585ea4.
    buffer.writeInt32(0x36585ea4);

    // Write fields.
    buffer.writeInt32(flags);
    final localMessageCopy = message;
    if (localMessageCopy != null) {
      buffer.writeString(localMessageCopy);
    }
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }
    buffer.writeInt32(cacheTime);

    // Finished serialization.
  }
}

/// Messages Message Edit Data.
///
/// ID: `26b5dde6`.
class MessagesMessageEditData extends MessagesMessageEditDataBase {
  /// Messages Message Edit Data constructor.
  const MessagesMessageEditData({
    required this.caption,
  }) : super._();

  /// Deserialize.
  factory MessagesMessageEditData.deserialize(BinaryReader reader) {
    // Read [MessagesMessageEditData] fields.
    final flags = reader.readInt32();
    final caption = (flags & 1) != 0;

    // Construct [MessagesMessageEditData] object.
    final returnValue = MessagesMessageEditData(
      caption: caption,
    );

    // Now return the deserialized [MessagesMessageEditData].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: caption,
    );

    return v;
  }

  /// caption: bit 0 of flags.0?true
  final bool caption;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x26b5dde6.
    buffer.writeInt32(0x26b5dde6);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Input Bot Inline Message I D.
///
/// ID: `890c3d89`.
class InputBotInlineMessageID extends InputBotInlineMessageIDBase {
  /// Input Bot Inline Message I D constructor.
  const InputBotInlineMessageID({
    required this.dcId,
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineMessageID.deserialize(BinaryReader reader) {
    // Read [InputBotInlineMessageID] fields.
    final dcId = reader.readInt32();
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputBotInlineMessageID] object.
    final returnValue = InputBotInlineMessageID(
      dcId: dcId,
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputBotInlineMessageID].
    return returnValue;
  }

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x890c3d89.
    buffer.writeInt32(0x890c3d89);

    // Write fields.
    buffer.writeInt32(dcId);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Bot Inline Message I D64.
///
/// ID: `b6d915d7`.
class InputBotInlineMessageID64 extends InputBotInlineMessageIDBase {
  /// Input Bot Inline Message I D64 constructor.
  const InputBotInlineMessageID64({
    required this.dcId,
    required this.ownerId,
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputBotInlineMessageID64.deserialize(BinaryReader reader) {
    // Read [InputBotInlineMessageID64] fields.
    final dcId = reader.readInt32();
    final ownerId = reader.readInt64();
    final id = reader.readInt32();
    final accessHash = reader.readInt64();

    // Construct [InputBotInlineMessageID64] object.
    final returnValue = InputBotInlineMessageID64(
      dcId: dcId,
      ownerId: ownerId,
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputBotInlineMessageID64].
    return returnValue;
  }

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Owner Id.
  ///
  /// Field type is Int64.
  final int ownerId;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb6d915d7.
    buffer.writeInt32(0xb6d915d7);

    // Write fields.
    buffer.writeInt32(dcId);
    buffer.writeInt64(ownerId);
    buffer.writeInt32(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Inline Bot Switch P M.
///
/// ID: `3c20629f`.
class InlineBotSwitchPM extends InlineBotSwitchPMBase {
  /// Inline Bot Switch P M constructor.
  const InlineBotSwitchPM({
    required this.text,
    required this.startParam,
  }) : super._();

  /// Deserialize.
  factory InlineBotSwitchPM.deserialize(BinaryReader reader) {
    // Read [InlineBotSwitchPM] fields.
    final text = reader.readString();
    final startParam = reader.readString();

    // Construct [InlineBotSwitchPM] object.
    final returnValue = InlineBotSwitchPM(
      text: text,
      startParam: startParam,
    );

    // Now return the deserialized [InlineBotSwitchPM].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Start Param.
  final String startParam;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3c20629f.
    buffer.writeInt32(0x3c20629f);

    // Write fields.
    buffer.writeString(text);
    buffer.writeString(startParam);

    // Finished serialization.
  }
}

/// Messages Peer Dialogs.
///
/// ID: `3371c354`.
class MessagesPeerDialogs extends MessagesPeerDialogsBase {
  /// Messages Peer Dialogs constructor.
  const MessagesPeerDialogs({
    required this.dialogs,
    required this.messages,
    required this.chats,
    required this.users,
    required this.state,
  }) : super._();

  /// Deserialize.
  factory MessagesPeerDialogs.deserialize(BinaryReader reader) {
    // Read [MessagesPeerDialogs] fields.
    final dialogs = reader.readVectorObject<DialogBase>();
    final messages = reader.readVectorObject<MessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final state = reader.readObject() as UpdatesStateBase;

    // Construct [MessagesPeerDialogs] object.
    final returnValue = MessagesPeerDialogs(
      dialogs: dialogs,
      messages: messages,
      chats: chats,
      users: users,
      state: state,
    );

    // Now return the deserialized [MessagesPeerDialogs].
    return returnValue;
  }

  /// Dialogs.
  final List<DialogBase> dialogs;

  /// Messages.
  final List<MessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// State.
  final UpdatesStateBase state;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3371c354.
    buffer.writeInt32(0x3371c354);

    // Write fields.
    buffer.writeVectorObject(dialogs);
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    buffer.writeObject(state);

    // Finished serialization.
  }
}

/// Top Peer.
///
/// ID: `edcdc05b`.
class TopPeer extends TopPeerBase {
  /// Top Peer constructor.
  const TopPeer({
    required this.peer,
    required this.rating,
  }) : super._();

  /// Deserialize.
  factory TopPeer.deserialize(BinaryReader reader) {
    // Read [TopPeer] fields.
    final peer = reader.readObject() as PeerBase;
    final rating = reader.readFloat64();

    // Construct [TopPeer] object.
    final returnValue = TopPeer(
      peer: peer,
      rating: rating,
    );

    // Now return the deserialized [TopPeer].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Rating.
  final double rating;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xedcdc05b.
    buffer.writeInt32(0xedcdc05b);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeDouble(rating);

    // Finished serialization.
  }
}

/// Top Peer Category Bots P M.
///
/// ID: `ab661b5b`.
class TopPeerCategoryBotsPM extends TopPeerCategoryBase {
  /// Top Peer Category Bots P M constructor.
  const TopPeerCategoryBotsPM() : super._();

  /// Deserialize.
  factory TopPeerCategoryBotsPM.deserialize(BinaryReader reader) {
    // Construct [TopPeerCategoryBotsPM] object.
    final returnValue = TopPeerCategoryBotsPM();

    // Now return the deserialized [TopPeerCategoryBotsPM].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xab661b5b.
    buffer.writeInt32(0xab661b5b);

    // Finished serialization.
  }
}

/// Top Peer Category Bots Inline.
///
/// ID: `148677e2`.
class TopPeerCategoryBotsInline extends TopPeerCategoryBase {
  /// Top Peer Category Bots Inline constructor.
  const TopPeerCategoryBotsInline() : super._();

  /// Deserialize.
  factory TopPeerCategoryBotsInline.deserialize(BinaryReader reader) {
    // Construct [TopPeerCategoryBotsInline] object.
    final returnValue = TopPeerCategoryBotsInline();

    // Now return the deserialized [TopPeerCategoryBotsInline].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x148677e2.
    buffer.writeInt32(0x148677e2);

    // Finished serialization.
  }
}

/// Top Peer Category Correspondents.
///
/// ID: `0637b7ed`.
class TopPeerCategoryCorrespondents extends TopPeerCategoryBase {
  /// Top Peer Category Correspondents constructor.
  const TopPeerCategoryCorrespondents() : super._();

  /// Deserialize.
  factory TopPeerCategoryCorrespondents.deserialize(BinaryReader reader) {
    // Construct [TopPeerCategoryCorrespondents] object.
    final returnValue = TopPeerCategoryCorrespondents();

    // Now return the deserialized [TopPeerCategoryCorrespondents].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0637b7ed.
    buffer.writeInt32(0x0637b7ed);

    // Finished serialization.
  }
}

/// Top Peer Category Groups.
///
/// ID: `bd17a14a`.
class TopPeerCategoryGroups extends TopPeerCategoryBase {
  /// Top Peer Category Groups constructor.
  const TopPeerCategoryGroups() : super._();

  /// Deserialize.
  factory TopPeerCategoryGroups.deserialize(BinaryReader reader) {
    // Construct [TopPeerCategoryGroups] object.
    final returnValue = TopPeerCategoryGroups();

    // Now return the deserialized [TopPeerCategoryGroups].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbd17a14a.
    buffer.writeInt32(0xbd17a14a);

    // Finished serialization.
  }
}

/// Top Peer Category Channels.
///
/// ID: `161d9628`.
class TopPeerCategoryChannels extends TopPeerCategoryBase {
  /// Top Peer Category Channels constructor.
  const TopPeerCategoryChannels() : super._();

  /// Deserialize.
  factory TopPeerCategoryChannels.deserialize(BinaryReader reader) {
    // Construct [TopPeerCategoryChannels] object.
    final returnValue = TopPeerCategoryChannels();

    // Now return the deserialized [TopPeerCategoryChannels].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x161d9628.
    buffer.writeInt32(0x161d9628);

    // Finished serialization.
  }
}

/// Top Peer Category Phone Calls.
///
/// ID: `1e76a78c`.
class TopPeerCategoryPhoneCalls extends TopPeerCategoryBase {
  /// Top Peer Category Phone Calls constructor.
  const TopPeerCategoryPhoneCalls() : super._();

  /// Deserialize.
  factory TopPeerCategoryPhoneCalls.deserialize(BinaryReader reader) {
    // Construct [TopPeerCategoryPhoneCalls] object.
    final returnValue = TopPeerCategoryPhoneCalls();

    // Now return the deserialized [TopPeerCategoryPhoneCalls].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1e76a78c.
    buffer.writeInt32(0x1e76a78c);

    // Finished serialization.
  }
}

/// Top Peer Category Forward Users.
///
/// ID: `a8406ca9`.
class TopPeerCategoryForwardUsers extends TopPeerCategoryBase {
  /// Top Peer Category Forward Users constructor.
  const TopPeerCategoryForwardUsers() : super._();

  /// Deserialize.
  factory TopPeerCategoryForwardUsers.deserialize(BinaryReader reader) {
    // Construct [TopPeerCategoryForwardUsers] object.
    final returnValue = TopPeerCategoryForwardUsers();

    // Now return the deserialized [TopPeerCategoryForwardUsers].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa8406ca9.
    buffer.writeInt32(0xa8406ca9);

    // Finished serialization.
  }
}

/// Top Peer Category Forward Chats.
///
/// ID: `fbeec0f0`.
class TopPeerCategoryForwardChats extends TopPeerCategoryBase {
  /// Top Peer Category Forward Chats constructor.
  const TopPeerCategoryForwardChats() : super._();

  /// Deserialize.
  factory TopPeerCategoryForwardChats.deserialize(BinaryReader reader) {
    // Construct [TopPeerCategoryForwardChats] object.
    final returnValue = TopPeerCategoryForwardChats();

    // Now return the deserialized [TopPeerCategoryForwardChats].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfbeec0f0.
    buffer.writeInt32(0xfbeec0f0);

    // Finished serialization.
  }
}

/// Top Peer Category Peers.
///
/// ID: `fb834291`.
class TopPeerCategoryPeers extends TopPeerCategoryPeersBase {
  /// Top Peer Category Peers constructor.
  const TopPeerCategoryPeers({
    required this.category,
    required this.count,
    required this.peers,
  }) : super._();

  /// Deserialize.
  factory TopPeerCategoryPeers.deserialize(BinaryReader reader) {
    // Read [TopPeerCategoryPeers] fields.
    final category = reader.readObject() as TopPeerCategoryBase;
    final count = reader.readInt32();
    final peers = reader.readVectorObject<TopPeerBase>();

    // Construct [TopPeerCategoryPeers] object.
    final returnValue = TopPeerCategoryPeers(
      category: category,
      count: count,
      peers: peers,
    );

    // Now return the deserialized [TopPeerCategoryPeers].
    return returnValue;
  }

  /// Category.
  final TopPeerCategoryBase category;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Peers.
  final List<TopPeerBase> peers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfb834291.
    buffer.writeInt32(0xfb834291);

    // Write fields.
    buffer.writeObject(category);
    buffer.writeInt32(count);
    buffer.writeVectorObject(peers);

    // Finished serialization.
  }
}

/// Contacts Top Peers Not Modified.
///
/// ID: `de266ef5`.
class ContactsTopPeersNotModified extends ContactsTopPeersBase {
  /// Contacts Top Peers Not Modified constructor.
  const ContactsTopPeersNotModified() : super._();

  /// Deserialize.
  factory ContactsTopPeersNotModified.deserialize(BinaryReader reader) {
    // Construct [ContactsTopPeersNotModified] object.
    final returnValue = ContactsTopPeersNotModified();

    // Now return the deserialized [ContactsTopPeersNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xde266ef5.
    buffer.writeInt32(0xde266ef5);

    // Finished serialization.
  }
}

/// Contacts Top Peers.
///
/// ID: `70b772a8`.
class ContactsTopPeers extends ContactsTopPeersBase {
  /// Contacts Top Peers constructor.
  const ContactsTopPeers({
    required this.categories,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ContactsTopPeers.deserialize(BinaryReader reader) {
    // Read [ContactsTopPeers] fields.
    final categories = reader.readVectorObject<TopPeerCategoryPeersBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ContactsTopPeers] object.
    final returnValue = ContactsTopPeers(
      categories: categories,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ContactsTopPeers].
    return returnValue;
  }

  /// Categories.
  final List<TopPeerCategoryPeersBase> categories;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x70b772a8.
    buffer.writeInt32(0x70b772a8);

    // Write fields.
    buffer.writeVectorObject(categories);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Contacts Top Peers Disabled.
///
/// ID: `b52c939d`.
class ContactsTopPeersDisabled extends ContactsTopPeersBase {
  /// Contacts Top Peers Disabled constructor.
  const ContactsTopPeersDisabled() : super._();

  /// Deserialize.
  factory ContactsTopPeersDisabled.deserialize(BinaryReader reader) {
    // Construct [ContactsTopPeersDisabled] object.
    final returnValue = ContactsTopPeersDisabled();

    // Now return the deserialized [ContactsTopPeersDisabled].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb52c939d.
    buffer.writeInt32(0xb52c939d);

    // Finished serialization.
  }
}

/// Draft Message Empty.
///
/// ID: `1b0c841a`.
class DraftMessageEmpty extends DraftMessageBase {
  /// Draft Message Empty constructor.
  const DraftMessageEmpty({
    this.date,
  }) : super._();

  /// Deserialize.
  factory DraftMessageEmpty.deserialize(BinaryReader reader) {
    // Read [DraftMessageEmpty] fields.
    final flags = reader.readInt32();
    final hasDateField = (flags & 1) != 0;
    final date = hasDateField ? reader.readDateTime() : null;

    // Construct [DraftMessageEmpty] object.
    final returnValue = DraftMessageEmpty(
      date: date,
    );

    // Now return the deserialized [DraftMessageEmpty].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: date != null,
    );

    return v;
  }

  /// Date.
  final DateTime? date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1b0c841a.
    buffer.writeInt32(0x1b0c841a);

    // Write fields.
    buffer.writeInt32(flags);
    final localDateCopy = date;
    if (localDateCopy != null) {
      buffer.writeDateTime(localDateCopy);
    }

    // Finished serialization.
  }
}

/// Draft Message.
///
/// ID: `3fccf7ef`.
class DraftMessage extends DraftMessageBase {
  /// Draft Message constructor.
  const DraftMessage({
    required this.noWebpage,
    required this.invertMedia,
    this.replyTo,
    required this.message,
    this.entities,
    this.media,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory DraftMessage.deserialize(BinaryReader reader) {
    // Read [DraftMessage] fields.
    final flags = reader.readInt32();
    final noWebpage = (flags & 2) != 0;
    final invertMedia = (flags & 64) != 0;
    final hasReplyToField = (flags & 16) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as InputReplyToBase : null;
    final message = reader.readString();
    final hasEntitiesField = (flags & 8) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasMediaField = (flags & 32) != 0;
    final media = hasMediaField ? reader.readObject() as InputMediaBase : null;
    final date = reader.readDateTime();

    // Construct [DraftMessage] object.
    final returnValue = DraftMessage(
      noWebpage: noWebpage,
      invertMedia: invertMedia,
      replyTo: replyTo,
      message: message,
      entities: entities,
      media: media,
      date: date,
    );

    // Now return the deserialized [DraftMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: noWebpage,
      b06: invertMedia,
      b04: replyTo != null,
      b03: entities != null,
      b05: media != null,
    );

    return v;
  }

  /// no_webpage: bit 1 of flags.1?true
  final bool noWebpage;

  /// invert_media: bit 6 of flags.6?true
  final bool invertMedia;

  /// Reply To.
  final InputReplyToBase? replyTo;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Media.
  final InputMediaBase? media;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3fccf7ef.
    buffer.writeInt32(0x3fccf7ef);

    // Write fields.
    buffer.writeInt32(flags);
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localMediaCopy = media;
    if (localMediaCopy != null) {
      buffer.writeObject(localMediaCopy);
    }
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Messages Featured Stickers Not Modified.
///
/// ID: `c6dc0c66`.
class MessagesFeaturedStickersNotModified extends MessagesFeaturedStickersBase {
  /// Messages Featured Stickers Not Modified constructor.
  const MessagesFeaturedStickersNotModified({
    required this.count,
  }) : super._();

  /// Deserialize.
  factory MessagesFeaturedStickersNotModified.deserialize(BinaryReader reader) {
    // Read [MessagesFeaturedStickersNotModified] fields.
    final count = reader.readInt32();

    // Construct [MessagesFeaturedStickersNotModified] object.
    final returnValue = MessagesFeaturedStickersNotModified(
      count: count,
    );

    // Now return the deserialized [MessagesFeaturedStickersNotModified].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc6dc0c66.
    buffer.writeInt32(0xc6dc0c66);

    // Write fields.
    buffer.writeInt32(count);

    // Finished serialization.
  }
}

/// Messages Featured Stickers.
///
/// ID: `be382906`.
class MessagesFeaturedStickers extends MessagesFeaturedStickersBase {
  /// Messages Featured Stickers constructor.
  const MessagesFeaturedStickers({
    required this.premium,
    required this.hash,
    required this.count,
    required this.sets,
    required this.unread,
  }) : super._();

  /// Deserialize.
  factory MessagesFeaturedStickers.deserialize(BinaryReader reader) {
    // Read [MessagesFeaturedStickers] fields.
    final flags = reader.readInt32();
    final premium = (flags & 1) != 0;
    final hash = reader.readInt64();
    final count = reader.readInt32();
    final sets = reader.readVectorObject<StickerSetCoveredBase>();
    final unread = reader.readVectorInt64();

    // Construct [MessagesFeaturedStickers] object.
    final returnValue = MessagesFeaturedStickers(
      premium: premium,
      hash: hash,
      count: count,
      sets: sets,
      unread: unread,
    );

    // Now return the deserialized [MessagesFeaturedStickers].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: premium,
    );

    return v;
  }

  /// premium: bit 0 of flags.0?true
  final bool premium;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Sets.
  final List<StickerSetCoveredBase> sets;

  /// Unread.
  final List<int> unread;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbe382906.
    buffer.writeInt32(0xbe382906);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(hash);
    buffer.writeInt32(count);
    buffer.writeVectorObject(sets);
    buffer.writeVectorInt64(unread);

    // Finished serialization.
  }
}

/// Messages Recent Stickers Not Modified.
///
/// ID: `0b17f890`.
class MessagesRecentStickersNotModified extends MessagesRecentStickersBase {
  /// Messages Recent Stickers Not Modified constructor.
  const MessagesRecentStickersNotModified() : super._();

  /// Deserialize.
  factory MessagesRecentStickersNotModified.deserialize(BinaryReader reader) {
    // Construct [MessagesRecentStickersNotModified] object.
    final returnValue = MessagesRecentStickersNotModified();

    // Now return the deserialized [MessagesRecentStickersNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0b17f890.
    buffer.writeInt32(0x0b17f890);

    // Finished serialization.
  }
}

/// Messages Recent Stickers.
///
/// ID: `88d37c56`.
class MessagesRecentStickers extends MessagesRecentStickersBase {
  /// Messages Recent Stickers constructor.
  const MessagesRecentStickers({
    required this.hash,
    required this.packs,
    required this.stickers,
    required this.dates,
  }) : super._();

  /// Deserialize.
  factory MessagesRecentStickers.deserialize(BinaryReader reader) {
    // Read [MessagesRecentStickers] fields.
    final hash = reader.readInt64();
    final packs = reader.readVectorObject<StickerPackBase>();
    final stickers = reader.readVectorObject<DocumentBase>();
    final dates = reader.readVectorInt32();

    // Construct [MessagesRecentStickers] object.
    final returnValue = MessagesRecentStickers(
      hash: hash,
      packs: packs,
      stickers: stickers,
      dates: dates,
    );

    // Now return the deserialized [MessagesRecentStickers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Packs.
  final List<StickerPackBase> packs;

  /// Stickers.
  final List<DocumentBase> stickers;

  /// Dates.
  final List<int> dates;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x88d37c56.
    buffer.writeInt32(0x88d37c56);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(packs);
    buffer.writeVectorObject(stickers);
    buffer.writeVectorInt32(dates);

    // Finished serialization.
  }
}

/// Messages Archived Stickers.
///
/// ID: `4fcba9c8`.
class MessagesArchivedStickers extends MessagesArchivedStickersBase {
  /// Messages Archived Stickers constructor.
  const MessagesArchivedStickers({
    required this.count,
    required this.sets,
  }) : super._();

  /// Deserialize.
  factory MessagesArchivedStickers.deserialize(BinaryReader reader) {
    // Read [MessagesArchivedStickers] fields.
    final count = reader.readInt32();
    final sets = reader.readVectorObject<StickerSetCoveredBase>();

    // Construct [MessagesArchivedStickers] object.
    final returnValue = MessagesArchivedStickers(
      count: count,
      sets: sets,
    );

    // Now return the deserialized [MessagesArchivedStickers].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Sets.
  final List<StickerSetCoveredBase> sets;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4fcba9c8.
    buffer.writeInt32(0x4fcba9c8);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(sets);

    // Finished serialization.
  }
}

/// Messages Sticker Set Install Result Success.
///
/// ID: `38641628`.
class MessagesStickerSetInstallResultSuccess
    extends MessagesStickerSetInstallResultBase {
  /// Messages Sticker Set Install Result Success constructor.
  const MessagesStickerSetInstallResultSuccess() : super._();

  /// Deserialize.
  factory MessagesStickerSetInstallResultSuccess.deserialize(
      BinaryReader reader) {
    // Construct [MessagesStickerSetInstallResultSuccess] object.
    final returnValue = MessagesStickerSetInstallResultSuccess();

    // Now return the deserialized [MessagesStickerSetInstallResultSuccess].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x38641628.
    buffer.writeInt32(0x38641628);

    // Finished serialization.
  }
}

/// Messages Sticker Set Install Result Archive.
///
/// ID: `35e410a8`.
class MessagesStickerSetInstallResultArchive
    extends MessagesStickerSetInstallResultBase {
  /// Messages Sticker Set Install Result Archive constructor.
  const MessagesStickerSetInstallResultArchive({
    required this.sets,
  }) : super._();

  /// Deserialize.
  factory MessagesStickerSetInstallResultArchive.deserialize(
      BinaryReader reader) {
    // Read [MessagesStickerSetInstallResultArchive] fields.
    final sets = reader.readVectorObject<StickerSetCoveredBase>();

    // Construct [MessagesStickerSetInstallResultArchive] object.
    final returnValue = MessagesStickerSetInstallResultArchive(
      sets: sets,
    );

    // Now return the deserialized [MessagesStickerSetInstallResultArchive].
    return returnValue;
  }

  /// Sets.
  final List<StickerSetCoveredBase> sets;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x35e410a8.
    buffer.writeInt32(0x35e410a8);

    // Write fields.
    buffer.writeVectorObject(sets);

    // Finished serialization.
  }
}

/// Sticker Set Covered.
///
/// ID: `6410a5d2`.
class StickerSetCovered extends StickerSetCoveredBase {
  /// Sticker Set Covered constructor.
  const StickerSetCovered({
    required this.set,
    required this.cover,
  }) : super._();

  /// Deserialize.
  factory StickerSetCovered.deserialize(BinaryReader reader) {
    // Read [StickerSetCovered] fields.
    final set = reader.readObject() as StickerSetBase;
    final cover = reader.readObject() as DocumentBase;

    // Construct [StickerSetCovered] object.
    final returnValue = StickerSetCovered(
      set: set,
      cover: cover,
    );

    // Now return the deserialized [StickerSetCovered].
    return returnValue;
  }

  /// Set.
  final StickerSetBase set;

  /// Cover.
  final DocumentBase cover;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6410a5d2.
    buffer.writeInt32(0x6410a5d2);

    // Write fields.
    buffer.writeObject(set);
    buffer.writeObject(cover);

    // Finished serialization.
  }
}

/// Sticker Set Multi Covered.
///
/// ID: `3407e51b`.
class StickerSetMultiCovered extends StickerSetCoveredBase {
  /// Sticker Set Multi Covered constructor.
  const StickerSetMultiCovered({
    required this.set,
    required this.covers,
  }) : super._();

  /// Deserialize.
  factory StickerSetMultiCovered.deserialize(BinaryReader reader) {
    // Read [StickerSetMultiCovered] fields.
    final set = reader.readObject() as StickerSetBase;
    final covers = reader.readVectorObject<DocumentBase>();

    // Construct [StickerSetMultiCovered] object.
    final returnValue = StickerSetMultiCovered(
      set: set,
      covers: covers,
    );

    // Now return the deserialized [StickerSetMultiCovered].
    return returnValue;
  }

  /// Set.
  final StickerSetBase set;

  /// Covers.
  final List<DocumentBase> covers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3407e51b.
    buffer.writeInt32(0x3407e51b);

    // Write fields.
    buffer.writeObject(set);
    buffer.writeVectorObject(covers);

    // Finished serialization.
  }
}

/// Sticker Set Full Covered.
///
/// ID: `40d13c0e`.
class StickerSetFullCovered extends StickerSetCoveredBase {
  /// Sticker Set Full Covered constructor.
  const StickerSetFullCovered({
    required this.set,
    required this.packs,
    required this.keywords,
    required this.documents,
  }) : super._();

  /// Deserialize.
  factory StickerSetFullCovered.deserialize(BinaryReader reader) {
    // Read [StickerSetFullCovered] fields.
    final set = reader.readObject() as StickerSetBase;
    final packs = reader.readVectorObject<StickerPackBase>();
    final keywords = reader.readVectorObject<StickerKeywordBase>();
    final documents = reader.readVectorObject<DocumentBase>();

    // Construct [StickerSetFullCovered] object.
    final returnValue = StickerSetFullCovered(
      set: set,
      packs: packs,
      keywords: keywords,
      documents: documents,
    );

    // Now return the deserialized [StickerSetFullCovered].
    return returnValue;
  }

  /// Set.
  final StickerSetBase set;

  /// Packs.
  final List<StickerPackBase> packs;

  /// Keywords.
  final List<StickerKeywordBase> keywords;

  /// Documents.
  final List<DocumentBase> documents;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x40d13c0e.
    buffer.writeInt32(0x40d13c0e);

    // Write fields.
    buffer.writeObject(set);
    buffer.writeVectorObject(packs);
    buffer.writeVectorObject(keywords);
    buffer.writeVectorObject(documents);

    // Finished serialization.
  }
}

/// Sticker Set No Covered.
///
/// ID: `77b15d1c`.
class StickerSetNoCovered extends StickerSetCoveredBase {
  /// Sticker Set No Covered constructor.
  const StickerSetNoCovered({
    required this.set,
  }) : super._();

  /// Deserialize.
  factory StickerSetNoCovered.deserialize(BinaryReader reader) {
    // Read [StickerSetNoCovered] fields.
    final set = reader.readObject() as StickerSetBase;

    // Construct [StickerSetNoCovered] object.
    final returnValue = StickerSetNoCovered(
      set: set,
    );

    // Now return the deserialized [StickerSetNoCovered].
    return returnValue;
  }

  /// Set.
  final StickerSetBase set;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x77b15d1c.
    buffer.writeInt32(0x77b15d1c);

    // Write fields.
    buffer.writeObject(set);

    // Finished serialization.
  }
}

/// Mask Coords.
///
/// ID: `aed6dbb2`.
class MaskCoords extends MaskCoordsBase {
  /// Mask Coords constructor.
  const MaskCoords({
    required this.n,
    required this.x,
    required this.y,
    required this.zoom,
  }) : super._();

  /// Deserialize.
  factory MaskCoords.deserialize(BinaryReader reader) {
    // Read [MaskCoords] fields.
    final n = reader.readInt32();
    final x = reader.readFloat64();
    final y = reader.readFloat64();
    final zoom = reader.readFloat64();

    // Construct [MaskCoords] object.
    final returnValue = MaskCoords(
      n: n,
      x: x,
      y: y,
      zoom: zoom,
    );

    // Now return the deserialized [MaskCoords].
    return returnValue;
  }

  /// N.
  ///
  /// Field type is Int32.
  final int n;

  /// X.
  final double x;

  /// Y.
  final double y;

  /// Zoom.
  final double zoom;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaed6dbb2.
    buffer.writeInt32(0xaed6dbb2);

    // Write fields.
    buffer.writeInt32(n);
    buffer.writeDouble(x);
    buffer.writeDouble(y);
    buffer.writeDouble(zoom);

    // Finished serialization.
  }
}

/// Input Stickered Media Photo.
///
/// ID: `4a992157`.
class InputStickeredMediaPhoto extends InputStickeredMediaBase {
  /// Input Stickered Media Photo constructor.
  const InputStickeredMediaPhoto({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory InputStickeredMediaPhoto.deserialize(BinaryReader reader) {
    // Read [InputStickeredMediaPhoto] fields.
    final id = reader.readObject() as InputPhotoBase;

    // Construct [InputStickeredMediaPhoto] object.
    final returnValue = InputStickeredMediaPhoto(
      id: id,
    );

    // Now return the deserialized [InputStickeredMediaPhoto].
    return returnValue;
  }

  /// Id.
  final InputPhotoBase id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4a992157.
    buffer.writeInt32(0x4a992157);

    // Write fields.
    buffer.writeObject(id);

    // Finished serialization.
  }
}

/// Input Stickered Media Document.
///
/// ID: `0438865b`.
class InputStickeredMediaDocument extends InputStickeredMediaBase {
  /// Input Stickered Media Document constructor.
  const InputStickeredMediaDocument({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory InputStickeredMediaDocument.deserialize(BinaryReader reader) {
    // Read [InputStickeredMediaDocument] fields.
    final id = reader.readObject() as InputDocumentBase;

    // Construct [InputStickeredMediaDocument] object.
    final returnValue = InputStickeredMediaDocument(
      id: id,
    );

    // Now return the deserialized [InputStickeredMediaDocument].
    return returnValue;
  }

  /// Id.
  final InputDocumentBase id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0438865b.
    buffer.writeInt32(0x0438865b);

    // Write fields.
    buffer.writeObject(id);

    // Finished serialization.
  }
}

/// Game.
///
/// ID: `bdf9653b`.
class Game extends GameBase {
  /// Game constructor.
  const Game({
    required this.id,
    required this.accessHash,
    required this.shortName,
    required this.title,
    required this.description,
    required this.photo,
    this.document,
  }) : super._();

  /// Deserialize.
  factory Game.deserialize(BinaryReader reader) {
    // Read [Game] fields.
    final flags = reader.readInt32();
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final shortName = reader.readString();
    final title = reader.readString();
    final description = reader.readString();
    final photo = reader.readObject() as PhotoBase;
    final hasDocumentField = (flags & 1) != 0;
    final document =
        hasDocumentField ? reader.readObject() as DocumentBase : null;

    // Construct [Game] object.
    final returnValue = Game(
      id: id,
      accessHash: accessHash,
      shortName: shortName,
      title: title,
      description: description,
      photo: photo,
      document: document,
    );

    // Now return the deserialized [Game].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: document != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Short Name.
  final String shortName;

  /// Title.
  final String title;

  /// Description.
  final String description;

  /// Photo.
  final PhotoBase photo;

  /// Document.
  final DocumentBase? document;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbdf9653b.
    buffer.writeInt32(0xbdf9653b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeString(shortName);
    buffer.writeString(title);
    buffer.writeString(description);
    buffer.writeObject(photo);
    final localDocumentCopy = document;
    if (localDocumentCopy != null) {
      buffer.writeObject(localDocumentCopy);
    }

    // Finished serialization.
  }
}

/// Input Game I D.
///
/// ID: `032c3e77`.
class InputGameID extends InputGameBase {
  /// Input Game I D constructor.
  const InputGameID({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputGameID.deserialize(BinaryReader reader) {
    // Read [InputGameID] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputGameID] object.
    final returnValue = InputGameID(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputGameID].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x032c3e77.
    buffer.writeInt32(0x032c3e77);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Game Short Name.
///
/// ID: `c331e80a`.
class InputGameShortName extends InputGameBase {
  /// Input Game Short Name constructor.
  const InputGameShortName({
    required this.botId,
    required this.shortName,
  }) : super._();

  /// Deserialize.
  factory InputGameShortName.deserialize(BinaryReader reader) {
    // Read [InputGameShortName] fields.
    final botId = reader.readObject() as InputUserBase;
    final shortName = reader.readString();

    // Construct [InputGameShortName] object.
    final returnValue = InputGameShortName(
      botId: botId,
      shortName: shortName,
    );

    // Now return the deserialized [InputGameShortName].
    return returnValue;
  }

  /// Bot Id.
  final InputUserBase botId;

  /// Short Name.
  final String shortName;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc331e80a.
    buffer.writeInt32(0xc331e80a);

    // Write fields.
    buffer.writeObject(botId);
    buffer.writeString(shortName);

    // Finished serialization.
  }
}

/// High Score.
///
/// ID: `73a379eb`.
class HighScore extends HighScoreBase {
  /// High Score constructor.
  const HighScore({
    required this.pos,
    required this.userId,
    required this.score,
  }) : super._();

  /// Deserialize.
  factory HighScore.deserialize(BinaryReader reader) {
    // Read [HighScore] fields.
    final pos = reader.readInt32();
    final userId = reader.readInt64();
    final score = reader.readInt32();

    // Construct [HighScore] object.
    final returnValue = HighScore(
      pos: pos,
      userId: userId,
      score: score,
    );

    // Now return the deserialized [HighScore].
    return returnValue;
  }

  /// Pos.
  ///
  /// Field type is Int32.
  final int pos;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Score.
  ///
  /// Field type is Int32.
  final int score;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x73a379eb.
    buffer.writeInt32(0x73a379eb);

    // Write fields.
    buffer.writeInt32(pos);
    buffer.writeInt64(userId);
    buffer.writeInt32(score);

    // Finished serialization.
  }
}

/// Messages High Scores.
///
/// ID: `9a3bfd99`.
class MessagesHighScores extends MessagesHighScoresBase {
  /// Messages High Scores constructor.
  const MessagesHighScores({
    required this.scores,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesHighScores.deserialize(BinaryReader reader) {
    // Read [MessagesHighScores] fields.
    final scores = reader.readVectorObject<HighScoreBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesHighScores] object.
    final returnValue = MessagesHighScores(
      scores: scores,
      users: users,
    );

    // Now return the deserialized [MessagesHighScores].
    return returnValue;
  }

  /// Scores.
  final List<HighScoreBase> scores;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9a3bfd99.
    buffer.writeInt32(0x9a3bfd99);

    // Write fields.
    buffer.writeVectorObject(scores);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Text Empty.
///
/// ID: `dc3d824f`.
class TextEmpty extends RichTextBase {
  /// Text Empty constructor.
  const TextEmpty() : super._();

  /// Deserialize.
  factory TextEmpty.deserialize(BinaryReader reader) {
    // Construct [TextEmpty] object.
    final returnValue = TextEmpty();

    // Now return the deserialized [TextEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdc3d824f.
    buffer.writeInt32(0xdc3d824f);

    // Finished serialization.
  }
}

/// Text Plain.
///
/// ID: `744694e0`.
class TextPlain extends RichTextBase {
  /// Text Plain constructor.
  const TextPlain({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory TextPlain.deserialize(BinaryReader reader) {
    // Read [TextPlain] fields.
    final text = reader.readString();

    // Construct [TextPlain] object.
    final returnValue = TextPlain(
      text: text,
    );

    // Now return the deserialized [TextPlain].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x744694e0.
    buffer.writeInt32(0x744694e0);

    // Write fields.
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Text Bold.
///
/// ID: `6724abc4`.
class TextBold extends RichTextBase {
  /// Text Bold constructor.
  const TextBold({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory TextBold.deserialize(BinaryReader reader) {
    // Read [TextBold] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [TextBold] object.
    final returnValue = TextBold(
      text: text,
    );

    // Now return the deserialized [TextBold].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6724abc4.
    buffer.writeInt32(0x6724abc4);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Text Italic.
///
/// ID: `d912a59c`.
class TextItalic extends RichTextBase {
  /// Text Italic constructor.
  const TextItalic({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory TextItalic.deserialize(BinaryReader reader) {
    // Read [TextItalic] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [TextItalic] object.
    final returnValue = TextItalic(
      text: text,
    );

    // Now return the deserialized [TextItalic].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd912a59c.
    buffer.writeInt32(0xd912a59c);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Text Underline.
///
/// ID: `c12622c4`.
class TextUnderline extends RichTextBase {
  /// Text Underline constructor.
  const TextUnderline({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory TextUnderline.deserialize(BinaryReader reader) {
    // Read [TextUnderline] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [TextUnderline] object.
    final returnValue = TextUnderline(
      text: text,
    );

    // Now return the deserialized [TextUnderline].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc12622c4.
    buffer.writeInt32(0xc12622c4);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Text Strike.
///
/// ID: `9bf8bb95`.
class TextStrike extends RichTextBase {
  /// Text Strike constructor.
  const TextStrike({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory TextStrike.deserialize(BinaryReader reader) {
    // Read [TextStrike] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [TextStrike] object.
    final returnValue = TextStrike(
      text: text,
    );

    // Now return the deserialized [TextStrike].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9bf8bb95.
    buffer.writeInt32(0x9bf8bb95);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Text Fixed.
///
/// ID: `6c3f19b9`.
class TextFixed extends RichTextBase {
  /// Text Fixed constructor.
  const TextFixed({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory TextFixed.deserialize(BinaryReader reader) {
    // Read [TextFixed] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [TextFixed] object.
    final returnValue = TextFixed(
      text: text,
    );

    // Now return the deserialized [TextFixed].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6c3f19b9.
    buffer.writeInt32(0x6c3f19b9);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Text Url.
///
/// ID: `3c2884c1`.
class TextUrl extends RichTextBase {
  /// Text Url constructor.
  const TextUrl({
    required this.text,
    required this.url,
    required this.webpageId,
  }) : super._();

  /// Deserialize.
  factory TextUrl.deserialize(BinaryReader reader) {
    // Read [TextUrl] fields.
    final text = reader.readObject() as RichTextBase;
    final url = reader.readString();
    final webpageId = reader.readInt64();

    // Construct [TextUrl] object.
    final returnValue = TextUrl(
      text: text,
      url: url,
      webpageId: webpageId,
    );

    // Now return the deserialized [TextUrl].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Url.
  final String url;

  /// Webpage Id.
  ///
  /// Field type is Int64.
  final int webpageId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3c2884c1.
    buffer.writeInt32(0x3c2884c1);

    // Write fields.
    buffer.writeObject(text);
    buffer.writeString(url);
    buffer.writeInt64(webpageId);

    // Finished serialization.
  }
}

/// Text Email.
///
/// ID: `de5a0dd6`.
class TextEmail extends RichTextBase {
  /// Text Email constructor.
  const TextEmail({
    required this.text,
    required this.email,
  }) : super._();

  /// Deserialize.
  factory TextEmail.deserialize(BinaryReader reader) {
    // Read [TextEmail] fields.
    final text = reader.readObject() as RichTextBase;
    final email = reader.readString();

    // Construct [TextEmail] object.
    final returnValue = TextEmail(
      text: text,
      email: email,
    );

    // Now return the deserialized [TextEmail].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Email.
  final String email;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xde5a0dd6.
    buffer.writeInt32(0xde5a0dd6);

    // Write fields.
    buffer.writeObject(text);
    buffer.writeString(email);

    // Finished serialization.
  }
}

/// Text Concat.
///
/// ID: `7e6260d7`.
class TextConcat extends RichTextBase {
  /// Text Concat constructor.
  const TextConcat({
    required this.texts,
  }) : super._();

  /// Deserialize.
  factory TextConcat.deserialize(BinaryReader reader) {
    // Read [TextConcat] fields.
    final texts = reader.readVectorObject<RichTextBase>();

    // Construct [TextConcat] object.
    final returnValue = TextConcat(
      texts: texts,
    );

    // Now return the deserialized [TextConcat].
    return returnValue;
  }

  /// Texts.
  final List<RichTextBase> texts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7e6260d7.
    buffer.writeInt32(0x7e6260d7);

    // Write fields.
    buffer.writeVectorObject(texts);

    // Finished serialization.
  }
}

/// Text Subscript.
///
/// ID: `ed6a8504`.
class TextSubscript extends RichTextBase {
  /// Text Subscript constructor.
  const TextSubscript({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory TextSubscript.deserialize(BinaryReader reader) {
    // Read [TextSubscript] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [TextSubscript] object.
    final returnValue = TextSubscript(
      text: text,
    );

    // Now return the deserialized [TextSubscript].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xed6a8504.
    buffer.writeInt32(0xed6a8504);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Text Superscript.
///
/// ID: `c7fb5e01`.
class TextSuperscript extends RichTextBase {
  /// Text Superscript constructor.
  const TextSuperscript({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory TextSuperscript.deserialize(BinaryReader reader) {
    // Read [TextSuperscript] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [TextSuperscript] object.
    final returnValue = TextSuperscript(
      text: text,
    );

    // Now return the deserialized [TextSuperscript].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc7fb5e01.
    buffer.writeInt32(0xc7fb5e01);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Text Marked.
///
/// ID: `034b8621`.
class TextMarked extends RichTextBase {
  /// Text Marked constructor.
  const TextMarked({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory TextMarked.deserialize(BinaryReader reader) {
    // Read [TextMarked] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [TextMarked] object.
    final returnValue = TextMarked(
      text: text,
    );

    // Now return the deserialized [TextMarked].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x034b8621.
    buffer.writeInt32(0x034b8621);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Text Phone.
///
/// ID: `1ccb966a`.
class TextPhone extends RichTextBase {
  /// Text Phone constructor.
  const TextPhone({
    required this.text,
    required this.phone,
  }) : super._();

  /// Deserialize.
  factory TextPhone.deserialize(BinaryReader reader) {
    // Read [TextPhone] fields.
    final text = reader.readObject() as RichTextBase;
    final phone = reader.readString();

    // Construct [TextPhone] object.
    final returnValue = TextPhone(
      text: text,
      phone: phone,
    );

    // Now return the deserialized [TextPhone].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Phone.
  final String phone;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1ccb966a.
    buffer.writeInt32(0x1ccb966a);

    // Write fields.
    buffer.writeObject(text);
    buffer.writeString(phone);

    // Finished serialization.
  }
}

/// Text Image.
///
/// ID: `081ccf4f`.
class TextImage extends RichTextBase {
  /// Text Image constructor.
  const TextImage({
    required this.documentId,
    required this.w,
    required this.h,
  }) : super._();

  /// Deserialize.
  factory TextImage.deserialize(BinaryReader reader) {
    // Read [TextImage] fields.
    final documentId = reader.readInt64();
    final w = reader.readInt32();
    final h = reader.readInt32();

    // Construct [TextImage] object.
    final returnValue = TextImage(
      documentId: documentId,
      w: w,
      h: h,
    );

    // Now return the deserialized [TextImage].
    return returnValue;
  }

  /// Document Id.
  ///
  /// Field type is Int64.
  final int documentId;

  /// W.
  ///
  /// Field type is Int32.
  final int w;

  /// H.
  ///
  /// Field type is Int32.
  final int h;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x081ccf4f.
    buffer.writeInt32(0x081ccf4f);

    // Write fields.
    buffer.writeInt64(documentId);
    buffer.writeInt32(w);
    buffer.writeInt32(h);

    // Finished serialization.
  }
}

/// Text Anchor.
///
/// ID: `35553762`.
class TextAnchor extends RichTextBase {
  /// Text Anchor constructor.
  const TextAnchor({
    required this.text,
    required this.name,
  }) : super._();

  /// Deserialize.
  factory TextAnchor.deserialize(BinaryReader reader) {
    // Read [TextAnchor] fields.
    final text = reader.readObject() as RichTextBase;
    final name = reader.readString();

    // Construct [TextAnchor] object.
    final returnValue = TextAnchor(
      text: text,
      name: name,
    );

    // Now return the deserialized [TextAnchor].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Name.
  final String name;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x35553762.
    buffer.writeInt32(0x35553762);

    // Write fields.
    buffer.writeObject(text);
    buffer.writeString(name);

    // Finished serialization.
  }
}

/// Page Block Unsupported.
///
/// ID: `13567e8a`.
class PageBlockUnsupported extends PageBlockBase {
  /// Page Block Unsupported constructor.
  const PageBlockUnsupported() : super._();

  /// Deserialize.
  factory PageBlockUnsupported.deserialize(BinaryReader reader) {
    // Construct [PageBlockUnsupported] object.
    final returnValue = PageBlockUnsupported();

    // Now return the deserialized [PageBlockUnsupported].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x13567e8a.
    buffer.writeInt32(0x13567e8a);

    // Finished serialization.
  }
}

/// Page Block Title.
///
/// ID: `70abc3fd`.
class PageBlockTitle extends PageBlockBase {
  /// Page Block Title constructor.
  const PageBlockTitle({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory PageBlockTitle.deserialize(BinaryReader reader) {
    // Read [PageBlockTitle] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [PageBlockTitle] object.
    final returnValue = PageBlockTitle(
      text: text,
    );

    // Now return the deserialized [PageBlockTitle].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x70abc3fd.
    buffer.writeInt32(0x70abc3fd);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Page Block Subtitle.
///
/// ID: `8ffa9a1f`.
class PageBlockSubtitle extends PageBlockBase {
  /// Page Block Subtitle constructor.
  const PageBlockSubtitle({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory PageBlockSubtitle.deserialize(BinaryReader reader) {
    // Read [PageBlockSubtitle] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [PageBlockSubtitle] object.
    final returnValue = PageBlockSubtitle(
      text: text,
    );

    // Now return the deserialized [PageBlockSubtitle].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8ffa9a1f.
    buffer.writeInt32(0x8ffa9a1f);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Page Block Author Date.
///
/// ID: `baafe5e0`.
class PageBlockAuthorDate extends PageBlockBase {
  /// Page Block Author Date constructor.
  const PageBlockAuthorDate({
    required this.author,
    required this.publishedDate,
  }) : super._();

  /// Deserialize.
  factory PageBlockAuthorDate.deserialize(BinaryReader reader) {
    // Read [PageBlockAuthorDate] fields.
    final author = reader.readObject() as RichTextBase;
    final publishedDate = reader.readDateTime();

    // Construct [PageBlockAuthorDate] object.
    final returnValue = PageBlockAuthorDate(
      author: author,
      publishedDate: publishedDate,
    );

    // Now return the deserialized [PageBlockAuthorDate].
    return returnValue;
  }

  /// Author.
  final RichTextBase author;

  /// Published Date.
  final DateTime publishedDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbaafe5e0.
    buffer.writeInt32(0xbaafe5e0);

    // Write fields.
    buffer.writeObject(author);
    buffer.writeDateTime(publishedDate);

    // Finished serialization.
  }
}

/// Page Block Header.
///
/// ID: `bfd064ec`.
class PageBlockHeader extends PageBlockBase {
  /// Page Block Header constructor.
  const PageBlockHeader({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory PageBlockHeader.deserialize(BinaryReader reader) {
    // Read [PageBlockHeader] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [PageBlockHeader] object.
    final returnValue = PageBlockHeader(
      text: text,
    );

    // Now return the deserialized [PageBlockHeader].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbfd064ec.
    buffer.writeInt32(0xbfd064ec);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Page Block Subheader.
///
/// ID: `f12bb6e1`.
class PageBlockSubheader extends PageBlockBase {
  /// Page Block Subheader constructor.
  const PageBlockSubheader({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory PageBlockSubheader.deserialize(BinaryReader reader) {
    // Read [PageBlockSubheader] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [PageBlockSubheader] object.
    final returnValue = PageBlockSubheader(
      text: text,
    );

    // Now return the deserialized [PageBlockSubheader].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf12bb6e1.
    buffer.writeInt32(0xf12bb6e1);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Page Block Paragraph.
///
/// ID: `467a0766`.
class PageBlockParagraph extends PageBlockBase {
  /// Page Block Paragraph constructor.
  const PageBlockParagraph({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory PageBlockParagraph.deserialize(BinaryReader reader) {
    // Read [PageBlockParagraph] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [PageBlockParagraph] object.
    final returnValue = PageBlockParagraph(
      text: text,
    );

    // Now return the deserialized [PageBlockParagraph].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x467a0766.
    buffer.writeInt32(0x467a0766);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Page Block Preformatted.
///
/// ID: `c070d93e`.
class PageBlockPreformatted extends PageBlockBase {
  /// Page Block Preformatted constructor.
  const PageBlockPreformatted({
    required this.text,
    required this.language,
  }) : super._();

  /// Deserialize.
  factory PageBlockPreformatted.deserialize(BinaryReader reader) {
    // Read [PageBlockPreformatted] fields.
    final text = reader.readObject() as RichTextBase;
    final language = reader.readString();

    // Construct [PageBlockPreformatted] object.
    final returnValue = PageBlockPreformatted(
      text: text,
      language: language,
    );

    // Now return the deserialized [PageBlockPreformatted].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Language.
  final String language;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc070d93e.
    buffer.writeInt32(0xc070d93e);

    // Write fields.
    buffer.writeObject(text);
    buffer.writeString(language);

    // Finished serialization.
  }
}

/// Page Block Footer.
///
/// ID: `48870999`.
class PageBlockFooter extends PageBlockBase {
  /// Page Block Footer constructor.
  const PageBlockFooter({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory PageBlockFooter.deserialize(BinaryReader reader) {
    // Read [PageBlockFooter] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [PageBlockFooter] object.
    final returnValue = PageBlockFooter(
      text: text,
    );

    // Now return the deserialized [PageBlockFooter].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x48870999.
    buffer.writeInt32(0x48870999);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Page Block Divider.
///
/// ID: `db20b188`.
class PageBlockDivider extends PageBlockBase {
  /// Page Block Divider constructor.
  const PageBlockDivider() : super._();

  /// Deserialize.
  factory PageBlockDivider.deserialize(BinaryReader reader) {
    // Construct [PageBlockDivider] object.
    final returnValue = PageBlockDivider();

    // Now return the deserialized [PageBlockDivider].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdb20b188.
    buffer.writeInt32(0xdb20b188);

    // Finished serialization.
  }
}

/// Page Block Anchor.
///
/// ID: `ce0d37b0`.
class PageBlockAnchor extends PageBlockBase {
  /// Page Block Anchor constructor.
  const PageBlockAnchor({
    required this.name,
  }) : super._();

  /// Deserialize.
  factory PageBlockAnchor.deserialize(BinaryReader reader) {
    // Read [PageBlockAnchor] fields.
    final name = reader.readString();

    // Construct [PageBlockAnchor] object.
    final returnValue = PageBlockAnchor(
      name: name,
    );

    // Now return the deserialized [PageBlockAnchor].
    return returnValue;
  }

  /// Name.
  final String name;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xce0d37b0.
    buffer.writeInt32(0xce0d37b0);

    // Write fields.
    buffer.writeString(name);

    // Finished serialization.
  }
}

/// Page Block List.
///
/// ID: `e4e88011`.
class PageBlockList extends PageBlockBase {
  /// Page Block List constructor.
  const PageBlockList({
    required this.items,
  }) : super._();

  /// Deserialize.
  factory PageBlockList.deserialize(BinaryReader reader) {
    // Read [PageBlockList] fields.
    final items = reader.readVectorObject<PageListItemBase>();

    // Construct [PageBlockList] object.
    final returnValue = PageBlockList(
      items: items,
    );

    // Now return the deserialized [PageBlockList].
    return returnValue;
  }

  /// Items.
  final List<PageListItemBase> items;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe4e88011.
    buffer.writeInt32(0xe4e88011);

    // Write fields.
    buffer.writeVectorObject(items);

    // Finished serialization.
  }
}

/// Page Block Blockquote.
///
/// ID: `263d7c26`.
class PageBlockBlockquote extends PageBlockBase {
  /// Page Block Blockquote constructor.
  const PageBlockBlockquote({
    required this.text,
    required this.caption,
  }) : super._();

  /// Deserialize.
  factory PageBlockBlockquote.deserialize(BinaryReader reader) {
    // Read [PageBlockBlockquote] fields.
    final text = reader.readObject() as RichTextBase;
    final caption = reader.readObject() as RichTextBase;

    // Construct [PageBlockBlockquote] object.
    final returnValue = PageBlockBlockquote(
      text: text,
      caption: caption,
    );

    // Now return the deserialized [PageBlockBlockquote].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Caption.
  final RichTextBase caption;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x263d7c26.
    buffer.writeInt32(0x263d7c26);

    // Write fields.
    buffer.writeObject(text);
    buffer.writeObject(caption);

    // Finished serialization.
  }
}

/// Page Block Pullquote.
///
/// ID: `4f4456d3`.
class PageBlockPullquote extends PageBlockBase {
  /// Page Block Pullquote constructor.
  const PageBlockPullquote({
    required this.text,
    required this.caption,
  }) : super._();

  /// Deserialize.
  factory PageBlockPullquote.deserialize(BinaryReader reader) {
    // Read [PageBlockPullquote] fields.
    final text = reader.readObject() as RichTextBase;
    final caption = reader.readObject() as RichTextBase;

    // Construct [PageBlockPullquote] object.
    final returnValue = PageBlockPullquote(
      text: text,
      caption: caption,
    );

    // Now return the deserialized [PageBlockPullquote].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Caption.
  final RichTextBase caption;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4f4456d3.
    buffer.writeInt32(0x4f4456d3);

    // Write fields.
    buffer.writeObject(text);
    buffer.writeObject(caption);

    // Finished serialization.
  }
}

/// Page Block Photo.
///
/// ID: `1759c560`.
class PageBlockPhoto extends PageBlockBase {
  /// Page Block Photo constructor.
  const PageBlockPhoto({
    required this.photoId,
    required this.caption,
    this.url,
    this.webpageId,
  }) : super._();

  /// Deserialize.
  factory PageBlockPhoto.deserialize(BinaryReader reader) {
    // Read [PageBlockPhoto] fields.
    final flags = reader.readInt32();
    final photoId = reader.readInt64();
    final caption = reader.readObject() as PageCaptionBase;
    final hasUrlField = (flags & 1) != 0;
    final url = hasUrlField ? reader.readString() : null;
    final hasWebpageIdField = (flags & 1) != 0;
    final webpageId = hasWebpageIdField ? reader.readInt64() : null;

    // Construct [PageBlockPhoto] object.
    final returnValue = PageBlockPhoto(
      photoId: photoId,
      caption: caption,
      url: url,
      webpageId: webpageId,
    );

    // Now return the deserialized [PageBlockPhoto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: url != null || webpageId != null,
    );

    return v;
  }

  /// Photo Id.
  ///
  /// Field type is Int64.
  final int photoId;

  /// Caption.
  final PageCaptionBase caption;

  /// Url.
  final String? url;

  /// Webpage Id.
  final int? webpageId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1759c560.
    buffer.writeInt32(0x1759c560);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(photoId);
    buffer.writeObject(caption);
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }
    final localWebpageIdCopy = webpageId;
    if (localWebpageIdCopy != null) {
      buffer.writeInt64(localWebpageIdCopy);
    }

    // Finished serialization.
  }
}

/// Page Block Video.
///
/// ID: `7c8fe7b6`.
class PageBlockVideo extends PageBlockBase {
  /// Page Block Video constructor.
  const PageBlockVideo({
    required this.autoplay,
    required this.loop,
    required this.videoId,
    required this.caption,
  }) : super._();

  /// Deserialize.
  factory PageBlockVideo.deserialize(BinaryReader reader) {
    // Read [PageBlockVideo] fields.
    final flags = reader.readInt32();
    final autoplay = (flags & 1) != 0;
    final loop = (flags & 2) != 0;
    final videoId = reader.readInt64();
    final caption = reader.readObject() as PageCaptionBase;

    // Construct [PageBlockVideo] object.
    final returnValue = PageBlockVideo(
      autoplay: autoplay,
      loop: loop,
      videoId: videoId,
      caption: caption,
    );

    // Now return the deserialized [PageBlockVideo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: autoplay,
      b01: loop,
    );

    return v;
  }

  /// autoplay: bit 0 of flags.0?true
  final bool autoplay;

  /// loop: bit 1 of flags.1?true
  final bool loop;

  /// Video Id.
  ///
  /// Field type is Int64.
  final int videoId;

  /// Caption.
  final PageCaptionBase caption;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7c8fe7b6.
    buffer.writeInt32(0x7c8fe7b6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(videoId);
    buffer.writeObject(caption);

    // Finished serialization.
  }
}

/// Page Block Cover.
///
/// ID: `39f23300`.
class PageBlockCover extends PageBlockBase {
  /// Page Block Cover constructor.
  const PageBlockCover({
    required this.cover,
  }) : super._();

  /// Deserialize.
  factory PageBlockCover.deserialize(BinaryReader reader) {
    // Read [PageBlockCover] fields.
    final cover = reader.readObject() as PageBlockBase;

    // Construct [PageBlockCover] object.
    final returnValue = PageBlockCover(
      cover: cover,
    );

    // Now return the deserialized [PageBlockCover].
    return returnValue;
  }

  /// Cover.
  final PageBlockBase cover;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x39f23300.
    buffer.writeInt32(0x39f23300);

    // Write fields.
    buffer.writeObject(cover);

    // Finished serialization.
  }
}

/// Page Block Embed.
///
/// ID: `a8718dc5`.
class PageBlockEmbed extends PageBlockBase {
  /// Page Block Embed constructor.
  const PageBlockEmbed({
    required this.fullWidth,
    required this.allowScrolling,
    this.url,
    this.html,
    this.posterPhotoId,
    this.w,
    this.h,
    required this.caption,
  }) : super._();

  /// Deserialize.
  factory PageBlockEmbed.deserialize(BinaryReader reader) {
    // Read [PageBlockEmbed] fields.
    final flags = reader.readInt32();
    final fullWidth = (flags & 1) != 0;
    final allowScrolling = (flags & 8) != 0;
    final hasUrlField = (flags & 2) != 0;
    final url = hasUrlField ? reader.readString() : null;
    final hasHtmlField = (flags & 4) != 0;
    final html = hasHtmlField ? reader.readString() : null;
    final hasPosterPhotoIdField = (flags & 16) != 0;
    final posterPhotoId = hasPosterPhotoIdField ? reader.readInt64() : null;
    final hasWField = (flags & 32) != 0;
    final w = hasWField ? reader.readInt32() : null;
    final hasHField = (flags & 32) != 0;
    final h = hasHField ? reader.readInt32() : null;
    final caption = reader.readObject() as PageCaptionBase;

    // Construct [PageBlockEmbed] object.
    final returnValue = PageBlockEmbed(
      fullWidth: fullWidth,
      allowScrolling: allowScrolling,
      url: url,
      html: html,
      posterPhotoId: posterPhotoId,
      w: w,
      h: h,
      caption: caption,
    );

    // Now return the deserialized [PageBlockEmbed].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: fullWidth,
      b03: allowScrolling,
      b01: url != null,
      b02: html != null,
      b04: posterPhotoId != null,
      b05: w != null || h != null,
    );

    return v;
  }

  /// full_width: bit 0 of flags.0?true
  final bool fullWidth;

  /// allow_scrolling: bit 3 of flags.3?true
  final bool allowScrolling;

  /// Url.
  final String? url;

  /// Html.
  final String? html;

  /// Poster Photo Id.
  final int? posterPhotoId;

  /// W.
  final int? w;

  /// H.
  final int? h;

  /// Caption.
  final PageCaptionBase caption;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa8718dc5.
    buffer.writeInt32(0xa8718dc5);

    // Write fields.
    buffer.writeInt32(flags);
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }
    final localHtmlCopy = html;
    if (localHtmlCopy != null) {
      buffer.writeString(localHtmlCopy);
    }
    final localPosterPhotoIdCopy = posterPhotoId;
    if (localPosterPhotoIdCopy != null) {
      buffer.writeInt64(localPosterPhotoIdCopy);
    }
    final localWCopy = w;
    if (localWCopy != null) {
      buffer.writeInt32(localWCopy);
    }
    final localHCopy = h;
    if (localHCopy != null) {
      buffer.writeInt32(localHCopy);
    }
    buffer.writeObject(caption);

    // Finished serialization.
  }
}

/// Page Block Embed Post.
///
/// ID: `f259a80b`.
class PageBlockEmbedPost extends PageBlockBase {
  /// Page Block Embed Post constructor.
  const PageBlockEmbedPost({
    required this.url,
    required this.webpageId,
    required this.authorPhotoId,
    required this.author,
    required this.date,
    required this.blocks,
    required this.caption,
  }) : super._();

  /// Deserialize.
  factory PageBlockEmbedPost.deserialize(BinaryReader reader) {
    // Read [PageBlockEmbedPost] fields.
    final url = reader.readString();
    final webpageId = reader.readInt64();
    final authorPhotoId = reader.readInt64();
    final author = reader.readString();
    final date = reader.readDateTime();
    final blocks = reader.readVectorObject<PageBlockBase>();
    final caption = reader.readObject() as PageCaptionBase;

    // Construct [PageBlockEmbedPost] object.
    final returnValue = PageBlockEmbedPost(
      url: url,
      webpageId: webpageId,
      authorPhotoId: authorPhotoId,
      author: author,
      date: date,
      blocks: blocks,
      caption: caption,
    );

    // Now return the deserialized [PageBlockEmbedPost].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Webpage Id.
  ///
  /// Field type is Int64.
  final int webpageId;

  /// Author Photo Id.
  ///
  /// Field type is Int64.
  final int authorPhotoId;

  /// Author.
  final String author;

  /// Date.
  final DateTime date;

  /// Blocks.
  final List<PageBlockBase> blocks;

  /// Caption.
  final PageCaptionBase caption;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf259a80b.
    buffer.writeInt32(0xf259a80b);

    // Write fields.
    buffer.writeString(url);
    buffer.writeInt64(webpageId);
    buffer.writeInt64(authorPhotoId);
    buffer.writeString(author);
    buffer.writeDateTime(date);
    buffer.writeVectorObject(blocks);
    buffer.writeObject(caption);

    // Finished serialization.
  }
}

/// Page Block Collage.
///
/// ID: `65a0fa4d`.
class PageBlockCollage extends PageBlockBase {
  /// Page Block Collage constructor.
  const PageBlockCollage({
    required this.items,
    required this.caption,
  }) : super._();

  /// Deserialize.
  factory PageBlockCollage.deserialize(BinaryReader reader) {
    // Read [PageBlockCollage] fields.
    final items = reader.readVectorObject<PageBlockBase>();
    final caption = reader.readObject() as PageCaptionBase;

    // Construct [PageBlockCollage] object.
    final returnValue = PageBlockCollage(
      items: items,
      caption: caption,
    );

    // Now return the deserialized [PageBlockCollage].
    return returnValue;
  }

  /// Items.
  final List<PageBlockBase> items;

  /// Caption.
  final PageCaptionBase caption;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x65a0fa4d.
    buffer.writeInt32(0x65a0fa4d);

    // Write fields.
    buffer.writeVectorObject(items);
    buffer.writeObject(caption);

    // Finished serialization.
  }
}

/// Page Block Slideshow.
///
/// ID: `031f9590`.
class PageBlockSlideshow extends PageBlockBase {
  /// Page Block Slideshow constructor.
  const PageBlockSlideshow({
    required this.items,
    required this.caption,
  }) : super._();

  /// Deserialize.
  factory PageBlockSlideshow.deserialize(BinaryReader reader) {
    // Read [PageBlockSlideshow] fields.
    final items = reader.readVectorObject<PageBlockBase>();
    final caption = reader.readObject() as PageCaptionBase;

    // Construct [PageBlockSlideshow] object.
    final returnValue = PageBlockSlideshow(
      items: items,
      caption: caption,
    );

    // Now return the deserialized [PageBlockSlideshow].
    return returnValue;
  }

  /// Items.
  final List<PageBlockBase> items;

  /// Caption.
  final PageCaptionBase caption;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x031f9590.
    buffer.writeInt32(0x031f9590);

    // Write fields.
    buffer.writeVectorObject(items);
    buffer.writeObject(caption);

    // Finished serialization.
  }
}

/// Page Block Channel.
///
/// ID: `ef1751b5`.
class PageBlockChannel extends PageBlockBase {
  /// Page Block Channel constructor.
  const PageBlockChannel({
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory PageBlockChannel.deserialize(BinaryReader reader) {
    // Read [PageBlockChannel] fields.
    final channel = reader.readObject() as ChatBase;

    // Construct [PageBlockChannel] object.
    final returnValue = PageBlockChannel(
      channel: channel,
    );

    // Now return the deserialized [PageBlockChannel].
    return returnValue;
  }

  /// Channel.
  final ChatBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xef1751b5.
    buffer.writeInt32(0xef1751b5);

    // Write fields.
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Page Block Audio.
///
/// ID: `804361ea`.
class PageBlockAudio extends PageBlockBase {
  /// Page Block Audio constructor.
  const PageBlockAudio({
    required this.audioId,
    required this.caption,
  }) : super._();

  /// Deserialize.
  factory PageBlockAudio.deserialize(BinaryReader reader) {
    // Read [PageBlockAudio] fields.
    final audioId = reader.readInt64();
    final caption = reader.readObject() as PageCaptionBase;

    // Construct [PageBlockAudio] object.
    final returnValue = PageBlockAudio(
      audioId: audioId,
      caption: caption,
    );

    // Now return the deserialized [PageBlockAudio].
    return returnValue;
  }

  /// Audio Id.
  ///
  /// Field type is Int64.
  final int audioId;

  /// Caption.
  final PageCaptionBase caption;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x804361ea.
    buffer.writeInt32(0x804361ea);

    // Write fields.
    buffer.writeInt64(audioId);
    buffer.writeObject(caption);

    // Finished serialization.
  }
}

/// Page Block Kicker.
///
/// ID: `1e148390`.
class PageBlockKicker extends PageBlockBase {
  /// Page Block Kicker constructor.
  const PageBlockKicker({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory PageBlockKicker.deserialize(BinaryReader reader) {
    // Read [PageBlockKicker] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [PageBlockKicker] object.
    final returnValue = PageBlockKicker(
      text: text,
    );

    // Now return the deserialized [PageBlockKicker].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1e148390.
    buffer.writeInt32(0x1e148390);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Page Block Table.
///
/// ID: `bf4dea82`.
class PageBlockTable extends PageBlockBase {
  /// Page Block Table constructor.
  const PageBlockTable({
    required this.bordered,
    required this.striped,
    required this.title,
    required this.rows,
  }) : super._();

  /// Deserialize.
  factory PageBlockTable.deserialize(BinaryReader reader) {
    // Read [PageBlockTable] fields.
    final flags = reader.readInt32();
    final bordered = (flags & 1) != 0;
    final striped = (flags & 2) != 0;
    final title = reader.readObject() as RichTextBase;
    final rows = reader.readVectorObject<PageTableRowBase>();

    // Construct [PageBlockTable] object.
    final returnValue = PageBlockTable(
      bordered: bordered,
      striped: striped,
      title: title,
      rows: rows,
    );

    // Now return the deserialized [PageBlockTable].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: bordered,
      b01: striped,
    );

    return v;
  }

  /// bordered: bit 0 of flags.0?true
  final bool bordered;

  /// striped: bit 1 of flags.1?true
  final bool striped;

  /// Title.
  final RichTextBase title;

  /// Rows.
  final List<PageTableRowBase> rows;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbf4dea82.
    buffer.writeInt32(0xbf4dea82);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(title);
    buffer.writeVectorObject(rows);

    // Finished serialization.
  }
}

/// Page Block Ordered List.
///
/// ID: `9a8ae1e1`.
class PageBlockOrderedList extends PageBlockBase {
  /// Page Block Ordered List constructor.
  const PageBlockOrderedList({
    required this.items,
  }) : super._();

  /// Deserialize.
  factory PageBlockOrderedList.deserialize(BinaryReader reader) {
    // Read [PageBlockOrderedList] fields.
    final items = reader.readVectorObject<PageListOrderedItemBase>();

    // Construct [PageBlockOrderedList] object.
    final returnValue = PageBlockOrderedList(
      items: items,
    );

    // Now return the deserialized [PageBlockOrderedList].
    return returnValue;
  }

  /// Items.
  final List<PageListOrderedItemBase> items;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9a8ae1e1.
    buffer.writeInt32(0x9a8ae1e1);

    // Write fields.
    buffer.writeVectorObject(items);

    // Finished serialization.
  }
}

/// Page Block Details.
///
/// ID: `76768bed`.
class PageBlockDetails extends PageBlockBase {
  /// Page Block Details constructor.
  const PageBlockDetails({
    required this.open,
    required this.blocks,
    required this.title,
  }) : super._();

  /// Deserialize.
  factory PageBlockDetails.deserialize(BinaryReader reader) {
    // Read [PageBlockDetails] fields.
    final flags = reader.readInt32();
    final open = (flags & 1) != 0;
    final blocks = reader.readVectorObject<PageBlockBase>();
    final title = reader.readObject() as RichTextBase;

    // Construct [PageBlockDetails] object.
    final returnValue = PageBlockDetails(
      open: open,
      blocks: blocks,
      title: title,
    );

    // Now return the deserialized [PageBlockDetails].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: open,
    );

    return v;
  }

  /// open: bit 0 of flags.0?true
  final bool open;

  /// Blocks.
  final List<PageBlockBase> blocks;

  /// Title.
  final RichTextBase title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x76768bed.
    buffer.writeInt32(0x76768bed);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(blocks);
    buffer.writeObject(title);

    // Finished serialization.
  }
}

/// Page Block Related Articles.
///
/// ID: `16115a96`.
class PageBlockRelatedArticles extends PageBlockBase {
  /// Page Block Related Articles constructor.
  const PageBlockRelatedArticles({
    required this.title,
    required this.articles,
  }) : super._();

  /// Deserialize.
  factory PageBlockRelatedArticles.deserialize(BinaryReader reader) {
    // Read [PageBlockRelatedArticles] fields.
    final title = reader.readObject() as RichTextBase;
    final articles = reader.readVectorObject<PageRelatedArticleBase>();

    // Construct [PageBlockRelatedArticles] object.
    final returnValue = PageBlockRelatedArticles(
      title: title,
      articles: articles,
    );

    // Now return the deserialized [PageBlockRelatedArticles].
    return returnValue;
  }

  /// Title.
  final RichTextBase title;

  /// Articles.
  final List<PageRelatedArticleBase> articles;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x16115a96.
    buffer.writeInt32(0x16115a96);

    // Write fields.
    buffer.writeObject(title);
    buffer.writeVectorObject(articles);

    // Finished serialization.
  }
}

/// Page Block Map.
///
/// ID: `a44f3ef6`.
class PageBlockMap extends PageBlockBase {
  /// Page Block Map constructor.
  const PageBlockMap({
    required this.geo,
    required this.zoom,
    required this.w,
    required this.h,
    required this.caption,
  }) : super._();

  /// Deserialize.
  factory PageBlockMap.deserialize(BinaryReader reader) {
    // Read [PageBlockMap] fields.
    final geo = reader.readObject() as GeoPointBase;
    final zoom = reader.readInt32();
    final w = reader.readInt32();
    final h = reader.readInt32();
    final caption = reader.readObject() as PageCaptionBase;

    // Construct [PageBlockMap] object.
    final returnValue = PageBlockMap(
      geo: geo,
      zoom: zoom,
      w: w,
      h: h,
      caption: caption,
    );

    // Now return the deserialized [PageBlockMap].
    return returnValue;
  }

  /// Geo.
  final GeoPointBase geo;

  /// Zoom.
  ///
  /// Field type is Int32.
  final int zoom;

  /// W.
  ///
  /// Field type is Int32.
  final int w;

  /// H.
  ///
  /// Field type is Int32.
  final int h;

  /// Caption.
  final PageCaptionBase caption;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa44f3ef6.
    buffer.writeInt32(0xa44f3ef6);

    // Write fields.
    buffer.writeObject(geo);
    buffer.writeInt32(zoom);
    buffer.writeInt32(w);
    buffer.writeInt32(h);
    buffer.writeObject(caption);

    // Finished serialization.
  }
}

/// Phone Call Discard Reason Missed.
///
/// ID: `85e42301`.
class PhoneCallDiscardReasonMissed extends PhoneCallDiscardReasonBase {
  /// Phone Call Discard Reason Missed constructor.
  const PhoneCallDiscardReasonMissed() : super._();

  /// Deserialize.
  factory PhoneCallDiscardReasonMissed.deserialize(BinaryReader reader) {
    // Construct [PhoneCallDiscardReasonMissed] object.
    final returnValue = PhoneCallDiscardReasonMissed();

    // Now return the deserialized [PhoneCallDiscardReasonMissed].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x85e42301.
    buffer.writeInt32(0x85e42301);

    // Finished serialization.
  }
}

/// Phone Call Discard Reason Disconnect.
///
/// ID: `e095c1a0`.
class PhoneCallDiscardReasonDisconnect extends PhoneCallDiscardReasonBase {
  /// Phone Call Discard Reason Disconnect constructor.
  const PhoneCallDiscardReasonDisconnect() : super._();

  /// Deserialize.
  factory PhoneCallDiscardReasonDisconnect.deserialize(BinaryReader reader) {
    // Construct [PhoneCallDiscardReasonDisconnect] object.
    final returnValue = PhoneCallDiscardReasonDisconnect();

    // Now return the deserialized [PhoneCallDiscardReasonDisconnect].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe095c1a0.
    buffer.writeInt32(0xe095c1a0);

    // Finished serialization.
  }
}

/// Phone Call Discard Reason Hangup.
///
/// ID: `57adc690`.
class PhoneCallDiscardReasonHangup extends PhoneCallDiscardReasonBase {
  /// Phone Call Discard Reason Hangup constructor.
  const PhoneCallDiscardReasonHangup() : super._();

  /// Deserialize.
  factory PhoneCallDiscardReasonHangup.deserialize(BinaryReader reader) {
    // Construct [PhoneCallDiscardReasonHangup] object.
    final returnValue = PhoneCallDiscardReasonHangup();

    // Now return the deserialized [PhoneCallDiscardReasonHangup].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x57adc690.
    buffer.writeInt32(0x57adc690);

    // Finished serialization.
  }
}

/// Phone Call Discard Reason Busy.
///
/// ID: `faf7e8c9`.
class PhoneCallDiscardReasonBusy extends PhoneCallDiscardReasonBase {
  /// Phone Call Discard Reason Busy constructor.
  const PhoneCallDiscardReasonBusy() : super._();

  /// Deserialize.
  factory PhoneCallDiscardReasonBusy.deserialize(BinaryReader reader) {
    // Construct [PhoneCallDiscardReasonBusy] object.
    final returnValue = PhoneCallDiscardReasonBusy();

    // Now return the deserialized [PhoneCallDiscardReasonBusy].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfaf7e8c9.
    buffer.writeInt32(0xfaf7e8c9);

    // Finished serialization.
  }
}

/// Data J S O N.
///
/// ID: `7d748d04`.
class DataJSON extends DataJSONBase {
  /// Data J S O N constructor.
  const DataJSON({
    required this.data,
  }) : super._();

  /// Deserialize.
  factory DataJSON.deserialize(BinaryReader reader) {
    // Read [DataJSON] fields.
    final data = reader.readString();

    // Construct [DataJSON] object.
    final returnValue = DataJSON(
      data: data,
    );

    // Now return the deserialized [DataJSON].
    return returnValue;
  }

  /// Data.
  final String data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7d748d04.
    buffer.writeInt32(0x7d748d04);

    // Write fields.
    buffer.writeString(data);

    // Finished serialization.
  }
}

/// Labeled Price.
///
/// ID: `cb296bf8`.
class LabeledPrice extends LabeledPriceBase {
  /// Labeled Price constructor.
  const LabeledPrice({
    required this.label,
    required this.amount,
  }) : super._();

  /// Deserialize.
  factory LabeledPrice.deserialize(BinaryReader reader) {
    // Read [LabeledPrice] fields.
    final label = reader.readString();
    final amount = reader.readInt64();

    // Construct [LabeledPrice] object.
    final returnValue = LabeledPrice(
      label: label,
      amount: amount,
    );

    // Now return the deserialized [LabeledPrice].
    return returnValue;
  }

  /// Label.
  final String label;

  /// Amount.
  ///
  /// Field type is Int64.
  final int amount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcb296bf8.
    buffer.writeInt32(0xcb296bf8);

    // Write fields.
    buffer.writeString(label);
    buffer.writeInt64(amount);

    // Finished serialization.
  }
}

/// Invoice.
///
/// ID: `5db95a15`.
class Invoice extends InvoiceBase {
  /// Invoice constructor.
  const Invoice({
    required this.test,
    required this.nameRequested,
    required this.phoneRequested,
    required this.emailRequested,
    required this.shippingAddressRequested,
    required this.flexible,
    required this.phoneToProvider,
    required this.emailToProvider,
    required this.recurring,
    required this.currency,
    required this.prices,
    this.maxTipAmount,
    this.suggestedTipAmounts,
    this.termsUrl,
  }) : super._();

  /// Deserialize.
  factory Invoice.deserialize(BinaryReader reader) {
    // Read [Invoice] fields.
    final flags = reader.readInt32();
    final test = (flags & 1) != 0;
    final nameRequested = (flags & 2) != 0;
    final phoneRequested = (flags & 4) != 0;
    final emailRequested = (flags & 8) != 0;
    final shippingAddressRequested = (flags & 16) != 0;
    final flexible = (flags & 32) != 0;
    final phoneToProvider = (flags & 64) != 0;
    final emailToProvider = (flags & 128) != 0;
    final recurring = (flags & 512) != 0;
    final currency = reader.readString();
    final prices = reader.readVectorObject<LabeledPriceBase>();
    final hasMaxTipAmountField = (flags & 256) != 0;
    final maxTipAmount = hasMaxTipAmountField ? reader.readInt64() : null;
    final hasSuggestedTipAmountsField = (flags & 256) != 0;
    final suggestedTipAmounts =
        hasSuggestedTipAmountsField ? reader.readVectorInt64() : null;
    final hasTermsUrlField = (flags & 1024) != 0;
    final termsUrl = hasTermsUrlField ? reader.readString() : null;

    // Construct [Invoice] object.
    final returnValue = Invoice(
      test: test,
      nameRequested: nameRequested,
      phoneRequested: phoneRequested,
      emailRequested: emailRequested,
      shippingAddressRequested: shippingAddressRequested,
      flexible: flexible,
      phoneToProvider: phoneToProvider,
      emailToProvider: emailToProvider,
      recurring: recurring,
      currency: currency,
      prices: prices,
      maxTipAmount: maxTipAmount,
      suggestedTipAmounts: suggestedTipAmounts,
      termsUrl: termsUrl,
    );

    // Now return the deserialized [Invoice].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: test,
      b01: nameRequested,
      b02: phoneRequested,
      b03: emailRequested,
      b04: shippingAddressRequested,
      b05: flexible,
      b06: phoneToProvider,
      b07: emailToProvider,
      b09: recurring,
      b08: maxTipAmount != null || suggestedTipAmounts != null,
      b10: termsUrl != null,
    );

    return v;
  }

  /// test: bit 0 of flags.0?true
  final bool test;

  /// name_requested: bit 1 of flags.1?true
  final bool nameRequested;

  /// phone_requested: bit 2 of flags.2?true
  final bool phoneRequested;

  /// email_requested: bit 3 of flags.3?true
  final bool emailRequested;

  /// shipping_address_requested: bit 4 of flags.4?true
  final bool shippingAddressRequested;

  /// flexible: bit 5 of flags.5?true
  final bool flexible;

  /// phone_to_provider: bit 6 of flags.6?true
  final bool phoneToProvider;

  /// email_to_provider: bit 7 of flags.7?true
  final bool emailToProvider;

  /// recurring: bit 9 of flags.9?true
  final bool recurring;

  /// Currency.
  final String currency;

  /// Prices.
  final List<LabeledPriceBase> prices;

  /// Max Tip Amount.
  final int? maxTipAmount;

  /// Suggested Tip Amounts.
  final List<int>? suggestedTipAmounts;

  /// Terms Url.
  final String? termsUrl;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5db95a15.
    buffer.writeInt32(0x5db95a15);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(currency);
    buffer.writeVectorObject(prices);
    final localMaxTipAmountCopy = maxTipAmount;
    if (localMaxTipAmountCopy != null) {
      buffer.writeInt64(localMaxTipAmountCopy);
    }
    final localSuggestedTipAmountsCopy = suggestedTipAmounts;
    if (localSuggestedTipAmountsCopy != null) {
      buffer.writeVectorInt64(localSuggestedTipAmountsCopy);
    }
    final localTermsUrlCopy = termsUrl;
    if (localTermsUrlCopy != null) {
      buffer.writeString(localTermsUrlCopy);
    }

    // Finished serialization.
  }
}

/// Payment Charge.
///
/// ID: `ea02c27e`.
class PaymentCharge extends PaymentChargeBase {
  /// Payment Charge constructor.
  const PaymentCharge({
    required this.id,
    required this.providerChargeId,
  }) : super._();

  /// Deserialize.
  factory PaymentCharge.deserialize(BinaryReader reader) {
    // Read [PaymentCharge] fields.
    final id = reader.readString();
    final providerChargeId = reader.readString();

    // Construct [PaymentCharge] object.
    final returnValue = PaymentCharge(
      id: id,
      providerChargeId: providerChargeId,
    );

    // Now return the deserialized [PaymentCharge].
    return returnValue;
  }

  /// Id.
  final String id;

  /// Provider Charge Id.
  final String providerChargeId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xea02c27e.
    buffer.writeInt32(0xea02c27e);

    // Write fields.
    buffer.writeString(id);
    buffer.writeString(providerChargeId);

    // Finished serialization.
  }
}

/// Post Address.
///
/// ID: `1e8caaeb`.
class PostAddress extends PostAddressBase {
  /// Post Address constructor.
  const PostAddress({
    required this.streetLine1,
    required this.streetLine2,
    required this.city,
    required this.state,
    required this.countryIso2,
    required this.postCode,
  }) : super._();

  /// Deserialize.
  factory PostAddress.deserialize(BinaryReader reader) {
    // Read [PostAddress] fields.
    final streetLine1 = reader.readString();
    final streetLine2 = reader.readString();
    final city = reader.readString();
    final state = reader.readString();
    final countryIso2 = reader.readString();
    final postCode = reader.readString();

    // Construct [PostAddress] object.
    final returnValue = PostAddress(
      streetLine1: streetLine1,
      streetLine2: streetLine2,
      city: city,
      state: state,
      countryIso2: countryIso2,
      postCode: postCode,
    );

    // Now return the deserialized [PostAddress].
    return returnValue;
  }

  /// Street Line1.
  final String streetLine1;

  /// Street Line2.
  final String streetLine2;

  /// City.
  final String city;

  /// State.
  final String state;

  /// Country Iso2.
  final String countryIso2;

  /// Post Code.
  final String postCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1e8caaeb.
    buffer.writeInt32(0x1e8caaeb);

    // Write fields.
    buffer.writeString(streetLine1);
    buffer.writeString(streetLine2);
    buffer.writeString(city);
    buffer.writeString(state);
    buffer.writeString(countryIso2);
    buffer.writeString(postCode);

    // Finished serialization.
  }
}

/// Payment Requested Info.
///
/// ID: `909c3f94`.
class PaymentRequestedInfo extends PaymentRequestedInfoBase {
  /// Payment Requested Info constructor.
  const PaymentRequestedInfo({
    this.name,
    this.phone,
    this.email,
    this.shippingAddress,
  }) : super._();

  /// Deserialize.
  factory PaymentRequestedInfo.deserialize(BinaryReader reader) {
    // Read [PaymentRequestedInfo] fields.
    final flags = reader.readInt32();
    final hasNameField = (flags & 1) != 0;
    final name = hasNameField ? reader.readString() : null;
    final hasPhoneField = (flags & 2) != 0;
    final phone = hasPhoneField ? reader.readString() : null;
    final hasEmailField = (flags & 4) != 0;
    final email = hasEmailField ? reader.readString() : null;
    final hasShippingAddressField = (flags & 8) != 0;
    final shippingAddress =
        hasShippingAddressField ? reader.readObject() as PostAddressBase : null;

    // Construct [PaymentRequestedInfo] object.
    final returnValue = PaymentRequestedInfo(
      name: name,
      phone: phone,
      email: email,
      shippingAddress: shippingAddress,
    );

    // Now return the deserialized [PaymentRequestedInfo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: name != null,
      b01: phone != null,
      b02: email != null,
      b03: shippingAddress != null,
    );

    return v;
  }

  /// Name.
  final String? name;

  /// Phone.
  final String? phone;

  /// Email.
  final String? email;

  /// Shipping Address.
  final PostAddressBase? shippingAddress;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x909c3f94.
    buffer.writeInt32(0x909c3f94);

    // Write fields.
    buffer.writeInt32(flags);
    final localNameCopy = name;
    if (localNameCopy != null) {
      buffer.writeString(localNameCopy);
    }
    final localPhoneCopy = phone;
    if (localPhoneCopy != null) {
      buffer.writeString(localPhoneCopy);
    }
    final localEmailCopy = email;
    if (localEmailCopy != null) {
      buffer.writeString(localEmailCopy);
    }
    final localShippingAddressCopy = shippingAddress;
    if (localShippingAddressCopy != null) {
      buffer.writeObject(localShippingAddressCopy);
    }

    // Finished serialization.
  }
}

/// Payment Saved Credentials Card.
///
/// ID: `cdc27a1f`.
class PaymentSavedCredentialsCard extends PaymentSavedCredentialsBase {
  /// Payment Saved Credentials Card constructor.
  const PaymentSavedCredentialsCard({
    required this.id,
    required this.title,
  }) : super._();

  /// Deserialize.
  factory PaymentSavedCredentialsCard.deserialize(BinaryReader reader) {
    // Read [PaymentSavedCredentialsCard] fields.
    final id = reader.readString();
    final title = reader.readString();

    // Construct [PaymentSavedCredentialsCard] object.
    final returnValue = PaymentSavedCredentialsCard(
      id: id,
      title: title,
    );

    // Now return the deserialized [PaymentSavedCredentialsCard].
    return returnValue;
  }

  /// Id.
  final String id;

  /// Title.
  final String title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcdc27a1f.
    buffer.writeInt32(0xcdc27a1f);

    // Write fields.
    buffer.writeString(id);
    buffer.writeString(title);

    // Finished serialization.
  }
}

/// Web Document.
///
/// ID: `1c570ed1`.
class WebDocument extends WebDocumentBase {
  /// Web Document constructor.
  const WebDocument({
    required this.url,
    required this.accessHash,
    required this.size,
    required this.mimeType,
    required this.attributes,
  }) : super._();

  /// Deserialize.
  factory WebDocument.deserialize(BinaryReader reader) {
    // Read [WebDocument] fields.
    final url = reader.readString();
    final accessHash = reader.readInt64();
    final size = reader.readInt32();
    final mimeType = reader.readString();
    final attributes = reader.readVectorObject<DocumentAttributeBase>();

    // Construct [WebDocument] object.
    final returnValue = WebDocument(
      url: url,
      accessHash: accessHash,
      size: size,
      mimeType: mimeType,
      attributes: attributes,
    );

    // Now return the deserialized [WebDocument].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Size.
  ///
  /// Field type is Int32.
  final int size;

  /// Mime Type.
  final String mimeType;

  /// Attributes.
  final List<DocumentAttributeBase> attributes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1c570ed1.
    buffer.writeInt32(0x1c570ed1);

    // Write fields.
    buffer.writeString(url);
    buffer.writeInt64(accessHash);
    buffer.writeInt32(size);
    buffer.writeString(mimeType);
    buffer.writeVectorObject(attributes);

    // Finished serialization.
  }
}

/// Web Document No Proxy.
///
/// ID: `f9c8bcc6`.
class WebDocumentNoProxy extends WebDocumentBase {
  /// Web Document No Proxy constructor.
  const WebDocumentNoProxy({
    required this.url,
    required this.size,
    required this.mimeType,
    required this.attributes,
  }) : super._();

  /// Deserialize.
  factory WebDocumentNoProxy.deserialize(BinaryReader reader) {
    // Read [WebDocumentNoProxy] fields.
    final url = reader.readString();
    final size = reader.readInt32();
    final mimeType = reader.readString();
    final attributes = reader.readVectorObject<DocumentAttributeBase>();

    // Construct [WebDocumentNoProxy] object.
    final returnValue = WebDocumentNoProxy(
      url: url,
      size: size,
      mimeType: mimeType,
      attributes: attributes,
    );

    // Now return the deserialized [WebDocumentNoProxy].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Size.
  ///
  /// Field type is Int32.
  final int size;

  /// Mime Type.
  final String mimeType;

  /// Attributes.
  final List<DocumentAttributeBase> attributes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf9c8bcc6.
    buffer.writeInt32(0xf9c8bcc6);

    // Write fields.
    buffer.writeString(url);
    buffer.writeInt32(size);
    buffer.writeString(mimeType);
    buffer.writeVectorObject(attributes);

    // Finished serialization.
  }
}

/// Input Web Document.
///
/// ID: `9bed434d`.
class InputWebDocument extends InputWebDocumentBase {
  /// Input Web Document constructor.
  const InputWebDocument({
    required this.url,
    required this.size,
    required this.mimeType,
    required this.attributes,
  }) : super._();

  /// Deserialize.
  factory InputWebDocument.deserialize(BinaryReader reader) {
    // Read [InputWebDocument] fields.
    final url = reader.readString();
    final size = reader.readInt32();
    final mimeType = reader.readString();
    final attributes = reader.readVectorObject<DocumentAttributeBase>();

    // Construct [InputWebDocument] object.
    final returnValue = InputWebDocument(
      url: url,
      size: size,
      mimeType: mimeType,
      attributes: attributes,
    );

    // Now return the deserialized [InputWebDocument].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Size.
  ///
  /// Field type is Int32.
  final int size;

  /// Mime Type.
  final String mimeType;

  /// Attributes.
  final List<DocumentAttributeBase> attributes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9bed434d.
    buffer.writeInt32(0x9bed434d);

    // Write fields.
    buffer.writeString(url);
    buffer.writeInt32(size);
    buffer.writeString(mimeType);
    buffer.writeVectorObject(attributes);

    // Finished serialization.
  }
}

/// Input Web File Location.
///
/// ID: `c239d686`.
class InputWebFileLocation extends InputWebFileLocationBase {
  /// Input Web File Location constructor.
  const InputWebFileLocation({
    required this.url,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputWebFileLocation.deserialize(BinaryReader reader) {
    // Read [InputWebFileLocation] fields.
    final url = reader.readString();
    final accessHash = reader.readInt64();

    // Construct [InputWebFileLocation] object.
    final returnValue = InputWebFileLocation(
      url: url,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputWebFileLocation].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc239d686.
    buffer.writeInt32(0xc239d686);

    // Write fields.
    buffer.writeString(url);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Web File Geo Point Location.
///
/// ID: `9f2221c9`.
class InputWebFileGeoPointLocation extends InputWebFileLocationBase {
  /// Input Web File Geo Point Location constructor.
  const InputWebFileGeoPointLocation({
    required this.geoPoint,
    required this.accessHash,
    required this.w,
    required this.h,
    required this.zoom,
    required this.scale,
  }) : super._();

  /// Deserialize.
  factory InputWebFileGeoPointLocation.deserialize(BinaryReader reader) {
    // Read [InputWebFileGeoPointLocation] fields.
    final geoPoint = reader.readObject() as InputGeoPointBase;
    final accessHash = reader.readInt64();
    final w = reader.readInt32();
    final h = reader.readInt32();
    final zoom = reader.readInt32();
    final scale = reader.readInt32();

    // Construct [InputWebFileGeoPointLocation] object.
    final returnValue = InputWebFileGeoPointLocation(
      geoPoint: geoPoint,
      accessHash: accessHash,
      w: w,
      h: h,
      zoom: zoom,
      scale: scale,
    );

    // Now return the deserialized [InputWebFileGeoPointLocation].
    return returnValue;
  }

  /// Geo Point.
  final InputGeoPointBase geoPoint;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// W.
  ///
  /// Field type is Int32.
  final int w;

  /// H.
  ///
  /// Field type is Int32.
  final int h;

  /// Zoom.
  ///
  /// Field type is Int32.
  final int zoom;

  /// Scale.
  ///
  /// Field type is Int32.
  final int scale;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9f2221c9.
    buffer.writeInt32(0x9f2221c9);

    // Write fields.
    buffer.writeObject(geoPoint);
    buffer.writeInt64(accessHash);
    buffer.writeInt32(w);
    buffer.writeInt32(h);
    buffer.writeInt32(zoom);
    buffer.writeInt32(scale);

    // Finished serialization.
  }
}

/// Input Web File Audio Album Thumb Location.
///
/// ID: `f46fe924`.
class InputWebFileAudioAlbumThumbLocation extends InputWebFileLocationBase {
  /// Input Web File Audio Album Thumb Location constructor.
  const InputWebFileAudioAlbumThumbLocation({
    required this.small,
    this.document,
    this.title,
    this.performer,
  }) : super._();

  /// Deserialize.
  factory InputWebFileAudioAlbumThumbLocation.deserialize(BinaryReader reader) {
    // Read [InputWebFileAudioAlbumThumbLocation] fields.
    final flags = reader.readInt32();
    final small = (flags & 4) != 0;
    final hasDocumentField = (flags & 1) != 0;
    final document =
        hasDocumentField ? reader.readObject() as InputDocumentBase : null;
    final hasTitleField = (flags & 2) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasPerformerField = (flags & 2) != 0;
    final performer = hasPerformerField ? reader.readString() : null;

    // Construct [InputWebFileAudioAlbumThumbLocation] object.
    final returnValue = InputWebFileAudioAlbumThumbLocation(
      small: small,
      document: document,
      title: title,
      performer: performer,
    );

    // Now return the deserialized [InputWebFileAudioAlbumThumbLocation].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: small,
      b00: document != null,
      b01: title != null || performer != null,
    );

    return v;
  }

  /// small: bit 2 of flags.2?true
  final bool small;

  /// Document.
  final InputDocumentBase? document;

  /// Title.
  final String? title;

  /// Performer.
  final String? performer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf46fe924.
    buffer.writeInt32(0xf46fe924);

    // Write fields.
    buffer.writeInt32(flags);
    final localDocumentCopy = document;
    if (localDocumentCopy != null) {
      buffer.writeObject(localDocumentCopy);
    }
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localPerformerCopy = performer;
    if (localPerformerCopy != null) {
      buffer.writeString(localPerformerCopy);
    }

    // Finished serialization.
  }
}

/// Upload Web File.
///
/// ID: `21e753bc`.
class UploadWebFile extends UploadWebFileBase {
  /// Upload Web File constructor.
  const UploadWebFile({
    required this.size,
    required this.mimeType,
    required this.fileType,
    required this.mtime,
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory UploadWebFile.deserialize(BinaryReader reader) {
    // Read [UploadWebFile] fields.
    final size = reader.readInt32();
    final mimeType = reader.readString();
    final fileType = reader.readObject() as StorageFileTypeBase;
    final mtime = reader.readInt32();
    final bytes = reader.readBytes();

    // Construct [UploadWebFile] object.
    final returnValue = UploadWebFile(
      size: size,
      mimeType: mimeType,
      fileType: fileType,
      mtime: mtime,
      bytes: bytes,
    );

    // Now return the deserialized [UploadWebFile].
    return returnValue;
  }

  /// Size.
  ///
  /// Field type is Int32.
  final int size;

  /// Mime Type.
  final String mimeType;

  /// File Type.
  final StorageFileTypeBase fileType;

  /// Mtime.
  ///
  /// Field type is Int32.
  final int mtime;

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x21e753bc.
    buffer.writeInt32(0x21e753bc);

    // Write fields.
    buffer.writeInt32(size);
    buffer.writeString(mimeType);
    buffer.writeObject(fileType);
    buffer.writeInt32(mtime);
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Payments Payment Form.
///
/// ID: `a0058751`.
class PaymentsPaymentForm extends PaymentsPaymentFormBase {
  /// Payments Payment Form constructor.
  const PaymentsPaymentForm({
    required this.canSaveCredentials,
    required this.passwordMissing,
    required this.formId,
    required this.botId,
    required this.title,
    required this.description,
    this.photo,
    required this.invoice,
    required this.providerId,
    required this.url,
    this.nativeProvider,
    this.nativeParams,
    this.additionalMethods,
    this.savedInfo,
    this.savedCredentials,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PaymentsPaymentForm.deserialize(BinaryReader reader) {
    // Read [PaymentsPaymentForm] fields.
    final flags = reader.readInt32();
    final canSaveCredentials = (flags & 4) != 0;
    final passwordMissing = (flags & 8) != 0;
    final formId = reader.readInt64();
    final botId = reader.readInt64();
    final title = reader.readString();
    final description = reader.readString();
    final hasPhotoField = (flags & 32) != 0;
    final photo = hasPhotoField ? reader.readObject() as WebDocumentBase : null;
    final invoice = reader.readObject() as InvoiceBase;
    final providerId = reader.readInt64();
    final url = reader.readString();
    final hasNativeProviderField = (flags & 16) != 0;
    final nativeProvider = hasNativeProviderField ? reader.readString() : null;
    final hasNativeParamsField = (flags & 16) != 0;
    final nativeParams =
        hasNativeParamsField ? reader.readObject() as DataJSONBase : null;
    final hasAdditionalMethodsField = (flags & 64) != 0;
    final additionalMethods = hasAdditionalMethodsField
        ? reader.readVectorObject<PaymentFormMethodBase>()
        : null;
    final hasSavedInfoField = (flags & 1) != 0;
    final savedInfo = hasSavedInfoField
        ? reader.readObject() as PaymentRequestedInfoBase
        : null;
    final hasSavedCredentialsField = (flags & 2) != 0;
    final savedCredentials = hasSavedCredentialsField
        ? reader.readVectorObject<PaymentSavedCredentialsBase>()
        : null;
    final users = reader.readVectorObject<UserBase>();

    // Construct [PaymentsPaymentForm] object.
    final returnValue = PaymentsPaymentForm(
      canSaveCredentials: canSaveCredentials,
      passwordMissing: passwordMissing,
      formId: formId,
      botId: botId,
      title: title,
      description: description,
      photo: photo,
      invoice: invoice,
      providerId: providerId,
      url: url,
      nativeProvider: nativeProvider,
      nativeParams: nativeParams,
      additionalMethods: additionalMethods,
      savedInfo: savedInfo,
      savedCredentials: savedCredentials,
      users: users,
    );

    // Now return the deserialized [PaymentsPaymentForm].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: canSaveCredentials,
      b03: passwordMissing,
      b05: photo != null,
      b04: nativeProvider != null || nativeParams != null,
      b06: additionalMethods != null,
      b00: savedInfo != null,
      b01: savedCredentials != null,
    );

    return v;
  }

  /// can_save_credentials: bit 2 of flags.2?true
  final bool canSaveCredentials;

  /// password_missing: bit 3 of flags.3?true
  final bool passwordMissing;

  /// Form Id.
  ///
  /// Field type is Int64.
  final int formId;

  /// Bot Id.
  ///
  /// Field type is Int64.
  final int botId;

  /// Title.
  final String title;

  /// Description.
  final String description;

  /// Photo.
  final WebDocumentBase? photo;

  /// Invoice.
  final InvoiceBase invoice;

  /// Provider Id.
  ///
  /// Field type is Int64.
  final int providerId;

  /// Url.
  final String url;

  /// Native Provider.
  final String? nativeProvider;

  /// Native Params.
  final DataJSONBase? nativeParams;

  /// Additional Methods.
  final List<PaymentFormMethodBase>? additionalMethods;

  /// Saved Info.
  final PaymentRequestedInfoBase? savedInfo;

  /// Saved Credentials.
  final List<PaymentSavedCredentialsBase>? savedCredentials;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa0058751.
    buffer.writeInt32(0xa0058751);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(formId);
    buffer.writeInt64(botId);
    buffer.writeString(title);
    buffer.writeString(description);
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }
    buffer.writeObject(invoice);
    buffer.writeInt64(providerId);
    buffer.writeString(url);
    final localNativeProviderCopy = nativeProvider;
    if (localNativeProviderCopy != null) {
      buffer.writeString(localNativeProviderCopy);
    }
    final localNativeParamsCopy = nativeParams;
    if (localNativeParamsCopy != null) {
      buffer.writeObject(localNativeParamsCopy);
    }
    final localAdditionalMethodsCopy = additionalMethods;
    if (localAdditionalMethodsCopy != null) {
      buffer.writeVectorObject(localAdditionalMethodsCopy);
    }
    final localSavedInfoCopy = savedInfo;
    if (localSavedInfoCopy != null) {
      buffer.writeObject(localSavedInfoCopy);
    }
    final localSavedCredentialsCopy = savedCredentials;
    if (localSavedCredentialsCopy != null) {
      buffer.writeVectorObject(localSavedCredentialsCopy);
    }
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Payments Validated Requested Info.
///
/// ID: `d1451883`.
class PaymentsValidatedRequestedInfo
    extends PaymentsValidatedRequestedInfoBase {
  /// Payments Validated Requested Info constructor.
  const PaymentsValidatedRequestedInfo({
    this.id,
    this.shippingOptions,
  }) : super._();

  /// Deserialize.
  factory PaymentsValidatedRequestedInfo.deserialize(BinaryReader reader) {
    // Read [PaymentsValidatedRequestedInfo] fields.
    final flags = reader.readInt32();
    final hasIdField = (flags & 1) != 0;
    final id = hasIdField ? reader.readString() : null;
    final hasShippingOptionsField = (flags & 2) != 0;
    final shippingOptions = hasShippingOptionsField
        ? reader.readVectorObject<ShippingOptionBase>()
        : null;

    // Construct [PaymentsValidatedRequestedInfo] object.
    final returnValue = PaymentsValidatedRequestedInfo(
      id: id,
      shippingOptions: shippingOptions,
    );

    // Now return the deserialized [PaymentsValidatedRequestedInfo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: id != null,
      b01: shippingOptions != null,
    );

    return v;
  }

  /// Id.
  final String? id;

  /// Shipping Options.
  final List<ShippingOptionBase>? shippingOptions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd1451883.
    buffer.writeInt32(0xd1451883);

    // Write fields.
    buffer.writeInt32(flags);
    final localIdCopy = id;
    if (localIdCopy != null) {
      buffer.writeString(localIdCopy);
    }
    final localShippingOptionsCopy = shippingOptions;
    if (localShippingOptionsCopy != null) {
      buffer.writeVectorObject(localShippingOptionsCopy);
    }

    // Finished serialization.
  }
}

/// Payments Payment Result.
///
/// ID: `4e5f810d`.
class PaymentsPaymentResult extends PaymentsPaymentResultBase {
  /// Payments Payment Result constructor.
  const PaymentsPaymentResult({
    required this.updates,
  }) : super._();

  /// Deserialize.
  factory PaymentsPaymentResult.deserialize(BinaryReader reader) {
    // Read [PaymentsPaymentResult] fields.
    final updates = reader.readObject() as UpdatesBase;

    // Construct [PaymentsPaymentResult] object.
    final returnValue = PaymentsPaymentResult(
      updates: updates,
    );

    // Now return the deserialized [PaymentsPaymentResult].
    return returnValue;
  }

  /// Updates.
  final UpdatesBase updates;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4e5f810d.
    buffer.writeInt32(0x4e5f810d);

    // Write fields.
    buffer.writeObject(updates);

    // Finished serialization.
  }
}

/// Payments Payment Verification Needed.
///
/// ID: `d8411139`.
class PaymentsPaymentVerificationNeeded extends PaymentsPaymentResultBase {
  /// Payments Payment Verification Needed constructor.
  const PaymentsPaymentVerificationNeeded({
    required this.url,
  }) : super._();

  /// Deserialize.
  factory PaymentsPaymentVerificationNeeded.deserialize(BinaryReader reader) {
    // Read [PaymentsPaymentVerificationNeeded] fields.
    final url = reader.readString();

    // Construct [PaymentsPaymentVerificationNeeded] object.
    final returnValue = PaymentsPaymentVerificationNeeded(
      url: url,
    );

    // Now return the deserialized [PaymentsPaymentVerificationNeeded].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd8411139.
    buffer.writeInt32(0xd8411139);

    // Write fields.
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Payments Payment Receipt.
///
/// ID: `70c4fe03`.
class PaymentsPaymentReceipt extends PaymentsPaymentReceiptBase {
  /// Payments Payment Receipt constructor.
  const PaymentsPaymentReceipt({
    required this.date,
    required this.botId,
    required this.providerId,
    required this.title,
    required this.description,
    this.photo,
    required this.invoice,
    this.info,
    this.shipping,
    this.tipAmount,
    required this.currency,
    required this.totalAmount,
    required this.credentialsTitle,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PaymentsPaymentReceipt.deserialize(BinaryReader reader) {
    // Read [PaymentsPaymentReceipt] fields.
    final flags = reader.readInt32();
    final date = reader.readDateTime();
    final botId = reader.readInt64();
    final providerId = reader.readInt64();
    final title = reader.readString();
    final description = reader.readString();
    final hasPhotoField = (flags & 4) != 0;
    final photo = hasPhotoField ? reader.readObject() as WebDocumentBase : null;
    final invoice = reader.readObject() as InvoiceBase;
    final hasInfoField = (flags & 1) != 0;
    final info =
        hasInfoField ? reader.readObject() as PaymentRequestedInfoBase : null;
    final hasShippingField = (flags & 2) != 0;
    final shipping =
        hasShippingField ? reader.readObject() as ShippingOptionBase : null;
    final hasTipAmountField = (flags & 8) != 0;
    final tipAmount = hasTipAmountField ? reader.readInt64() : null;
    final currency = reader.readString();
    final totalAmount = reader.readInt64();
    final credentialsTitle = reader.readString();
    final users = reader.readVectorObject<UserBase>();

    // Construct [PaymentsPaymentReceipt] object.
    final returnValue = PaymentsPaymentReceipt(
      date: date,
      botId: botId,
      providerId: providerId,
      title: title,
      description: description,
      photo: photo,
      invoice: invoice,
      info: info,
      shipping: shipping,
      tipAmount: tipAmount,
      currency: currency,
      totalAmount: totalAmount,
      credentialsTitle: credentialsTitle,
      users: users,
    );

    // Now return the deserialized [PaymentsPaymentReceipt].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: photo != null,
      b00: info != null,
      b01: shipping != null,
      b03: tipAmount != null,
    );

    return v;
  }

  /// Date.
  final DateTime date;

  /// Bot Id.
  ///
  /// Field type is Int64.
  final int botId;

  /// Provider Id.
  ///
  /// Field type is Int64.
  final int providerId;

  /// Title.
  final String title;

  /// Description.
  final String description;

  /// Photo.
  final WebDocumentBase? photo;

  /// Invoice.
  final InvoiceBase invoice;

  /// Info.
  final PaymentRequestedInfoBase? info;

  /// Shipping.
  final ShippingOptionBase? shipping;

  /// Tip Amount.
  final int? tipAmount;

  /// Currency.
  final String currency;

  /// Total Amount.
  ///
  /// Field type is Int64.
  final int totalAmount;

  /// Credentials Title.
  final String credentialsTitle;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x70c4fe03.
    buffer.writeInt32(0x70c4fe03);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeDateTime(date);
    buffer.writeInt64(botId);
    buffer.writeInt64(providerId);
    buffer.writeString(title);
    buffer.writeString(description);
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }
    buffer.writeObject(invoice);
    final localInfoCopy = info;
    if (localInfoCopy != null) {
      buffer.writeObject(localInfoCopy);
    }
    final localShippingCopy = shipping;
    if (localShippingCopy != null) {
      buffer.writeObject(localShippingCopy);
    }
    final localTipAmountCopy = tipAmount;
    if (localTipAmountCopy != null) {
      buffer.writeInt64(localTipAmountCopy);
    }
    buffer.writeString(currency);
    buffer.writeInt64(totalAmount);
    buffer.writeString(credentialsTitle);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Payments Saved Info.
///
/// ID: `fb8fe43c`.
class PaymentsSavedInfo extends PaymentsSavedInfoBase {
  /// Payments Saved Info constructor.
  const PaymentsSavedInfo({
    required this.hasSavedCredentials,
    this.savedInfo,
  }) : super._();

  /// Deserialize.
  factory PaymentsSavedInfo.deserialize(BinaryReader reader) {
    // Read [PaymentsSavedInfo] fields.
    final flags = reader.readInt32();
    final hasSavedCredentials = (flags & 2) != 0;
    final hasSavedInfoField = (flags & 1) != 0;
    final savedInfo = hasSavedInfoField
        ? reader.readObject() as PaymentRequestedInfoBase
        : null;

    // Construct [PaymentsSavedInfo] object.
    final returnValue = PaymentsSavedInfo(
      hasSavedCredentials: hasSavedCredentials,
      savedInfo: savedInfo,
    );

    // Now return the deserialized [PaymentsSavedInfo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: hasSavedCredentials,
      b00: savedInfo != null,
    );

    return v;
  }

  /// has_saved_credentials: bit 1 of flags.1?true
  final bool hasSavedCredentials;

  /// Saved Info.
  final PaymentRequestedInfoBase? savedInfo;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfb8fe43c.
    buffer.writeInt32(0xfb8fe43c);

    // Write fields.
    buffer.writeInt32(flags);
    final localSavedInfoCopy = savedInfo;
    if (localSavedInfoCopy != null) {
      buffer.writeObject(localSavedInfoCopy);
    }

    // Finished serialization.
  }
}

/// Input Payment Credentials Saved.
///
/// ID: `c10eb2cf`.
class InputPaymentCredentialsSaved extends InputPaymentCredentialsBase {
  /// Input Payment Credentials Saved constructor.
  const InputPaymentCredentialsSaved({
    required this.id,
    required this.tmpPassword,
  }) : super._();

  /// Deserialize.
  factory InputPaymentCredentialsSaved.deserialize(BinaryReader reader) {
    // Read [InputPaymentCredentialsSaved] fields.
    final id = reader.readString();
    final tmpPassword = reader.readBytes();

    // Construct [InputPaymentCredentialsSaved] object.
    final returnValue = InputPaymentCredentialsSaved(
      id: id,
      tmpPassword: tmpPassword,
    );

    // Now return the deserialized [InputPaymentCredentialsSaved].
    return returnValue;
  }

  /// Id.
  final String id;

  /// Tmp Password.
  final Uint8List tmpPassword;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc10eb2cf.
    buffer.writeInt32(0xc10eb2cf);

    // Write fields.
    buffer.writeString(id);
    buffer.writeBytes(tmpPassword);

    // Finished serialization.
  }
}

/// Input Payment Credentials.
///
/// ID: `3417d728`.
class InputPaymentCredentials extends InputPaymentCredentialsBase {
  /// Input Payment Credentials constructor.
  const InputPaymentCredentials({
    required this.save,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory InputPaymentCredentials.deserialize(BinaryReader reader) {
    // Read [InputPaymentCredentials] fields.
    final flags = reader.readInt32();
    final save = (flags & 1) != 0;
    final data = reader.readObject() as DataJSONBase;

    // Construct [InputPaymentCredentials] object.
    final returnValue = InputPaymentCredentials(
      save: save,
      data: data,
    );

    // Now return the deserialized [InputPaymentCredentials].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: save,
    );

    return v;
  }

  /// save: bit 0 of flags.0?true
  final bool save;

  /// Data.
  final DataJSONBase data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3417d728.
    buffer.writeInt32(0x3417d728);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(data);

    // Finished serialization.
  }
}

/// Input Payment Credentials Apple Pay.
///
/// ID: `0aa1c39f`.
class InputPaymentCredentialsApplePay extends InputPaymentCredentialsBase {
  /// Input Payment Credentials Apple Pay constructor.
  const InputPaymentCredentialsApplePay({
    required this.paymentData,
  }) : super._();

  /// Deserialize.
  factory InputPaymentCredentialsApplePay.deserialize(BinaryReader reader) {
    // Read [InputPaymentCredentialsApplePay] fields.
    final paymentData = reader.readObject() as DataJSONBase;

    // Construct [InputPaymentCredentialsApplePay] object.
    final returnValue = InputPaymentCredentialsApplePay(
      paymentData: paymentData,
    );

    // Now return the deserialized [InputPaymentCredentialsApplePay].
    return returnValue;
  }

  /// Payment Data.
  final DataJSONBase paymentData;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0aa1c39f.
    buffer.writeInt32(0x0aa1c39f);

    // Write fields.
    buffer.writeObject(paymentData);

    // Finished serialization.
  }
}

/// Input Payment Credentials Google Pay.
///
/// ID: `8ac32801`.
class InputPaymentCredentialsGooglePay extends InputPaymentCredentialsBase {
  /// Input Payment Credentials Google Pay constructor.
  const InputPaymentCredentialsGooglePay({
    required this.paymentToken,
  }) : super._();

  /// Deserialize.
  factory InputPaymentCredentialsGooglePay.deserialize(BinaryReader reader) {
    // Read [InputPaymentCredentialsGooglePay] fields.
    final paymentToken = reader.readObject() as DataJSONBase;

    // Construct [InputPaymentCredentialsGooglePay] object.
    final returnValue = InputPaymentCredentialsGooglePay(
      paymentToken: paymentToken,
    );

    // Now return the deserialized [InputPaymentCredentialsGooglePay].
    return returnValue;
  }

  /// Payment Token.
  final DataJSONBase paymentToken;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8ac32801.
    buffer.writeInt32(0x8ac32801);

    // Write fields.
    buffer.writeObject(paymentToken);

    // Finished serialization.
  }
}

/// Account Tmp Password.
///
/// ID: `db64fd34`.
class AccountTmpPassword extends AccountTmpPasswordBase {
  /// Account Tmp Password constructor.
  const AccountTmpPassword({
    required this.tmpPassword,
    required this.validUntil,
  }) : super._();

  /// Deserialize.
  factory AccountTmpPassword.deserialize(BinaryReader reader) {
    // Read [AccountTmpPassword] fields.
    final tmpPassword = reader.readBytes();
    final validUntil = reader.readInt32();

    // Construct [AccountTmpPassword] object.
    final returnValue = AccountTmpPassword(
      tmpPassword: tmpPassword,
      validUntil: validUntil,
    );

    // Now return the deserialized [AccountTmpPassword].
    return returnValue;
  }

  /// Tmp Password.
  final Uint8List tmpPassword;

  /// Valid Until.
  ///
  /// Field type is Int32.
  final int validUntil;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdb64fd34.
    buffer.writeInt32(0xdb64fd34);

    // Write fields.
    buffer.writeBytes(tmpPassword);
    buffer.writeInt32(validUntil);

    // Finished serialization.
  }
}

/// Shipping Option.
///
/// ID: `b6213cdf`.
class ShippingOption extends ShippingOptionBase {
  /// Shipping Option constructor.
  const ShippingOption({
    required this.id,
    required this.title,
    required this.prices,
  }) : super._();

  /// Deserialize.
  factory ShippingOption.deserialize(BinaryReader reader) {
    // Read [ShippingOption] fields.
    final id = reader.readString();
    final title = reader.readString();
    final prices = reader.readVectorObject<LabeledPriceBase>();

    // Construct [ShippingOption] object.
    final returnValue = ShippingOption(
      id: id,
      title: title,
      prices: prices,
    );

    // Now return the deserialized [ShippingOption].
    return returnValue;
  }

  /// Id.
  final String id;

  /// Title.
  final String title;

  /// Prices.
  final List<LabeledPriceBase> prices;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb6213cdf.
    buffer.writeInt32(0xb6213cdf);

    // Write fields.
    buffer.writeString(id);
    buffer.writeString(title);
    buffer.writeVectorObject(prices);

    // Finished serialization.
  }
}

/// Input Sticker Set Item.
///
/// ID: `32da9e9c`.
class InputStickerSetItem extends InputStickerSetItemBase {
  /// Input Sticker Set Item constructor.
  const InputStickerSetItem({
    required this.document,
    required this.emoji,
    this.maskCoords,
    this.keywords,
  }) : super._();

  /// Deserialize.
  factory InputStickerSetItem.deserialize(BinaryReader reader) {
    // Read [InputStickerSetItem] fields.
    final flags = reader.readInt32();
    final document = reader.readObject() as InputDocumentBase;
    final emoji = reader.readString();
    final hasMaskCoordsField = (flags & 1) != 0;
    final maskCoords =
        hasMaskCoordsField ? reader.readObject() as MaskCoordsBase : null;
    final hasKeywordsField = (flags & 2) != 0;
    final keywords = hasKeywordsField ? reader.readString() : null;

    // Construct [InputStickerSetItem] object.
    final returnValue = InputStickerSetItem(
      document: document,
      emoji: emoji,
      maskCoords: maskCoords,
      keywords: keywords,
    );

    // Now return the deserialized [InputStickerSetItem].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: maskCoords != null,
      b01: keywords != null,
    );

    return v;
  }

  /// Document.
  final InputDocumentBase document;

  /// Emoji.
  final String emoji;

  /// Mask Coords.
  final MaskCoordsBase? maskCoords;

  /// Keywords.
  final String? keywords;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x32da9e9c.
    buffer.writeInt32(0x32da9e9c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(document);
    buffer.writeString(emoji);
    final localMaskCoordsCopy = maskCoords;
    if (localMaskCoordsCopy != null) {
      buffer.writeObject(localMaskCoordsCopy);
    }
    final localKeywordsCopy = keywords;
    if (localKeywordsCopy != null) {
      buffer.writeString(localKeywordsCopy);
    }

    // Finished serialization.
  }
}

/// Input Phone Call.
///
/// ID: `1e36fded`.
class InputPhoneCall extends InputPhoneCallBase {
  /// Input Phone Call constructor.
  const InputPhoneCall({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputPhoneCall.deserialize(BinaryReader reader) {
    // Read [InputPhoneCall] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputPhoneCall] object.
    final returnValue = InputPhoneCall(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputPhoneCall].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1e36fded.
    buffer.writeInt32(0x1e36fded);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Phone Call Empty.
///
/// ID: `5366c915`.
class PhoneCallEmpty extends PhoneCallBase {
  /// Phone Call Empty constructor.
  const PhoneCallEmpty({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory PhoneCallEmpty.deserialize(BinaryReader reader) {
    // Read [PhoneCallEmpty] fields.
    final id = reader.readInt64();

    // Construct [PhoneCallEmpty] object.
    final returnValue = PhoneCallEmpty(
      id: id,
    );

    // Now return the deserialized [PhoneCallEmpty].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5366c915.
    buffer.writeInt32(0x5366c915);

    // Write fields.
    buffer.writeInt64(id);

    // Finished serialization.
  }
}

/// Phone Call Waiting.
///
/// ID: `c5226f17`.
class PhoneCallWaiting extends PhoneCallBase {
  /// Phone Call Waiting constructor.
  const PhoneCallWaiting({
    required this.video,
    required this.id,
    required this.accessHash,
    required this.date,
    required this.adminId,
    required this.participantId,
    required this.protocol,
    this.receiveDate,
  }) : super._();

  /// Deserialize.
  factory PhoneCallWaiting.deserialize(BinaryReader reader) {
    // Read [PhoneCallWaiting] fields.
    final flags = reader.readInt32();
    final video = (flags & 64) != 0;
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final date = reader.readDateTime();
    final adminId = reader.readInt64();
    final participantId = reader.readInt64();
    final protocol = reader.readObject() as PhoneCallProtocolBase;
    final hasReceiveDateField = (flags & 1) != 0;
    final receiveDate = hasReceiveDateField ? reader.readDateTime() : null;

    // Construct [PhoneCallWaiting] object.
    final returnValue = PhoneCallWaiting(
      video: video,
      id: id,
      accessHash: accessHash,
      date: date,
      adminId: adminId,
      participantId: participantId,
      protocol: protocol,
      receiveDate: receiveDate,
    );

    // Now return the deserialized [PhoneCallWaiting].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b06: video,
      b00: receiveDate != null,
    );

    return v;
  }

  /// video: bit 6 of flags.6?true
  final bool video;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Date.
  final DateTime date;

  /// Admin Id.
  ///
  /// Field type is Int64.
  final int adminId;

  /// Participant Id.
  ///
  /// Field type is Int64.
  final int participantId;

  /// Protocol.
  final PhoneCallProtocolBase protocol;

  /// Receive Date.
  final DateTime? receiveDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc5226f17.
    buffer.writeInt32(0xc5226f17);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeDateTime(date);
    buffer.writeInt64(adminId);
    buffer.writeInt64(participantId);
    buffer.writeObject(protocol);
    final localReceiveDateCopy = receiveDate;
    if (localReceiveDateCopy != null) {
      buffer.writeDateTime(localReceiveDateCopy);
    }

    // Finished serialization.
  }
}

/// Phone Call Requested.
///
/// ID: `14b0ed0c`.
class PhoneCallRequested extends PhoneCallBase {
  /// Phone Call Requested constructor.
  const PhoneCallRequested({
    required this.video,
    required this.id,
    required this.accessHash,
    required this.date,
    required this.adminId,
    required this.participantId,
    required this.gAHash,
    required this.protocol,
  }) : super._();

  /// Deserialize.
  factory PhoneCallRequested.deserialize(BinaryReader reader) {
    // Read [PhoneCallRequested] fields.
    final flags = reader.readInt32();
    final video = (flags & 64) != 0;
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final date = reader.readDateTime();
    final adminId = reader.readInt64();
    final participantId = reader.readInt64();
    final gAHash = reader.readBytes();
    final protocol = reader.readObject() as PhoneCallProtocolBase;

    // Construct [PhoneCallRequested] object.
    final returnValue = PhoneCallRequested(
      video: video,
      id: id,
      accessHash: accessHash,
      date: date,
      adminId: adminId,
      participantId: participantId,
      gAHash: gAHash,
      protocol: protocol,
    );

    // Now return the deserialized [PhoneCallRequested].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b06: video,
    );

    return v;
  }

  /// video: bit 6 of flags.6?true
  final bool video;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Date.
  final DateTime date;

  /// Admin Id.
  ///
  /// Field type is Int64.
  final int adminId;

  /// Participant Id.
  ///
  /// Field type is Int64.
  final int participantId;

  /// G A Hash.
  final Uint8List gAHash;

  /// Protocol.
  final PhoneCallProtocolBase protocol;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x14b0ed0c.
    buffer.writeInt32(0x14b0ed0c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeDateTime(date);
    buffer.writeInt64(adminId);
    buffer.writeInt64(participantId);
    buffer.writeBytes(gAHash);
    buffer.writeObject(protocol);

    // Finished serialization.
  }
}

/// Phone Call Accepted.
///
/// ID: `3660c311`.
class PhoneCallAccepted extends PhoneCallBase {
  /// Phone Call Accepted constructor.
  const PhoneCallAccepted({
    required this.video,
    required this.id,
    required this.accessHash,
    required this.date,
    required this.adminId,
    required this.participantId,
    required this.gB,
    required this.protocol,
  }) : super._();

  /// Deserialize.
  factory PhoneCallAccepted.deserialize(BinaryReader reader) {
    // Read [PhoneCallAccepted] fields.
    final flags = reader.readInt32();
    final video = (flags & 64) != 0;
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final date = reader.readDateTime();
    final adminId = reader.readInt64();
    final participantId = reader.readInt64();
    final gB = reader.readBytes();
    final protocol = reader.readObject() as PhoneCallProtocolBase;

    // Construct [PhoneCallAccepted] object.
    final returnValue = PhoneCallAccepted(
      video: video,
      id: id,
      accessHash: accessHash,
      date: date,
      adminId: adminId,
      participantId: participantId,
      gB: gB,
      protocol: protocol,
    );

    // Now return the deserialized [PhoneCallAccepted].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b06: video,
    );

    return v;
  }

  /// video: bit 6 of flags.6?true
  final bool video;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Date.
  final DateTime date;

  /// Admin Id.
  ///
  /// Field type is Int64.
  final int adminId;

  /// Participant Id.
  ///
  /// Field type is Int64.
  final int participantId;

  /// G B.
  final Uint8List gB;

  /// Protocol.
  final PhoneCallProtocolBase protocol;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3660c311.
    buffer.writeInt32(0x3660c311);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeDateTime(date);
    buffer.writeInt64(adminId);
    buffer.writeInt64(participantId);
    buffer.writeBytes(gB);
    buffer.writeObject(protocol);

    // Finished serialization.
  }
}

/// Phone Call.
///
/// ID: `967f7c67`.
class PhoneCall extends PhoneCallBase {
  /// Phone Call constructor.
  const PhoneCall({
    required this.p2pAllowed,
    required this.video,
    required this.id,
    required this.accessHash,
    required this.date,
    required this.adminId,
    required this.participantId,
    required this.gAOrB,
    required this.keyFingerprint,
    required this.protocol,
    required this.connections,
    required this.startDate,
  }) : super._();

  /// Deserialize.
  factory PhoneCall.deserialize(BinaryReader reader) {
    // Read [PhoneCall] fields.
    final flags = reader.readInt32();
    final p2pAllowed = (flags & 32) != 0;
    final video = (flags & 64) != 0;
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final date = reader.readDateTime();
    final adminId = reader.readInt64();
    final participantId = reader.readInt64();
    final gAOrB = reader.readBytes();
    final keyFingerprint = reader.readInt64();
    final protocol = reader.readObject() as PhoneCallProtocolBase;
    final connections = reader.readVectorObject<PhoneConnectionBase>();
    final startDate = reader.readDateTime();

    // Construct [PhoneCall] object.
    final returnValue = PhoneCall(
      p2pAllowed: p2pAllowed,
      video: video,
      id: id,
      accessHash: accessHash,
      date: date,
      adminId: adminId,
      participantId: participantId,
      gAOrB: gAOrB,
      keyFingerprint: keyFingerprint,
      protocol: protocol,
      connections: connections,
      startDate: startDate,
    );

    // Now return the deserialized [PhoneCall].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b05: p2pAllowed,
      b06: video,
    );

    return v;
  }

  /// p2p_allowed: bit 5 of flags.5?true
  final bool p2pAllowed;

  /// video: bit 6 of flags.6?true
  final bool video;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Date.
  final DateTime date;

  /// Admin Id.
  ///
  /// Field type is Int64.
  final int adminId;

  /// Participant Id.
  ///
  /// Field type is Int64.
  final int participantId;

  /// G A Or B.
  final Uint8List gAOrB;

  /// Key Fingerprint.
  ///
  /// Field type is Int64.
  final int keyFingerprint;

  /// Protocol.
  final PhoneCallProtocolBase protocol;

  /// Connections.
  final List<PhoneConnectionBase> connections;

  /// Start Date.
  final DateTime startDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x967f7c67.
    buffer.writeInt32(0x967f7c67);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeDateTime(date);
    buffer.writeInt64(adminId);
    buffer.writeInt64(participantId);
    buffer.writeBytes(gAOrB);
    buffer.writeInt64(keyFingerprint);
    buffer.writeObject(protocol);
    buffer.writeVectorObject(connections);
    buffer.writeDateTime(startDate);

    // Finished serialization.
  }
}

/// Phone Call Discarded.
///
/// ID: `50ca4de1`.
class PhoneCallDiscarded extends PhoneCallBase {
  /// Phone Call Discarded constructor.
  const PhoneCallDiscarded({
    required this.needRating,
    required this.needDebug,
    required this.video,
    required this.id,
    this.reason,
    this.duration,
  }) : super._();

  /// Deserialize.
  factory PhoneCallDiscarded.deserialize(BinaryReader reader) {
    // Read [PhoneCallDiscarded] fields.
    final flags = reader.readInt32();
    final needRating = (flags & 4) != 0;
    final needDebug = (flags & 8) != 0;
    final video = (flags & 64) != 0;
    final id = reader.readInt64();
    final hasReasonField = (flags & 1) != 0;
    final reason = hasReasonField
        ? reader.readObject() as PhoneCallDiscardReasonBase
        : null;
    final hasDurationField = (flags & 2) != 0;
    final duration = hasDurationField ? reader.readInt32() : null;

    // Construct [PhoneCallDiscarded] object.
    final returnValue = PhoneCallDiscarded(
      needRating: needRating,
      needDebug: needDebug,
      video: video,
      id: id,
      reason: reason,
      duration: duration,
    );

    // Now return the deserialized [PhoneCallDiscarded].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: needRating,
      b03: needDebug,
      b06: video,
      b00: reason != null,
      b01: duration != null,
    );

    return v;
  }

  /// need_rating: bit 2 of flags.2?true
  final bool needRating;

  /// need_debug: bit 3 of flags.3?true
  final bool needDebug;

  /// video: bit 6 of flags.6?true
  final bool video;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Reason.
  final PhoneCallDiscardReasonBase? reason;

  /// Duration.
  final int? duration;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x50ca4de1.
    buffer.writeInt32(0x50ca4de1);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    final localReasonCopy = reason;
    if (localReasonCopy != null) {
      buffer.writeObject(localReasonCopy);
    }
    final localDurationCopy = duration;
    if (localDurationCopy != null) {
      buffer.writeInt32(localDurationCopy);
    }

    // Finished serialization.
  }
}

/// Phone Connection.
///
/// ID: `9cc123c7`.
class PhoneConnection extends PhoneConnectionBase {
  /// Phone Connection constructor.
  const PhoneConnection({
    required this.tcp,
    required this.id,
    required this.ip,
    required this.ipv6,
    required this.port,
    required this.peerTag,
  }) : super._();

  /// Deserialize.
  factory PhoneConnection.deserialize(BinaryReader reader) {
    // Read [PhoneConnection] fields.
    final flags = reader.readInt32();
    final tcp = (flags & 1) != 0;
    final id = reader.readInt64();
    final ip = reader.readString();
    final ipv6 = reader.readString();
    final port = reader.readInt32();
    final peerTag = reader.readBytes();

    // Construct [PhoneConnection] object.
    final returnValue = PhoneConnection(
      tcp: tcp,
      id: id,
      ip: ip,
      ipv6: ipv6,
      port: port,
      peerTag: peerTag,
    );

    // Now return the deserialized [PhoneConnection].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: tcp,
    );

    return v;
  }

  /// tcp: bit 0 of flags.0?true
  final bool tcp;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Ip.
  final String ip;

  /// Ipv6.
  final String ipv6;

  /// Port.
  ///
  /// Field type is Int32.
  final int port;

  /// Peer Tag.
  final Uint8List peerTag;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9cc123c7.
    buffer.writeInt32(0x9cc123c7);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeString(ip);
    buffer.writeString(ipv6);
    buffer.writeInt32(port);
    buffer.writeBytes(peerTag);

    // Finished serialization.
  }
}

/// Phone Connection Webrtc.
///
/// ID: `635fe375`.
class PhoneConnectionWebrtc extends PhoneConnectionBase {
  /// Phone Connection Webrtc constructor.
  const PhoneConnectionWebrtc({
    required this.turn,
    required this.stun,
    required this.id,
    required this.ip,
    required this.ipv6,
    required this.port,
    required this.username,
    required this.password,
  }) : super._();

  /// Deserialize.
  factory PhoneConnectionWebrtc.deserialize(BinaryReader reader) {
    // Read [PhoneConnectionWebrtc] fields.
    final flags = reader.readInt32();
    final turn = (flags & 1) != 0;
    final stun = (flags & 2) != 0;
    final id = reader.readInt64();
    final ip = reader.readString();
    final ipv6 = reader.readString();
    final port = reader.readInt32();
    final username = reader.readString();
    final password = reader.readString();

    // Construct [PhoneConnectionWebrtc] object.
    final returnValue = PhoneConnectionWebrtc(
      turn: turn,
      stun: stun,
      id: id,
      ip: ip,
      ipv6: ipv6,
      port: port,
      username: username,
      password: password,
    );

    // Now return the deserialized [PhoneConnectionWebrtc].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: turn,
      b01: stun,
    );

    return v;
  }

  /// turn: bit 0 of flags.0?true
  final bool turn;

  /// stun: bit 1 of flags.1?true
  final bool stun;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Ip.
  final String ip;

  /// Ipv6.
  final String ipv6;

  /// Port.
  ///
  /// Field type is Int32.
  final int port;

  /// Username.
  final String username;

  /// Password.
  final String password;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x635fe375.
    buffer.writeInt32(0x635fe375);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeString(ip);
    buffer.writeString(ipv6);
    buffer.writeInt32(port);
    buffer.writeString(username);
    buffer.writeString(password);

    // Finished serialization.
  }
}

/// Phone Call Protocol.
///
/// ID: `fc878fc8`.
class PhoneCallProtocol extends PhoneCallProtocolBase {
  /// Phone Call Protocol constructor.
  const PhoneCallProtocol({
    required this.udpP2p,
    required this.udpReflector,
    required this.minLayer,
    required this.maxLayer,
    required this.libraryVersions,
  }) : super._();

  /// Deserialize.
  factory PhoneCallProtocol.deserialize(BinaryReader reader) {
    // Read [PhoneCallProtocol] fields.
    final flags = reader.readInt32();
    final udpP2p = (flags & 1) != 0;
    final udpReflector = (flags & 2) != 0;
    final minLayer = reader.readInt32();
    final maxLayer = reader.readInt32();
    final libraryVersions = reader.readVectorString();

    // Construct [PhoneCallProtocol] object.
    final returnValue = PhoneCallProtocol(
      udpP2p: udpP2p,
      udpReflector: udpReflector,
      minLayer: minLayer,
      maxLayer: maxLayer,
      libraryVersions: libraryVersions,
    );

    // Now return the deserialized [PhoneCallProtocol].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: udpP2p,
      b01: udpReflector,
    );

    return v;
  }

  /// udp_p2p: bit 0 of flags.0?true
  final bool udpP2p;

  /// udp_reflector: bit 1 of flags.1?true
  final bool udpReflector;

  /// Min Layer.
  ///
  /// Field type is Int32.
  final int minLayer;

  /// Max Layer.
  ///
  /// Field type is Int32.
  final int maxLayer;

  /// Library Versions.
  final List<String> libraryVersions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfc878fc8.
    buffer.writeInt32(0xfc878fc8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(minLayer);
    buffer.writeInt32(maxLayer);
    buffer.writeVectorString(libraryVersions);

    // Finished serialization.
  }
}

/// Phone Phone Call.
///
/// ID: `ec82e140`.
class PhonePhoneCall extends PhonePhoneCallBase {
  /// Phone Phone Call constructor.
  const PhonePhoneCall({
    required this.phoneCall,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PhonePhoneCall.deserialize(BinaryReader reader) {
    // Read [PhonePhoneCall] fields.
    final phoneCall = reader.readObject() as PhoneCallBase;
    final users = reader.readVectorObject<UserBase>();

    // Construct [PhonePhoneCall] object.
    final returnValue = PhonePhoneCall(
      phoneCall: phoneCall,
      users: users,
    );

    // Now return the deserialized [PhonePhoneCall].
    return returnValue;
  }

  /// Phone Call.
  final PhoneCallBase phoneCall;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xec82e140.
    buffer.writeInt32(0xec82e140);

    // Write fields.
    buffer.writeObject(phoneCall);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Upload Cdn File Reupload Needed.
///
/// ID: `eea8e46e`.
class UploadCdnFileReuploadNeeded extends UploadCdnFileBase {
  /// Upload Cdn File Reupload Needed constructor.
  const UploadCdnFileReuploadNeeded({
    required this.requestToken,
  }) : super._();

  /// Deserialize.
  factory UploadCdnFileReuploadNeeded.deserialize(BinaryReader reader) {
    // Read [UploadCdnFileReuploadNeeded] fields.
    final requestToken = reader.readBytes();

    // Construct [UploadCdnFileReuploadNeeded] object.
    final returnValue = UploadCdnFileReuploadNeeded(
      requestToken: requestToken,
    );

    // Now return the deserialized [UploadCdnFileReuploadNeeded].
    return returnValue;
  }

  /// Request Token.
  final Uint8List requestToken;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeea8e46e.
    buffer.writeInt32(0xeea8e46e);

    // Write fields.
    buffer.writeBytes(requestToken);

    // Finished serialization.
  }
}

/// Upload Cdn File.
///
/// ID: `a99fca4f`.
class UploadCdnFile extends UploadCdnFileBase {
  /// Upload Cdn File constructor.
  const UploadCdnFile({
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory UploadCdnFile.deserialize(BinaryReader reader) {
    // Read [UploadCdnFile] fields.
    final bytes = reader.readBytes();

    // Construct [UploadCdnFile] object.
    final returnValue = UploadCdnFile(
      bytes: bytes,
    );

    // Now return the deserialized [UploadCdnFile].
    return returnValue;
  }

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa99fca4f.
    buffer.writeInt32(0xa99fca4f);

    // Write fields.
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Cdn Public Key.
///
/// ID: `c982eaba`.
class CdnPublicKey extends CdnPublicKeyBase {
  /// Cdn Public Key constructor.
  const CdnPublicKey({
    required this.dcId,
    required this.publicKey,
  }) : super._();

  /// Deserialize.
  factory CdnPublicKey.deserialize(BinaryReader reader) {
    // Read [CdnPublicKey] fields.
    final dcId = reader.readInt32();
    final publicKey = reader.readString();

    // Construct [CdnPublicKey] object.
    final returnValue = CdnPublicKey(
      dcId: dcId,
      publicKey: publicKey,
    );

    // Now return the deserialized [CdnPublicKey].
    return returnValue;
  }

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Public Key.
  final String publicKey;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc982eaba.
    buffer.writeInt32(0xc982eaba);

    // Write fields.
    buffer.writeInt32(dcId);
    buffer.writeString(publicKey);

    // Finished serialization.
  }
}

/// Cdn Config.
///
/// ID: `5725e40a`.
class CdnConfig extends CdnConfigBase {
  /// Cdn Config constructor.
  const CdnConfig({
    required this.publicKeys,
  }) : super._();

  /// Deserialize.
  factory CdnConfig.deserialize(BinaryReader reader) {
    // Read [CdnConfig] fields.
    final publicKeys = reader.readVectorObject<CdnPublicKeyBase>();

    // Construct [CdnConfig] object.
    final returnValue = CdnConfig(
      publicKeys: publicKeys,
    );

    // Now return the deserialized [CdnConfig].
    return returnValue;
  }

  /// Public Keys.
  final List<CdnPublicKeyBase> publicKeys;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5725e40a.
    buffer.writeInt32(0x5725e40a);

    // Write fields.
    buffer.writeVectorObject(publicKeys);

    // Finished serialization.
  }
}

/// Lang Pack String.
///
/// ID: `cad181f6`.
class LangPackString extends LangPackStringBase {
  /// Lang Pack String constructor.
  const LangPackString({
    required this.key,
    required this.value,
  }) : super._();

  /// Deserialize.
  factory LangPackString.deserialize(BinaryReader reader) {
    // Read [LangPackString] fields.
    final key = reader.readString();
    final value = reader.readString();

    // Construct [LangPackString] object.
    final returnValue = LangPackString(
      key: key,
      value: value,
    );

    // Now return the deserialized [LangPackString].
    return returnValue;
  }

  /// Key.
  final String key;

  /// Value.
  final String value;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcad181f6.
    buffer.writeInt32(0xcad181f6);

    // Write fields.
    buffer.writeString(key);
    buffer.writeString(value);

    // Finished serialization.
  }
}

/// Lang Pack String Pluralized.
///
/// ID: `6c47ac9f`.
class LangPackStringPluralized extends LangPackStringBase {
  /// Lang Pack String Pluralized constructor.
  const LangPackStringPluralized({
    required this.key,
    this.zeroValue,
    this.oneValue,
    this.twoValue,
    this.fewValue,
    this.manyValue,
    required this.otherValue,
  }) : super._();

  /// Deserialize.
  factory LangPackStringPluralized.deserialize(BinaryReader reader) {
    // Read [LangPackStringPluralized] fields.
    final flags = reader.readInt32();
    final key = reader.readString();
    final hasZeroValueField = (flags & 1) != 0;
    final zeroValue = hasZeroValueField ? reader.readString() : null;
    final hasOneValueField = (flags & 2) != 0;
    final oneValue = hasOneValueField ? reader.readString() : null;
    final hasTwoValueField = (flags & 4) != 0;
    final twoValue = hasTwoValueField ? reader.readString() : null;
    final hasFewValueField = (flags & 8) != 0;
    final fewValue = hasFewValueField ? reader.readString() : null;
    final hasManyValueField = (flags & 16) != 0;
    final manyValue = hasManyValueField ? reader.readString() : null;
    final otherValue = reader.readString();

    // Construct [LangPackStringPluralized] object.
    final returnValue = LangPackStringPluralized(
      key: key,
      zeroValue: zeroValue,
      oneValue: oneValue,
      twoValue: twoValue,
      fewValue: fewValue,
      manyValue: manyValue,
      otherValue: otherValue,
    );

    // Now return the deserialized [LangPackStringPluralized].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: zeroValue != null,
      b01: oneValue != null,
      b02: twoValue != null,
      b03: fewValue != null,
      b04: manyValue != null,
    );

    return v;
  }

  /// Key.
  final String key;

  /// Zero Value.
  final String? zeroValue;

  /// One Value.
  final String? oneValue;

  /// Two Value.
  final String? twoValue;

  /// Few Value.
  final String? fewValue;

  /// Many Value.
  final String? manyValue;

  /// Other Value.
  final String otherValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6c47ac9f.
    buffer.writeInt32(0x6c47ac9f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(key);
    final localZeroValueCopy = zeroValue;
    if (localZeroValueCopy != null) {
      buffer.writeString(localZeroValueCopy);
    }
    final localOneValueCopy = oneValue;
    if (localOneValueCopy != null) {
      buffer.writeString(localOneValueCopy);
    }
    final localTwoValueCopy = twoValue;
    if (localTwoValueCopy != null) {
      buffer.writeString(localTwoValueCopy);
    }
    final localFewValueCopy = fewValue;
    if (localFewValueCopy != null) {
      buffer.writeString(localFewValueCopy);
    }
    final localManyValueCopy = manyValue;
    if (localManyValueCopy != null) {
      buffer.writeString(localManyValueCopy);
    }
    buffer.writeString(otherValue);

    // Finished serialization.
  }
}

/// Lang Pack String Deleted.
///
/// ID: `2979eeb2`.
class LangPackStringDeleted extends LangPackStringBase {
  /// Lang Pack String Deleted constructor.
  const LangPackStringDeleted({
    required this.key,
  }) : super._();

  /// Deserialize.
  factory LangPackStringDeleted.deserialize(BinaryReader reader) {
    // Read [LangPackStringDeleted] fields.
    final key = reader.readString();

    // Construct [LangPackStringDeleted] object.
    final returnValue = LangPackStringDeleted(
      key: key,
    );

    // Now return the deserialized [LangPackStringDeleted].
    return returnValue;
  }

  /// Key.
  final String key;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2979eeb2.
    buffer.writeInt32(0x2979eeb2);

    // Write fields.
    buffer.writeString(key);

    // Finished serialization.
  }
}

/// Lang Pack Difference.
///
/// ID: `f385c1f6`.
class LangPackDifference extends LangPackDifferenceBase {
  /// Lang Pack Difference constructor.
  const LangPackDifference({
    required this.langCode,
    required this.fromVersion,
    required this.version,
    required this.strings,
  }) : super._();

  /// Deserialize.
  factory LangPackDifference.deserialize(BinaryReader reader) {
    // Read [LangPackDifference] fields.
    final langCode = reader.readString();
    final fromVersion = reader.readInt32();
    final version = reader.readInt32();
    final strings = reader.readVectorObject<LangPackStringBase>();

    // Construct [LangPackDifference] object.
    final returnValue = LangPackDifference(
      langCode: langCode,
      fromVersion: fromVersion,
      version: version,
      strings: strings,
    );

    // Now return the deserialized [LangPackDifference].
    return returnValue;
  }

  /// Lang Code.
  final String langCode;

  /// From Version.
  ///
  /// Field type is Int32.
  final int fromVersion;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Strings.
  final List<LangPackStringBase> strings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf385c1f6.
    buffer.writeInt32(0xf385c1f6);

    // Write fields.
    buffer.writeString(langCode);
    buffer.writeInt32(fromVersion);
    buffer.writeInt32(version);
    buffer.writeVectorObject(strings);

    // Finished serialization.
  }
}

/// Lang Pack Language.
///
/// ID: `eeca5ce3`.
class LangPackLanguage extends LangPackLanguageBase {
  /// Lang Pack Language constructor.
  const LangPackLanguage({
    required this.official,
    required this.rtl,
    required this.beta,
    required this.name,
    required this.nativeName,
    required this.langCode,
    this.baseLangCode,
    required this.pluralCode,
    required this.stringsCount,
    required this.translatedCount,
    required this.translationsUrl,
  }) : super._();

  /// Deserialize.
  factory LangPackLanguage.deserialize(BinaryReader reader) {
    // Read [LangPackLanguage] fields.
    final flags = reader.readInt32();
    final official = (flags & 1) != 0;
    final rtl = (flags & 4) != 0;
    final beta = (flags & 8) != 0;
    final name = reader.readString();
    final nativeName = reader.readString();
    final langCode = reader.readString();
    final hasBaseLangCodeField = (flags & 2) != 0;
    final baseLangCode = hasBaseLangCodeField ? reader.readString() : null;
    final pluralCode = reader.readString();
    final stringsCount = reader.readInt32();
    final translatedCount = reader.readInt32();
    final translationsUrl = reader.readString();

    // Construct [LangPackLanguage] object.
    final returnValue = LangPackLanguage(
      official: official,
      rtl: rtl,
      beta: beta,
      name: name,
      nativeName: nativeName,
      langCode: langCode,
      baseLangCode: baseLangCode,
      pluralCode: pluralCode,
      stringsCount: stringsCount,
      translatedCount: translatedCount,
      translationsUrl: translationsUrl,
    );

    // Now return the deserialized [LangPackLanguage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: official,
      b02: rtl,
      b03: beta,
      b01: baseLangCode != null,
    );

    return v;
  }

  /// official: bit 0 of flags.0?true
  final bool official;

  /// rtl: bit 2 of flags.2?true
  final bool rtl;

  /// beta: bit 3 of flags.3?true
  final bool beta;

  /// Name.
  final String name;

  /// Native Name.
  final String nativeName;

  /// Lang Code.
  final String langCode;

  /// Base Lang Code.
  final String? baseLangCode;

  /// Plural Code.
  final String pluralCode;

  /// Strings Count.
  ///
  /// Field type is Int32.
  final int stringsCount;

  /// Translated Count.
  ///
  /// Field type is Int32.
  final int translatedCount;

  /// Translations Url.
  final String translationsUrl;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeeca5ce3.
    buffer.writeInt32(0xeeca5ce3);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(name);
    buffer.writeString(nativeName);
    buffer.writeString(langCode);
    final localBaseLangCodeCopy = baseLangCode;
    if (localBaseLangCodeCopy != null) {
      buffer.writeString(localBaseLangCodeCopy);
    }
    buffer.writeString(pluralCode);
    buffer.writeInt32(stringsCount);
    buffer.writeInt32(translatedCount);
    buffer.writeString(translationsUrl);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Title.
///
/// ID: `e6dfb825`.
class ChannelAdminLogEventActionChangeTitle
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Title constructor.
  const ChannelAdminLogEventActionChangeTitle({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeTitle.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeTitle] fields.
    final prevValue = reader.readString();
    final newValue = reader.readString();

    // Construct [ChannelAdminLogEventActionChangeTitle] object.
    final returnValue = ChannelAdminLogEventActionChangeTitle(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeTitle].
    return returnValue;
  }

  /// Prev Value.
  final String prevValue;

  /// New Value.
  final String newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe6dfb825.
    buffer.writeInt32(0xe6dfb825);

    // Write fields.
    buffer.writeString(prevValue);
    buffer.writeString(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change About.
///
/// ID: `55188a2e`.
class ChannelAdminLogEventActionChangeAbout
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change About constructor.
  const ChannelAdminLogEventActionChangeAbout({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeAbout.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeAbout] fields.
    final prevValue = reader.readString();
    final newValue = reader.readString();

    // Construct [ChannelAdminLogEventActionChangeAbout] object.
    final returnValue = ChannelAdminLogEventActionChangeAbout(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeAbout].
    return returnValue;
  }

  /// Prev Value.
  final String prevValue;

  /// New Value.
  final String newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x55188a2e.
    buffer.writeInt32(0x55188a2e);

    // Write fields.
    buffer.writeString(prevValue);
    buffer.writeString(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Username.
///
/// ID: `6a4afc38`.
class ChannelAdminLogEventActionChangeUsername
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Username constructor.
  const ChannelAdminLogEventActionChangeUsername({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeUsername.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeUsername] fields.
    final prevValue = reader.readString();
    final newValue = reader.readString();

    // Construct [ChannelAdminLogEventActionChangeUsername] object.
    final returnValue = ChannelAdminLogEventActionChangeUsername(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeUsername].
    return returnValue;
  }

  /// Prev Value.
  final String prevValue;

  /// New Value.
  final String newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6a4afc38.
    buffer.writeInt32(0x6a4afc38);

    // Write fields.
    buffer.writeString(prevValue);
    buffer.writeString(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Photo.
///
/// ID: `434bd2af`.
class ChannelAdminLogEventActionChangePhoto
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Photo constructor.
  const ChannelAdminLogEventActionChangePhoto({
    required this.prevPhoto,
    required this.newPhoto,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangePhoto.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangePhoto] fields.
    final prevPhoto = reader.readObject() as PhotoBase;
    final newPhoto = reader.readObject() as PhotoBase;

    // Construct [ChannelAdminLogEventActionChangePhoto] object.
    final returnValue = ChannelAdminLogEventActionChangePhoto(
      prevPhoto: prevPhoto,
      newPhoto: newPhoto,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangePhoto].
    return returnValue;
  }

  /// Prev Photo.
  final PhotoBase prevPhoto;

  /// New Photo.
  final PhotoBase newPhoto;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x434bd2af.
    buffer.writeInt32(0x434bd2af);

    // Write fields.
    buffer.writeObject(prevPhoto);
    buffer.writeObject(newPhoto);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Toggle Invites.
///
/// ID: `1b7907ae`.
class ChannelAdminLogEventActionToggleInvites
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Toggle Invites constructor.
  const ChannelAdminLogEventActionToggleInvites({
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionToggleInvites.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionToggleInvites] fields.
    final newValue = reader.readBool();

    // Construct [ChannelAdminLogEventActionToggleInvites] object.
    final returnValue = ChannelAdminLogEventActionToggleInvites(
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionToggleInvites].
    return returnValue;
  }

  /// New Value.
  final bool newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1b7907ae.
    buffer.writeInt32(0x1b7907ae);

    // Write fields.
    buffer.writeBool(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Toggle Signatures.
///
/// ID: `26ae0971`.
class ChannelAdminLogEventActionToggleSignatures
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Toggle Signatures constructor.
  const ChannelAdminLogEventActionToggleSignatures({
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionToggleSignatures.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionToggleSignatures] fields.
    final newValue = reader.readBool();

    // Construct [ChannelAdminLogEventActionToggleSignatures] object.
    final returnValue = ChannelAdminLogEventActionToggleSignatures(
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionToggleSignatures].
    return returnValue;
  }

  /// New Value.
  final bool newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x26ae0971.
    buffer.writeInt32(0x26ae0971);

    // Write fields.
    buffer.writeBool(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Update Pinned.
///
/// ID: `e9e82c18`.
class ChannelAdminLogEventActionUpdatePinned
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Update Pinned constructor.
  const ChannelAdminLogEventActionUpdatePinned({
    required this.message,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionUpdatePinned.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionUpdatePinned] fields.
    final message = reader.readObject() as MessageBase;

    // Construct [ChannelAdminLogEventActionUpdatePinned] object.
    final returnValue = ChannelAdminLogEventActionUpdatePinned(
      message: message,
    );

    // Now return the deserialized [ChannelAdminLogEventActionUpdatePinned].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe9e82c18.
    buffer.writeInt32(0xe9e82c18);

    // Write fields.
    buffer.writeObject(message);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Edit Message.
///
/// ID: `709b2405`.
class ChannelAdminLogEventActionEditMessage
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Edit Message constructor.
  const ChannelAdminLogEventActionEditMessage({
    required this.prevMessage,
    required this.newMessage,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionEditMessage.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionEditMessage] fields.
    final prevMessage = reader.readObject() as MessageBase;
    final newMessage = reader.readObject() as MessageBase;

    // Construct [ChannelAdminLogEventActionEditMessage] object.
    final returnValue = ChannelAdminLogEventActionEditMessage(
      prevMessage: prevMessage,
      newMessage: newMessage,
    );

    // Now return the deserialized [ChannelAdminLogEventActionEditMessage].
    return returnValue;
  }

  /// Prev Message.
  final MessageBase prevMessage;

  /// New Message.
  final MessageBase newMessage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x709b2405.
    buffer.writeInt32(0x709b2405);

    // Write fields.
    buffer.writeObject(prevMessage);
    buffer.writeObject(newMessage);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Delete Message.
///
/// ID: `42e047bb`.
class ChannelAdminLogEventActionDeleteMessage
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Delete Message constructor.
  const ChannelAdminLogEventActionDeleteMessage({
    required this.message,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionDeleteMessage.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionDeleteMessage] fields.
    final message = reader.readObject() as MessageBase;

    // Construct [ChannelAdminLogEventActionDeleteMessage] object.
    final returnValue = ChannelAdminLogEventActionDeleteMessage(
      message: message,
    );

    // Now return the deserialized [ChannelAdminLogEventActionDeleteMessage].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x42e047bb.
    buffer.writeInt32(0x42e047bb);

    // Write fields.
    buffer.writeObject(message);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Participant Join.
///
/// ID: `183040d3`.
class ChannelAdminLogEventActionParticipantJoin
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Participant Join constructor.
  const ChannelAdminLogEventActionParticipantJoin() : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionParticipantJoin.deserialize(
      BinaryReader reader) {
    // Construct [ChannelAdminLogEventActionParticipantJoin] object.
    final returnValue = ChannelAdminLogEventActionParticipantJoin();

    // Now return the deserialized [ChannelAdminLogEventActionParticipantJoin].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x183040d3.
    buffer.writeInt32(0x183040d3);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Participant Leave.
///
/// ID: `f89777f2`.
class ChannelAdminLogEventActionParticipantLeave
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Participant Leave constructor.
  const ChannelAdminLogEventActionParticipantLeave() : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionParticipantLeave.deserialize(
      BinaryReader reader) {
    // Construct [ChannelAdminLogEventActionParticipantLeave] object.
    final returnValue = ChannelAdminLogEventActionParticipantLeave();

    // Now return the deserialized [ChannelAdminLogEventActionParticipantLeave].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf89777f2.
    buffer.writeInt32(0xf89777f2);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Participant Invite.
///
/// ID: `e31c34d8`.
class ChannelAdminLogEventActionParticipantInvite
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Participant Invite constructor.
  const ChannelAdminLogEventActionParticipantInvite({
    required this.participant,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionParticipantInvite.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionParticipantInvite] fields.
    final participant = reader.readObject() as ChannelParticipantBase;

    // Construct [ChannelAdminLogEventActionParticipantInvite] object.
    final returnValue = ChannelAdminLogEventActionParticipantInvite(
      participant: participant,
    );

    // Now return the deserialized [ChannelAdminLogEventActionParticipantInvite].
    return returnValue;
  }

  /// Participant.
  final ChannelParticipantBase participant;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe31c34d8.
    buffer.writeInt32(0xe31c34d8);

    // Write fields.
    buffer.writeObject(participant);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Participant Toggle Ban.
///
/// ID: `e6d83d7e`.
class ChannelAdminLogEventActionParticipantToggleBan
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Participant Toggle Ban constructor.
  const ChannelAdminLogEventActionParticipantToggleBan({
    required this.prevParticipant,
    required this.newParticipant,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionParticipantToggleBan.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionParticipantToggleBan] fields.
    final prevParticipant = reader.readObject() as ChannelParticipantBase;
    final newParticipant = reader.readObject() as ChannelParticipantBase;

    // Construct [ChannelAdminLogEventActionParticipantToggleBan] object.
    final returnValue = ChannelAdminLogEventActionParticipantToggleBan(
      prevParticipant: prevParticipant,
      newParticipant: newParticipant,
    );

    // Now return the deserialized [ChannelAdminLogEventActionParticipantToggleBan].
    return returnValue;
  }

  /// Prev Participant.
  final ChannelParticipantBase prevParticipant;

  /// New Participant.
  final ChannelParticipantBase newParticipant;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe6d83d7e.
    buffer.writeInt32(0xe6d83d7e);

    // Write fields.
    buffer.writeObject(prevParticipant);
    buffer.writeObject(newParticipant);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Participant Toggle Admin.
///
/// ID: `d5676710`.
class ChannelAdminLogEventActionParticipantToggleAdmin
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Participant Toggle Admin constructor.
  const ChannelAdminLogEventActionParticipantToggleAdmin({
    required this.prevParticipant,
    required this.newParticipant,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionParticipantToggleAdmin.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionParticipantToggleAdmin] fields.
    final prevParticipant = reader.readObject() as ChannelParticipantBase;
    final newParticipant = reader.readObject() as ChannelParticipantBase;

    // Construct [ChannelAdminLogEventActionParticipantToggleAdmin] object.
    final returnValue = ChannelAdminLogEventActionParticipantToggleAdmin(
      prevParticipant: prevParticipant,
      newParticipant: newParticipant,
    );

    // Now return the deserialized [ChannelAdminLogEventActionParticipantToggleAdmin].
    return returnValue;
  }

  /// Prev Participant.
  final ChannelParticipantBase prevParticipant;

  /// New Participant.
  final ChannelParticipantBase newParticipant;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd5676710.
    buffer.writeInt32(0xd5676710);

    // Write fields.
    buffer.writeObject(prevParticipant);
    buffer.writeObject(newParticipant);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Sticker Set.
///
/// ID: `b1c3caa7`.
class ChannelAdminLogEventActionChangeStickerSet
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Sticker Set constructor.
  const ChannelAdminLogEventActionChangeStickerSet({
    required this.prevStickerset,
    required this.newStickerset,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeStickerSet.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeStickerSet] fields.
    final prevStickerset = reader.readObject() as InputStickerSetBase;
    final newStickerset = reader.readObject() as InputStickerSetBase;

    // Construct [ChannelAdminLogEventActionChangeStickerSet] object.
    final returnValue = ChannelAdminLogEventActionChangeStickerSet(
      prevStickerset: prevStickerset,
      newStickerset: newStickerset,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeStickerSet].
    return returnValue;
  }

  /// Prev Stickerset.
  final InputStickerSetBase prevStickerset;

  /// New Stickerset.
  final InputStickerSetBase newStickerset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb1c3caa7.
    buffer.writeInt32(0xb1c3caa7);

    // Write fields.
    buffer.writeObject(prevStickerset);
    buffer.writeObject(newStickerset);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Toggle Pre History Hidden.
///
/// ID: `5f5c95f1`.
class ChannelAdminLogEventActionTogglePreHistoryHidden
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Toggle Pre History Hidden constructor.
  const ChannelAdminLogEventActionTogglePreHistoryHidden({
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionTogglePreHistoryHidden.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionTogglePreHistoryHidden] fields.
    final newValue = reader.readBool();

    // Construct [ChannelAdminLogEventActionTogglePreHistoryHidden] object.
    final returnValue = ChannelAdminLogEventActionTogglePreHistoryHidden(
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionTogglePreHistoryHidden].
    return returnValue;
  }

  /// New Value.
  final bool newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5f5c95f1.
    buffer.writeInt32(0x5f5c95f1);

    // Write fields.
    buffer.writeBool(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Default Banned Rights.
///
/// ID: `2df5fc0a`.
class ChannelAdminLogEventActionDefaultBannedRights
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Default Banned Rights constructor.
  const ChannelAdminLogEventActionDefaultBannedRights({
    required this.prevBannedRights,
    required this.newBannedRights,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionDefaultBannedRights.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionDefaultBannedRights] fields.
    final prevBannedRights = reader.readObject() as ChatBannedRightsBase;
    final newBannedRights = reader.readObject() as ChatBannedRightsBase;

    // Construct [ChannelAdminLogEventActionDefaultBannedRights] object.
    final returnValue = ChannelAdminLogEventActionDefaultBannedRights(
      prevBannedRights: prevBannedRights,
      newBannedRights: newBannedRights,
    );

    // Now return the deserialized [ChannelAdminLogEventActionDefaultBannedRights].
    return returnValue;
  }

  /// Prev Banned Rights.
  final ChatBannedRightsBase prevBannedRights;

  /// New Banned Rights.
  final ChatBannedRightsBase newBannedRights;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2df5fc0a.
    buffer.writeInt32(0x2df5fc0a);

    // Write fields.
    buffer.writeObject(prevBannedRights);
    buffer.writeObject(newBannedRights);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Stop Poll.
///
/// ID: `8f079643`.
class ChannelAdminLogEventActionStopPoll
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Stop Poll constructor.
  const ChannelAdminLogEventActionStopPoll({
    required this.message,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionStopPoll.deserialize(BinaryReader reader) {
    // Read [ChannelAdminLogEventActionStopPoll] fields.
    final message = reader.readObject() as MessageBase;

    // Construct [ChannelAdminLogEventActionStopPoll] object.
    final returnValue = ChannelAdminLogEventActionStopPoll(
      message: message,
    );

    // Now return the deserialized [ChannelAdminLogEventActionStopPoll].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8f079643.
    buffer.writeInt32(0x8f079643);

    // Write fields.
    buffer.writeObject(message);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Linked Chat.
///
/// ID: `050c7ac8`.
class ChannelAdminLogEventActionChangeLinkedChat
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Linked Chat constructor.
  const ChannelAdminLogEventActionChangeLinkedChat({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeLinkedChat.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeLinkedChat] fields.
    final prevValue = reader.readInt64();
    final newValue = reader.readInt64();

    // Construct [ChannelAdminLogEventActionChangeLinkedChat] object.
    final returnValue = ChannelAdminLogEventActionChangeLinkedChat(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeLinkedChat].
    return returnValue;
  }

  /// Prev Value.
  ///
  /// Field type is Int64.
  final int prevValue;

  /// New Value.
  ///
  /// Field type is Int64.
  final int newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x050c7ac8.
    buffer.writeInt32(0x050c7ac8);

    // Write fields.
    buffer.writeInt64(prevValue);
    buffer.writeInt64(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Location.
///
/// ID: `0e6b76ae`.
class ChannelAdminLogEventActionChangeLocation
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Location constructor.
  const ChannelAdminLogEventActionChangeLocation({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeLocation.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeLocation] fields.
    final prevValue = reader.readObject() as ChannelLocationBase;
    final newValue = reader.readObject() as ChannelLocationBase;

    // Construct [ChannelAdminLogEventActionChangeLocation] object.
    final returnValue = ChannelAdminLogEventActionChangeLocation(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeLocation].
    return returnValue;
  }

  /// Prev Value.
  final ChannelLocationBase prevValue;

  /// New Value.
  final ChannelLocationBase newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0e6b76ae.
    buffer.writeInt32(0x0e6b76ae);

    // Write fields.
    buffer.writeObject(prevValue);
    buffer.writeObject(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Toggle Slow Mode.
///
/// ID: `53909779`.
class ChannelAdminLogEventActionToggleSlowMode
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Toggle Slow Mode constructor.
  const ChannelAdminLogEventActionToggleSlowMode({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionToggleSlowMode.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionToggleSlowMode] fields.
    final prevValue = reader.readInt32();
    final newValue = reader.readInt32();

    // Construct [ChannelAdminLogEventActionToggleSlowMode] object.
    final returnValue = ChannelAdminLogEventActionToggleSlowMode(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionToggleSlowMode].
    return returnValue;
  }

  /// Prev Value.
  ///
  /// Field type is Int32.
  final int prevValue;

  /// New Value.
  ///
  /// Field type is Int32.
  final int newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x53909779.
    buffer.writeInt32(0x53909779);

    // Write fields.
    buffer.writeInt32(prevValue);
    buffer.writeInt32(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Start Group Call.
///
/// ID: `23209745`.
class ChannelAdminLogEventActionStartGroupCall
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Start Group Call constructor.
  const ChannelAdminLogEventActionStartGroupCall({
    required this.call,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionStartGroupCall.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionStartGroupCall] fields.
    final call = reader.readObject() as InputGroupCallBase;

    // Construct [ChannelAdminLogEventActionStartGroupCall] object.
    final returnValue = ChannelAdminLogEventActionStartGroupCall(
      call: call,
    );

    // Now return the deserialized [ChannelAdminLogEventActionStartGroupCall].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x23209745.
    buffer.writeInt32(0x23209745);

    // Write fields.
    buffer.writeObject(call);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Discard Group Call.
///
/// ID: `db9f9140`.
class ChannelAdminLogEventActionDiscardGroupCall
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Discard Group Call constructor.
  const ChannelAdminLogEventActionDiscardGroupCall({
    required this.call,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionDiscardGroupCall.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionDiscardGroupCall] fields.
    final call = reader.readObject() as InputGroupCallBase;

    // Construct [ChannelAdminLogEventActionDiscardGroupCall] object.
    final returnValue = ChannelAdminLogEventActionDiscardGroupCall(
      call: call,
    );

    // Now return the deserialized [ChannelAdminLogEventActionDiscardGroupCall].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdb9f9140.
    buffer.writeInt32(0xdb9f9140);

    // Write fields.
    buffer.writeObject(call);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Participant Mute.
///
/// ID: `f92424d2`.
class ChannelAdminLogEventActionParticipantMute
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Participant Mute constructor.
  const ChannelAdminLogEventActionParticipantMute({
    required this.participant,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionParticipantMute.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionParticipantMute] fields.
    final participant = reader.readObject() as GroupCallParticipantBase;

    // Construct [ChannelAdminLogEventActionParticipantMute] object.
    final returnValue = ChannelAdminLogEventActionParticipantMute(
      participant: participant,
    );

    // Now return the deserialized [ChannelAdminLogEventActionParticipantMute].
    return returnValue;
  }

  /// Participant.
  final GroupCallParticipantBase participant;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf92424d2.
    buffer.writeInt32(0xf92424d2);

    // Write fields.
    buffer.writeObject(participant);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Participant Unmute.
///
/// ID: `e64429c0`.
class ChannelAdminLogEventActionParticipantUnmute
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Participant Unmute constructor.
  const ChannelAdminLogEventActionParticipantUnmute({
    required this.participant,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionParticipantUnmute.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionParticipantUnmute] fields.
    final participant = reader.readObject() as GroupCallParticipantBase;

    // Construct [ChannelAdminLogEventActionParticipantUnmute] object.
    final returnValue = ChannelAdminLogEventActionParticipantUnmute(
      participant: participant,
    );

    // Now return the deserialized [ChannelAdminLogEventActionParticipantUnmute].
    return returnValue;
  }

  /// Participant.
  final GroupCallParticipantBase participant;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe64429c0.
    buffer.writeInt32(0xe64429c0);

    // Write fields.
    buffer.writeObject(participant);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Toggle Group Call Setting.
///
/// ID: `56d6a247`.
class ChannelAdminLogEventActionToggleGroupCallSetting
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Toggle Group Call Setting constructor.
  const ChannelAdminLogEventActionToggleGroupCallSetting({
    required this.joinMuted,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionToggleGroupCallSetting.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionToggleGroupCallSetting] fields.
    final joinMuted = reader.readBool();

    // Construct [ChannelAdminLogEventActionToggleGroupCallSetting] object.
    final returnValue = ChannelAdminLogEventActionToggleGroupCallSetting(
      joinMuted: joinMuted,
    );

    // Now return the deserialized [ChannelAdminLogEventActionToggleGroupCallSetting].
    return returnValue;
  }

  /// Join Muted.
  final bool joinMuted;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x56d6a247.
    buffer.writeInt32(0x56d6a247);

    // Write fields.
    buffer.writeBool(joinMuted);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Participant Join By Invite.
///
/// ID: `fe9fc158`.
class ChannelAdminLogEventActionParticipantJoinByInvite
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Participant Join By Invite constructor.
  const ChannelAdminLogEventActionParticipantJoinByInvite({
    required this.viaChatlist,
    required this.invite,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionParticipantJoinByInvite.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionParticipantJoinByInvite] fields.
    final flags = reader.readInt32();
    final viaChatlist = (flags & 1) != 0;
    final invite = reader.readObject() as ExportedChatInviteBase;

    // Construct [ChannelAdminLogEventActionParticipantJoinByInvite] object.
    final returnValue = ChannelAdminLogEventActionParticipantJoinByInvite(
      viaChatlist: viaChatlist,
      invite: invite,
    );

    // Now return the deserialized [ChannelAdminLogEventActionParticipantJoinByInvite].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: viaChatlist,
    );

    return v;
  }

  /// via_chatlist: bit 0 of flags.0?true
  final bool viaChatlist;

  /// Invite.
  final ExportedChatInviteBase invite;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfe9fc158.
    buffer.writeInt32(0xfe9fc158);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(invite);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Exported Invite Delete.
///
/// ID: `5a50fca4`.
class ChannelAdminLogEventActionExportedInviteDelete
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Exported Invite Delete constructor.
  const ChannelAdminLogEventActionExportedInviteDelete({
    required this.invite,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionExportedInviteDelete.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionExportedInviteDelete] fields.
    final invite = reader.readObject() as ExportedChatInviteBase;

    // Construct [ChannelAdminLogEventActionExportedInviteDelete] object.
    final returnValue = ChannelAdminLogEventActionExportedInviteDelete(
      invite: invite,
    );

    // Now return the deserialized [ChannelAdminLogEventActionExportedInviteDelete].
    return returnValue;
  }

  /// Invite.
  final ExportedChatInviteBase invite;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5a50fca4.
    buffer.writeInt32(0x5a50fca4);

    // Write fields.
    buffer.writeObject(invite);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Exported Invite Revoke.
///
/// ID: `410a134e`.
class ChannelAdminLogEventActionExportedInviteRevoke
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Exported Invite Revoke constructor.
  const ChannelAdminLogEventActionExportedInviteRevoke({
    required this.invite,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionExportedInviteRevoke.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionExportedInviteRevoke] fields.
    final invite = reader.readObject() as ExportedChatInviteBase;

    // Construct [ChannelAdminLogEventActionExportedInviteRevoke] object.
    final returnValue = ChannelAdminLogEventActionExportedInviteRevoke(
      invite: invite,
    );

    // Now return the deserialized [ChannelAdminLogEventActionExportedInviteRevoke].
    return returnValue;
  }

  /// Invite.
  final ExportedChatInviteBase invite;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x410a134e.
    buffer.writeInt32(0x410a134e);

    // Write fields.
    buffer.writeObject(invite);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Exported Invite Edit.
///
/// ID: `e90ebb59`.
class ChannelAdminLogEventActionExportedInviteEdit
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Exported Invite Edit constructor.
  const ChannelAdminLogEventActionExportedInviteEdit({
    required this.prevInvite,
    required this.newInvite,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionExportedInviteEdit.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionExportedInviteEdit] fields.
    final prevInvite = reader.readObject() as ExportedChatInviteBase;
    final newInvite = reader.readObject() as ExportedChatInviteBase;

    // Construct [ChannelAdminLogEventActionExportedInviteEdit] object.
    final returnValue = ChannelAdminLogEventActionExportedInviteEdit(
      prevInvite: prevInvite,
      newInvite: newInvite,
    );

    // Now return the deserialized [ChannelAdminLogEventActionExportedInviteEdit].
    return returnValue;
  }

  /// Prev Invite.
  final ExportedChatInviteBase prevInvite;

  /// New Invite.
  final ExportedChatInviteBase newInvite;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe90ebb59.
    buffer.writeInt32(0xe90ebb59);

    // Write fields.
    buffer.writeObject(prevInvite);
    buffer.writeObject(newInvite);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Participant Volume.
///
/// ID: `3e7f6847`.
class ChannelAdminLogEventActionParticipantVolume
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Participant Volume constructor.
  const ChannelAdminLogEventActionParticipantVolume({
    required this.participant,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionParticipantVolume.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionParticipantVolume] fields.
    final participant = reader.readObject() as GroupCallParticipantBase;

    // Construct [ChannelAdminLogEventActionParticipantVolume] object.
    final returnValue = ChannelAdminLogEventActionParticipantVolume(
      participant: participant,
    );

    // Now return the deserialized [ChannelAdminLogEventActionParticipantVolume].
    return returnValue;
  }

  /// Participant.
  final GroupCallParticipantBase participant;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3e7f6847.
    buffer.writeInt32(0x3e7f6847);

    // Write fields.
    buffer.writeObject(participant);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change History T T L.
///
/// ID: `6e941a38`.
class ChannelAdminLogEventActionChangeHistoryTTL
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change History T T L constructor.
  const ChannelAdminLogEventActionChangeHistoryTTL({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeHistoryTTL.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeHistoryTTL] fields.
    final prevValue = reader.readInt32();
    final newValue = reader.readInt32();

    // Construct [ChannelAdminLogEventActionChangeHistoryTTL] object.
    final returnValue = ChannelAdminLogEventActionChangeHistoryTTL(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeHistoryTTL].
    return returnValue;
  }

  /// Prev Value.
  ///
  /// Field type is Int32.
  final int prevValue;

  /// New Value.
  ///
  /// Field type is Int32.
  final int newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6e941a38.
    buffer.writeInt32(0x6e941a38);

    // Write fields.
    buffer.writeInt32(prevValue);
    buffer.writeInt32(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Participant Join By Request.
///
/// ID: `afb6144a`.
class ChannelAdminLogEventActionParticipantJoinByRequest
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Participant Join By Request constructor.
  const ChannelAdminLogEventActionParticipantJoinByRequest({
    required this.invite,
    required this.approvedBy,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionParticipantJoinByRequest.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionParticipantJoinByRequest] fields.
    final invite = reader.readObject() as ExportedChatInviteBase;
    final approvedBy = reader.readInt64();

    // Construct [ChannelAdminLogEventActionParticipantJoinByRequest] object.
    final returnValue = ChannelAdminLogEventActionParticipantJoinByRequest(
      invite: invite,
      approvedBy: approvedBy,
    );

    // Now return the deserialized [ChannelAdminLogEventActionParticipantJoinByRequest].
    return returnValue;
  }

  /// Invite.
  final ExportedChatInviteBase invite;

  /// Approved By.
  ///
  /// Field type is Int64.
  final int approvedBy;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xafb6144a.
    buffer.writeInt32(0xafb6144a);

    // Write fields.
    buffer.writeObject(invite);
    buffer.writeInt64(approvedBy);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Toggle No Forwards.
///
/// ID: `cb2ac766`.
class ChannelAdminLogEventActionToggleNoForwards
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Toggle No Forwards constructor.
  const ChannelAdminLogEventActionToggleNoForwards({
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionToggleNoForwards.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionToggleNoForwards] fields.
    final newValue = reader.readBool();

    // Construct [ChannelAdminLogEventActionToggleNoForwards] object.
    final returnValue = ChannelAdminLogEventActionToggleNoForwards(
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionToggleNoForwards].
    return returnValue;
  }

  /// New Value.
  final bool newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcb2ac766.
    buffer.writeInt32(0xcb2ac766);

    // Write fields.
    buffer.writeBool(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Send Message.
///
/// ID: `278f2868`.
class ChannelAdminLogEventActionSendMessage
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Send Message constructor.
  const ChannelAdminLogEventActionSendMessage({
    required this.message,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionSendMessage.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionSendMessage] fields.
    final message = reader.readObject() as MessageBase;

    // Construct [ChannelAdminLogEventActionSendMessage] object.
    final returnValue = ChannelAdminLogEventActionSendMessage(
      message: message,
    );

    // Now return the deserialized [ChannelAdminLogEventActionSendMessage].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x278f2868.
    buffer.writeInt32(0x278f2868);

    // Write fields.
    buffer.writeObject(message);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Available Reactions.
///
/// ID: `be4e0ef8`.
class ChannelAdminLogEventActionChangeAvailableReactions
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Available Reactions constructor.
  const ChannelAdminLogEventActionChangeAvailableReactions({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeAvailableReactions.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeAvailableReactions] fields.
    final prevValue = reader.readObject() as ChatReactionsBase;
    final newValue = reader.readObject() as ChatReactionsBase;

    // Construct [ChannelAdminLogEventActionChangeAvailableReactions] object.
    final returnValue = ChannelAdminLogEventActionChangeAvailableReactions(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeAvailableReactions].
    return returnValue;
  }

  /// Prev Value.
  final ChatReactionsBase prevValue;

  /// New Value.
  final ChatReactionsBase newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbe4e0ef8.
    buffer.writeInt32(0xbe4e0ef8);

    // Write fields.
    buffer.writeObject(prevValue);
    buffer.writeObject(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Usernames.
///
/// ID: `f04fb3a9`.
class ChannelAdminLogEventActionChangeUsernames
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Usernames constructor.
  const ChannelAdminLogEventActionChangeUsernames({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeUsernames.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeUsernames] fields.
    final prevValue = reader.readVectorString();
    final newValue = reader.readVectorString();

    // Construct [ChannelAdminLogEventActionChangeUsernames] object.
    final returnValue = ChannelAdminLogEventActionChangeUsernames(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeUsernames].
    return returnValue;
  }

  /// Prev Value.
  final List<String> prevValue;

  /// New Value.
  final List<String> newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf04fb3a9.
    buffer.writeInt32(0xf04fb3a9);

    // Write fields.
    buffer.writeVectorString(prevValue);
    buffer.writeVectorString(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Toggle Forum.
///
/// ID: `02cc6383`.
class ChannelAdminLogEventActionToggleForum
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Toggle Forum constructor.
  const ChannelAdminLogEventActionToggleForum({
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionToggleForum.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionToggleForum] fields.
    final newValue = reader.readBool();

    // Construct [ChannelAdminLogEventActionToggleForum] object.
    final returnValue = ChannelAdminLogEventActionToggleForum(
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionToggleForum].
    return returnValue;
  }

  /// New Value.
  final bool newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x02cc6383.
    buffer.writeInt32(0x02cc6383);

    // Write fields.
    buffer.writeBool(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Create Topic.
///
/// ID: `58707d28`.
class ChannelAdminLogEventActionCreateTopic
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Create Topic constructor.
  const ChannelAdminLogEventActionCreateTopic({
    required this.topic,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionCreateTopic.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionCreateTopic] fields.
    final topic = reader.readObject() as ForumTopicBase;

    // Construct [ChannelAdminLogEventActionCreateTopic] object.
    final returnValue = ChannelAdminLogEventActionCreateTopic(
      topic: topic,
    );

    // Now return the deserialized [ChannelAdminLogEventActionCreateTopic].
    return returnValue;
  }

  /// Topic.
  final ForumTopicBase topic;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x58707d28.
    buffer.writeInt32(0x58707d28);

    // Write fields.
    buffer.writeObject(topic);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Edit Topic.
///
/// ID: `f06fe208`.
class ChannelAdminLogEventActionEditTopic
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Edit Topic constructor.
  const ChannelAdminLogEventActionEditTopic({
    required this.prevTopic,
    required this.newTopic,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionEditTopic.deserialize(BinaryReader reader) {
    // Read [ChannelAdminLogEventActionEditTopic] fields.
    final prevTopic = reader.readObject() as ForumTopicBase;
    final newTopic = reader.readObject() as ForumTopicBase;

    // Construct [ChannelAdminLogEventActionEditTopic] object.
    final returnValue = ChannelAdminLogEventActionEditTopic(
      prevTopic: prevTopic,
      newTopic: newTopic,
    );

    // Now return the deserialized [ChannelAdminLogEventActionEditTopic].
    return returnValue;
  }

  /// Prev Topic.
  final ForumTopicBase prevTopic;

  /// New Topic.
  final ForumTopicBase newTopic;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf06fe208.
    buffer.writeInt32(0xf06fe208);

    // Write fields.
    buffer.writeObject(prevTopic);
    buffer.writeObject(newTopic);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Delete Topic.
///
/// ID: `ae168909`.
class ChannelAdminLogEventActionDeleteTopic
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Delete Topic constructor.
  const ChannelAdminLogEventActionDeleteTopic({
    required this.topic,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionDeleteTopic.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionDeleteTopic] fields.
    final topic = reader.readObject() as ForumTopicBase;

    // Construct [ChannelAdminLogEventActionDeleteTopic] object.
    final returnValue = ChannelAdminLogEventActionDeleteTopic(
      topic: topic,
    );

    // Now return the deserialized [ChannelAdminLogEventActionDeleteTopic].
    return returnValue;
  }

  /// Topic.
  final ForumTopicBase topic;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xae168909.
    buffer.writeInt32(0xae168909);

    // Write fields.
    buffer.writeObject(topic);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Pin Topic.
///
/// ID: `5d8d353b`.
class ChannelAdminLogEventActionPinTopic
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Pin Topic constructor.
  const ChannelAdminLogEventActionPinTopic({
    this.prevTopic,
    this.newTopic,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionPinTopic.deserialize(BinaryReader reader) {
    // Read [ChannelAdminLogEventActionPinTopic] fields.
    final flags = reader.readInt32();
    final hasPrevTopicField = (flags & 1) != 0;
    final prevTopic =
        hasPrevTopicField ? reader.readObject() as ForumTopicBase : null;
    final hasNewTopicField = (flags & 2) != 0;
    final newTopic =
        hasNewTopicField ? reader.readObject() as ForumTopicBase : null;

    // Construct [ChannelAdminLogEventActionPinTopic] object.
    final returnValue = ChannelAdminLogEventActionPinTopic(
      prevTopic: prevTopic,
      newTopic: newTopic,
    );

    // Now return the deserialized [ChannelAdminLogEventActionPinTopic].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: prevTopic != null,
      b01: newTopic != null,
    );

    return v;
  }

  /// Prev Topic.
  final ForumTopicBase? prevTopic;

  /// New Topic.
  final ForumTopicBase? newTopic;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5d8d353b.
    buffer.writeInt32(0x5d8d353b);

    // Write fields.
    buffer.writeInt32(flags);
    final localPrevTopicCopy = prevTopic;
    if (localPrevTopicCopy != null) {
      buffer.writeObject(localPrevTopicCopy);
    }
    final localNewTopicCopy = newTopic;
    if (localNewTopicCopy != null) {
      buffer.writeObject(localNewTopicCopy);
    }

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Toggle Anti Spam.
///
/// ID: `64f36dfc`.
class ChannelAdminLogEventActionToggleAntiSpam
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Toggle Anti Spam constructor.
  const ChannelAdminLogEventActionToggleAntiSpam({
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionToggleAntiSpam.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionToggleAntiSpam] fields.
    final newValue = reader.readBool();

    // Construct [ChannelAdminLogEventActionToggleAntiSpam] object.
    final returnValue = ChannelAdminLogEventActionToggleAntiSpam(
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionToggleAntiSpam].
    return returnValue;
  }

  /// New Value.
  final bool newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x64f36dfc.
    buffer.writeInt32(0x64f36dfc);

    // Write fields.
    buffer.writeBool(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Peer Color.
///
/// ID: `5796e780`.
class ChannelAdminLogEventActionChangePeerColor
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Peer Color constructor.
  const ChannelAdminLogEventActionChangePeerColor({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangePeerColor.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangePeerColor] fields.
    final prevValue = reader.readObject() as PeerColorBase;
    final newValue = reader.readObject() as PeerColorBase;

    // Construct [ChannelAdminLogEventActionChangePeerColor] object.
    final returnValue = ChannelAdminLogEventActionChangePeerColor(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangePeerColor].
    return returnValue;
  }

  /// Prev Value.
  final PeerColorBase prevValue;

  /// New Value.
  final PeerColorBase newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5796e780.
    buffer.writeInt32(0x5796e780);

    // Write fields.
    buffer.writeObject(prevValue);
    buffer.writeObject(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Profile Peer Color.
///
/// ID: `5e477b25`.
class ChannelAdminLogEventActionChangeProfilePeerColor
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Profile Peer Color constructor.
  const ChannelAdminLogEventActionChangeProfilePeerColor({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeProfilePeerColor.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeProfilePeerColor] fields.
    final prevValue = reader.readObject() as PeerColorBase;
    final newValue = reader.readObject() as PeerColorBase;

    // Construct [ChannelAdminLogEventActionChangeProfilePeerColor] object.
    final returnValue = ChannelAdminLogEventActionChangeProfilePeerColor(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeProfilePeerColor].
    return returnValue;
  }

  /// Prev Value.
  final PeerColorBase prevValue;

  /// New Value.
  final PeerColorBase newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5e477b25.
    buffer.writeInt32(0x5e477b25);

    // Write fields.
    buffer.writeObject(prevValue);
    buffer.writeObject(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Wallpaper.
///
/// ID: `31bb5d52`.
class ChannelAdminLogEventActionChangeWallpaper
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Wallpaper constructor.
  const ChannelAdminLogEventActionChangeWallpaper({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeWallpaper.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeWallpaper] fields.
    final prevValue = reader.readObject() as WallPaperBase;
    final newValue = reader.readObject() as WallPaperBase;

    // Construct [ChannelAdminLogEventActionChangeWallpaper] object.
    final returnValue = ChannelAdminLogEventActionChangeWallpaper(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeWallpaper].
    return returnValue;
  }

  /// Prev Value.
  final WallPaperBase prevValue;

  /// New Value.
  final WallPaperBase newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x31bb5d52.
    buffer.writeInt32(0x31bb5d52);

    // Write fields.
    buffer.writeObject(prevValue);
    buffer.writeObject(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event Action Change Emoji Status.
///
/// ID: `3ea9feb1`.
class ChannelAdminLogEventActionChangeEmojiStatus
    extends ChannelAdminLogEventActionBase {
  /// Channel Admin Log Event Action Change Emoji Status constructor.
  const ChannelAdminLogEventActionChangeEmojiStatus({
    required this.prevValue,
    required this.newValue,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventActionChangeEmojiStatus.deserialize(
      BinaryReader reader) {
    // Read [ChannelAdminLogEventActionChangeEmojiStatus] fields.
    final prevValue = reader.readObject() as EmojiStatusBase;
    final newValue = reader.readObject() as EmojiStatusBase;

    // Construct [ChannelAdminLogEventActionChangeEmojiStatus] object.
    final returnValue = ChannelAdminLogEventActionChangeEmojiStatus(
      prevValue: prevValue,
      newValue: newValue,
    );

    // Now return the deserialized [ChannelAdminLogEventActionChangeEmojiStatus].
    return returnValue;
  }

  /// Prev Value.
  final EmojiStatusBase prevValue;

  /// New Value.
  final EmojiStatusBase newValue;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3ea9feb1.
    buffer.writeInt32(0x3ea9feb1);

    // Write fields.
    buffer.writeObject(prevValue);
    buffer.writeObject(newValue);

    // Finished serialization.
  }
}

/// Channel Admin Log Event.
///
/// ID: `1fad68cd`.
class ChannelAdminLogEvent extends ChannelAdminLogEventBase {
  /// Channel Admin Log Event constructor.
  const ChannelAdminLogEvent({
    required this.id,
    required this.date,
    required this.userId,
    required this.action,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEvent.deserialize(BinaryReader reader) {
    // Read [ChannelAdminLogEvent] fields.
    final id = reader.readInt64();
    final date = reader.readDateTime();
    final userId = reader.readInt64();
    final action = reader.readObject() as ChannelAdminLogEventActionBase;

    // Construct [ChannelAdminLogEvent] object.
    final returnValue = ChannelAdminLogEvent(
      id: id,
      date: date,
      userId: userId,
      action: action,
    );

    // Now return the deserialized [ChannelAdminLogEvent].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Date.
  final DateTime date;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Action.
  final ChannelAdminLogEventActionBase action;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1fad68cd.
    buffer.writeInt32(0x1fad68cd);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeDateTime(date);
    buffer.writeInt64(userId);
    buffer.writeObject(action);

    // Finished serialization.
  }
}

/// Channels Admin Log Results.
///
/// ID: `ed8af74d`.
class ChannelsAdminLogResults extends ChannelsAdminLogResultsBase {
  /// Channels Admin Log Results constructor.
  const ChannelsAdminLogResults({
    required this.events,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ChannelsAdminLogResults.deserialize(BinaryReader reader) {
    // Read [ChannelsAdminLogResults] fields.
    final events = reader.readVectorObject<ChannelAdminLogEventBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ChannelsAdminLogResults] object.
    final returnValue = ChannelsAdminLogResults(
      events: events,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ChannelsAdminLogResults].
    return returnValue;
  }

  /// Events.
  final List<ChannelAdminLogEventBase> events;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xed8af74d.
    buffer.writeInt32(0xed8af74d);

    // Write fields.
    buffer.writeVectorObject(events);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Channel Admin Log Events Filter.
///
/// ID: `ea107ae4`.
class ChannelAdminLogEventsFilter extends ChannelAdminLogEventsFilterBase {
  /// Channel Admin Log Events Filter constructor.
  const ChannelAdminLogEventsFilter({
    required this.join,
    required this.leave,
    required this.invite,
    required this.ban,
    required this.unban,
    required this.kick,
    required this.unkick,
    required this.promote,
    required this.demote,
    required this.info,
    required this.settings,
    required this.pinned,
    required this.edit,
    required this.delete,
    required this.groupCall,
    required this.invites,
    required this.send,
    required this.forums,
  }) : super._();

  /// Deserialize.
  factory ChannelAdminLogEventsFilter.deserialize(BinaryReader reader) {
    // Read [ChannelAdminLogEventsFilter] fields.
    final flags = reader.readInt32();
    final join = (flags & 1) != 0;
    final leave = (flags & 2) != 0;
    final invite = (flags & 4) != 0;
    final ban = (flags & 8) != 0;
    final unban = (flags & 16) != 0;
    final kick = (flags & 32) != 0;
    final unkick = (flags & 64) != 0;
    final promote = (flags & 128) != 0;
    final demote = (flags & 256) != 0;
    final info = (flags & 512) != 0;
    final settings = (flags & 1024) != 0;
    final pinned = (flags & 2048) != 0;
    final edit = (flags & 4096) != 0;
    final delete = (flags & 8192) != 0;
    final groupCall = (flags & 16384) != 0;
    final invites = (flags & 32768) != 0;
    final send = (flags & 65536) != 0;
    final forums = (flags & 131072) != 0;

    // Construct [ChannelAdminLogEventsFilter] object.
    final returnValue = ChannelAdminLogEventsFilter(
      join: join,
      leave: leave,
      invite: invite,
      ban: ban,
      unban: unban,
      kick: kick,
      unkick: unkick,
      promote: promote,
      demote: demote,
      info: info,
      settings: settings,
      pinned: pinned,
      edit: edit,
      delete: delete,
      groupCall: groupCall,
      invites: invites,
      send: send,
      forums: forums,
    );

    // Now return the deserialized [ChannelAdminLogEventsFilter].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: join,
      b01: leave,
      b02: invite,
      b03: ban,
      b04: unban,
      b05: kick,
      b06: unkick,
      b07: promote,
      b08: demote,
      b09: info,
      b10: settings,
      b11: pinned,
      b12: edit,
      b13: delete,
      b14: groupCall,
      b15: invites,
      b16: send,
      b17: forums,
    );

    return v;
  }

  /// join: bit 0 of flags.0?true
  final bool join;

  /// leave: bit 1 of flags.1?true
  final bool leave;

  /// invite: bit 2 of flags.2?true
  final bool invite;

  /// ban: bit 3 of flags.3?true
  final bool ban;

  /// unban: bit 4 of flags.4?true
  final bool unban;

  /// kick: bit 5 of flags.5?true
  final bool kick;

  /// unkick: bit 6 of flags.6?true
  final bool unkick;

  /// promote: bit 7 of flags.7?true
  final bool promote;

  /// demote: bit 8 of flags.8?true
  final bool demote;

  /// info: bit 9 of flags.9?true
  final bool info;

  /// settings: bit 10 of flags.10?true
  final bool settings;

  /// pinned: bit 11 of flags.11?true
  final bool pinned;

  /// edit: bit 12 of flags.12?true
  final bool edit;

  /// delete: bit 13 of flags.13?true
  final bool delete;

  /// group_call: bit 14 of flags.14?true
  final bool groupCall;

  /// invites: bit 15 of flags.15?true
  final bool invites;

  /// send: bit 16 of flags.16?true
  final bool send;

  /// forums: bit 17 of flags.17?true
  final bool forums;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xea107ae4.
    buffer.writeInt32(0xea107ae4);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Popular Contact.
///
/// ID: `5ce14175`.
class PopularContact extends PopularContactBase {
  /// Popular Contact constructor.
  const PopularContact({
    required this.clientId,
    required this.importers,
  }) : super._();

  /// Deserialize.
  factory PopularContact.deserialize(BinaryReader reader) {
    // Read [PopularContact] fields.
    final clientId = reader.readInt64();
    final importers = reader.readInt32();

    // Construct [PopularContact] object.
    final returnValue = PopularContact(
      clientId: clientId,
      importers: importers,
    );

    // Now return the deserialized [PopularContact].
    return returnValue;
  }

  /// Client Id.
  ///
  /// Field type is Int64.
  final int clientId;

  /// Importers.
  ///
  /// Field type is Int32.
  final int importers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5ce14175.
    buffer.writeInt32(0x5ce14175);

    // Write fields.
    buffer.writeInt64(clientId);
    buffer.writeInt32(importers);

    // Finished serialization.
  }
}

/// Messages Faved Stickers Not Modified.
///
/// ID: `9e8fa6d3`.
class MessagesFavedStickersNotModified extends MessagesFavedStickersBase {
  /// Messages Faved Stickers Not Modified constructor.
  const MessagesFavedStickersNotModified() : super._();

  /// Deserialize.
  factory MessagesFavedStickersNotModified.deserialize(BinaryReader reader) {
    // Construct [MessagesFavedStickersNotModified] object.
    final returnValue = MessagesFavedStickersNotModified();

    // Now return the deserialized [MessagesFavedStickersNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9e8fa6d3.
    buffer.writeInt32(0x9e8fa6d3);

    // Finished serialization.
  }
}

/// Messages Faved Stickers.
///
/// ID: `2cb51097`.
class MessagesFavedStickers extends MessagesFavedStickersBase {
  /// Messages Faved Stickers constructor.
  const MessagesFavedStickers({
    required this.hash,
    required this.packs,
    required this.stickers,
  }) : super._();

  /// Deserialize.
  factory MessagesFavedStickers.deserialize(BinaryReader reader) {
    // Read [MessagesFavedStickers] fields.
    final hash = reader.readInt64();
    final packs = reader.readVectorObject<StickerPackBase>();
    final stickers = reader.readVectorObject<DocumentBase>();

    // Construct [MessagesFavedStickers] object.
    final returnValue = MessagesFavedStickers(
      hash: hash,
      packs: packs,
      stickers: stickers,
    );

    // Now return the deserialized [MessagesFavedStickers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Packs.
  final List<StickerPackBase> packs;

  /// Stickers.
  final List<DocumentBase> stickers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2cb51097.
    buffer.writeInt32(0x2cb51097);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(packs);
    buffer.writeVectorObject(stickers);

    // Finished serialization.
  }
}

/// Recent Me Url Unknown.
///
/// ID: `46e1d13d`.
class RecentMeUrlUnknown extends RecentMeUrlBase {
  /// Recent Me Url Unknown constructor.
  const RecentMeUrlUnknown({
    required this.url,
  }) : super._();

  /// Deserialize.
  factory RecentMeUrlUnknown.deserialize(BinaryReader reader) {
    // Read [RecentMeUrlUnknown] fields.
    final url = reader.readString();

    // Construct [RecentMeUrlUnknown] object.
    final returnValue = RecentMeUrlUnknown(
      url: url,
    );

    // Now return the deserialized [RecentMeUrlUnknown].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x46e1d13d.
    buffer.writeInt32(0x46e1d13d);

    // Write fields.
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Recent Me Url User.
///
/// ID: `b92c09e2`.
class RecentMeUrlUser extends RecentMeUrlBase {
  /// Recent Me Url User constructor.
  const RecentMeUrlUser({
    required this.url,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory RecentMeUrlUser.deserialize(BinaryReader reader) {
    // Read [RecentMeUrlUser] fields.
    final url = reader.readString();
    final userId = reader.readInt64();

    // Construct [RecentMeUrlUser] object.
    final returnValue = RecentMeUrlUser(
      url: url,
      userId: userId,
    );

    // Now return the deserialized [RecentMeUrlUser].
    return returnValue;
  }

  /// Url.
  final String url;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb92c09e2.
    buffer.writeInt32(0xb92c09e2);

    // Write fields.
    buffer.writeString(url);
    buffer.writeInt64(userId);

    // Finished serialization.
  }
}

/// Recent Me Url Chat.
///
/// ID: `b2da71d2`.
class RecentMeUrlChat extends RecentMeUrlBase {
  /// Recent Me Url Chat constructor.
  const RecentMeUrlChat({
    required this.url,
    required this.chatId,
  }) : super._();

  /// Deserialize.
  factory RecentMeUrlChat.deserialize(BinaryReader reader) {
    // Read [RecentMeUrlChat] fields.
    final url = reader.readString();
    final chatId = reader.readInt64();

    // Construct [RecentMeUrlChat] object.
    final returnValue = RecentMeUrlChat(
      url: url,
      chatId: chatId,
    );

    // Now return the deserialized [RecentMeUrlChat].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb2da71d2.
    buffer.writeInt32(0xb2da71d2);

    // Write fields.
    buffer.writeString(url);
    buffer.writeInt64(chatId);

    // Finished serialization.
  }
}

/// Recent Me Url Chat Invite.
///
/// ID: `eb49081d`.
class RecentMeUrlChatInvite extends RecentMeUrlBase {
  /// Recent Me Url Chat Invite constructor.
  const RecentMeUrlChatInvite({
    required this.url,
    required this.chatInvite,
  }) : super._();

  /// Deserialize.
  factory RecentMeUrlChatInvite.deserialize(BinaryReader reader) {
    // Read [RecentMeUrlChatInvite] fields.
    final url = reader.readString();
    final chatInvite = reader.readObject() as ChatInviteBase;

    // Construct [RecentMeUrlChatInvite] object.
    final returnValue = RecentMeUrlChatInvite(
      url: url,
      chatInvite: chatInvite,
    );

    // Now return the deserialized [RecentMeUrlChatInvite].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Chat Invite.
  final ChatInviteBase chatInvite;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeb49081d.
    buffer.writeInt32(0xeb49081d);

    // Write fields.
    buffer.writeString(url);
    buffer.writeObject(chatInvite);

    // Finished serialization.
  }
}

/// Recent Me Url Sticker Set.
///
/// ID: `bc0a57dc`.
class RecentMeUrlStickerSet extends RecentMeUrlBase {
  /// Recent Me Url Sticker Set constructor.
  const RecentMeUrlStickerSet({
    required this.url,
    required this.set,
  }) : super._();

  /// Deserialize.
  factory RecentMeUrlStickerSet.deserialize(BinaryReader reader) {
    // Read [RecentMeUrlStickerSet] fields.
    final url = reader.readString();
    final set = reader.readObject() as StickerSetCoveredBase;

    // Construct [RecentMeUrlStickerSet] object.
    final returnValue = RecentMeUrlStickerSet(
      url: url,
      set: set,
    );

    // Now return the deserialized [RecentMeUrlStickerSet].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Set.
  final StickerSetCoveredBase set;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbc0a57dc.
    buffer.writeInt32(0xbc0a57dc);

    // Write fields.
    buffer.writeString(url);
    buffer.writeObject(set);

    // Finished serialization.
  }
}

/// Help Recent Me Urls.
///
/// ID: `0e0310d7`.
class HelpRecentMeUrls extends HelpRecentMeUrlsBase {
  /// Help Recent Me Urls constructor.
  const HelpRecentMeUrls({
    required this.urls,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory HelpRecentMeUrls.deserialize(BinaryReader reader) {
    // Read [HelpRecentMeUrls] fields.
    final urls = reader.readVectorObject<RecentMeUrlBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [HelpRecentMeUrls] object.
    final returnValue = HelpRecentMeUrls(
      urls: urls,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [HelpRecentMeUrls].
    return returnValue;
  }

  /// Urls.
  final List<RecentMeUrlBase> urls;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0e0310d7.
    buffer.writeInt32(0x0e0310d7);

    // Write fields.
    buffer.writeVectorObject(urls);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Input Single Media.
///
/// ID: `1cc6e91f`.
class InputSingleMedia extends InputSingleMediaBase {
  /// Input Single Media constructor.
  const InputSingleMedia({
    required this.media,
    required this.randomId,
    required this.message,
    this.entities,
  }) : super._();

  /// Deserialize.
  factory InputSingleMedia.deserialize(BinaryReader reader) {
    // Read [InputSingleMedia] fields.
    final flags = reader.readInt32();
    final media = reader.readObject() as InputMediaBase;
    final randomId = reader.readInt64();
    final message = reader.readString();
    final hasEntitiesField = (flags & 1) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;

    // Construct [InputSingleMedia] object.
    final returnValue = InputSingleMedia(
      media: media,
      randomId: randomId,
      message: message,
      entities: entities,
    );

    // Now return the deserialized [InputSingleMedia].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: entities != null,
    );

    return v;
  }

  /// Media.
  final InputMediaBase media;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1cc6e91f.
    buffer.writeInt32(0x1cc6e91f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(media);
    buffer.writeInt64(randomId);
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }

    // Finished serialization.
  }
}

/// Web Authorization.
///
/// ID: `a6f8f452`.
class WebAuthorization extends WebAuthorizationBase {
  /// Web Authorization constructor.
  const WebAuthorization({
    required this.hash,
    required this.botId,
    required this.domain,
    required this.browser,
    required this.platform,
    required this.dateCreated,
    required this.dateActive,
    required this.ip,
    required this.region,
  }) : super._();

  /// Deserialize.
  factory WebAuthorization.deserialize(BinaryReader reader) {
    // Read [WebAuthorization] fields.
    final hash = reader.readInt64();
    final botId = reader.readInt64();
    final domain = reader.readString();
    final browser = reader.readString();
    final platform = reader.readString();
    final dateCreated = reader.readDateTime();
    final dateActive = reader.readDateTime();
    final ip = reader.readString();
    final region = reader.readString();

    // Construct [WebAuthorization] object.
    final returnValue = WebAuthorization(
      hash: hash,
      botId: botId,
      domain: domain,
      browser: browser,
      platform: platform,
      dateCreated: dateCreated,
      dateActive: dateActive,
      ip: ip,
      region: region,
    );

    // Now return the deserialized [WebAuthorization].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Bot Id.
  ///
  /// Field type is Int64.
  final int botId;

  /// Domain.
  final String domain;

  /// Browser.
  final String browser;

  /// Platform.
  final String platform;

  /// Date Created.
  final DateTime dateCreated;

  /// Date Active.
  final DateTime dateActive;

  /// Ip.
  final String ip;

  /// Region.
  final String region;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa6f8f452.
    buffer.writeInt32(0xa6f8f452);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeInt64(botId);
    buffer.writeString(domain);
    buffer.writeString(browser);
    buffer.writeString(platform);
    buffer.writeDateTime(dateCreated);
    buffer.writeDateTime(dateActive);
    buffer.writeString(ip);
    buffer.writeString(region);

    // Finished serialization.
  }
}

/// Account Web Authorizations.
///
/// ID: `ed56c9fc`.
class AccountWebAuthorizations extends AccountWebAuthorizationsBase {
  /// Account Web Authorizations constructor.
  const AccountWebAuthorizations({
    required this.authorizations,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory AccountWebAuthorizations.deserialize(BinaryReader reader) {
    // Read [AccountWebAuthorizations] fields.
    final authorizations = reader.readVectorObject<WebAuthorizationBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [AccountWebAuthorizations] object.
    final returnValue = AccountWebAuthorizations(
      authorizations: authorizations,
      users: users,
    );

    // Now return the deserialized [AccountWebAuthorizations].
    return returnValue;
  }

  /// Authorizations.
  final List<WebAuthorizationBase> authorizations;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xed56c9fc.
    buffer.writeInt32(0xed56c9fc);

    // Write fields.
    buffer.writeVectorObject(authorizations);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Input Message I D.
///
/// ID: `a676a322`.
class InputMessageID extends InputMessageBase {
  /// Input Message I D constructor.
  const InputMessageID({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory InputMessageID.deserialize(BinaryReader reader) {
    // Read [InputMessageID] fields.
    final id = reader.readInt32();

    // Construct [InputMessageID] object.
    final returnValue = InputMessageID(
      id: id,
    );

    // Now return the deserialized [InputMessageID].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa676a322.
    buffer.writeInt32(0xa676a322);

    // Write fields.
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Input Message Reply To.
///
/// ID: `bad88395`.
class InputMessageReplyTo extends InputMessageBase {
  /// Input Message Reply To constructor.
  const InputMessageReplyTo({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory InputMessageReplyTo.deserialize(BinaryReader reader) {
    // Read [InputMessageReplyTo] fields.
    final id = reader.readInt32();

    // Construct [InputMessageReplyTo] object.
    final returnValue = InputMessageReplyTo(
      id: id,
    );

    // Now return the deserialized [InputMessageReplyTo].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbad88395.
    buffer.writeInt32(0xbad88395);

    // Write fields.
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Input Message Pinned.
///
/// ID: `86872538`.
class InputMessagePinned extends InputMessageBase {
  /// Input Message Pinned constructor.
  const InputMessagePinned() : super._();

  /// Deserialize.
  factory InputMessagePinned.deserialize(BinaryReader reader) {
    // Construct [InputMessagePinned] object.
    final returnValue = InputMessagePinned();

    // Now return the deserialized [InputMessagePinned].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x86872538.
    buffer.writeInt32(0x86872538);

    // Finished serialization.
  }
}

/// Input Message Callback Query.
///
/// ID: `acfa1a7e`.
class InputMessageCallbackQuery extends InputMessageBase {
  /// Input Message Callback Query constructor.
  const InputMessageCallbackQuery({
    required this.id,
    required this.queryId,
  }) : super._();

  /// Deserialize.
  factory InputMessageCallbackQuery.deserialize(BinaryReader reader) {
    // Read [InputMessageCallbackQuery] fields.
    final id = reader.readInt32();
    final queryId = reader.readInt64();

    // Construct [InputMessageCallbackQuery] object.
    final returnValue = InputMessageCallbackQuery(
      id: id,
      queryId: queryId,
    );

    // Now return the deserialized [InputMessageCallbackQuery].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xacfa1a7e.
    buffer.writeInt32(0xacfa1a7e);

    // Write fields.
    buffer.writeInt32(id);
    buffer.writeInt64(queryId);

    // Finished serialization.
  }
}

/// Input Dialog Peer.
///
/// ID: `fcaafeb7`.
class InputDialogPeer extends InputDialogPeerBase {
  /// Input Dialog Peer constructor.
  const InputDialogPeer({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory InputDialogPeer.deserialize(BinaryReader reader) {
    // Read [InputDialogPeer] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [InputDialogPeer] object.
    final returnValue = InputDialogPeer(
      peer: peer,
    );

    // Now return the deserialized [InputDialogPeer].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfcaafeb7.
    buffer.writeInt32(0xfcaafeb7);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Input Dialog Peer Folder.
///
/// ID: `64600527`.
class InputDialogPeerFolder extends InputDialogPeerBase {
  /// Input Dialog Peer Folder constructor.
  const InputDialogPeerFolder({
    required this.folderId,
  }) : super._();

  /// Deserialize.
  factory InputDialogPeerFolder.deserialize(BinaryReader reader) {
    // Read [InputDialogPeerFolder] fields.
    final folderId = reader.readInt32();

    // Construct [InputDialogPeerFolder] object.
    final returnValue = InputDialogPeerFolder(
      folderId: folderId,
    );

    // Now return the deserialized [InputDialogPeerFolder].
    return returnValue;
  }

  /// Folder Id.
  ///
  /// Field type is Int32.
  final int folderId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x64600527.
    buffer.writeInt32(0x64600527);

    // Write fields.
    buffer.writeInt32(folderId);

    // Finished serialization.
  }
}

/// Dialog Peer.
///
/// ID: `e56dbf05`.
class DialogPeer extends DialogPeerBase {
  /// Dialog Peer constructor.
  const DialogPeer({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory DialogPeer.deserialize(BinaryReader reader) {
    // Read [DialogPeer] fields.
    final peer = reader.readObject() as PeerBase;

    // Construct [DialogPeer] object.
    final returnValue = DialogPeer(
      peer: peer,
    );

    // Now return the deserialized [DialogPeer].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe56dbf05.
    buffer.writeInt32(0xe56dbf05);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Dialog Peer Folder.
///
/// ID: `514519e2`.
class DialogPeerFolder extends DialogPeerBase {
  /// Dialog Peer Folder constructor.
  const DialogPeerFolder({
    required this.folderId,
  }) : super._();

  /// Deserialize.
  factory DialogPeerFolder.deserialize(BinaryReader reader) {
    // Read [DialogPeerFolder] fields.
    final folderId = reader.readInt32();

    // Construct [DialogPeerFolder] object.
    final returnValue = DialogPeerFolder(
      folderId: folderId,
    );

    // Now return the deserialized [DialogPeerFolder].
    return returnValue;
  }

  /// Folder Id.
  ///
  /// Field type is Int32.
  final int folderId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x514519e2.
    buffer.writeInt32(0x514519e2);

    // Write fields.
    buffer.writeInt32(folderId);

    // Finished serialization.
  }
}

/// Messages Found Sticker Sets Not Modified.
///
/// ID: `0d54b65d`.
class MessagesFoundStickerSetsNotModified extends MessagesFoundStickerSetsBase {
  /// Messages Found Sticker Sets Not Modified constructor.
  const MessagesFoundStickerSetsNotModified() : super._();

  /// Deserialize.
  factory MessagesFoundStickerSetsNotModified.deserialize(BinaryReader reader) {
    // Construct [MessagesFoundStickerSetsNotModified] object.
    final returnValue = MessagesFoundStickerSetsNotModified();

    // Now return the deserialized [MessagesFoundStickerSetsNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0d54b65d.
    buffer.writeInt32(0x0d54b65d);

    // Finished serialization.
  }
}

/// Messages Found Sticker Sets.
///
/// ID: `8af09dd2`.
class MessagesFoundStickerSets extends MessagesFoundStickerSetsBase {
  /// Messages Found Sticker Sets constructor.
  const MessagesFoundStickerSets({
    required this.hash,
    required this.sets,
  }) : super._();

  /// Deserialize.
  factory MessagesFoundStickerSets.deserialize(BinaryReader reader) {
    // Read [MessagesFoundStickerSets] fields.
    final hash = reader.readInt64();
    final sets = reader.readVectorObject<StickerSetCoveredBase>();

    // Construct [MessagesFoundStickerSets] object.
    final returnValue = MessagesFoundStickerSets(
      hash: hash,
      sets: sets,
    );

    // Now return the deserialized [MessagesFoundStickerSets].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Sets.
  final List<StickerSetCoveredBase> sets;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8af09dd2.
    buffer.writeInt32(0x8af09dd2);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(sets);

    // Finished serialization.
  }
}

/// File Hash.
///
/// ID: `f39b035c`.
class FileHash extends FileHashBase {
  /// File Hash constructor.
  const FileHash({
    required this.offset,
    required this.limit,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory FileHash.deserialize(BinaryReader reader) {
    // Read [FileHash] fields.
    final offset = reader.readInt64();
    final limit = reader.readInt32();
    final hash = reader.readBytes();

    // Construct [FileHash] object.
    final returnValue = FileHash(
      offset: offset,
      limit: limit,
      hash: hash,
    );

    // Now return the deserialized [FileHash].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int64.
  final int offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Hash.
  final Uint8List hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf39b035c.
    buffer.writeInt32(0xf39b035c);

    // Write fields.
    buffer.writeInt64(offset);
    buffer.writeInt32(limit);
    buffer.writeBytes(hash);

    // Finished serialization.
  }
}

/// Input Client Proxy.
///
/// ID: `75588b3f`.
class InputClientProxy extends InputClientProxyBase {
  /// Input Client Proxy constructor.
  const InputClientProxy({
    required this.address,
    required this.port,
  }) : super._();

  /// Deserialize.
  factory InputClientProxy.deserialize(BinaryReader reader) {
    // Read [InputClientProxy] fields.
    final address = reader.readString();
    final port = reader.readInt32();

    // Construct [InputClientProxy] object.
    final returnValue = InputClientProxy(
      address: address,
      port: port,
    );

    // Now return the deserialized [InputClientProxy].
    return returnValue;
  }

  /// Address.
  final String address;

  /// Port.
  ///
  /// Field type is Int32.
  final int port;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x75588b3f.
    buffer.writeInt32(0x75588b3f);

    // Write fields.
    buffer.writeString(address);
    buffer.writeInt32(port);

    // Finished serialization.
  }
}

/// Help Terms Of Service Update Empty.
///
/// ID: `e3309f7f`.
class HelpTermsOfServiceUpdateEmpty extends HelpTermsOfServiceUpdateBase {
  /// Help Terms Of Service Update Empty constructor.
  const HelpTermsOfServiceUpdateEmpty({
    required this.expires,
  }) : super._();

  /// Deserialize.
  factory HelpTermsOfServiceUpdateEmpty.deserialize(BinaryReader reader) {
    // Read [HelpTermsOfServiceUpdateEmpty] fields.
    final expires = reader.readInt32();

    // Construct [HelpTermsOfServiceUpdateEmpty] object.
    final returnValue = HelpTermsOfServiceUpdateEmpty(
      expires: expires,
    );

    // Now return the deserialized [HelpTermsOfServiceUpdateEmpty].
    return returnValue;
  }

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe3309f7f.
    buffer.writeInt32(0xe3309f7f);

    // Write fields.
    buffer.writeInt32(expires);

    // Finished serialization.
  }
}

/// Help Terms Of Service Update.
///
/// ID: `28ecf961`.
class HelpTermsOfServiceUpdate extends HelpTermsOfServiceUpdateBase {
  /// Help Terms Of Service Update constructor.
  const HelpTermsOfServiceUpdate({
    required this.expires,
    required this.termsOfService,
  }) : super._();

  /// Deserialize.
  factory HelpTermsOfServiceUpdate.deserialize(BinaryReader reader) {
    // Read [HelpTermsOfServiceUpdate] fields.
    final expires = reader.readInt32();
    final termsOfService = reader.readObject() as HelpTermsOfServiceBase;

    // Construct [HelpTermsOfServiceUpdate] object.
    final returnValue = HelpTermsOfServiceUpdate(
      expires: expires,
      termsOfService: termsOfService,
    );

    // Now return the deserialized [HelpTermsOfServiceUpdate].
    return returnValue;
  }

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Terms Of Service.
  final HelpTermsOfServiceBase termsOfService;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x28ecf961.
    buffer.writeInt32(0x28ecf961);

    // Write fields.
    buffer.writeInt32(expires);
    buffer.writeObject(termsOfService);

    // Finished serialization.
  }
}

/// Input Secure File Uploaded.
///
/// ID: `3334b0f0`.
class InputSecureFileUploaded extends InputSecureFileBase {
  /// Input Secure File Uploaded constructor.
  const InputSecureFileUploaded({
    required this.id,
    required this.parts,
    required this.md5Checksum,
    required this.fileHash,
    required this.secret,
  }) : super._();

  /// Deserialize.
  factory InputSecureFileUploaded.deserialize(BinaryReader reader) {
    // Read [InputSecureFileUploaded] fields.
    final id = reader.readInt64();
    final parts = reader.readInt32();
    final md5Checksum = reader.readString();
    final fileHash = reader.readBytes();
    final secret = reader.readBytes();

    // Construct [InputSecureFileUploaded] object.
    final returnValue = InputSecureFileUploaded(
      id: id,
      parts: parts,
      md5Checksum: md5Checksum,
      fileHash: fileHash,
      secret: secret,
    );

    // Now return the deserialized [InputSecureFileUploaded].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Parts.
  ///
  /// Field type is Int32.
  final int parts;

  /// Md5 Checksum.
  final String md5Checksum;

  /// File Hash.
  final Uint8List fileHash;

  /// Secret.
  final Uint8List secret;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3334b0f0.
    buffer.writeInt32(0x3334b0f0);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt32(parts);
    buffer.writeString(md5Checksum);
    buffer.writeBytes(fileHash);
    buffer.writeBytes(secret);

    // Finished serialization.
  }
}

/// Input Secure File.
///
/// ID: `5367e5be`.
class InputSecureFile extends InputSecureFileBase {
  /// Input Secure File constructor.
  const InputSecureFile({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputSecureFile.deserialize(BinaryReader reader) {
    // Read [InputSecureFile] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputSecureFile] object.
    final returnValue = InputSecureFile(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputSecureFile].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5367e5be.
    buffer.writeInt32(0x5367e5be);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Secure File Empty.
///
/// ID: `64199744`.
class SecureFileEmpty extends SecureFileBase {
  /// Secure File Empty constructor.
  const SecureFileEmpty() : super._();

  /// Deserialize.
  factory SecureFileEmpty.deserialize(BinaryReader reader) {
    // Construct [SecureFileEmpty] object.
    final returnValue = SecureFileEmpty();

    // Now return the deserialized [SecureFileEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x64199744.
    buffer.writeInt32(0x64199744);

    // Finished serialization.
  }
}

/// Secure File.
///
/// ID: `7d09c27e`.
class SecureFile extends SecureFileBase {
  /// Secure File constructor.
  const SecureFile({
    required this.id,
    required this.accessHash,
    required this.size,
    required this.dcId,
    required this.date,
    required this.fileHash,
    required this.secret,
  }) : super._();

  /// Deserialize.
  factory SecureFile.deserialize(BinaryReader reader) {
    // Read [SecureFile] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final size = reader.readInt64();
    final dcId = reader.readInt32();
    final date = reader.readDateTime();
    final fileHash = reader.readBytes();
    final secret = reader.readBytes();

    // Construct [SecureFile] object.
    final returnValue = SecureFile(
      id: id,
      accessHash: accessHash,
      size: size,
      dcId: dcId,
      date: date,
      fileHash: fileHash,
      secret: secret,
    );

    // Now return the deserialized [SecureFile].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Size.
  ///
  /// Field type is Int64.
  final int size;

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Date.
  final DateTime date;

  /// File Hash.
  final Uint8List fileHash;

  /// Secret.
  final Uint8List secret;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7d09c27e.
    buffer.writeInt32(0x7d09c27e);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeInt64(size);
    buffer.writeInt32(dcId);
    buffer.writeDateTime(date);
    buffer.writeBytes(fileHash);
    buffer.writeBytes(secret);

    // Finished serialization.
  }
}

/// Secure Data.
///
/// ID: `8aeabec3`.
class SecureData extends SecureDataBase {
  /// Secure Data constructor.
  const SecureData({
    required this.data,
    required this.dataHash,
    required this.secret,
  }) : super._();

  /// Deserialize.
  factory SecureData.deserialize(BinaryReader reader) {
    // Read [SecureData] fields.
    final data = reader.readBytes();
    final dataHash = reader.readBytes();
    final secret = reader.readBytes();

    // Construct [SecureData] object.
    final returnValue = SecureData(
      data: data,
      dataHash: dataHash,
      secret: secret,
    );

    // Now return the deserialized [SecureData].
    return returnValue;
  }

  /// Data.
  final Uint8List data;

  /// Data Hash.
  final Uint8List dataHash;

  /// Secret.
  final Uint8List secret;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8aeabec3.
    buffer.writeInt32(0x8aeabec3);

    // Write fields.
    buffer.writeBytes(data);
    buffer.writeBytes(dataHash);
    buffer.writeBytes(secret);

    // Finished serialization.
  }
}

/// Secure Plain Phone.
///
/// ID: `7d6099dd`.
class SecurePlainPhone extends SecurePlainDataBase {
  /// Secure Plain Phone constructor.
  const SecurePlainPhone({
    required this.phone,
  }) : super._();

  /// Deserialize.
  factory SecurePlainPhone.deserialize(BinaryReader reader) {
    // Read [SecurePlainPhone] fields.
    final phone = reader.readString();

    // Construct [SecurePlainPhone] object.
    final returnValue = SecurePlainPhone(
      phone: phone,
    );

    // Now return the deserialized [SecurePlainPhone].
    return returnValue;
  }

  /// Phone.
  final String phone;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7d6099dd.
    buffer.writeInt32(0x7d6099dd);

    // Write fields.
    buffer.writeString(phone);

    // Finished serialization.
  }
}

/// Secure Plain Email.
///
/// ID: `21ec5a5f`.
class SecurePlainEmail extends SecurePlainDataBase {
  /// Secure Plain Email constructor.
  const SecurePlainEmail({
    required this.email,
  }) : super._();

  /// Deserialize.
  factory SecurePlainEmail.deserialize(BinaryReader reader) {
    // Read [SecurePlainEmail] fields.
    final email = reader.readString();

    // Construct [SecurePlainEmail] object.
    final returnValue = SecurePlainEmail(
      email: email,
    );

    // Now return the deserialized [SecurePlainEmail].
    return returnValue;
  }

  /// Email.
  final String email;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x21ec5a5f.
    buffer.writeInt32(0x21ec5a5f);

    // Write fields.
    buffer.writeString(email);

    // Finished serialization.
  }
}

/// Secure Value Type Personal Details.
///
/// ID: `9d2a81e3`.
class SecureValueTypePersonalDetails extends SecureValueTypeBase {
  /// Secure Value Type Personal Details constructor.
  const SecureValueTypePersonalDetails() : super._();

  /// Deserialize.
  factory SecureValueTypePersonalDetails.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypePersonalDetails] object.
    final returnValue = SecureValueTypePersonalDetails();

    // Now return the deserialized [SecureValueTypePersonalDetails].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9d2a81e3.
    buffer.writeInt32(0x9d2a81e3);

    // Finished serialization.
  }
}

/// Secure Value Type Passport.
///
/// ID: `3dac6a00`.
class SecureValueTypePassport extends SecureValueTypeBase {
  /// Secure Value Type Passport constructor.
  const SecureValueTypePassport() : super._();

  /// Deserialize.
  factory SecureValueTypePassport.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypePassport] object.
    final returnValue = SecureValueTypePassport();

    // Now return the deserialized [SecureValueTypePassport].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3dac6a00.
    buffer.writeInt32(0x3dac6a00);

    // Finished serialization.
  }
}

/// Secure Value Type Driver License.
///
/// ID: `06e425c4`.
class SecureValueTypeDriverLicense extends SecureValueTypeBase {
  /// Secure Value Type Driver License constructor.
  const SecureValueTypeDriverLicense() : super._();

  /// Deserialize.
  factory SecureValueTypeDriverLicense.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypeDriverLicense] object.
    final returnValue = SecureValueTypeDriverLicense();

    // Now return the deserialized [SecureValueTypeDriverLicense].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x06e425c4.
    buffer.writeInt32(0x06e425c4);

    // Finished serialization.
  }
}

/// Secure Value Type Identity Card.
///
/// ID: `a0d0744b`.
class SecureValueTypeIdentityCard extends SecureValueTypeBase {
  /// Secure Value Type Identity Card constructor.
  const SecureValueTypeIdentityCard() : super._();

  /// Deserialize.
  factory SecureValueTypeIdentityCard.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypeIdentityCard] object.
    final returnValue = SecureValueTypeIdentityCard();

    // Now return the deserialized [SecureValueTypeIdentityCard].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa0d0744b.
    buffer.writeInt32(0xa0d0744b);

    // Finished serialization.
  }
}

/// Secure Value Type Internal Passport.
///
/// ID: `99a48f23`.
class SecureValueTypeInternalPassport extends SecureValueTypeBase {
  /// Secure Value Type Internal Passport constructor.
  const SecureValueTypeInternalPassport() : super._();

  /// Deserialize.
  factory SecureValueTypeInternalPassport.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypeInternalPassport] object.
    final returnValue = SecureValueTypeInternalPassport();

    // Now return the deserialized [SecureValueTypeInternalPassport].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x99a48f23.
    buffer.writeInt32(0x99a48f23);

    // Finished serialization.
  }
}

/// Secure Value Type Address.
///
/// ID: `cbe31e26`.
class SecureValueTypeAddress extends SecureValueTypeBase {
  /// Secure Value Type Address constructor.
  const SecureValueTypeAddress() : super._();

  /// Deserialize.
  factory SecureValueTypeAddress.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypeAddress] object.
    final returnValue = SecureValueTypeAddress();

    // Now return the deserialized [SecureValueTypeAddress].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcbe31e26.
    buffer.writeInt32(0xcbe31e26);

    // Finished serialization.
  }
}

/// Secure Value Type Utility Bill.
///
/// ID: `fc36954e`.
class SecureValueTypeUtilityBill extends SecureValueTypeBase {
  /// Secure Value Type Utility Bill constructor.
  const SecureValueTypeUtilityBill() : super._();

  /// Deserialize.
  factory SecureValueTypeUtilityBill.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypeUtilityBill] object.
    final returnValue = SecureValueTypeUtilityBill();

    // Now return the deserialized [SecureValueTypeUtilityBill].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfc36954e.
    buffer.writeInt32(0xfc36954e);

    // Finished serialization.
  }
}

/// Secure Value Type Bank Statement.
///
/// ID: `89137c0d`.
class SecureValueTypeBankStatement extends SecureValueTypeBase {
  /// Secure Value Type Bank Statement constructor.
  const SecureValueTypeBankStatement() : super._();

  /// Deserialize.
  factory SecureValueTypeBankStatement.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypeBankStatement] object.
    final returnValue = SecureValueTypeBankStatement();

    // Now return the deserialized [SecureValueTypeBankStatement].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x89137c0d.
    buffer.writeInt32(0x89137c0d);

    // Finished serialization.
  }
}

/// Secure Value Type Rental Agreement.
///
/// ID: `8b883488`.
class SecureValueTypeRentalAgreement extends SecureValueTypeBase {
  /// Secure Value Type Rental Agreement constructor.
  const SecureValueTypeRentalAgreement() : super._();

  /// Deserialize.
  factory SecureValueTypeRentalAgreement.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypeRentalAgreement] object.
    final returnValue = SecureValueTypeRentalAgreement();

    // Now return the deserialized [SecureValueTypeRentalAgreement].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8b883488.
    buffer.writeInt32(0x8b883488);

    // Finished serialization.
  }
}

/// Secure Value Type Passport Registration.
///
/// ID: `99e3806a`.
class SecureValueTypePassportRegistration extends SecureValueTypeBase {
  /// Secure Value Type Passport Registration constructor.
  const SecureValueTypePassportRegistration() : super._();

  /// Deserialize.
  factory SecureValueTypePassportRegistration.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypePassportRegistration] object.
    final returnValue = SecureValueTypePassportRegistration();

    // Now return the deserialized [SecureValueTypePassportRegistration].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x99e3806a.
    buffer.writeInt32(0x99e3806a);

    // Finished serialization.
  }
}

/// Secure Value Type Temporary Registration.
///
/// ID: `ea02ec33`.
class SecureValueTypeTemporaryRegistration extends SecureValueTypeBase {
  /// Secure Value Type Temporary Registration constructor.
  const SecureValueTypeTemporaryRegistration() : super._();

  /// Deserialize.
  factory SecureValueTypeTemporaryRegistration.deserialize(
      BinaryReader reader) {
    // Construct [SecureValueTypeTemporaryRegistration] object.
    final returnValue = SecureValueTypeTemporaryRegistration();

    // Now return the deserialized [SecureValueTypeTemporaryRegistration].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xea02ec33.
    buffer.writeInt32(0xea02ec33);

    // Finished serialization.
  }
}

/// Secure Value Type Phone.
///
/// ID: `b320aadb`.
class SecureValueTypePhone extends SecureValueTypeBase {
  /// Secure Value Type Phone constructor.
  const SecureValueTypePhone() : super._();

  /// Deserialize.
  factory SecureValueTypePhone.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypePhone] object.
    final returnValue = SecureValueTypePhone();

    // Now return the deserialized [SecureValueTypePhone].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb320aadb.
    buffer.writeInt32(0xb320aadb);

    // Finished serialization.
  }
}

/// Secure Value Type Email.
///
/// ID: `8e3ca7ee`.
class SecureValueTypeEmail extends SecureValueTypeBase {
  /// Secure Value Type Email constructor.
  const SecureValueTypeEmail() : super._();

  /// Deserialize.
  factory SecureValueTypeEmail.deserialize(BinaryReader reader) {
    // Construct [SecureValueTypeEmail] object.
    final returnValue = SecureValueTypeEmail();

    // Now return the deserialized [SecureValueTypeEmail].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8e3ca7ee.
    buffer.writeInt32(0x8e3ca7ee);

    // Finished serialization.
  }
}

/// Secure Value.
///
/// ID: `187fa0ca`.
class SecureValue extends SecureValueBase {
  /// Secure Value constructor.
  const SecureValue({
    required this.type,
    this.data,
    this.frontSide,
    this.reverseSide,
    this.selfie,
    this.translation,
    this.files,
    this.plainData,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory SecureValue.deserialize(BinaryReader reader) {
    // Read [SecureValue] fields.
    final flags = reader.readInt32();
    final type = reader.readObject() as SecureValueTypeBase;
    final hasDataField = (flags & 1) != 0;
    final data = hasDataField ? reader.readObject() as SecureDataBase : null;
    final hasFrontSideField = (flags & 2) != 0;
    final frontSide =
        hasFrontSideField ? reader.readObject() as SecureFileBase : null;
    final hasReverseSideField = (flags & 4) != 0;
    final reverseSide =
        hasReverseSideField ? reader.readObject() as SecureFileBase : null;
    final hasSelfieField = (flags & 8) != 0;
    final selfie =
        hasSelfieField ? reader.readObject() as SecureFileBase : null;
    final hasTranslationField = (flags & 64) != 0;
    final translation =
        hasTranslationField ? reader.readVectorObject<SecureFileBase>() : null;
    final hasFilesField = (flags & 16) != 0;
    final files =
        hasFilesField ? reader.readVectorObject<SecureFileBase>() : null;
    final hasPlainDataField = (flags & 32) != 0;
    final plainData =
        hasPlainDataField ? reader.readObject() as SecurePlainDataBase : null;
    final hash = reader.readBytes();

    // Construct [SecureValue] object.
    final returnValue = SecureValue(
      type: type,
      data: data,
      frontSide: frontSide,
      reverseSide: reverseSide,
      selfie: selfie,
      translation: translation,
      files: files,
      plainData: plainData,
      hash: hash,
    );

    // Now return the deserialized [SecureValue].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: data != null,
      b01: frontSide != null,
      b02: reverseSide != null,
      b03: selfie != null,
      b06: translation != null,
      b04: files != null,
      b05: plainData != null,
    );

    return v;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// Data.
  final SecureDataBase? data;

  /// Front Side.
  final SecureFileBase? frontSide;

  /// Reverse Side.
  final SecureFileBase? reverseSide;

  /// Selfie.
  final SecureFileBase? selfie;

  /// Translation.
  final List<SecureFileBase>? translation;

  /// Files.
  final List<SecureFileBase>? files;

  /// Plain Data.
  final SecurePlainDataBase? plainData;

  /// Hash.
  final Uint8List hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x187fa0ca.
    buffer.writeInt32(0x187fa0ca);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(type);
    final localDataCopy = data;
    if (localDataCopy != null) {
      buffer.writeObject(localDataCopy);
    }
    final localFrontSideCopy = frontSide;
    if (localFrontSideCopy != null) {
      buffer.writeObject(localFrontSideCopy);
    }
    final localReverseSideCopy = reverseSide;
    if (localReverseSideCopy != null) {
      buffer.writeObject(localReverseSideCopy);
    }
    final localSelfieCopy = selfie;
    if (localSelfieCopy != null) {
      buffer.writeObject(localSelfieCopy);
    }
    final localTranslationCopy = translation;
    if (localTranslationCopy != null) {
      buffer.writeVectorObject(localTranslationCopy);
    }
    final localFilesCopy = files;
    if (localFilesCopy != null) {
      buffer.writeVectorObject(localFilesCopy);
    }
    final localPlainDataCopy = plainData;
    if (localPlainDataCopy != null) {
      buffer.writeObject(localPlainDataCopy);
    }
    buffer.writeBytes(hash);

    // Finished serialization.
  }
}

/// Input Secure Value.
///
/// ID: `db21d0a7`.
class InputSecureValue extends InputSecureValueBase {
  /// Input Secure Value constructor.
  const InputSecureValue({
    required this.type,
    this.data,
    this.frontSide,
    this.reverseSide,
    this.selfie,
    this.translation,
    this.files,
    this.plainData,
  }) : super._();

  /// Deserialize.
  factory InputSecureValue.deserialize(BinaryReader reader) {
    // Read [InputSecureValue] fields.
    final flags = reader.readInt32();
    final type = reader.readObject() as SecureValueTypeBase;
    final hasDataField = (flags & 1) != 0;
    final data = hasDataField ? reader.readObject() as SecureDataBase : null;
    final hasFrontSideField = (flags & 2) != 0;
    final frontSide =
        hasFrontSideField ? reader.readObject() as InputSecureFileBase : null;
    final hasReverseSideField = (flags & 4) != 0;
    final reverseSide =
        hasReverseSideField ? reader.readObject() as InputSecureFileBase : null;
    final hasSelfieField = (flags & 8) != 0;
    final selfie =
        hasSelfieField ? reader.readObject() as InputSecureFileBase : null;
    final hasTranslationField = (flags & 64) != 0;
    final translation = hasTranslationField
        ? reader.readVectorObject<InputSecureFileBase>()
        : null;
    final hasFilesField = (flags & 16) != 0;
    final files =
        hasFilesField ? reader.readVectorObject<InputSecureFileBase>() : null;
    final hasPlainDataField = (flags & 32) != 0;
    final plainData =
        hasPlainDataField ? reader.readObject() as SecurePlainDataBase : null;

    // Construct [InputSecureValue] object.
    final returnValue = InputSecureValue(
      type: type,
      data: data,
      frontSide: frontSide,
      reverseSide: reverseSide,
      selfie: selfie,
      translation: translation,
      files: files,
      plainData: plainData,
    );

    // Now return the deserialized [InputSecureValue].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: data != null,
      b01: frontSide != null,
      b02: reverseSide != null,
      b03: selfie != null,
      b06: translation != null,
      b04: files != null,
      b05: plainData != null,
    );

    return v;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// Data.
  final SecureDataBase? data;

  /// Front Side.
  final InputSecureFileBase? frontSide;

  /// Reverse Side.
  final InputSecureFileBase? reverseSide;

  /// Selfie.
  final InputSecureFileBase? selfie;

  /// Translation.
  final List<InputSecureFileBase>? translation;

  /// Files.
  final List<InputSecureFileBase>? files;

  /// Plain Data.
  final SecurePlainDataBase? plainData;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdb21d0a7.
    buffer.writeInt32(0xdb21d0a7);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(type);
    final localDataCopy = data;
    if (localDataCopy != null) {
      buffer.writeObject(localDataCopy);
    }
    final localFrontSideCopy = frontSide;
    if (localFrontSideCopy != null) {
      buffer.writeObject(localFrontSideCopy);
    }
    final localReverseSideCopy = reverseSide;
    if (localReverseSideCopy != null) {
      buffer.writeObject(localReverseSideCopy);
    }
    final localSelfieCopy = selfie;
    if (localSelfieCopy != null) {
      buffer.writeObject(localSelfieCopy);
    }
    final localTranslationCopy = translation;
    if (localTranslationCopy != null) {
      buffer.writeVectorObject(localTranslationCopy);
    }
    final localFilesCopy = files;
    if (localFilesCopy != null) {
      buffer.writeVectorObject(localFilesCopy);
    }
    final localPlainDataCopy = plainData;
    if (localPlainDataCopy != null) {
      buffer.writeObject(localPlainDataCopy);
    }

    // Finished serialization.
  }
}

/// Secure Value Hash.
///
/// ID: `ed1ecdb0`.
class SecureValueHash extends SecureValueHashBase {
  /// Secure Value Hash constructor.
  const SecureValueHash({
    required this.type,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory SecureValueHash.deserialize(BinaryReader reader) {
    // Read [SecureValueHash] fields.
    final type = reader.readObject() as SecureValueTypeBase;
    final hash = reader.readBytes();

    // Construct [SecureValueHash] object.
    final returnValue = SecureValueHash(
      type: type,
      hash: hash,
    );

    // Now return the deserialized [SecureValueHash].
    return returnValue;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// Hash.
  final Uint8List hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xed1ecdb0.
    buffer.writeInt32(0xed1ecdb0);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeBytes(hash);

    // Finished serialization.
  }
}

/// Secure Value Error Data.
///
/// ID: `e8a40bd9`.
class SecureValueErrorData extends SecureValueErrorBase {
  /// Secure Value Error Data constructor.
  const SecureValueErrorData({
    required this.type,
    required this.dataHash,
    required this.field,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory SecureValueErrorData.deserialize(BinaryReader reader) {
    // Read [SecureValueErrorData] fields.
    final type = reader.readObject() as SecureValueTypeBase;
    final dataHash = reader.readBytes();
    final field = reader.readString();
    final text = reader.readString();

    // Construct [SecureValueErrorData] object.
    final returnValue = SecureValueErrorData(
      type: type,
      dataHash: dataHash,
      field: field,
      text: text,
    );

    // Now return the deserialized [SecureValueErrorData].
    return returnValue;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// Data Hash.
  final Uint8List dataHash;

  /// Field.
  final String field;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe8a40bd9.
    buffer.writeInt32(0xe8a40bd9);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeBytes(dataHash);
    buffer.writeString(field);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Secure Value Error Front Side.
///
/// ID: `00be3dfa`.
class SecureValueErrorFrontSide extends SecureValueErrorBase {
  /// Secure Value Error Front Side constructor.
  const SecureValueErrorFrontSide({
    required this.type,
    required this.fileHash,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory SecureValueErrorFrontSide.deserialize(BinaryReader reader) {
    // Read [SecureValueErrorFrontSide] fields.
    final type = reader.readObject() as SecureValueTypeBase;
    final fileHash = reader.readBytes();
    final text = reader.readString();

    // Construct [SecureValueErrorFrontSide] object.
    final returnValue = SecureValueErrorFrontSide(
      type: type,
      fileHash: fileHash,
      text: text,
    );

    // Now return the deserialized [SecureValueErrorFrontSide].
    return returnValue;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// File Hash.
  final Uint8List fileHash;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x00be3dfa.
    buffer.writeInt32(0x00be3dfa);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeBytes(fileHash);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Secure Value Error Reverse Side.
///
/// ID: `868a2aa5`.
class SecureValueErrorReverseSide extends SecureValueErrorBase {
  /// Secure Value Error Reverse Side constructor.
  const SecureValueErrorReverseSide({
    required this.type,
    required this.fileHash,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory SecureValueErrorReverseSide.deserialize(BinaryReader reader) {
    // Read [SecureValueErrorReverseSide] fields.
    final type = reader.readObject() as SecureValueTypeBase;
    final fileHash = reader.readBytes();
    final text = reader.readString();

    // Construct [SecureValueErrorReverseSide] object.
    final returnValue = SecureValueErrorReverseSide(
      type: type,
      fileHash: fileHash,
      text: text,
    );

    // Now return the deserialized [SecureValueErrorReverseSide].
    return returnValue;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// File Hash.
  final Uint8List fileHash;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x868a2aa5.
    buffer.writeInt32(0x868a2aa5);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeBytes(fileHash);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Secure Value Error Selfie.
///
/// ID: `e537ced6`.
class SecureValueErrorSelfie extends SecureValueErrorBase {
  /// Secure Value Error Selfie constructor.
  const SecureValueErrorSelfie({
    required this.type,
    required this.fileHash,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory SecureValueErrorSelfie.deserialize(BinaryReader reader) {
    // Read [SecureValueErrorSelfie] fields.
    final type = reader.readObject() as SecureValueTypeBase;
    final fileHash = reader.readBytes();
    final text = reader.readString();

    // Construct [SecureValueErrorSelfie] object.
    final returnValue = SecureValueErrorSelfie(
      type: type,
      fileHash: fileHash,
      text: text,
    );

    // Now return the deserialized [SecureValueErrorSelfie].
    return returnValue;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// File Hash.
  final Uint8List fileHash;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe537ced6.
    buffer.writeInt32(0xe537ced6);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeBytes(fileHash);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Secure Value Error File.
///
/// ID: `7a700873`.
class SecureValueErrorFile extends SecureValueErrorBase {
  /// Secure Value Error File constructor.
  const SecureValueErrorFile({
    required this.type,
    required this.fileHash,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory SecureValueErrorFile.deserialize(BinaryReader reader) {
    // Read [SecureValueErrorFile] fields.
    final type = reader.readObject() as SecureValueTypeBase;
    final fileHash = reader.readBytes();
    final text = reader.readString();

    // Construct [SecureValueErrorFile] object.
    final returnValue = SecureValueErrorFile(
      type: type,
      fileHash: fileHash,
      text: text,
    );

    // Now return the deserialized [SecureValueErrorFile].
    return returnValue;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// File Hash.
  final Uint8List fileHash;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7a700873.
    buffer.writeInt32(0x7a700873);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeBytes(fileHash);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Secure Value Error Files.
///
/// ID: `666220e9`.
class SecureValueErrorFiles extends SecureValueErrorBase {
  /// Secure Value Error Files constructor.
  const SecureValueErrorFiles({
    required this.type,
    required this.fileHash,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory SecureValueErrorFiles.deserialize(BinaryReader reader) {
    // Read [SecureValueErrorFiles] fields.
    final type = reader.readObject() as SecureValueTypeBase;
    final fileHash = reader.readVectorBytes();
    final text = reader.readString();

    // Construct [SecureValueErrorFiles] object.
    final returnValue = SecureValueErrorFiles(
      type: type,
      fileHash: fileHash,
      text: text,
    );

    // Now return the deserialized [SecureValueErrorFiles].
    return returnValue;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// File Hash.
  final List<Uint8List> fileHash;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x666220e9.
    buffer.writeInt32(0x666220e9);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeVectorBytes(fileHash);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Secure Value Error.
///
/// ID: `869d758f`.
class SecureValueError extends SecureValueErrorBase {
  /// Secure Value Error constructor.
  const SecureValueError({
    required this.type,
    required this.hash,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory SecureValueError.deserialize(BinaryReader reader) {
    // Read [SecureValueError] fields.
    final type = reader.readObject() as SecureValueTypeBase;
    final hash = reader.readBytes();
    final text = reader.readString();

    // Construct [SecureValueError] object.
    final returnValue = SecureValueError(
      type: type,
      hash: hash,
      text: text,
    );

    // Now return the deserialized [SecureValueError].
    return returnValue;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// Hash.
  final Uint8List hash;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x869d758f.
    buffer.writeInt32(0x869d758f);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeBytes(hash);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Secure Value Error Translation File.
///
/// ID: `a1144770`.
class SecureValueErrorTranslationFile extends SecureValueErrorBase {
  /// Secure Value Error Translation File constructor.
  const SecureValueErrorTranslationFile({
    required this.type,
    required this.fileHash,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory SecureValueErrorTranslationFile.deserialize(BinaryReader reader) {
    // Read [SecureValueErrorTranslationFile] fields.
    final type = reader.readObject() as SecureValueTypeBase;
    final fileHash = reader.readBytes();
    final text = reader.readString();

    // Construct [SecureValueErrorTranslationFile] object.
    final returnValue = SecureValueErrorTranslationFile(
      type: type,
      fileHash: fileHash,
      text: text,
    );

    // Now return the deserialized [SecureValueErrorTranslationFile].
    return returnValue;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// File Hash.
  final Uint8List fileHash;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa1144770.
    buffer.writeInt32(0xa1144770);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeBytes(fileHash);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Secure Value Error Translation Files.
///
/// ID: `34636dd8`.
class SecureValueErrorTranslationFiles extends SecureValueErrorBase {
  /// Secure Value Error Translation Files constructor.
  const SecureValueErrorTranslationFiles({
    required this.type,
    required this.fileHash,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory SecureValueErrorTranslationFiles.deserialize(BinaryReader reader) {
    // Read [SecureValueErrorTranslationFiles] fields.
    final type = reader.readObject() as SecureValueTypeBase;
    final fileHash = reader.readVectorBytes();
    final text = reader.readString();

    // Construct [SecureValueErrorTranslationFiles] object.
    final returnValue = SecureValueErrorTranslationFiles(
      type: type,
      fileHash: fileHash,
      text: text,
    );

    // Now return the deserialized [SecureValueErrorTranslationFiles].
    return returnValue;
  }

  /// Type.
  final SecureValueTypeBase type;

  /// File Hash.
  final List<Uint8List> fileHash;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x34636dd8.
    buffer.writeInt32(0x34636dd8);

    // Write fields.
    buffer.writeObject(type);
    buffer.writeVectorBytes(fileHash);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Secure Credentials Encrypted.
///
/// ID: `33f0ea47`.
class SecureCredentialsEncrypted extends SecureCredentialsEncryptedBase {
  /// Secure Credentials Encrypted constructor.
  const SecureCredentialsEncrypted({
    required this.data,
    required this.hash,
    required this.secret,
  }) : super._();

  /// Deserialize.
  factory SecureCredentialsEncrypted.deserialize(BinaryReader reader) {
    // Read [SecureCredentialsEncrypted] fields.
    final data = reader.readBytes();
    final hash = reader.readBytes();
    final secret = reader.readBytes();

    // Construct [SecureCredentialsEncrypted] object.
    final returnValue = SecureCredentialsEncrypted(
      data: data,
      hash: hash,
      secret: secret,
    );

    // Now return the deserialized [SecureCredentialsEncrypted].
    return returnValue;
  }

  /// Data.
  final Uint8List data;

  /// Hash.
  final Uint8List hash;

  /// Secret.
  final Uint8List secret;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x33f0ea47.
    buffer.writeInt32(0x33f0ea47);

    // Write fields.
    buffer.writeBytes(data);
    buffer.writeBytes(hash);
    buffer.writeBytes(secret);

    // Finished serialization.
  }
}

/// Account Authorization Form.
///
/// ID: `ad2e1cd8`.
class AccountAuthorizationForm extends AccountAuthorizationFormBase {
  /// Account Authorization Form constructor.
  const AccountAuthorizationForm({
    required this.requiredTypes,
    required this.values,
    required this.errors,
    required this.users,
    this.privacyPolicyUrl,
  }) : super._();

  /// Deserialize.
  factory AccountAuthorizationForm.deserialize(BinaryReader reader) {
    // Read [AccountAuthorizationForm] fields.
    final flags = reader.readInt32();
    final requiredTypes = reader.readVectorObject<SecureRequiredTypeBase>();
    final values = reader.readVectorObject<SecureValueBase>();
    final errors = reader.readVectorObject<SecureValueErrorBase>();
    final users = reader.readVectorObject<UserBase>();
    final hasPrivacyPolicyUrlField = (flags & 1) != 0;
    final privacyPolicyUrl =
        hasPrivacyPolicyUrlField ? reader.readString() : null;

    // Construct [AccountAuthorizationForm] object.
    final returnValue = AccountAuthorizationForm(
      requiredTypes: requiredTypes,
      values: values,
      errors: errors,
      users: users,
      privacyPolicyUrl: privacyPolicyUrl,
    );

    // Now return the deserialized [AccountAuthorizationForm].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: privacyPolicyUrl != null,
    );

    return v;
  }

  /// Required Types.
  final List<SecureRequiredTypeBase> requiredTypes;

  /// Values.
  final List<SecureValueBase> values;

  /// Errors.
  final List<SecureValueErrorBase> errors;

  /// Users.
  final List<UserBase> users;

  /// Privacy Policy Url.
  final String? privacyPolicyUrl;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xad2e1cd8.
    buffer.writeInt32(0xad2e1cd8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(requiredTypes);
    buffer.writeVectorObject(values);
    buffer.writeVectorObject(errors);
    buffer.writeVectorObject(users);
    final localPrivacyPolicyUrlCopy = privacyPolicyUrl;
    if (localPrivacyPolicyUrlCopy != null) {
      buffer.writeString(localPrivacyPolicyUrlCopy);
    }

    // Finished serialization.
  }
}

/// Account Sent Email Code.
///
/// ID: `811f854f`.
class AccountSentEmailCode extends AccountSentEmailCodeBase {
  /// Account Sent Email Code constructor.
  const AccountSentEmailCode({
    required this.emailPattern,
    required this.length,
  }) : super._();

  /// Deserialize.
  factory AccountSentEmailCode.deserialize(BinaryReader reader) {
    // Read [AccountSentEmailCode] fields.
    final emailPattern = reader.readString();
    final length = reader.readInt32();

    // Construct [AccountSentEmailCode] object.
    final returnValue = AccountSentEmailCode(
      emailPattern: emailPattern,
      length: length,
    );

    // Now return the deserialized [AccountSentEmailCode].
    return returnValue;
  }

  /// Email Pattern.
  final String emailPattern;

  /// Length.
  ///
  /// Field type is Int32.
  final int length;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x811f854f.
    buffer.writeInt32(0x811f854f);

    // Write fields.
    buffer.writeString(emailPattern);
    buffer.writeInt32(length);

    // Finished serialization.
  }
}

/// Help Deep Link Info Empty.
///
/// ID: `66afa166`.
class HelpDeepLinkInfoEmpty extends HelpDeepLinkInfoBase {
  /// Help Deep Link Info Empty constructor.
  const HelpDeepLinkInfoEmpty() : super._();

  /// Deserialize.
  factory HelpDeepLinkInfoEmpty.deserialize(BinaryReader reader) {
    // Construct [HelpDeepLinkInfoEmpty] object.
    final returnValue = HelpDeepLinkInfoEmpty();

    // Now return the deserialized [HelpDeepLinkInfoEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x66afa166.
    buffer.writeInt32(0x66afa166);

    // Finished serialization.
  }
}

/// Help Deep Link Info.
///
/// ID: `6a4ee832`.
class HelpDeepLinkInfo extends HelpDeepLinkInfoBase {
  /// Help Deep Link Info constructor.
  const HelpDeepLinkInfo({
    required this.updateApp,
    required this.message,
    this.entities,
  }) : super._();

  /// Deserialize.
  factory HelpDeepLinkInfo.deserialize(BinaryReader reader) {
    // Read [HelpDeepLinkInfo] fields.
    final flags = reader.readInt32();
    final updateApp = (flags & 1) != 0;
    final message = reader.readString();
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;

    // Construct [HelpDeepLinkInfo] object.
    final returnValue = HelpDeepLinkInfo(
      updateApp: updateApp,
      message: message,
      entities: entities,
    );

    // Now return the deserialized [HelpDeepLinkInfo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: updateApp,
      b01: entities != null,
    );

    return v;
  }

  /// update_app: bit 0 of flags.0?true
  final bool updateApp;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6a4ee832.
    buffer.writeInt32(0x6a4ee832);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }

    // Finished serialization.
  }
}

/// Saved Phone Contact.
///
/// ID: `1142bd56`.
class SavedPhoneContact extends SavedContactBase {
  /// Saved Phone Contact constructor.
  const SavedPhoneContact({
    required this.phone,
    required this.firstName,
    required this.lastName,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory SavedPhoneContact.deserialize(BinaryReader reader) {
    // Read [SavedPhoneContact] fields.
    final phone = reader.readString();
    final firstName = reader.readString();
    final lastName = reader.readString();
    final date = reader.readDateTime();

    // Construct [SavedPhoneContact] object.
    final returnValue = SavedPhoneContact(
      phone: phone,
      firstName: firstName,
      lastName: lastName,
      date: date,
    );

    // Now return the deserialized [SavedPhoneContact].
    return returnValue;
  }

  /// Phone.
  final String phone;

  /// First Name.
  final String firstName;

  /// Last Name.
  final String lastName;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1142bd56.
    buffer.writeInt32(0x1142bd56);

    // Write fields.
    buffer.writeString(phone);
    buffer.writeString(firstName);
    buffer.writeString(lastName);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Account Takeout.
///
/// ID: `4dba4501`.
class AccountTakeout extends AccountTakeoutBase {
  /// Account Takeout constructor.
  const AccountTakeout({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory AccountTakeout.deserialize(BinaryReader reader) {
    // Read [AccountTakeout] fields.
    final id = reader.readInt64();

    // Construct [AccountTakeout] object.
    final returnValue = AccountTakeout(
      id: id,
    );

    // Now return the deserialized [AccountTakeout].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4dba4501.
    buffer.writeInt32(0x4dba4501);

    // Write fields.
    buffer.writeInt64(id);

    // Finished serialization.
  }
}

/// Password Kdf Algo Unknown.
///
/// ID: `d45ab096`.
class PasswordKdfAlgoUnknown extends PasswordKdfAlgoBase {
  /// Password Kdf Algo Unknown constructor.
  const PasswordKdfAlgoUnknown() : super._();

  /// Deserialize.
  factory PasswordKdfAlgoUnknown.deserialize(BinaryReader reader) {
    // Construct [PasswordKdfAlgoUnknown] object.
    final returnValue = PasswordKdfAlgoUnknown();

    // Now return the deserialized [PasswordKdfAlgoUnknown].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd45ab096.
    buffer.writeInt32(0xd45ab096);

    // Finished serialization.
  }
}

/// Password Kdf Algo S H A256 S H A256 P B K D F2 H M A C S H A512iter100000 S H A256 Mod Pow.
///
/// ID: `3a912d4a`.
class PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow
    extends PasswordKdfAlgoBase {
  /// Password Kdf Algo S H A256 S H A256 P B K D F2 H M A C S H A512iter100000 S H A256 Mod Pow constructor.
  const PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow({
    required this.salt1,
    required this.salt2,
    required this.g,
    required this.p,
  }) : super._();

  /// Deserialize.
  factory PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow.deserialize(
      BinaryReader reader) {
    // Read [PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow] fields.
    final salt1 = reader.readBytes();
    final salt2 = reader.readBytes();
    final g = reader.readInt32();
    final p = reader.readBytes();

    // Construct [PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow] object.
    final returnValue =
        PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow(
      salt1: salt1,
      salt2: salt2,
      g: g,
      p: p,
    );

    // Now return the deserialized [PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow].
    return returnValue;
  }

  /// Salt1.
  final Uint8List salt1;

  /// Salt2.
  final Uint8List salt2;

  /// G.
  ///
  /// Field type is Int32.
  final int g;

  /// P.
  final Uint8List p;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3a912d4a.
    buffer.writeInt32(0x3a912d4a);

    // Write fields.
    buffer.writeBytes(salt1);
    buffer.writeBytes(salt2);
    buffer.writeInt32(g);
    buffer.writeBytes(p);

    // Finished serialization.
  }
}

/// Secure Password Kdf Algo Unknown.
///
/// ID: `004a8537`.
class SecurePasswordKdfAlgoUnknown extends SecurePasswordKdfAlgoBase {
  /// Secure Password Kdf Algo Unknown constructor.
  const SecurePasswordKdfAlgoUnknown() : super._();

  /// Deserialize.
  factory SecurePasswordKdfAlgoUnknown.deserialize(BinaryReader reader) {
    // Construct [SecurePasswordKdfAlgoUnknown] object.
    final returnValue = SecurePasswordKdfAlgoUnknown();

    // Now return the deserialized [SecurePasswordKdfAlgoUnknown].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x004a8537.
    buffer.writeInt32(0x004a8537);

    // Finished serialization.
  }
}

/// Secure Password Kdf Algo P B K D F2 H M A C S H A512iter100000.
///
/// ID: `bbf2dda0`.
class SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000
    extends SecurePasswordKdfAlgoBase {
  /// Secure Password Kdf Algo P B K D F2 H M A C S H A512iter100000 constructor.
  const SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000({
    required this.salt,
  }) : super._();

  /// Deserialize.
  factory SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000.deserialize(
      BinaryReader reader) {
    // Read [SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000] fields.
    final salt = reader.readBytes();

    // Construct [SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000] object.
    final returnValue = SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000(
      salt: salt,
    );

    // Now return the deserialized [SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000].
    return returnValue;
  }

  /// Salt.
  final Uint8List salt;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbbf2dda0.
    buffer.writeInt32(0xbbf2dda0);

    // Write fields.
    buffer.writeBytes(salt);

    // Finished serialization.
  }
}

/// Secure Password Kdf Algo S H A512.
///
/// ID: `86471d92`.
class SecurePasswordKdfAlgoSHA512 extends SecurePasswordKdfAlgoBase {
  /// Secure Password Kdf Algo S H A512 constructor.
  const SecurePasswordKdfAlgoSHA512({
    required this.salt,
  }) : super._();

  /// Deserialize.
  factory SecurePasswordKdfAlgoSHA512.deserialize(BinaryReader reader) {
    // Read [SecurePasswordKdfAlgoSHA512] fields.
    final salt = reader.readBytes();

    // Construct [SecurePasswordKdfAlgoSHA512] object.
    final returnValue = SecurePasswordKdfAlgoSHA512(
      salt: salt,
    );

    // Now return the deserialized [SecurePasswordKdfAlgoSHA512].
    return returnValue;
  }

  /// Salt.
  final Uint8List salt;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x86471d92.
    buffer.writeInt32(0x86471d92);

    // Write fields.
    buffer.writeBytes(salt);

    // Finished serialization.
  }
}

/// Secure Secret Settings.
///
/// ID: `1527bcac`.
class SecureSecretSettings extends SecureSecretSettingsBase {
  /// Secure Secret Settings constructor.
  const SecureSecretSettings({
    required this.secureAlgo,
    required this.secureSecret,
    required this.secureSecretId,
  }) : super._();

  /// Deserialize.
  factory SecureSecretSettings.deserialize(BinaryReader reader) {
    // Read [SecureSecretSettings] fields.
    final secureAlgo = reader.readObject() as SecurePasswordKdfAlgoBase;
    final secureSecret = reader.readBytes();
    final secureSecretId = reader.readInt64();

    // Construct [SecureSecretSettings] object.
    final returnValue = SecureSecretSettings(
      secureAlgo: secureAlgo,
      secureSecret: secureSecret,
      secureSecretId: secureSecretId,
    );

    // Now return the deserialized [SecureSecretSettings].
    return returnValue;
  }

  /// Secure Algo.
  final SecurePasswordKdfAlgoBase secureAlgo;

  /// Secure Secret.
  final Uint8List secureSecret;

  /// Secure Secret Id.
  ///
  /// Field type is Int64.
  final int secureSecretId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1527bcac.
    buffer.writeInt32(0x1527bcac);

    // Write fields.
    buffer.writeObject(secureAlgo);
    buffer.writeBytes(secureSecret);
    buffer.writeInt64(secureSecretId);

    // Finished serialization.
  }
}

/// Input Check Password Empty.
///
/// ID: `9880f658`.
class InputCheckPasswordEmpty extends InputCheckPasswordSRPBase {
  /// Input Check Password Empty constructor.
  const InputCheckPasswordEmpty() : super._();

  /// Deserialize.
  factory InputCheckPasswordEmpty.deserialize(BinaryReader reader) {
    // Construct [InputCheckPasswordEmpty] object.
    final returnValue = InputCheckPasswordEmpty();

    // Now return the deserialized [InputCheckPasswordEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9880f658.
    buffer.writeInt32(0x9880f658);

    // Finished serialization.
  }
}

/// Input Check Password S R P.
///
/// ID: `d27ff082`.
class InputCheckPasswordSRP extends InputCheckPasswordSRPBase {
  /// Input Check Password S R P constructor.
  const InputCheckPasswordSRP({
    required this.srpId,
    required this.a,
    required this.m1,
  }) : super._();

  /// Deserialize.
  factory InputCheckPasswordSRP.deserialize(BinaryReader reader) {
    // Read [InputCheckPasswordSRP] fields.
    final srpId = reader.readInt64();
    final a = reader.readBytes();
    final m1 = reader.readBytes();

    // Construct [InputCheckPasswordSRP] object.
    final returnValue = InputCheckPasswordSRP(
      srpId: srpId,
      a: a,
      m1: m1,
    );

    // Now return the deserialized [InputCheckPasswordSRP].
    return returnValue;
  }

  /// Srp Id.
  ///
  /// Field type is Int64.
  final int srpId;

  /// A.
  final Uint8List a;

  /// M1.
  final Uint8List m1;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd27ff082.
    buffer.writeInt32(0xd27ff082);

    // Write fields.
    buffer.writeInt64(srpId);
    buffer.writeBytes(a);
    buffer.writeBytes(m1);

    // Finished serialization.
  }
}

/// Secure Required Type.
///
/// ID: `829d99da`.
class SecureRequiredType extends SecureRequiredTypeBase {
  /// Secure Required Type constructor.
  const SecureRequiredType({
    required this.nativeNames,
    required this.selfieRequired,
    required this.translationRequired,
    required this.type,
  }) : super._();

  /// Deserialize.
  factory SecureRequiredType.deserialize(BinaryReader reader) {
    // Read [SecureRequiredType] fields.
    final flags = reader.readInt32();
    final nativeNames = (flags & 1) != 0;
    final selfieRequired = (flags & 2) != 0;
    final translationRequired = (flags & 4) != 0;
    final type = reader.readObject() as SecureValueTypeBase;

    // Construct [SecureRequiredType] object.
    final returnValue = SecureRequiredType(
      nativeNames: nativeNames,
      selfieRequired: selfieRequired,
      translationRequired: translationRequired,
      type: type,
    );

    // Now return the deserialized [SecureRequiredType].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: nativeNames,
      b01: selfieRequired,
      b02: translationRequired,
    );

    return v;
  }

  /// native_names: bit 0 of flags.0?true
  final bool nativeNames;

  /// selfie_required: bit 1 of flags.1?true
  final bool selfieRequired;

  /// translation_required: bit 2 of flags.2?true
  final bool translationRequired;

  /// Type.
  final SecureValueTypeBase type;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x829d99da.
    buffer.writeInt32(0x829d99da);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(type);

    // Finished serialization.
  }
}

/// Secure Required Type One Of.
///
/// ID: `027477b4`.
class SecureRequiredTypeOneOf extends SecureRequiredTypeBase {
  /// Secure Required Type One Of constructor.
  const SecureRequiredTypeOneOf({
    required this.types,
  }) : super._();

  /// Deserialize.
  factory SecureRequiredTypeOneOf.deserialize(BinaryReader reader) {
    // Read [SecureRequiredTypeOneOf] fields.
    final types = reader.readVectorObject<SecureRequiredTypeBase>();

    // Construct [SecureRequiredTypeOneOf] object.
    final returnValue = SecureRequiredTypeOneOf(
      types: types,
    );

    // Now return the deserialized [SecureRequiredTypeOneOf].
    return returnValue;
  }

  /// Types.
  final List<SecureRequiredTypeBase> types;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x027477b4.
    buffer.writeInt32(0x027477b4);

    // Write fields.
    buffer.writeVectorObject(types);

    // Finished serialization.
  }
}

/// Help Passport Config Not Modified.
///
/// ID: `bfb9f457`.
class HelpPassportConfigNotModified extends HelpPassportConfigBase {
  /// Help Passport Config Not Modified constructor.
  const HelpPassportConfigNotModified() : super._();

  /// Deserialize.
  factory HelpPassportConfigNotModified.deserialize(BinaryReader reader) {
    // Construct [HelpPassportConfigNotModified] object.
    final returnValue = HelpPassportConfigNotModified();

    // Now return the deserialized [HelpPassportConfigNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbfb9f457.
    buffer.writeInt32(0xbfb9f457);

    // Finished serialization.
  }
}

/// Help Passport Config.
///
/// ID: `a098d6af`.
class HelpPassportConfig extends HelpPassportConfigBase {
  /// Help Passport Config constructor.
  const HelpPassportConfig({
    required this.hash,
    required this.countriesLangs,
  }) : super._();

  /// Deserialize.
  factory HelpPassportConfig.deserialize(BinaryReader reader) {
    // Read [HelpPassportConfig] fields.
    final hash = reader.readInt32();
    final countriesLangs = reader.readObject() as DataJSONBase;

    // Construct [HelpPassportConfig] object.
    final returnValue = HelpPassportConfig(
      hash: hash,
      countriesLangs: countriesLangs,
    );

    // Now return the deserialized [HelpPassportConfig].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Countries Langs.
  final DataJSONBase countriesLangs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa098d6af.
    buffer.writeInt32(0xa098d6af);

    // Write fields.
    buffer.writeInt32(hash);
    buffer.writeObject(countriesLangs);

    // Finished serialization.
  }
}

/// Input App Event.
///
/// ID: `1d1b1245`.
class InputAppEvent extends InputAppEventBase {
  /// Input App Event constructor.
  const InputAppEvent({
    required this.time,
    required this.type,
    required this.peer,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory InputAppEvent.deserialize(BinaryReader reader) {
    // Read [InputAppEvent] fields.
    final time = reader.readFloat64();
    final type = reader.readString();
    final peer = reader.readInt64();
    final data = reader.readObject() as JSONValueBase;

    // Construct [InputAppEvent] object.
    final returnValue = InputAppEvent(
      time: time,
      type: type,
      peer: peer,
      data: data,
    );

    // Now return the deserialized [InputAppEvent].
    return returnValue;
  }

  /// Time.
  final double time;

  /// Type.
  final String type;

  /// Peer.
  ///
  /// Field type is Int64.
  final int peer;

  /// Data.
  final JSONValueBase data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1d1b1245.
    buffer.writeInt32(0x1d1b1245);

    // Write fields.
    buffer.writeDouble(time);
    buffer.writeString(type);
    buffer.writeInt64(peer);
    buffer.writeObject(data);

    // Finished serialization.
  }
}

/// Json Object Value.
///
/// ID: `c0de1bd9`.
class JsonObjectValue extends JSONObjectValueBase {
  /// Json Object Value constructor.
  const JsonObjectValue({
    required this.key,
    required this.value,
  }) : super._();

  /// Deserialize.
  factory JsonObjectValue.deserialize(BinaryReader reader) {
    // Read [JsonObjectValue] fields.
    final key = reader.readString();
    final value = reader.readObject() as JSONValueBase;

    // Construct [JsonObjectValue] object.
    final returnValue = JsonObjectValue(
      key: key,
      value: value,
    );

    // Now return the deserialized [JsonObjectValue].
    return returnValue;
  }

  /// Key.
  final String key;

  /// Value.
  final JSONValueBase value;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc0de1bd9.
    buffer.writeInt32(0xc0de1bd9);

    // Write fields.
    buffer.writeString(key);
    buffer.writeObject(value);

    // Finished serialization.
  }
}

/// Json Null.
///
/// ID: `3f6d7b68`.
class JsonNull extends JSONValueBase {
  /// Json Null constructor.
  const JsonNull() : super._();

  /// Deserialize.
  factory JsonNull.deserialize(BinaryReader reader) {
    // Construct [JsonNull] object.
    final returnValue = JsonNull();

    // Now return the deserialized [JsonNull].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3f6d7b68.
    buffer.writeInt32(0x3f6d7b68);

    // Finished serialization.
  }
}

/// Json Bool.
///
/// ID: `c7345e6a`.
class JsonBool extends JSONValueBase {
  /// Json Bool constructor.
  const JsonBool({
    required this.value,
  }) : super._();

  /// Deserialize.
  factory JsonBool.deserialize(BinaryReader reader) {
    // Read [JsonBool] fields.
    final value = reader.readBool();

    // Construct [JsonBool] object.
    final returnValue = JsonBool(
      value: value,
    );

    // Now return the deserialized [JsonBool].
    return returnValue;
  }

  /// Value.
  final bool value;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc7345e6a.
    buffer.writeInt32(0xc7345e6a);

    // Write fields.
    buffer.writeBool(value);

    // Finished serialization.
  }
}

/// Json Number.
///
/// ID: `2be0dfa4`.
class JsonNumber extends JSONValueBase {
  /// Json Number constructor.
  const JsonNumber({
    required this.value,
  }) : super._();

  /// Deserialize.
  factory JsonNumber.deserialize(BinaryReader reader) {
    // Read [JsonNumber] fields.
    final value = reader.readFloat64();

    // Construct [JsonNumber] object.
    final returnValue = JsonNumber(
      value: value,
    );

    // Now return the deserialized [JsonNumber].
    return returnValue;
  }

  /// Value.
  final double value;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2be0dfa4.
    buffer.writeInt32(0x2be0dfa4);

    // Write fields.
    buffer.writeDouble(value);

    // Finished serialization.
  }
}

/// Json String.
///
/// ID: `b71e767a`.
class JsonString extends JSONValueBase {
  /// Json String constructor.
  const JsonString({
    required this.value,
  }) : super._();

  /// Deserialize.
  factory JsonString.deserialize(BinaryReader reader) {
    // Read [JsonString] fields.
    final value = reader.readString();

    // Construct [JsonString] object.
    final returnValue = JsonString(
      value: value,
    );

    // Now return the deserialized [JsonString].
    return returnValue;
  }

  /// Value.
  final String value;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb71e767a.
    buffer.writeInt32(0xb71e767a);

    // Write fields.
    buffer.writeString(value);

    // Finished serialization.
  }
}

/// Json Array.
///
/// ID: `f7444763`.
class JsonArray extends JSONValueBase {
  /// Json Array constructor.
  const JsonArray({
    required this.value,
  }) : super._();

  /// Deserialize.
  factory JsonArray.deserialize(BinaryReader reader) {
    // Read [JsonArray] fields.
    final value = reader.readVectorObject<JSONValueBase>();

    // Construct [JsonArray] object.
    final returnValue = JsonArray(
      value: value,
    );

    // Now return the deserialized [JsonArray].
    return returnValue;
  }

  /// Value.
  final List<JSONValueBase> value;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf7444763.
    buffer.writeInt32(0xf7444763);

    // Write fields.
    buffer.writeVectorObject(value);

    // Finished serialization.
  }
}

/// Json Object.
///
/// ID: `99c1d49d`.
class JsonObject extends JSONValueBase {
  /// Json Object constructor.
  const JsonObject({
    required this.value,
  }) : super._();

  /// Deserialize.
  factory JsonObject.deserialize(BinaryReader reader) {
    // Read [JsonObject] fields.
    final value = reader.readVectorObject<JSONObjectValueBase>();

    // Construct [JsonObject] object.
    final returnValue = JsonObject(
      value: value,
    );

    // Now return the deserialized [JsonObject].
    return returnValue;
  }

  /// Value.
  final List<JSONObjectValueBase> value;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x99c1d49d.
    buffer.writeInt32(0x99c1d49d);

    // Write fields.
    buffer.writeVectorObject(value);

    // Finished serialization.
  }
}

/// Page Table Cell.
///
/// ID: `34566b6a`.
class PageTableCell extends PageTableCellBase {
  /// Page Table Cell constructor.
  const PageTableCell({
    required this.header,
    required this.alignCenter,
    required this.alignRight,
    required this.valignMiddle,
    required this.valignBottom,
    this.text,
    this.colspan,
    this.rowspan,
  }) : super._();

  /// Deserialize.
  factory PageTableCell.deserialize(BinaryReader reader) {
    // Read [PageTableCell] fields.
    final flags = reader.readInt32();
    final header = (flags & 1) != 0;
    final alignCenter = (flags & 8) != 0;
    final alignRight = (flags & 16) != 0;
    final valignMiddle = (flags & 32) != 0;
    final valignBottom = (flags & 64) != 0;
    final hasTextField = (flags & 128) != 0;
    final text = hasTextField ? reader.readObject() as RichTextBase : null;
    final hasColspanField = (flags & 2) != 0;
    final colspan = hasColspanField ? reader.readInt32() : null;
    final hasRowspanField = (flags & 4) != 0;
    final rowspan = hasRowspanField ? reader.readInt32() : null;

    // Construct [PageTableCell] object.
    final returnValue = PageTableCell(
      header: header,
      alignCenter: alignCenter,
      alignRight: alignRight,
      valignMiddle: valignMiddle,
      valignBottom: valignBottom,
      text: text,
      colspan: colspan,
      rowspan: rowspan,
    );

    // Now return the deserialized [PageTableCell].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: header,
      b03: alignCenter,
      b04: alignRight,
      b05: valignMiddle,
      b06: valignBottom,
      b07: text != null,
      b01: colspan != null,
      b02: rowspan != null,
    );

    return v;
  }

  /// header: bit 0 of flags.0?true
  final bool header;

  /// align_center: bit 3 of flags.3?true
  final bool alignCenter;

  /// align_right: bit 4 of flags.4?true
  final bool alignRight;

  /// valign_middle: bit 5 of flags.5?true
  final bool valignMiddle;

  /// valign_bottom: bit 6 of flags.6?true
  final bool valignBottom;

  /// Text.
  final RichTextBase? text;

  /// Colspan.
  final int? colspan;

  /// Rowspan.
  final int? rowspan;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x34566b6a.
    buffer.writeInt32(0x34566b6a);

    // Write fields.
    buffer.writeInt32(flags);
    final localTextCopy = text;
    if (localTextCopy != null) {
      buffer.writeObject(localTextCopy);
    }
    final localColspanCopy = colspan;
    if (localColspanCopy != null) {
      buffer.writeInt32(localColspanCopy);
    }
    final localRowspanCopy = rowspan;
    if (localRowspanCopy != null) {
      buffer.writeInt32(localRowspanCopy);
    }

    // Finished serialization.
  }
}

/// Page Table Row.
///
/// ID: `e0c0c5e5`.
class PageTableRow extends PageTableRowBase {
  /// Page Table Row constructor.
  const PageTableRow({
    required this.cells,
  }) : super._();

  /// Deserialize.
  factory PageTableRow.deserialize(BinaryReader reader) {
    // Read [PageTableRow] fields.
    final cells = reader.readVectorObject<PageTableCellBase>();

    // Construct [PageTableRow] object.
    final returnValue = PageTableRow(
      cells: cells,
    );

    // Now return the deserialized [PageTableRow].
    return returnValue;
  }

  /// Cells.
  final List<PageTableCellBase> cells;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe0c0c5e5.
    buffer.writeInt32(0xe0c0c5e5);

    // Write fields.
    buffer.writeVectorObject(cells);

    // Finished serialization.
  }
}

/// Page Caption.
///
/// ID: `6f747657`.
class PageCaption extends PageCaptionBase {
  /// Page Caption constructor.
  const PageCaption({
    required this.text,
    required this.credit,
  }) : super._();

  /// Deserialize.
  factory PageCaption.deserialize(BinaryReader reader) {
    // Read [PageCaption] fields.
    final text = reader.readObject() as RichTextBase;
    final credit = reader.readObject() as RichTextBase;

    // Construct [PageCaption] object.
    final returnValue = PageCaption(
      text: text,
      credit: credit,
    );

    // Now return the deserialized [PageCaption].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Credit.
  final RichTextBase credit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6f747657.
    buffer.writeInt32(0x6f747657);

    // Write fields.
    buffer.writeObject(text);
    buffer.writeObject(credit);

    // Finished serialization.
  }
}

/// Page List Item Text.
///
/// ID: `b92fb6cd`.
class PageListItemText extends PageListItemBase {
  /// Page List Item Text constructor.
  const PageListItemText({
    required this.text,
  }) : super._();

  /// Deserialize.
  factory PageListItemText.deserialize(BinaryReader reader) {
    // Read [PageListItemText] fields.
    final text = reader.readObject() as RichTextBase;

    // Construct [PageListItemText] object.
    final returnValue = PageListItemText(
      text: text,
    );

    // Now return the deserialized [PageListItemText].
    return returnValue;
  }

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb92fb6cd.
    buffer.writeInt32(0xb92fb6cd);

    // Write fields.
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Page List Item Blocks.
///
/// ID: `25e073fc`.
class PageListItemBlocks extends PageListItemBase {
  /// Page List Item Blocks constructor.
  const PageListItemBlocks({
    required this.blocks,
  }) : super._();

  /// Deserialize.
  factory PageListItemBlocks.deserialize(BinaryReader reader) {
    // Read [PageListItemBlocks] fields.
    final blocks = reader.readVectorObject<PageBlockBase>();

    // Construct [PageListItemBlocks] object.
    final returnValue = PageListItemBlocks(
      blocks: blocks,
    );

    // Now return the deserialized [PageListItemBlocks].
    return returnValue;
  }

  /// Blocks.
  final List<PageBlockBase> blocks;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x25e073fc.
    buffer.writeInt32(0x25e073fc);

    // Write fields.
    buffer.writeVectorObject(blocks);

    // Finished serialization.
  }
}

/// Page List Ordered Item Text.
///
/// ID: `5e068047`.
class PageListOrderedItemText extends PageListOrderedItemBase {
  /// Page List Ordered Item Text constructor.
  const PageListOrderedItemText({
    required this.num,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory PageListOrderedItemText.deserialize(BinaryReader reader) {
    // Read [PageListOrderedItemText] fields.
    final num = reader.readString();
    final text = reader.readObject() as RichTextBase;

    // Construct [PageListOrderedItemText] object.
    final returnValue = PageListOrderedItemText(
      num: num,
      text: text,
    );

    // Now return the deserialized [PageListOrderedItemText].
    return returnValue;
  }

  /// Num.
  final String num;

  /// Text.
  final RichTextBase text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5e068047.
    buffer.writeInt32(0x5e068047);

    // Write fields.
    buffer.writeString(num);
    buffer.writeObject(text);

    // Finished serialization.
  }
}

/// Page List Ordered Item Blocks.
///
/// ID: `98dd8936`.
class PageListOrderedItemBlocks extends PageListOrderedItemBase {
  /// Page List Ordered Item Blocks constructor.
  const PageListOrderedItemBlocks({
    required this.num,
    required this.blocks,
  }) : super._();

  /// Deserialize.
  factory PageListOrderedItemBlocks.deserialize(BinaryReader reader) {
    // Read [PageListOrderedItemBlocks] fields.
    final num = reader.readString();
    final blocks = reader.readVectorObject<PageBlockBase>();

    // Construct [PageListOrderedItemBlocks] object.
    final returnValue = PageListOrderedItemBlocks(
      num: num,
      blocks: blocks,
    );

    // Now return the deserialized [PageListOrderedItemBlocks].
    return returnValue;
  }

  /// Num.
  final String num;

  /// Blocks.
  final List<PageBlockBase> blocks;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x98dd8936.
    buffer.writeInt32(0x98dd8936);

    // Write fields.
    buffer.writeString(num);
    buffer.writeVectorObject(blocks);

    // Finished serialization.
  }
}

/// Page Related Article.
///
/// ID: `b390dc08`.
class PageRelatedArticle extends PageRelatedArticleBase {
  /// Page Related Article constructor.
  const PageRelatedArticle({
    required this.url,
    required this.webpageId,
    this.title,
    this.description,
    this.photoId,
    this.author,
    this.publishedDate,
  }) : super._();

  /// Deserialize.
  factory PageRelatedArticle.deserialize(BinaryReader reader) {
    // Read [PageRelatedArticle] fields.
    final flags = reader.readInt32();
    final url = reader.readString();
    final webpageId = reader.readInt64();
    final hasTitleField = (flags & 1) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasDescriptionField = (flags & 2) != 0;
    final description = hasDescriptionField ? reader.readString() : null;
    final hasPhotoIdField = (flags & 4) != 0;
    final photoId = hasPhotoIdField ? reader.readInt64() : null;
    final hasAuthorField = (flags & 8) != 0;
    final author = hasAuthorField ? reader.readString() : null;
    final hasPublishedDateField = (flags & 16) != 0;
    final publishedDate = hasPublishedDateField ? reader.readDateTime() : null;

    // Construct [PageRelatedArticle] object.
    final returnValue = PageRelatedArticle(
      url: url,
      webpageId: webpageId,
      title: title,
      description: description,
      photoId: photoId,
      author: author,
      publishedDate: publishedDate,
    );

    // Now return the deserialized [PageRelatedArticle].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: title != null,
      b01: description != null,
      b02: photoId != null,
      b03: author != null,
      b04: publishedDate != null,
    );

    return v;
  }

  /// Url.
  final String url;

  /// Webpage Id.
  ///
  /// Field type is Int64.
  final int webpageId;

  /// Title.
  final String? title;

  /// Description.
  final String? description;

  /// Photo Id.
  final int? photoId;

  /// Author.
  final String? author;

  /// Published Date.
  final DateTime? publishedDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb390dc08.
    buffer.writeInt32(0xb390dc08);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(url);
    buffer.writeInt64(webpageId);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localDescriptionCopy = description;
    if (localDescriptionCopy != null) {
      buffer.writeString(localDescriptionCopy);
    }
    final localPhotoIdCopy = photoId;
    if (localPhotoIdCopy != null) {
      buffer.writeInt64(localPhotoIdCopy);
    }
    final localAuthorCopy = author;
    if (localAuthorCopy != null) {
      buffer.writeString(localAuthorCopy);
    }
    final localPublishedDateCopy = publishedDate;
    if (localPublishedDateCopy != null) {
      buffer.writeDateTime(localPublishedDateCopy);
    }

    // Finished serialization.
  }
}

/// Page.
///
/// ID: `98657f0d`.
class Page extends PageBase {
  /// Page constructor.
  const Page({
    required this.part,
    required this.rtl,
    required this.v2,
    required this.url,
    required this.blocks,
    required this.photos,
    required this.documents,
    this.views,
  }) : super._();

  /// Deserialize.
  factory Page.deserialize(BinaryReader reader) {
    // Read [Page] fields.
    final flags = reader.readInt32();
    final part = (flags & 1) != 0;
    final rtl = (flags & 2) != 0;
    final v2 = (flags & 4) != 0;
    final url = reader.readString();
    final blocks = reader.readVectorObject<PageBlockBase>();
    final photos = reader.readVectorObject<PhotoBase>();
    final documents = reader.readVectorObject<DocumentBase>();
    final hasViewsField = (flags & 8) != 0;
    final views = hasViewsField ? reader.readInt32() : null;

    // Construct [Page] object.
    final returnValue = Page(
      part: part,
      rtl: rtl,
      v2: v2,
      url: url,
      blocks: blocks,
      photos: photos,
      documents: documents,
      views: views,
    );

    // Now return the deserialized [Page].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: part,
      b01: rtl,
      b02: v2,
      b03: views != null,
    );

    return v;
  }

  /// part: bit 0 of flags.0?true
  final bool part;

  /// rtl: bit 1 of flags.1?true
  final bool rtl;

  /// v2: bit 2 of flags.2?true
  final bool v2;

  /// Url.
  final String url;

  /// Blocks.
  final List<PageBlockBase> blocks;

  /// Photos.
  final List<PhotoBase> photos;

  /// Documents.
  final List<DocumentBase> documents;

  /// Views.
  final int? views;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x98657f0d.
    buffer.writeInt32(0x98657f0d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(url);
    buffer.writeVectorObject(blocks);
    buffer.writeVectorObject(photos);
    buffer.writeVectorObject(documents);
    final localViewsCopy = views;
    if (localViewsCopy != null) {
      buffer.writeInt32(localViewsCopy);
    }

    // Finished serialization.
  }
}

/// Help Support Name.
///
/// ID: `8c05f1c9`.
class HelpSupportName extends HelpSupportNameBase {
  /// Help Support Name constructor.
  const HelpSupportName({
    required this.name,
  }) : super._();

  /// Deserialize.
  factory HelpSupportName.deserialize(BinaryReader reader) {
    // Read [HelpSupportName] fields.
    final name = reader.readString();

    // Construct [HelpSupportName] object.
    final returnValue = HelpSupportName(
      name: name,
    );

    // Now return the deserialized [HelpSupportName].
    return returnValue;
  }

  /// Name.
  final String name;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8c05f1c9.
    buffer.writeInt32(0x8c05f1c9);

    // Write fields.
    buffer.writeString(name);

    // Finished serialization.
  }
}

/// Help User Info Empty.
///
/// ID: `f3ae2eed`.
class HelpUserInfoEmpty extends HelpUserInfoBase {
  /// Help User Info Empty constructor.
  const HelpUserInfoEmpty() : super._();

  /// Deserialize.
  factory HelpUserInfoEmpty.deserialize(BinaryReader reader) {
    // Construct [HelpUserInfoEmpty] object.
    final returnValue = HelpUserInfoEmpty();

    // Now return the deserialized [HelpUserInfoEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf3ae2eed.
    buffer.writeInt32(0xf3ae2eed);

    // Finished serialization.
  }
}

/// Help User Info.
///
/// ID: `01eb3758`.
class HelpUserInfo extends HelpUserInfoBase {
  /// Help User Info constructor.
  const HelpUserInfo({
    required this.message,
    required this.entities,
    required this.author,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory HelpUserInfo.deserialize(BinaryReader reader) {
    // Read [HelpUserInfo] fields.
    final message = reader.readString();
    final entities = reader.readVectorObject<MessageEntityBase>();
    final author = reader.readString();
    final date = reader.readDateTime();

    // Construct [HelpUserInfo] object.
    final returnValue = HelpUserInfo(
      message: message,
      entities: entities,
      author: author,
      date: date,
    );

    // Now return the deserialized [HelpUserInfo].
    return returnValue;
  }

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase> entities;

  /// Author.
  final String author;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x01eb3758.
    buffer.writeInt32(0x01eb3758);

    // Write fields.
    buffer.writeString(message);
    buffer.writeVectorObject(entities);
    buffer.writeString(author);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Poll Answer.
///
/// ID: `6ca9c2e9`.
class PollAnswer extends PollAnswerBase {
  /// Poll Answer constructor.
  const PollAnswer({
    required this.text,
    required this.option,
  }) : super._();

  /// Deserialize.
  factory PollAnswer.deserialize(BinaryReader reader) {
    // Read [PollAnswer] fields.
    final text = reader.readString();
    final option = reader.readBytes();

    // Construct [PollAnswer] object.
    final returnValue = PollAnswer(
      text: text,
      option: option,
    );

    // Now return the deserialized [PollAnswer].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Option.
  final Uint8List option;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6ca9c2e9.
    buffer.writeInt32(0x6ca9c2e9);

    // Write fields.
    buffer.writeString(text);
    buffer.writeBytes(option);

    // Finished serialization.
  }
}

/// Poll.
///
/// ID: `86e18161`.
class Poll extends PollBase {
  /// Poll constructor.
  const Poll({
    required this.id,
    required this.closed,
    required this.publicVoters,
    required this.multipleChoice,
    required this.quiz,
    required this.question,
    required this.answers,
    this.closePeriod,
    this.closeDate,
  }) : super._();

  /// Deserialize.
  factory Poll.deserialize(BinaryReader reader) {
    // Read [Poll] fields.
    final id = reader.readInt64();
    final flags = reader.readInt32();
    final closed = (flags & 1) != 0;
    final publicVoters = (flags & 2) != 0;
    final multipleChoice = (flags & 4) != 0;
    final quiz = (flags & 8) != 0;
    final question = reader.readString();
    final answers = reader.readVectorObject<PollAnswerBase>();
    final hasClosePeriodField = (flags & 16) != 0;
    final closePeriod = hasClosePeriodField ? reader.readInt32() : null;
    final hasCloseDateField = (flags & 32) != 0;
    final closeDate = hasCloseDateField ? reader.readDateTime() : null;

    // Construct [Poll] object.
    final returnValue = Poll(
      id: id,
      closed: closed,
      publicVoters: publicVoters,
      multipleChoice: multipleChoice,
      quiz: quiz,
      question: question,
      answers: answers,
      closePeriod: closePeriod,
      closeDate: closeDate,
    );

    // Now return the deserialized [Poll].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: closed,
      b01: publicVoters,
      b02: multipleChoice,
      b03: quiz,
      b04: closePeriod != null,
      b05: closeDate != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// closed: bit 0 of flags.0?true
  final bool closed;

  /// public_voters: bit 1 of flags.1?true
  final bool publicVoters;

  /// multiple_choice: bit 2 of flags.2?true
  final bool multipleChoice;

  /// quiz: bit 3 of flags.3?true
  final bool quiz;

  /// Question.
  final String question;

  /// Answers.
  final List<PollAnswerBase> answers;

  /// Close Period.
  final int? closePeriod;

  /// Close Date.
  final DateTime? closeDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x86e18161.
    buffer.writeInt32(0x86e18161);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt32(flags);
    buffer.writeString(question);
    buffer.writeVectorObject(answers);
    final localClosePeriodCopy = closePeriod;
    if (localClosePeriodCopy != null) {
      buffer.writeInt32(localClosePeriodCopy);
    }
    final localCloseDateCopy = closeDate;
    if (localCloseDateCopy != null) {
      buffer.writeDateTime(localCloseDateCopy);
    }

    // Finished serialization.
  }
}

/// Poll Answer Voters.
///
/// ID: `3b6ddad2`.
class PollAnswerVoters extends PollAnswerVotersBase {
  /// Poll Answer Voters constructor.
  const PollAnswerVoters({
    required this.chosen,
    required this.correct,
    required this.option,
    required this.voters,
  }) : super._();

  /// Deserialize.
  factory PollAnswerVoters.deserialize(BinaryReader reader) {
    // Read [PollAnswerVoters] fields.
    final flags = reader.readInt32();
    final chosen = (flags & 1) != 0;
    final correct = (flags & 2) != 0;
    final option = reader.readBytes();
    final voters = reader.readInt32();

    // Construct [PollAnswerVoters] object.
    final returnValue = PollAnswerVoters(
      chosen: chosen,
      correct: correct,
      option: option,
      voters: voters,
    );

    // Now return the deserialized [PollAnswerVoters].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: chosen,
      b01: correct,
    );

    return v;
  }

  /// chosen: bit 0 of flags.0?true
  final bool chosen;

  /// correct: bit 1 of flags.1?true
  final bool correct;

  /// Option.
  final Uint8List option;

  /// Voters.
  ///
  /// Field type is Int32.
  final int voters;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3b6ddad2.
    buffer.writeInt32(0x3b6ddad2);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeBytes(option);
    buffer.writeInt32(voters);

    // Finished serialization.
  }
}

/// Poll Results.
///
/// ID: `7adf2420`.
class PollResults extends PollResultsBase {
  /// Poll Results constructor.
  const PollResults({
    required this.min,
    this.results,
    this.totalVoters,
    this.recentVoters,
    this.solution,
    this.solutionEntities,
  }) : super._();

  /// Deserialize.
  factory PollResults.deserialize(BinaryReader reader) {
    // Read [PollResults] fields.
    final flags = reader.readInt32();
    final min = (flags & 1) != 0;
    final hasResultsField = (flags & 2) != 0;
    final results = hasResultsField
        ? reader.readVectorObject<PollAnswerVotersBase>()
        : null;
    final hasTotalVotersField = (flags & 4) != 0;
    final totalVoters = hasTotalVotersField ? reader.readInt32() : null;
    final hasRecentVotersField = (flags & 8) != 0;
    final recentVoters =
        hasRecentVotersField ? reader.readVectorObject<PeerBase>() : null;
    final hasSolutionField = (flags & 16) != 0;
    final solution = hasSolutionField ? reader.readString() : null;
    final hasSolutionEntitiesField = (flags & 16) != 0;
    final solutionEntities = hasSolutionEntitiesField
        ? reader.readVectorObject<MessageEntityBase>()
        : null;

    // Construct [PollResults] object.
    final returnValue = PollResults(
      min: min,
      results: results,
      totalVoters: totalVoters,
      recentVoters: recentVoters,
      solution: solution,
      solutionEntities: solutionEntities,
    );

    // Now return the deserialized [PollResults].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: min,
      b01: results != null,
      b02: totalVoters != null,
      b03: recentVoters != null,
      b04: solution != null || solutionEntities != null,
    );

    return v;
  }

  /// min: bit 0 of flags.0?true
  final bool min;

  /// Results.
  final List<PollAnswerVotersBase>? results;

  /// Total Voters.
  final int? totalVoters;

  /// Recent Voters.
  final List<PeerBase>? recentVoters;

  /// Solution.
  final String? solution;

  /// Solution Entities.
  final List<MessageEntityBase>? solutionEntities;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7adf2420.
    buffer.writeInt32(0x7adf2420);

    // Write fields.
    buffer.writeInt32(flags);
    final localResultsCopy = results;
    if (localResultsCopy != null) {
      buffer.writeVectorObject(localResultsCopy);
    }
    final localTotalVotersCopy = totalVoters;
    if (localTotalVotersCopy != null) {
      buffer.writeInt32(localTotalVotersCopy);
    }
    final localRecentVotersCopy = recentVoters;
    if (localRecentVotersCopy != null) {
      buffer.writeVectorObject(localRecentVotersCopy);
    }
    final localSolutionCopy = solution;
    if (localSolutionCopy != null) {
      buffer.writeString(localSolutionCopy);
    }
    final localSolutionEntitiesCopy = solutionEntities;
    if (localSolutionEntitiesCopy != null) {
      buffer.writeVectorObject(localSolutionEntitiesCopy);
    }

    // Finished serialization.
  }
}

/// Chat Onlines.
///
/// ID: `f041e250`.
class ChatOnlines extends ChatOnlinesBase {
  /// Chat Onlines constructor.
  const ChatOnlines({
    required this.onlines,
  }) : super._();

  /// Deserialize.
  factory ChatOnlines.deserialize(BinaryReader reader) {
    // Read [ChatOnlines] fields.
    final onlines = reader.readInt32();

    // Construct [ChatOnlines] object.
    final returnValue = ChatOnlines(
      onlines: onlines,
    );

    // Now return the deserialized [ChatOnlines].
    return returnValue;
  }

  /// Onlines.
  ///
  /// Field type is Int32.
  final int onlines;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf041e250.
    buffer.writeInt32(0xf041e250);

    // Write fields.
    buffer.writeInt32(onlines);

    // Finished serialization.
  }
}

/// Stats U R L.
///
/// ID: `47a971e0`.
class StatsURL extends StatsURLBase {
  /// Stats U R L constructor.
  const StatsURL({
    required this.url,
  }) : super._();

  /// Deserialize.
  factory StatsURL.deserialize(BinaryReader reader) {
    // Read [StatsURL] fields.
    final url = reader.readString();

    // Construct [StatsURL] object.
    final returnValue = StatsURL(
      url: url,
    );

    // Now return the deserialized [StatsURL].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x47a971e0.
    buffer.writeInt32(0x47a971e0);

    // Write fields.
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Chat Admin Rights.
///
/// ID: `5fb224d5`.
class ChatAdminRights extends ChatAdminRightsBase {
  /// Chat Admin Rights constructor.
  const ChatAdminRights({
    required this.changeInfo,
    required this.postMessages,
    required this.editMessages,
    required this.deleteMessages,
    required this.banUsers,
    required this.inviteUsers,
    required this.pinMessages,
    required this.addAdmins,
    required this.anonymous,
    required this.manageCall,
    required this.other,
    required this.manageTopics,
    required this.postStories,
    required this.editStories,
    required this.deleteStories,
  }) : super._();

  /// Deserialize.
  factory ChatAdminRights.deserialize(BinaryReader reader) {
    // Read [ChatAdminRights] fields.
    final flags = reader.readInt32();
    final changeInfo = (flags & 1) != 0;
    final postMessages = (flags & 2) != 0;
    final editMessages = (flags & 4) != 0;
    final deleteMessages = (flags & 8) != 0;
    final banUsers = (flags & 16) != 0;
    final inviteUsers = (flags & 32) != 0;
    final pinMessages = (flags & 128) != 0;
    final addAdmins = (flags & 512) != 0;
    final anonymous = (flags & 1024) != 0;
    final manageCall = (flags & 2048) != 0;
    final other = (flags & 4096) != 0;
    final manageTopics = (flags & 8192) != 0;
    final postStories = (flags & 16384) != 0;
    final editStories = (flags & 32768) != 0;
    final deleteStories = (flags & 65536) != 0;

    // Construct [ChatAdminRights] object.
    final returnValue = ChatAdminRights(
      changeInfo: changeInfo,
      postMessages: postMessages,
      editMessages: editMessages,
      deleteMessages: deleteMessages,
      banUsers: banUsers,
      inviteUsers: inviteUsers,
      pinMessages: pinMessages,
      addAdmins: addAdmins,
      anonymous: anonymous,
      manageCall: manageCall,
      other: other,
      manageTopics: manageTopics,
      postStories: postStories,
      editStories: editStories,
      deleteStories: deleteStories,
    );

    // Now return the deserialized [ChatAdminRights].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: changeInfo,
      b01: postMessages,
      b02: editMessages,
      b03: deleteMessages,
      b04: banUsers,
      b05: inviteUsers,
      b07: pinMessages,
      b09: addAdmins,
      b10: anonymous,
      b11: manageCall,
      b12: other,
      b13: manageTopics,
      b14: postStories,
      b15: editStories,
      b16: deleteStories,
    );

    return v;
  }

  /// change_info: bit 0 of flags.0?true
  final bool changeInfo;

  /// post_messages: bit 1 of flags.1?true
  final bool postMessages;

  /// edit_messages: bit 2 of flags.2?true
  final bool editMessages;

  /// delete_messages: bit 3 of flags.3?true
  final bool deleteMessages;

  /// ban_users: bit 4 of flags.4?true
  final bool banUsers;

  /// invite_users: bit 5 of flags.5?true
  final bool inviteUsers;

  /// pin_messages: bit 7 of flags.7?true
  final bool pinMessages;

  /// add_admins: bit 9 of flags.9?true
  final bool addAdmins;

  /// anonymous: bit 10 of flags.10?true
  final bool anonymous;

  /// manage_call: bit 11 of flags.11?true
  final bool manageCall;

  /// other: bit 12 of flags.12?true
  final bool other;

  /// manage_topics: bit 13 of flags.13?true
  final bool manageTopics;

  /// post_stories: bit 14 of flags.14?true
  final bool postStories;

  /// edit_stories: bit 15 of flags.15?true
  final bool editStories;

  /// delete_stories: bit 16 of flags.16?true
  final bool deleteStories;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5fb224d5.
    buffer.writeInt32(0x5fb224d5);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Chat Banned Rights.
///
/// ID: `9f120418`.
class ChatBannedRights extends ChatBannedRightsBase {
  /// Chat Banned Rights constructor.
  const ChatBannedRights({
    required this.viewMessages,
    required this.sendMessages,
    required this.sendMedia,
    required this.sendStickers,
    required this.sendGifs,
    required this.sendGames,
    required this.sendInline,
    required this.embedLinks,
    required this.sendPolls,
    required this.changeInfo,
    required this.inviteUsers,
    required this.pinMessages,
    required this.manageTopics,
    required this.sendPhotos,
    required this.sendVideos,
    required this.sendRoundvideos,
    required this.sendAudios,
    required this.sendVoices,
    required this.sendDocs,
    required this.sendPlain,
    required this.untilDate,
  }) : super._();

  /// Deserialize.
  factory ChatBannedRights.deserialize(BinaryReader reader) {
    // Read [ChatBannedRights] fields.
    final flags = reader.readInt32();
    final viewMessages = (flags & 1) != 0;
    final sendMessages = (flags & 2) != 0;
    final sendMedia = (flags & 4) != 0;
    final sendStickers = (flags & 8) != 0;
    final sendGifs = (flags & 16) != 0;
    final sendGames = (flags & 32) != 0;
    final sendInline = (flags & 64) != 0;
    final embedLinks = (flags & 128) != 0;
    final sendPolls = (flags & 256) != 0;
    final changeInfo = (flags & 1024) != 0;
    final inviteUsers = (flags & 32768) != 0;
    final pinMessages = (flags & 131072) != 0;
    final manageTopics = (flags & 262144) != 0;
    final sendPhotos = (flags & 524288) != 0;
    final sendVideos = (flags & 1048576) != 0;
    final sendRoundvideos = (flags & 2097152) != 0;
    final sendAudios = (flags & 4194304) != 0;
    final sendVoices = (flags & 8388608) != 0;
    final sendDocs = (flags & 16777216) != 0;
    final sendPlain = (flags & 33554432) != 0;
    final untilDate = reader.readDateTime();

    // Construct [ChatBannedRights] object.
    final returnValue = ChatBannedRights(
      viewMessages: viewMessages,
      sendMessages: sendMessages,
      sendMedia: sendMedia,
      sendStickers: sendStickers,
      sendGifs: sendGifs,
      sendGames: sendGames,
      sendInline: sendInline,
      embedLinks: embedLinks,
      sendPolls: sendPolls,
      changeInfo: changeInfo,
      inviteUsers: inviteUsers,
      pinMessages: pinMessages,
      manageTopics: manageTopics,
      sendPhotos: sendPhotos,
      sendVideos: sendVideos,
      sendRoundvideos: sendRoundvideos,
      sendAudios: sendAudios,
      sendVoices: sendVoices,
      sendDocs: sendDocs,
      sendPlain: sendPlain,
      untilDate: untilDate,
    );

    // Now return the deserialized [ChatBannedRights].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: viewMessages,
      b01: sendMessages,
      b02: sendMedia,
      b03: sendStickers,
      b04: sendGifs,
      b05: sendGames,
      b06: sendInline,
      b07: embedLinks,
      b08: sendPolls,
      b10: changeInfo,
      b15: inviteUsers,
      b17: pinMessages,
      b18: manageTopics,
      b19: sendPhotos,
      b20: sendVideos,
      b21: sendRoundvideos,
      b22: sendAudios,
      b23: sendVoices,
      b24: sendDocs,
      b25: sendPlain,
    );

    return v;
  }

  /// view_messages: bit 0 of flags.0?true
  final bool viewMessages;

  /// send_messages: bit 1 of flags.1?true
  final bool sendMessages;

  /// send_media: bit 2 of flags.2?true
  final bool sendMedia;

  /// send_stickers: bit 3 of flags.3?true
  final bool sendStickers;

  /// send_gifs: bit 4 of flags.4?true
  final bool sendGifs;

  /// send_games: bit 5 of flags.5?true
  final bool sendGames;

  /// send_inline: bit 6 of flags.6?true
  final bool sendInline;

  /// embed_links: bit 7 of flags.7?true
  final bool embedLinks;

  /// send_polls: bit 8 of flags.8?true
  final bool sendPolls;

  /// change_info: bit 10 of flags.10?true
  final bool changeInfo;

  /// invite_users: bit 15 of flags.15?true
  final bool inviteUsers;

  /// pin_messages: bit 17 of flags.17?true
  final bool pinMessages;

  /// manage_topics: bit 18 of flags.18?true
  final bool manageTopics;

  /// send_photos: bit 19 of flags.19?true
  final bool sendPhotos;

  /// send_videos: bit 20 of flags.20?true
  final bool sendVideos;

  /// send_roundvideos: bit 21 of flags.21?true
  final bool sendRoundvideos;

  /// send_audios: bit 22 of flags.22?true
  final bool sendAudios;

  /// send_voices: bit 23 of flags.23?true
  final bool sendVoices;

  /// send_docs: bit 24 of flags.24?true
  final bool sendDocs;

  /// send_plain: bit 25 of flags.25?true
  final bool sendPlain;

  /// Until Date.
  final DateTime untilDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9f120418.
    buffer.writeInt32(0x9f120418);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeDateTime(untilDate);

    // Finished serialization.
  }
}

/// Input Wall Paper.
///
/// ID: `e630b979`.
class InputWallPaper extends InputWallPaperBase {
  /// Input Wall Paper constructor.
  const InputWallPaper({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputWallPaper.deserialize(BinaryReader reader) {
    // Read [InputWallPaper] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputWallPaper] object.
    final returnValue = InputWallPaper(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputWallPaper].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe630b979.
    buffer.writeInt32(0xe630b979);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Wall Paper Slug.
///
/// ID: `72091c80`.
class InputWallPaperSlug extends InputWallPaperBase {
  /// Input Wall Paper Slug constructor.
  const InputWallPaperSlug({
    required this.slug,
  }) : super._();

  /// Deserialize.
  factory InputWallPaperSlug.deserialize(BinaryReader reader) {
    // Read [InputWallPaperSlug] fields.
    final slug = reader.readString();

    // Construct [InputWallPaperSlug] object.
    final returnValue = InputWallPaperSlug(
      slug: slug,
    );

    // Now return the deserialized [InputWallPaperSlug].
    return returnValue;
  }

  /// Slug.
  final String slug;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x72091c80.
    buffer.writeInt32(0x72091c80);

    // Write fields.
    buffer.writeString(slug);

    // Finished serialization.
  }
}

/// Input Wall Paper No File.
///
/// ID: `967a462e`.
class InputWallPaperNoFile extends InputWallPaperBase {
  /// Input Wall Paper No File constructor.
  const InputWallPaperNoFile({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory InputWallPaperNoFile.deserialize(BinaryReader reader) {
    // Read [InputWallPaperNoFile] fields.
    final id = reader.readInt64();

    // Construct [InputWallPaperNoFile] object.
    final returnValue = InputWallPaperNoFile(
      id: id,
    );

    // Now return the deserialized [InputWallPaperNoFile].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x967a462e.
    buffer.writeInt32(0x967a462e);

    // Write fields.
    buffer.writeInt64(id);

    // Finished serialization.
  }
}

/// Account Wall Papers Not Modified.
///
/// ID: `1c199183`.
class AccountWallPapersNotModified extends AccountWallPapersBase {
  /// Account Wall Papers Not Modified constructor.
  const AccountWallPapersNotModified() : super._();

  /// Deserialize.
  factory AccountWallPapersNotModified.deserialize(BinaryReader reader) {
    // Construct [AccountWallPapersNotModified] object.
    final returnValue = AccountWallPapersNotModified();

    // Now return the deserialized [AccountWallPapersNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1c199183.
    buffer.writeInt32(0x1c199183);

    // Finished serialization.
  }
}

/// Account Wall Papers.
///
/// ID: `cdc3858c`.
class AccountWallPapers extends AccountWallPapersBase {
  /// Account Wall Papers constructor.
  const AccountWallPapers({
    required this.hash,
    required this.wallpapers,
  }) : super._();

  /// Deserialize.
  factory AccountWallPapers.deserialize(BinaryReader reader) {
    // Read [AccountWallPapers] fields.
    final hash = reader.readInt64();
    final wallpapers = reader.readVectorObject<WallPaperBase>();

    // Construct [AccountWallPapers] object.
    final returnValue = AccountWallPapers(
      hash: hash,
      wallpapers: wallpapers,
    );

    // Now return the deserialized [AccountWallPapers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Wallpapers.
  final List<WallPaperBase> wallpapers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcdc3858c.
    buffer.writeInt32(0xcdc3858c);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(wallpapers);

    // Finished serialization.
  }
}

/// Code Settings.
///
/// ID: `ad253d78`.
class CodeSettings extends CodeSettingsBase {
  /// Code Settings constructor.
  const CodeSettings({
    required this.allowFlashcall,
    required this.currentNumber,
    required this.allowAppHash,
    required this.allowMissedCall,
    required this.allowFirebase,
    this.logoutTokens,
    this.token,
    required this.appSandbox,
  }) : super._();

  /// Deserialize.
  factory CodeSettings.deserialize(BinaryReader reader) {
    // Read [CodeSettings] fields.
    final flags = reader.readInt32();
    final allowFlashcall = (flags & 1) != 0;
    final currentNumber = (flags & 2) != 0;
    final allowAppHash = (flags & 16) != 0;
    final allowMissedCall = (flags & 32) != 0;
    final allowFirebase = (flags & 128) != 0;
    final hasLogoutTokensField = (flags & 64) != 0;
    final logoutTokens = hasLogoutTokensField ? reader.readVectorBytes() : null;
    final hasTokenField = (flags & 256) != 0;
    final token = hasTokenField ? reader.readString() : null;
    final appSandbox = (flags & 256) != 0;

    // Construct [CodeSettings] object.
    final returnValue = CodeSettings(
      allowFlashcall: allowFlashcall,
      currentNumber: currentNumber,
      allowAppHash: allowAppHash,
      allowMissedCall: allowMissedCall,
      allowFirebase: allowFirebase,
      logoutTokens: logoutTokens,
      token: token,
      appSandbox: appSandbox,
    );

    // Now return the deserialized [CodeSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: allowFlashcall,
      b01: currentNumber,
      b04: allowAppHash,
      b05: allowMissedCall,
      b07: allowFirebase,
      b06: logoutTokens != null,
      b08: token != null || appSandbox,
    );

    return v;
  }

  /// allow_flashcall: bit 0 of flags.0?true
  final bool allowFlashcall;

  /// current_number: bit 1 of flags.1?true
  final bool currentNumber;

  /// allow_app_hash: bit 4 of flags.4?true
  final bool allowAppHash;

  /// allow_missed_call: bit 5 of flags.5?true
  final bool allowMissedCall;

  /// allow_firebase: bit 7 of flags.7?true
  final bool allowFirebase;

  /// Logout Tokens.
  final List<Uint8List>? logoutTokens;

  /// Token.
  final String? token;

  /// app_sandbox: bit 8 of flags.8?Bool
  final bool appSandbox;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xad253d78.
    buffer.writeInt32(0xad253d78);

    // Write fields.
    buffer.writeInt32(flags);
    final localLogoutTokensCopy = logoutTokens;
    if (localLogoutTokensCopy != null) {
      buffer.writeVectorBytes(localLogoutTokensCopy);
    }
    final localTokenCopy = token;
    if (localTokenCopy != null) {
      buffer.writeString(localTokenCopy);
    }

    // Finished serialization.
  }
}

/// Wall Paper Settings.
///
/// ID: `372efcd0`.
class WallPaperSettings extends WallPaperSettingsBase {
  /// Wall Paper Settings constructor.
  const WallPaperSettings({
    required this.blur,
    required this.motion,
    this.backgroundColor,
    this.secondBackgroundColor,
    this.thirdBackgroundColor,
    this.fourthBackgroundColor,
    this.intensity,
    this.rotation,
    this.emoticon,
  }) : super._();

  /// Deserialize.
  factory WallPaperSettings.deserialize(BinaryReader reader) {
    // Read [WallPaperSettings] fields.
    final flags = reader.readInt32();
    final blur = (flags & 2) != 0;
    final motion = (flags & 4) != 0;
    final hasBackgroundColorField = (flags & 1) != 0;
    final backgroundColor = hasBackgroundColorField ? reader.readInt32() : null;
    final hasSecondBackgroundColorField = (flags & 16) != 0;
    final secondBackgroundColor =
        hasSecondBackgroundColorField ? reader.readInt32() : null;
    final hasThirdBackgroundColorField = (flags & 32) != 0;
    final thirdBackgroundColor =
        hasThirdBackgroundColorField ? reader.readInt32() : null;
    final hasFourthBackgroundColorField = (flags & 64) != 0;
    final fourthBackgroundColor =
        hasFourthBackgroundColorField ? reader.readInt32() : null;
    final hasIntensityField = (flags & 8) != 0;
    final intensity = hasIntensityField ? reader.readInt32() : null;
    final hasRotationField = (flags & 16) != 0;
    final rotation = hasRotationField ? reader.readInt32() : null;
    final hasEmoticonField = (flags & 128) != 0;
    final emoticon = hasEmoticonField ? reader.readString() : null;

    // Construct [WallPaperSettings] object.
    final returnValue = WallPaperSettings(
      blur: blur,
      motion: motion,
      backgroundColor: backgroundColor,
      secondBackgroundColor: secondBackgroundColor,
      thirdBackgroundColor: thirdBackgroundColor,
      fourthBackgroundColor: fourthBackgroundColor,
      intensity: intensity,
      rotation: rotation,
      emoticon: emoticon,
    );

    // Now return the deserialized [WallPaperSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: blur,
      b02: motion,
      b00: backgroundColor != null,
      b04: secondBackgroundColor != null || rotation != null,
      b05: thirdBackgroundColor != null,
      b06: fourthBackgroundColor != null,
      b03: intensity != null,
      b07: emoticon != null,
    );

    return v;
  }

  /// blur: bit 1 of flags.1?true
  final bool blur;

  /// motion: bit 2 of flags.2?true
  final bool motion;

  /// Background Color.
  final int? backgroundColor;

  /// Second Background Color.
  final int? secondBackgroundColor;

  /// Third Background Color.
  final int? thirdBackgroundColor;

  /// Fourth Background Color.
  final int? fourthBackgroundColor;

  /// Intensity.
  final int? intensity;

  /// Rotation.
  final int? rotation;

  /// Emoticon.
  final String? emoticon;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x372efcd0.
    buffer.writeInt32(0x372efcd0);

    // Write fields.
    buffer.writeInt32(flags);
    final localBackgroundColorCopy = backgroundColor;
    if (localBackgroundColorCopy != null) {
      buffer.writeInt32(localBackgroundColorCopy);
    }
    final localSecondBackgroundColorCopy = secondBackgroundColor;
    if (localSecondBackgroundColorCopy != null) {
      buffer.writeInt32(localSecondBackgroundColorCopy);
    }
    final localThirdBackgroundColorCopy = thirdBackgroundColor;
    if (localThirdBackgroundColorCopy != null) {
      buffer.writeInt32(localThirdBackgroundColorCopy);
    }
    final localFourthBackgroundColorCopy = fourthBackgroundColor;
    if (localFourthBackgroundColorCopy != null) {
      buffer.writeInt32(localFourthBackgroundColorCopy);
    }
    final localIntensityCopy = intensity;
    if (localIntensityCopy != null) {
      buffer.writeInt32(localIntensityCopy);
    }
    final localRotationCopy = rotation;
    if (localRotationCopy != null) {
      buffer.writeInt32(localRotationCopy);
    }
    final localEmoticonCopy = emoticon;
    if (localEmoticonCopy != null) {
      buffer.writeString(localEmoticonCopy);
    }

    // Finished serialization.
  }
}

/// Auto Download Settings.
///
/// ID: `baa57628`.
class AutoDownloadSettings extends AutoDownloadSettingsBase {
  /// Auto Download Settings constructor.
  const AutoDownloadSettings({
    required this.disabled,
    required this.videoPreloadLarge,
    required this.audioPreloadNext,
    required this.phonecallsLessData,
    required this.storiesPreload,
    required this.photoSizeMax,
    required this.videoSizeMax,
    required this.fileSizeMax,
    required this.videoUploadMaxbitrate,
    required this.smallQueueActiveOperationsMax,
    required this.largeQueueActiveOperationsMax,
  }) : super._();

  /// Deserialize.
  factory AutoDownloadSettings.deserialize(BinaryReader reader) {
    // Read [AutoDownloadSettings] fields.
    final flags = reader.readInt32();
    final disabled = (flags & 1) != 0;
    final videoPreloadLarge = (flags & 2) != 0;
    final audioPreloadNext = (flags & 4) != 0;
    final phonecallsLessData = (flags & 8) != 0;
    final storiesPreload = (flags & 16) != 0;
    final photoSizeMax = reader.readInt32();
    final videoSizeMax = reader.readInt64();
    final fileSizeMax = reader.readInt64();
    final videoUploadMaxbitrate = reader.readInt32();
    final smallQueueActiveOperationsMax = reader.readInt32();
    final largeQueueActiveOperationsMax = reader.readInt32();

    // Construct [AutoDownloadSettings] object.
    final returnValue = AutoDownloadSettings(
      disabled: disabled,
      videoPreloadLarge: videoPreloadLarge,
      audioPreloadNext: audioPreloadNext,
      phonecallsLessData: phonecallsLessData,
      storiesPreload: storiesPreload,
      photoSizeMax: photoSizeMax,
      videoSizeMax: videoSizeMax,
      fileSizeMax: fileSizeMax,
      videoUploadMaxbitrate: videoUploadMaxbitrate,
      smallQueueActiveOperationsMax: smallQueueActiveOperationsMax,
      largeQueueActiveOperationsMax: largeQueueActiveOperationsMax,
    );

    // Now return the deserialized [AutoDownloadSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: disabled,
      b01: videoPreloadLarge,
      b02: audioPreloadNext,
      b03: phonecallsLessData,
      b04: storiesPreload,
    );

    return v;
  }

  /// disabled: bit 0 of flags.0?true
  final bool disabled;

  /// video_preload_large: bit 1 of flags.1?true
  final bool videoPreloadLarge;

  /// audio_preload_next: bit 2 of flags.2?true
  final bool audioPreloadNext;

  /// phonecalls_less_data: bit 3 of flags.3?true
  final bool phonecallsLessData;

  /// stories_preload: bit 4 of flags.4?true
  final bool storiesPreload;

  /// Photo Size Max.
  ///
  /// Field type is Int32.
  final int photoSizeMax;

  /// Video Size Max.
  ///
  /// Field type is Int64.
  final int videoSizeMax;

  /// File Size Max.
  ///
  /// Field type is Int64.
  final int fileSizeMax;

  /// Video Upload Maxbitrate.
  ///
  /// Field type is Int32.
  final int videoUploadMaxbitrate;

  /// Small Queue Active Operations Max.
  ///
  /// Field type is Int32.
  final int smallQueueActiveOperationsMax;

  /// Large Queue Active Operations Max.
  ///
  /// Field type is Int32.
  final int largeQueueActiveOperationsMax;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbaa57628.
    buffer.writeInt32(0xbaa57628);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(photoSizeMax);
    buffer.writeInt64(videoSizeMax);
    buffer.writeInt64(fileSizeMax);
    buffer.writeInt32(videoUploadMaxbitrate);
    buffer.writeInt32(smallQueueActiveOperationsMax);
    buffer.writeInt32(largeQueueActiveOperationsMax);

    // Finished serialization.
  }
}

/// Account Auto Download Settings.
///
/// ID: `63cacf26`.
class AccountAutoDownloadSettings extends AccountAutoDownloadSettingsBase {
  /// Account Auto Download Settings constructor.
  const AccountAutoDownloadSettings({
    required this.low,
    required this.medium,
    required this.high,
  }) : super._();

  /// Deserialize.
  factory AccountAutoDownloadSettings.deserialize(BinaryReader reader) {
    // Read [AccountAutoDownloadSettings] fields.
    final low = reader.readObject() as AutoDownloadSettingsBase;
    final medium = reader.readObject() as AutoDownloadSettingsBase;
    final high = reader.readObject() as AutoDownloadSettingsBase;

    // Construct [AccountAutoDownloadSettings] object.
    final returnValue = AccountAutoDownloadSettings(
      low: low,
      medium: medium,
      high: high,
    );

    // Now return the deserialized [AccountAutoDownloadSettings].
    return returnValue;
  }

  /// Low.
  final AutoDownloadSettingsBase low;

  /// Medium.
  final AutoDownloadSettingsBase medium;

  /// High.
  final AutoDownloadSettingsBase high;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x63cacf26.
    buffer.writeInt32(0x63cacf26);

    // Write fields.
    buffer.writeObject(low);
    buffer.writeObject(medium);
    buffer.writeObject(high);

    // Finished serialization.
  }
}

/// Emoji Keyword.
///
/// ID: `d5b3b9f9`.
class EmojiKeyword extends EmojiKeywordBase {
  /// Emoji Keyword constructor.
  const EmojiKeyword({
    required this.keyword,
    required this.emoticons,
  }) : super._();

  /// Deserialize.
  factory EmojiKeyword.deserialize(BinaryReader reader) {
    // Read [EmojiKeyword] fields.
    final keyword = reader.readString();
    final emoticons = reader.readVectorString();

    // Construct [EmojiKeyword] object.
    final returnValue = EmojiKeyword(
      keyword: keyword,
      emoticons: emoticons,
    );

    // Now return the deserialized [EmojiKeyword].
    return returnValue;
  }

  /// Keyword.
  final String keyword;

  /// Emoticons.
  final List<String> emoticons;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd5b3b9f9.
    buffer.writeInt32(0xd5b3b9f9);

    // Write fields.
    buffer.writeString(keyword);
    buffer.writeVectorString(emoticons);

    // Finished serialization.
  }
}

/// Emoji Keyword Deleted.
///
/// ID: `236df622`.
class EmojiKeywordDeleted extends EmojiKeywordBase {
  /// Emoji Keyword Deleted constructor.
  const EmojiKeywordDeleted({
    required this.keyword,
    required this.emoticons,
  }) : super._();

  /// Deserialize.
  factory EmojiKeywordDeleted.deserialize(BinaryReader reader) {
    // Read [EmojiKeywordDeleted] fields.
    final keyword = reader.readString();
    final emoticons = reader.readVectorString();

    // Construct [EmojiKeywordDeleted] object.
    final returnValue = EmojiKeywordDeleted(
      keyword: keyword,
      emoticons: emoticons,
    );

    // Now return the deserialized [EmojiKeywordDeleted].
    return returnValue;
  }

  /// Keyword.
  final String keyword;

  /// Emoticons.
  final List<String> emoticons;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x236df622.
    buffer.writeInt32(0x236df622);

    // Write fields.
    buffer.writeString(keyword);
    buffer.writeVectorString(emoticons);

    // Finished serialization.
  }
}

/// Emoji Keywords Difference.
///
/// ID: `5cc761bd`.
class EmojiKeywordsDifference extends EmojiKeywordsDifferenceBase {
  /// Emoji Keywords Difference constructor.
  const EmojiKeywordsDifference({
    required this.langCode,
    required this.fromVersion,
    required this.version,
    required this.keywords,
  }) : super._();

  /// Deserialize.
  factory EmojiKeywordsDifference.deserialize(BinaryReader reader) {
    // Read [EmojiKeywordsDifference] fields.
    final langCode = reader.readString();
    final fromVersion = reader.readInt32();
    final version = reader.readInt32();
    final keywords = reader.readVectorObject<EmojiKeywordBase>();

    // Construct [EmojiKeywordsDifference] object.
    final returnValue = EmojiKeywordsDifference(
      langCode: langCode,
      fromVersion: fromVersion,
      version: version,
      keywords: keywords,
    );

    // Now return the deserialized [EmojiKeywordsDifference].
    return returnValue;
  }

  /// Lang Code.
  final String langCode;

  /// From Version.
  ///
  /// Field type is Int32.
  final int fromVersion;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Keywords.
  final List<EmojiKeywordBase> keywords;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5cc761bd.
    buffer.writeInt32(0x5cc761bd);

    // Write fields.
    buffer.writeString(langCode);
    buffer.writeInt32(fromVersion);
    buffer.writeInt32(version);
    buffer.writeVectorObject(keywords);

    // Finished serialization.
  }
}

/// Emoji U R L.
///
/// ID: `a575739d`.
class EmojiURL extends EmojiURLBase {
  /// Emoji U R L constructor.
  const EmojiURL({
    required this.url,
  }) : super._();

  /// Deserialize.
  factory EmojiURL.deserialize(BinaryReader reader) {
    // Read [EmojiURL] fields.
    final url = reader.readString();

    // Construct [EmojiURL] object.
    final returnValue = EmojiURL(
      url: url,
    );

    // Now return the deserialized [EmojiURL].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa575739d.
    buffer.writeInt32(0xa575739d);

    // Write fields.
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Emoji Language.
///
/// ID: `b3fb5361`.
class EmojiLanguage extends EmojiLanguageBase {
  /// Emoji Language constructor.
  const EmojiLanguage({
    required this.langCode,
  }) : super._();

  /// Deserialize.
  factory EmojiLanguage.deserialize(BinaryReader reader) {
    // Read [EmojiLanguage] fields.
    final langCode = reader.readString();

    // Construct [EmojiLanguage] object.
    final returnValue = EmojiLanguage(
      langCode: langCode,
    );

    // Now return the deserialized [EmojiLanguage].
    return returnValue;
  }

  /// Lang Code.
  final String langCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb3fb5361.
    buffer.writeInt32(0xb3fb5361);

    // Write fields.
    buffer.writeString(langCode);

    // Finished serialization.
  }
}

/// Folder.
///
/// ID: `ff544e65`.
class Folder extends FolderBase {
  /// Folder constructor.
  const Folder({
    required this.autofillNewBroadcasts,
    required this.autofillPublicGroups,
    required this.autofillNewCorrespondents,
    required this.id,
    required this.title,
    this.photo,
  }) : super._();

  /// Deserialize.
  factory Folder.deserialize(BinaryReader reader) {
    // Read [Folder] fields.
    final flags = reader.readInt32();
    final autofillNewBroadcasts = (flags & 1) != 0;
    final autofillPublicGroups = (flags & 2) != 0;
    final autofillNewCorrespondents = (flags & 4) != 0;
    final id = reader.readInt32();
    final title = reader.readString();
    final hasPhotoField = (flags & 8) != 0;
    final photo = hasPhotoField ? reader.readObject() as ChatPhotoBase : null;

    // Construct [Folder] object.
    final returnValue = Folder(
      autofillNewBroadcasts: autofillNewBroadcasts,
      autofillPublicGroups: autofillPublicGroups,
      autofillNewCorrespondents: autofillNewCorrespondents,
      id: id,
      title: title,
      photo: photo,
    );

    // Now return the deserialized [Folder].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: autofillNewBroadcasts,
      b01: autofillPublicGroups,
      b02: autofillNewCorrespondents,
      b03: photo != null,
    );

    return v;
  }

  /// autofill_new_broadcasts: bit 0 of flags.0?true
  final bool autofillNewBroadcasts;

  /// autofill_public_groups: bit 1 of flags.1?true
  final bool autofillPublicGroups;

  /// autofill_new_correspondents: bit 2 of flags.2?true
  final bool autofillNewCorrespondents;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Title.
  final String title;

  /// Photo.
  final ChatPhotoBase? photo;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xff544e65.
    buffer.writeInt32(0xff544e65);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeString(title);
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }

    // Finished serialization.
  }
}

/// Input Folder Peer.
///
/// ID: `fbd2c296`.
class InputFolderPeer extends InputFolderPeerBase {
  /// Input Folder Peer constructor.
  const InputFolderPeer({
    required this.peer,
    required this.folderId,
  }) : super._();

  /// Deserialize.
  factory InputFolderPeer.deserialize(BinaryReader reader) {
    // Read [InputFolderPeer] fields.
    final peer = reader.readObject() as InputPeerBase;
    final folderId = reader.readInt32();

    // Construct [InputFolderPeer] object.
    final returnValue = InputFolderPeer(
      peer: peer,
      folderId: folderId,
    );

    // Now return the deserialized [InputFolderPeer].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Folder Id.
  ///
  /// Field type is Int32.
  final int folderId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfbd2c296.
    buffer.writeInt32(0xfbd2c296);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(folderId);

    // Finished serialization.
  }
}

/// Folder Peer.
///
/// ID: `e9baa668`.
class FolderPeer extends FolderPeerBase {
  /// Folder Peer constructor.
  const FolderPeer({
    required this.peer,
    required this.folderId,
  }) : super._();

  /// Deserialize.
  factory FolderPeer.deserialize(BinaryReader reader) {
    // Read [FolderPeer] fields.
    final peer = reader.readObject() as PeerBase;
    final folderId = reader.readInt32();

    // Construct [FolderPeer] object.
    final returnValue = FolderPeer(
      peer: peer,
      folderId: folderId,
    );

    // Now return the deserialized [FolderPeer].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Folder Id.
  ///
  /// Field type is Int32.
  final int folderId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe9baa668.
    buffer.writeInt32(0xe9baa668);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(folderId);

    // Finished serialization.
  }
}

/// Messages Search Counter.
///
/// ID: `e844ebff`.
class MessagesSearchCounter extends MessagesSearchCounterBase {
  /// Messages Search Counter constructor.
  const MessagesSearchCounter({
    required this.inexact,
    required this.filter,
    required this.count,
  }) : super._();

  /// Deserialize.
  factory MessagesSearchCounter.deserialize(BinaryReader reader) {
    // Read [MessagesSearchCounter] fields.
    final flags = reader.readInt32();
    final inexact = (flags & 2) != 0;
    final filter = reader.readObject() as MessagesFilterBase;
    final count = reader.readInt32();

    // Construct [MessagesSearchCounter] object.
    final returnValue = MessagesSearchCounter(
      inexact: inexact,
      filter: filter,
      count: count,
    );

    // Now return the deserialized [MessagesSearchCounter].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: inexact,
    );

    return v;
  }

  /// inexact: bit 1 of flags.1?true
  final bool inexact;

  /// Filter.
  final MessagesFilterBase filter;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe844ebff.
    buffer.writeInt32(0xe844ebff);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(filter);
    buffer.writeInt32(count);

    // Finished serialization.
  }
}

/// Url Auth Result Request.
///
/// ID: `92d33a0e`.
class UrlAuthResultRequest extends UrlAuthResultBase {
  /// Url Auth Result Request constructor.
  const UrlAuthResultRequest({
    required this.requestWriteAccess,
    required this.bot,
    required this.domain,
  }) : super._();

  /// Deserialize.
  factory UrlAuthResultRequest.deserialize(BinaryReader reader) {
    // Read [UrlAuthResultRequest] fields.
    final flags = reader.readInt32();
    final requestWriteAccess = (flags & 1) != 0;
    final bot = reader.readObject() as UserBase;
    final domain = reader.readString();

    // Construct [UrlAuthResultRequest] object.
    final returnValue = UrlAuthResultRequest(
      requestWriteAccess: requestWriteAccess,
      bot: bot,
      domain: domain,
    );

    // Now return the deserialized [UrlAuthResultRequest].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: requestWriteAccess,
    );

    return v;
  }

  /// request_write_access: bit 0 of flags.0?true
  final bool requestWriteAccess;

  /// Bot.
  final UserBase bot;

  /// Domain.
  final String domain;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x92d33a0e.
    buffer.writeInt32(0x92d33a0e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(bot);
    buffer.writeString(domain);

    // Finished serialization.
  }
}

/// Url Auth Result Accepted.
///
/// ID: `8f8c0e4e`.
class UrlAuthResultAccepted extends UrlAuthResultBase {
  /// Url Auth Result Accepted constructor.
  const UrlAuthResultAccepted({
    required this.url,
  }) : super._();

  /// Deserialize.
  factory UrlAuthResultAccepted.deserialize(BinaryReader reader) {
    // Read [UrlAuthResultAccepted] fields.
    final url = reader.readString();

    // Construct [UrlAuthResultAccepted] object.
    final returnValue = UrlAuthResultAccepted(
      url: url,
    );

    // Now return the deserialized [UrlAuthResultAccepted].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8f8c0e4e.
    buffer.writeInt32(0x8f8c0e4e);

    // Write fields.
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Url Auth Result Default.
///
/// ID: `a9d6db1f`.
class UrlAuthResultDefault extends UrlAuthResultBase {
  /// Url Auth Result Default constructor.
  const UrlAuthResultDefault() : super._();

  /// Deserialize.
  factory UrlAuthResultDefault.deserialize(BinaryReader reader) {
    // Construct [UrlAuthResultDefault] object.
    final returnValue = UrlAuthResultDefault();

    // Now return the deserialized [UrlAuthResultDefault].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa9d6db1f.
    buffer.writeInt32(0xa9d6db1f);

    // Finished serialization.
  }
}

/// Channel Location Empty.
///
/// ID: `bfb5ad8b`.
class ChannelLocationEmpty extends ChannelLocationBase {
  /// Channel Location Empty constructor.
  const ChannelLocationEmpty() : super._();

  /// Deserialize.
  factory ChannelLocationEmpty.deserialize(BinaryReader reader) {
    // Construct [ChannelLocationEmpty] object.
    final returnValue = ChannelLocationEmpty();

    // Now return the deserialized [ChannelLocationEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbfb5ad8b.
    buffer.writeInt32(0xbfb5ad8b);

    // Finished serialization.
  }
}

/// Channel Location.
///
/// ID: `209b82db`.
class ChannelLocation extends ChannelLocationBase {
  /// Channel Location constructor.
  const ChannelLocation({
    required this.geoPoint,
    required this.address,
  }) : super._();

  /// Deserialize.
  factory ChannelLocation.deserialize(BinaryReader reader) {
    // Read [ChannelLocation] fields.
    final geoPoint = reader.readObject() as GeoPointBase;
    final address = reader.readString();

    // Construct [ChannelLocation] object.
    final returnValue = ChannelLocation(
      geoPoint: geoPoint,
      address: address,
    );

    // Now return the deserialized [ChannelLocation].
    return returnValue;
  }

  /// Geo Point.
  final GeoPointBase geoPoint;

  /// Address.
  final String address;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x209b82db.
    buffer.writeInt32(0x209b82db);

    // Write fields.
    buffer.writeObject(geoPoint);
    buffer.writeString(address);

    // Finished serialization.
  }
}

/// Peer Located.
///
/// ID: `ca461b5d`.
class PeerLocated extends PeerLocatedBase {
  /// Peer Located constructor.
  const PeerLocated({
    required this.peer,
    required this.expires,
    required this.distance,
  }) : super._();

  /// Deserialize.
  factory PeerLocated.deserialize(BinaryReader reader) {
    // Read [PeerLocated] fields.
    final peer = reader.readObject() as PeerBase;
    final expires = reader.readInt32();
    final distance = reader.readInt32();

    // Construct [PeerLocated] object.
    final returnValue = PeerLocated(
      peer: peer,
      expires: expires,
      distance: distance,
    );

    // Now return the deserialized [PeerLocated].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Distance.
  ///
  /// Field type is Int32.
  final int distance;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xca461b5d.
    buffer.writeInt32(0xca461b5d);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(expires);
    buffer.writeInt32(distance);

    // Finished serialization.
  }
}

/// Peer Self Located.
///
/// ID: `f8ec284b`.
class PeerSelfLocated extends PeerLocatedBase {
  /// Peer Self Located constructor.
  const PeerSelfLocated({
    required this.expires,
  }) : super._();

  /// Deserialize.
  factory PeerSelfLocated.deserialize(BinaryReader reader) {
    // Read [PeerSelfLocated] fields.
    final expires = reader.readInt32();

    // Construct [PeerSelfLocated] object.
    final returnValue = PeerSelfLocated(
      expires: expires,
    );

    // Now return the deserialized [PeerSelfLocated].
    return returnValue;
  }

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf8ec284b.
    buffer.writeInt32(0xf8ec284b);

    // Write fields.
    buffer.writeInt32(expires);

    // Finished serialization.
  }
}

/// Restriction Reason.
///
/// ID: `d072acb4`.
class RestrictionReason extends RestrictionReasonBase {
  /// Restriction Reason constructor.
  const RestrictionReason({
    required this.platform,
    required this.reason,
    required this.text,
  }) : super._();

  /// Deserialize.
  factory RestrictionReason.deserialize(BinaryReader reader) {
    // Read [RestrictionReason] fields.
    final platform = reader.readString();
    final reason = reader.readString();
    final text = reader.readString();

    // Construct [RestrictionReason] object.
    final returnValue = RestrictionReason(
      platform: platform,
      reason: reason,
      text: text,
    );

    // Now return the deserialized [RestrictionReason].
    return returnValue;
  }

  /// Platform.
  final String platform;

  /// Reason.
  final String reason;

  /// Text.
  final String text;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd072acb4.
    buffer.writeInt32(0xd072acb4);

    // Write fields.
    buffer.writeString(platform);
    buffer.writeString(reason);
    buffer.writeString(text);

    // Finished serialization.
  }
}

/// Input Theme.
///
/// ID: `3c5693e9`.
class InputTheme extends InputThemeBase {
  /// Input Theme constructor.
  const InputTheme({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputTheme.deserialize(BinaryReader reader) {
    // Read [InputTheme] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputTheme] object.
    final returnValue = InputTheme(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputTheme].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3c5693e9.
    buffer.writeInt32(0x3c5693e9);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Theme Slug.
///
/// ID: `f5890df1`.
class InputThemeSlug extends InputThemeBase {
  /// Input Theme Slug constructor.
  const InputThemeSlug({
    required this.slug,
  }) : super._();

  /// Deserialize.
  factory InputThemeSlug.deserialize(BinaryReader reader) {
    // Read [InputThemeSlug] fields.
    final slug = reader.readString();

    // Construct [InputThemeSlug] object.
    final returnValue = InputThemeSlug(
      slug: slug,
    );

    // Now return the deserialized [InputThemeSlug].
    return returnValue;
  }

  /// Slug.
  final String slug;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf5890df1.
    buffer.writeInt32(0xf5890df1);

    // Write fields.
    buffer.writeString(slug);

    // Finished serialization.
  }
}

/// Theme.
///
/// ID: `a00e67d6`.
class Theme extends ThemeBase {
  /// Theme constructor.
  const Theme({
    required this.creator,
    required this.ddefault,
    required this.forChat,
    required this.id,
    required this.accessHash,
    required this.slug,
    required this.title,
    this.document,
    this.settings,
    this.emoticon,
    this.installsCount,
  }) : super._();

  /// Deserialize.
  factory Theme.deserialize(BinaryReader reader) {
    // Read [Theme] fields.
    final flags = reader.readInt32();
    final creator = (flags & 1) != 0;
    final ddefault = (flags & 2) != 0;
    final forChat = (flags & 32) != 0;
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final slug = reader.readString();
    final title = reader.readString();
    final hasDocumentField = (flags & 4) != 0;
    final document =
        hasDocumentField ? reader.readObject() as DocumentBase : null;
    final hasSettingsField = (flags & 8) != 0;
    final settings =
        hasSettingsField ? reader.readVectorObject<ThemeSettingsBase>() : null;
    final hasEmoticonField = (flags & 64) != 0;
    final emoticon = hasEmoticonField ? reader.readString() : null;
    final hasInstallsCountField = (flags & 16) != 0;
    final installsCount = hasInstallsCountField ? reader.readInt32() : null;

    // Construct [Theme] object.
    final returnValue = Theme(
      creator: creator,
      ddefault: ddefault,
      forChat: forChat,
      id: id,
      accessHash: accessHash,
      slug: slug,
      title: title,
      document: document,
      settings: settings,
      emoticon: emoticon,
      installsCount: installsCount,
    );

    // Now return the deserialized [Theme].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: creator,
      b01: ddefault,
      b05: forChat,
      b02: document != null,
      b03: settings != null,
      b06: emoticon != null,
      b04: installsCount != null,
    );

    return v;
  }

  /// creator: bit 0 of flags.0?true
  final bool creator;

  /// default: bit 1 of flags.1?true
  final bool ddefault;

  /// for_chat: bit 5 of flags.5?true
  final bool forChat;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Slug.
  final String slug;

  /// Title.
  final String title;

  /// Document.
  final DocumentBase? document;

  /// Settings.
  final List<ThemeSettingsBase>? settings;

  /// Emoticon.
  final String? emoticon;

  /// Installs Count.
  final int? installsCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa00e67d6.
    buffer.writeInt32(0xa00e67d6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeString(slug);
    buffer.writeString(title);
    final localDocumentCopy = document;
    if (localDocumentCopy != null) {
      buffer.writeObject(localDocumentCopy);
    }
    final localSettingsCopy = settings;
    if (localSettingsCopy != null) {
      buffer.writeVectorObject(localSettingsCopy);
    }
    final localEmoticonCopy = emoticon;
    if (localEmoticonCopy != null) {
      buffer.writeString(localEmoticonCopy);
    }
    final localInstallsCountCopy = installsCount;
    if (localInstallsCountCopy != null) {
      buffer.writeInt32(localInstallsCountCopy);
    }

    // Finished serialization.
  }
}

/// Account Themes Not Modified.
///
/// ID: `f41eb622`.
class AccountThemesNotModified extends AccountThemesBase {
  /// Account Themes Not Modified constructor.
  const AccountThemesNotModified() : super._();

  /// Deserialize.
  factory AccountThemesNotModified.deserialize(BinaryReader reader) {
    // Construct [AccountThemesNotModified] object.
    final returnValue = AccountThemesNotModified();

    // Now return the deserialized [AccountThemesNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf41eb622.
    buffer.writeInt32(0xf41eb622);

    // Finished serialization.
  }
}

/// Account Themes.
///
/// ID: `9a3d8c6d`.
class AccountThemes extends AccountThemesBase {
  /// Account Themes constructor.
  const AccountThemes({
    required this.hash,
    required this.themes,
  }) : super._();

  /// Deserialize.
  factory AccountThemes.deserialize(BinaryReader reader) {
    // Read [AccountThemes] fields.
    final hash = reader.readInt64();
    final themes = reader.readVectorObject<ThemeBase>();

    // Construct [AccountThemes] object.
    final returnValue = AccountThemes(
      hash: hash,
      themes: themes,
    );

    // Now return the deserialized [AccountThemes].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Themes.
  final List<ThemeBase> themes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9a3d8c6d.
    buffer.writeInt32(0x9a3d8c6d);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(themes);

    // Finished serialization.
  }
}

/// Auth Login Token.
///
/// ID: `629f1980`.
class AuthLoginToken extends AuthLoginTokenBase {
  /// Auth Login Token constructor.
  const AuthLoginToken({
    required this.expires,
    required this.token,
  }) : super._();

  /// Deserialize.
  factory AuthLoginToken.deserialize(BinaryReader reader) {
    // Read [AuthLoginToken] fields.
    final expires = reader.readInt32();
    final token = reader.readBytes();

    // Construct [AuthLoginToken] object.
    final returnValue = AuthLoginToken(
      expires: expires,
      token: token,
    );

    // Now return the deserialized [AuthLoginToken].
    return returnValue;
  }

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Token.
  final Uint8List token;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x629f1980.
    buffer.writeInt32(0x629f1980);

    // Write fields.
    buffer.writeInt32(expires);
    buffer.writeBytes(token);

    // Finished serialization.
  }
}

/// Auth Login Token Migrate To.
///
/// ID: `068e9916`.
class AuthLoginTokenMigrateTo extends AuthLoginTokenBase {
  /// Auth Login Token Migrate To constructor.
  const AuthLoginTokenMigrateTo({
    required this.dcId,
    required this.token,
  }) : super._();

  /// Deserialize.
  factory AuthLoginTokenMigrateTo.deserialize(BinaryReader reader) {
    // Read [AuthLoginTokenMigrateTo] fields.
    final dcId = reader.readInt32();
    final token = reader.readBytes();

    // Construct [AuthLoginTokenMigrateTo] object.
    final returnValue = AuthLoginTokenMigrateTo(
      dcId: dcId,
      token: token,
    );

    // Now return the deserialized [AuthLoginTokenMigrateTo].
    return returnValue;
  }

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Token.
  final Uint8List token;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x068e9916.
    buffer.writeInt32(0x068e9916);

    // Write fields.
    buffer.writeInt32(dcId);
    buffer.writeBytes(token);

    // Finished serialization.
  }
}

/// Auth Login Token Success.
///
/// ID: `390d5c5e`.
class AuthLoginTokenSuccess extends AuthLoginTokenBase {
  /// Auth Login Token Success constructor.
  const AuthLoginTokenSuccess({
    required this.authorization,
  }) : super._();

  /// Deserialize.
  factory AuthLoginTokenSuccess.deserialize(BinaryReader reader) {
    // Read [AuthLoginTokenSuccess] fields.
    final authorization = reader.readObject() as AuthAuthorizationBase;

    // Construct [AuthLoginTokenSuccess] object.
    final returnValue = AuthLoginTokenSuccess(
      authorization: authorization,
    );

    // Now return the deserialized [AuthLoginTokenSuccess].
    return returnValue;
  }

  /// Authorization.
  final AuthAuthorizationBase authorization;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x390d5c5e.
    buffer.writeInt32(0x390d5c5e);

    // Write fields.
    buffer.writeObject(authorization);

    // Finished serialization.
  }
}

/// Account Content Settings.
///
/// ID: `57e28221`.
class AccountContentSettings extends AccountContentSettingsBase {
  /// Account Content Settings constructor.
  const AccountContentSettings({
    required this.sensitiveEnabled,
    required this.sensitiveCanChange,
  }) : super._();

  /// Deserialize.
  factory AccountContentSettings.deserialize(BinaryReader reader) {
    // Read [AccountContentSettings] fields.
    final flags = reader.readInt32();
    final sensitiveEnabled = (flags & 1) != 0;
    final sensitiveCanChange = (flags & 2) != 0;

    // Construct [AccountContentSettings] object.
    final returnValue = AccountContentSettings(
      sensitiveEnabled: sensitiveEnabled,
      sensitiveCanChange: sensitiveCanChange,
    );

    // Now return the deserialized [AccountContentSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: sensitiveEnabled,
      b01: sensitiveCanChange,
    );

    return v;
  }

  /// sensitive_enabled: bit 0 of flags.0?true
  final bool sensitiveEnabled;

  /// sensitive_can_change: bit 1 of flags.1?true
  final bool sensitiveCanChange;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x57e28221.
    buffer.writeInt32(0x57e28221);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Messages Inactive Chats.
///
/// ID: `a927fec5`.
class MessagesInactiveChats extends MessagesInactiveChatsBase {
  /// Messages Inactive Chats constructor.
  const MessagesInactiveChats({
    required this.dates,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesInactiveChats.deserialize(BinaryReader reader) {
    // Read [MessagesInactiveChats] fields.
    final dates = reader.readVectorInt32();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesInactiveChats] object.
    final returnValue = MessagesInactiveChats(
      dates: dates,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesInactiveChats].
    return returnValue;
  }

  /// Dates.
  final List<int> dates;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa927fec5.
    buffer.writeInt32(0xa927fec5);

    // Write fields.
    buffer.writeVectorInt32(dates);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Base Theme Classic.
///
/// ID: `c3a12462`.
class BaseThemeClassic extends BaseThemeBase {
  /// Base Theme Classic constructor.
  const BaseThemeClassic() : super._();

  /// Deserialize.
  factory BaseThemeClassic.deserialize(BinaryReader reader) {
    // Construct [BaseThemeClassic] object.
    final returnValue = BaseThemeClassic();

    // Now return the deserialized [BaseThemeClassic].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc3a12462.
    buffer.writeInt32(0xc3a12462);

    // Finished serialization.
  }
}

/// Base Theme Day.
///
/// ID: `fbd81688`.
class BaseThemeDay extends BaseThemeBase {
  /// Base Theme Day constructor.
  const BaseThemeDay() : super._();

  /// Deserialize.
  factory BaseThemeDay.deserialize(BinaryReader reader) {
    // Construct [BaseThemeDay] object.
    final returnValue = BaseThemeDay();

    // Now return the deserialized [BaseThemeDay].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfbd81688.
    buffer.writeInt32(0xfbd81688);

    // Finished serialization.
  }
}

/// Base Theme Night.
///
/// ID: `b7b31ea8`.
class BaseThemeNight extends BaseThemeBase {
  /// Base Theme Night constructor.
  const BaseThemeNight() : super._();

  /// Deserialize.
  factory BaseThemeNight.deserialize(BinaryReader reader) {
    // Construct [BaseThemeNight] object.
    final returnValue = BaseThemeNight();

    // Now return the deserialized [BaseThemeNight].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb7b31ea8.
    buffer.writeInt32(0xb7b31ea8);

    // Finished serialization.
  }
}

/// Base Theme Tinted.
///
/// ID: `6d5f77ee`.
class BaseThemeTinted extends BaseThemeBase {
  /// Base Theme Tinted constructor.
  const BaseThemeTinted() : super._();

  /// Deserialize.
  factory BaseThemeTinted.deserialize(BinaryReader reader) {
    // Construct [BaseThemeTinted] object.
    final returnValue = BaseThemeTinted();

    // Now return the deserialized [BaseThemeTinted].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6d5f77ee.
    buffer.writeInt32(0x6d5f77ee);

    // Finished serialization.
  }
}

/// Base Theme Arctic.
///
/// ID: `5b11125a`.
class BaseThemeArctic extends BaseThemeBase {
  /// Base Theme Arctic constructor.
  const BaseThemeArctic() : super._();

  /// Deserialize.
  factory BaseThemeArctic.deserialize(BinaryReader reader) {
    // Construct [BaseThemeArctic] object.
    final returnValue = BaseThemeArctic();

    // Now return the deserialized [BaseThemeArctic].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5b11125a.
    buffer.writeInt32(0x5b11125a);

    // Finished serialization.
  }
}

/// Input Theme Settings.
///
/// ID: `8fde504f`.
class InputThemeSettings extends InputThemeSettingsBase {
  /// Input Theme Settings constructor.
  const InputThemeSettings({
    required this.messageColorsAnimated,
    required this.baseTheme,
    required this.accentColor,
    this.outboxAccentColor,
    this.messageColors,
    this.wallpaper,
    this.wallpaperSettings,
  }) : super._();

  /// Deserialize.
  factory InputThemeSettings.deserialize(BinaryReader reader) {
    // Read [InputThemeSettings] fields.
    final flags = reader.readInt32();
    final messageColorsAnimated = (flags & 4) != 0;
    final baseTheme = reader.readObject() as BaseThemeBase;
    final accentColor = reader.readInt32();
    final hasOutboxAccentColorField = (flags & 8) != 0;
    final outboxAccentColor =
        hasOutboxAccentColorField ? reader.readInt32() : null;
    final hasMessageColorsField = (flags & 1) != 0;
    final messageColors =
        hasMessageColorsField ? reader.readVectorInt32() : null;
    final hasWallpaperField = (flags & 2) != 0;
    final wallpaper =
        hasWallpaperField ? reader.readObject() as InputWallPaperBase : null;
    final hasWallpaperSettingsField = (flags & 2) != 0;
    final wallpaperSettings = hasWallpaperSettingsField
        ? reader.readObject() as WallPaperSettingsBase
        : null;

    // Construct [InputThemeSettings] object.
    final returnValue = InputThemeSettings(
      messageColorsAnimated: messageColorsAnimated,
      baseTheme: baseTheme,
      accentColor: accentColor,
      outboxAccentColor: outboxAccentColor,
      messageColors: messageColors,
      wallpaper: wallpaper,
      wallpaperSettings: wallpaperSettings,
    );

    // Now return the deserialized [InputThemeSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: messageColorsAnimated,
      b03: outboxAccentColor != null,
      b00: messageColors != null,
      b01: wallpaper != null || wallpaperSettings != null,
    );

    return v;
  }

  /// message_colors_animated: bit 2 of flags.2?true
  final bool messageColorsAnimated;

  /// Base Theme.
  final BaseThemeBase baseTheme;

  /// Accent Color.
  ///
  /// Field type is Int32.
  final int accentColor;

  /// Outbox Accent Color.
  final int? outboxAccentColor;

  /// Message Colors.
  final List<int>? messageColors;

  /// Wallpaper.
  final InputWallPaperBase? wallpaper;

  /// Wallpaper Settings.
  final WallPaperSettingsBase? wallpaperSettings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8fde504f.
    buffer.writeInt32(0x8fde504f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(baseTheme);
    buffer.writeInt32(accentColor);
    final localOutboxAccentColorCopy = outboxAccentColor;
    if (localOutboxAccentColorCopy != null) {
      buffer.writeInt32(localOutboxAccentColorCopy);
    }
    final localMessageColorsCopy = messageColors;
    if (localMessageColorsCopy != null) {
      buffer.writeVectorInt32(localMessageColorsCopy);
    }
    final localWallpaperCopy = wallpaper;
    if (localWallpaperCopy != null) {
      buffer.writeObject(localWallpaperCopy);
    }
    final localWallpaperSettingsCopy = wallpaperSettings;
    if (localWallpaperSettingsCopy != null) {
      buffer.writeObject(localWallpaperSettingsCopy);
    }

    // Finished serialization.
  }
}

/// Theme Settings.
///
/// ID: `fa58b6d4`.
class ThemeSettings extends ThemeSettingsBase {
  /// Theme Settings constructor.
  const ThemeSettings({
    required this.messageColorsAnimated,
    required this.baseTheme,
    required this.accentColor,
    this.outboxAccentColor,
    this.messageColors,
    this.wallpaper,
  }) : super._();

  /// Deserialize.
  factory ThemeSettings.deserialize(BinaryReader reader) {
    // Read [ThemeSettings] fields.
    final flags = reader.readInt32();
    final messageColorsAnimated = (flags & 4) != 0;
    final baseTheme = reader.readObject() as BaseThemeBase;
    final accentColor = reader.readInt32();
    final hasOutboxAccentColorField = (flags & 8) != 0;
    final outboxAccentColor =
        hasOutboxAccentColorField ? reader.readInt32() : null;
    final hasMessageColorsField = (flags & 1) != 0;
    final messageColors =
        hasMessageColorsField ? reader.readVectorInt32() : null;
    final hasWallpaperField = (flags & 2) != 0;
    final wallpaper =
        hasWallpaperField ? reader.readObject() as WallPaperBase : null;

    // Construct [ThemeSettings] object.
    final returnValue = ThemeSettings(
      messageColorsAnimated: messageColorsAnimated,
      baseTheme: baseTheme,
      accentColor: accentColor,
      outboxAccentColor: outboxAccentColor,
      messageColors: messageColors,
      wallpaper: wallpaper,
    );

    // Now return the deserialized [ThemeSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: messageColorsAnimated,
      b03: outboxAccentColor != null,
      b00: messageColors != null,
      b01: wallpaper != null,
    );

    return v;
  }

  /// message_colors_animated: bit 2 of flags.2?true
  final bool messageColorsAnimated;

  /// Base Theme.
  final BaseThemeBase baseTheme;

  /// Accent Color.
  ///
  /// Field type is Int32.
  final int accentColor;

  /// Outbox Accent Color.
  final int? outboxAccentColor;

  /// Message Colors.
  final List<int>? messageColors;

  /// Wallpaper.
  final WallPaperBase? wallpaper;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfa58b6d4.
    buffer.writeInt32(0xfa58b6d4);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(baseTheme);
    buffer.writeInt32(accentColor);
    final localOutboxAccentColorCopy = outboxAccentColor;
    if (localOutboxAccentColorCopy != null) {
      buffer.writeInt32(localOutboxAccentColorCopy);
    }
    final localMessageColorsCopy = messageColors;
    if (localMessageColorsCopy != null) {
      buffer.writeVectorInt32(localMessageColorsCopy);
    }
    final localWallpaperCopy = wallpaper;
    if (localWallpaperCopy != null) {
      buffer.writeObject(localWallpaperCopy);
    }

    // Finished serialization.
  }
}

/// Web Page Attribute Theme.
///
/// ID: `54b56617`.
class WebPageAttributeTheme extends WebPageAttributeBase {
  /// Web Page Attribute Theme constructor.
  const WebPageAttributeTheme({
    this.documents,
    this.settings,
  }) : super._();

  /// Deserialize.
  factory WebPageAttributeTheme.deserialize(BinaryReader reader) {
    // Read [WebPageAttributeTheme] fields.
    final flags = reader.readInt32();
    final hasDocumentsField = (flags & 1) != 0;
    final documents =
        hasDocumentsField ? reader.readVectorObject<DocumentBase>() : null;
    final hasSettingsField = (flags & 2) != 0;
    final settings =
        hasSettingsField ? reader.readObject() as ThemeSettingsBase : null;

    // Construct [WebPageAttributeTheme] object.
    final returnValue = WebPageAttributeTheme(
      documents: documents,
      settings: settings,
    );

    // Now return the deserialized [WebPageAttributeTheme].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: documents != null,
      b01: settings != null,
    );

    return v;
  }

  /// Documents.
  final List<DocumentBase>? documents;

  /// Settings.
  final ThemeSettingsBase? settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x54b56617.
    buffer.writeInt32(0x54b56617);

    // Write fields.
    buffer.writeInt32(flags);
    final localDocumentsCopy = documents;
    if (localDocumentsCopy != null) {
      buffer.writeVectorObject(localDocumentsCopy);
    }
    final localSettingsCopy = settings;
    if (localSettingsCopy != null) {
      buffer.writeObject(localSettingsCopy);
    }

    // Finished serialization.
  }
}

/// Web Page Attribute Story.
///
/// ID: `2e94c3e7`.
class WebPageAttributeStory extends WebPageAttributeBase {
  /// Web Page Attribute Story constructor.
  const WebPageAttributeStory({
    required this.peer,
    required this.id,
    this.story,
  }) : super._();

  /// Deserialize.
  factory WebPageAttributeStory.deserialize(BinaryReader reader) {
    // Read [WebPageAttributeStory] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as PeerBase;
    final id = reader.readInt32();
    final hasStoryField = (flags & 1) != 0;
    final story = hasStoryField ? reader.readObject() as StoryItemBase : null;

    // Construct [WebPageAttributeStory] object.
    final returnValue = WebPageAttributeStory(
      peer: peer,
      id: id,
      story: story,
    );

    // Now return the deserialized [WebPageAttributeStory].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: story != null,
    );

    return v;
  }

  /// Peer.
  final PeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Story.
  final StoryItemBase? story;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2e94c3e7.
    buffer.writeInt32(0x2e94c3e7);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    final localStoryCopy = story;
    if (localStoryCopy != null) {
      buffer.writeObject(localStoryCopy);
    }

    // Finished serialization.
  }
}

/// Messages Votes List.
///
/// ID: `4899484e`.
class MessagesVotesList extends MessagesVotesListBase {
  /// Messages Votes List constructor.
  const MessagesVotesList({
    required this.count,
    required this.votes,
    required this.chats,
    required this.users,
    this.nextOffset,
  }) : super._();

  /// Deserialize.
  factory MessagesVotesList.deserialize(BinaryReader reader) {
    // Read [MessagesVotesList] fields.
    final flags = reader.readInt32();
    final count = reader.readInt32();
    final votes = reader.readVectorObject<MessagePeerVoteBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final hasNextOffsetField = (flags & 1) != 0;
    final nextOffset = hasNextOffsetField ? reader.readString() : null;

    // Construct [MessagesVotesList] object.
    final returnValue = MessagesVotesList(
      count: count,
      votes: votes,
      chats: chats,
      users: users,
      nextOffset: nextOffset,
    );

    // Now return the deserialized [MessagesVotesList].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: nextOffset != null,
    );

    return v;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Votes.
  final List<MessagePeerVoteBase> votes;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Next Offset.
  final String? nextOffset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4899484e.
    buffer.writeInt32(0x4899484e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(count);
    buffer.writeVectorObject(votes);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    final localNextOffsetCopy = nextOffset;
    if (localNextOffsetCopy != null) {
      buffer.writeString(localNextOffsetCopy);
    }

    // Finished serialization.
  }
}

/// Bank Card Open Url.
///
/// ID: `f568028a`.
class BankCardOpenUrl extends BankCardOpenUrlBase {
  /// Bank Card Open Url constructor.
  const BankCardOpenUrl({
    required this.url,
    required this.name,
  }) : super._();

  /// Deserialize.
  factory BankCardOpenUrl.deserialize(BinaryReader reader) {
    // Read [BankCardOpenUrl] fields.
    final url = reader.readString();
    final name = reader.readString();

    // Construct [BankCardOpenUrl] object.
    final returnValue = BankCardOpenUrl(
      url: url,
      name: name,
    );

    // Now return the deserialized [BankCardOpenUrl].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Name.
  final String name;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf568028a.
    buffer.writeInt32(0xf568028a);

    // Write fields.
    buffer.writeString(url);
    buffer.writeString(name);

    // Finished serialization.
  }
}

/// Payments Bank Card Data.
///
/// ID: `3e24e573`.
class PaymentsBankCardData extends PaymentsBankCardDataBase {
  /// Payments Bank Card Data constructor.
  const PaymentsBankCardData({
    required this.title,
    required this.openUrls,
  }) : super._();

  /// Deserialize.
  factory PaymentsBankCardData.deserialize(BinaryReader reader) {
    // Read [PaymentsBankCardData] fields.
    final title = reader.readString();
    final openUrls = reader.readVectorObject<BankCardOpenUrlBase>();

    // Construct [PaymentsBankCardData] object.
    final returnValue = PaymentsBankCardData(
      title: title,
      openUrls: openUrls,
    );

    // Now return the deserialized [PaymentsBankCardData].
    return returnValue;
  }

  /// Title.
  final String title;

  /// Open Urls.
  final List<BankCardOpenUrlBase> openUrls;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3e24e573.
    buffer.writeInt32(0x3e24e573);

    // Write fields.
    buffer.writeString(title);
    buffer.writeVectorObject(openUrls);

    // Finished serialization.
  }
}

/// Dialog Filter.
///
/// ID: `7438f7e8`.
class DialogFilter extends DialogFilterBase {
  /// Dialog Filter constructor.
  const DialogFilter({
    required this.contacts,
    required this.nonContacts,
    required this.groups,
    required this.broadcasts,
    required this.bots,
    required this.excludeMuted,
    required this.excludeRead,
    required this.excludeArchived,
    required this.id,
    required this.title,
    this.emoticon,
    required this.pinnedPeers,
    required this.includePeers,
    required this.excludePeers,
  }) : super._();

  /// Deserialize.
  factory DialogFilter.deserialize(BinaryReader reader) {
    // Read [DialogFilter] fields.
    final flags = reader.readInt32();
    final contacts = (flags & 1) != 0;
    final nonContacts = (flags & 2) != 0;
    final groups = (flags & 4) != 0;
    final broadcasts = (flags & 8) != 0;
    final bots = (flags & 16) != 0;
    final excludeMuted = (flags & 2048) != 0;
    final excludeRead = (flags & 4096) != 0;
    final excludeArchived = (flags & 8192) != 0;
    final id = reader.readInt32();
    final title = reader.readString();
    final hasEmoticonField = (flags & 33554432) != 0;
    final emoticon = hasEmoticonField ? reader.readString() : null;
    final pinnedPeers = reader.readVectorObject<InputPeerBase>();
    final includePeers = reader.readVectorObject<InputPeerBase>();
    final excludePeers = reader.readVectorObject<InputPeerBase>();

    // Construct [DialogFilter] object.
    final returnValue = DialogFilter(
      contacts: contacts,
      nonContacts: nonContacts,
      groups: groups,
      broadcasts: broadcasts,
      bots: bots,
      excludeMuted: excludeMuted,
      excludeRead: excludeRead,
      excludeArchived: excludeArchived,
      id: id,
      title: title,
      emoticon: emoticon,
      pinnedPeers: pinnedPeers,
      includePeers: includePeers,
      excludePeers: excludePeers,
    );

    // Now return the deserialized [DialogFilter].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: contacts,
      b01: nonContacts,
      b02: groups,
      b03: broadcasts,
      b04: bots,
      b11: excludeMuted,
      b12: excludeRead,
      b13: excludeArchived,
      b25: emoticon != null,
    );

    return v;
  }

  /// contacts: bit 0 of flags.0?true
  final bool contacts;

  /// non_contacts: bit 1 of flags.1?true
  final bool nonContacts;

  /// groups: bit 2 of flags.2?true
  final bool groups;

  /// broadcasts: bit 3 of flags.3?true
  final bool broadcasts;

  /// bots: bit 4 of flags.4?true
  final bool bots;

  /// exclude_muted: bit 11 of flags.11?true
  final bool excludeMuted;

  /// exclude_read: bit 12 of flags.12?true
  final bool excludeRead;

  /// exclude_archived: bit 13 of flags.13?true
  final bool excludeArchived;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Title.
  final String title;

  /// Emoticon.
  final String? emoticon;

  /// Pinned Peers.
  final List<InputPeerBase> pinnedPeers;

  /// Include Peers.
  final List<InputPeerBase> includePeers;

  /// Exclude Peers.
  final List<InputPeerBase> excludePeers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7438f7e8.
    buffer.writeInt32(0x7438f7e8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeString(title);
    final localEmoticonCopy = emoticon;
    if (localEmoticonCopy != null) {
      buffer.writeString(localEmoticonCopy);
    }
    buffer.writeVectorObject(pinnedPeers);
    buffer.writeVectorObject(includePeers);
    buffer.writeVectorObject(excludePeers);

    // Finished serialization.
  }
}

/// Dialog Filter Default.
///
/// ID: `363293ae`.
class DialogFilterDefault extends DialogFilterBase {
  /// Dialog Filter Default constructor.
  const DialogFilterDefault() : super._();

  /// Deserialize.
  factory DialogFilterDefault.deserialize(BinaryReader reader) {
    // Construct [DialogFilterDefault] object.
    final returnValue = DialogFilterDefault();

    // Now return the deserialized [DialogFilterDefault].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x363293ae.
    buffer.writeInt32(0x363293ae);

    // Finished serialization.
  }
}

/// Dialog Filter Chatlist.
///
/// ID: `d64a04a8`.
class DialogFilterChatlist extends DialogFilterBase {
  /// Dialog Filter Chatlist constructor.
  const DialogFilterChatlist({
    required this.hasMyInvites,
    required this.id,
    required this.title,
    this.emoticon,
    required this.pinnedPeers,
    required this.includePeers,
  }) : super._();

  /// Deserialize.
  factory DialogFilterChatlist.deserialize(BinaryReader reader) {
    // Read [DialogFilterChatlist] fields.
    final flags = reader.readInt32();
    final hasMyInvites = (flags & 67108864) != 0;
    final id = reader.readInt32();
    final title = reader.readString();
    final hasEmoticonField = (flags & 33554432) != 0;
    final emoticon = hasEmoticonField ? reader.readString() : null;
    final pinnedPeers = reader.readVectorObject<InputPeerBase>();
    final includePeers = reader.readVectorObject<InputPeerBase>();

    // Construct [DialogFilterChatlist] object.
    final returnValue = DialogFilterChatlist(
      hasMyInvites: hasMyInvites,
      id: id,
      title: title,
      emoticon: emoticon,
      pinnedPeers: pinnedPeers,
      includePeers: includePeers,
    );

    // Now return the deserialized [DialogFilterChatlist].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b26: hasMyInvites,
      b25: emoticon != null,
    );

    return v;
  }

  /// has_my_invites: bit 26 of flags.26?true
  final bool hasMyInvites;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Title.
  final String title;

  /// Emoticon.
  final String? emoticon;

  /// Pinned Peers.
  final List<InputPeerBase> pinnedPeers;

  /// Include Peers.
  final List<InputPeerBase> includePeers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd64a04a8.
    buffer.writeInt32(0xd64a04a8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeString(title);
    final localEmoticonCopy = emoticon;
    if (localEmoticonCopy != null) {
      buffer.writeString(localEmoticonCopy);
    }
    buffer.writeVectorObject(pinnedPeers);
    buffer.writeVectorObject(includePeers);

    // Finished serialization.
  }
}

/// Dialog Filter Suggested.
///
/// ID: `77744d4a`.
class DialogFilterSuggested extends DialogFilterSuggestedBase {
  /// Dialog Filter Suggested constructor.
  const DialogFilterSuggested({
    required this.filter,
    required this.description,
  }) : super._();

  /// Deserialize.
  factory DialogFilterSuggested.deserialize(BinaryReader reader) {
    // Read [DialogFilterSuggested] fields.
    final filter = reader.readObject() as DialogFilterBase;
    final description = reader.readString();

    // Construct [DialogFilterSuggested] object.
    final returnValue = DialogFilterSuggested(
      filter: filter,
      description: description,
    );

    // Now return the deserialized [DialogFilterSuggested].
    return returnValue;
  }

  /// Filter.
  final DialogFilterBase filter;

  /// Description.
  final String description;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x77744d4a.
    buffer.writeInt32(0x77744d4a);

    // Write fields.
    buffer.writeObject(filter);
    buffer.writeString(description);

    // Finished serialization.
  }
}

/// Stats Date Range Days.
///
/// ID: `b637edaf`.
class StatsDateRangeDays extends StatsDateRangeDaysBase {
  /// Stats Date Range Days constructor.
  const StatsDateRangeDays({
    required this.minDate,
    required this.maxDate,
  }) : super._();

  /// Deserialize.
  factory StatsDateRangeDays.deserialize(BinaryReader reader) {
    // Read [StatsDateRangeDays] fields.
    final minDate = reader.readDateTime();
    final maxDate = reader.readDateTime();

    // Construct [StatsDateRangeDays] object.
    final returnValue = StatsDateRangeDays(
      minDate: minDate,
      maxDate: maxDate,
    );

    // Now return the deserialized [StatsDateRangeDays].
    return returnValue;
  }

  /// Min Date.
  final DateTime minDate;

  /// Max Date.
  final DateTime maxDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb637edaf.
    buffer.writeInt32(0xb637edaf);

    // Write fields.
    buffer.writeDateTime(minDate);
    buffer.writeDateTime(maxDate);

    // Finished serialization.
  }
}

/// Stats Abs Value And Prev.
///
/// ID: `cb43acde`.
class StatsAbsValueAndPrev extends StatsAbsValueAndPrevBase {
  /// Stats Abs Value And Prev constructor.
  const StatsAbsValueAndPrev({
    required this.current,
    required this.previous,
  }) : super._();

  /// Deserialize.
  factory StatsAbsValueAndPrev.deserialize(BinaryReader reader) {
    // Read [StatsAbsValueAndPrev] fields.
    final current = reader.readFloat64();
    final previous = reader.readFloat64();

    // Construct [StatsAbsValueAndPrev] object.
    final returnValue = StatsAbsValueAndPrev(
      current: current,
      previous: previous,
    );

    // Now return the deserialized [StatsAbsValueAndPrev].
    return returnValue;
  }

  /// Current.
  final double current;

  /// Previous.
  final double previous;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcb43acde.
    buffer.writeInt32(0xcb43acde);

    // Write fields.
    buffer.writeDouble(current);
    buffer.writeDouble(previous);

    // Finished serialization.
  }
}

/// Stats Percent Value.
///
/// ID: `cbce2fe0`.
class StatsPercentValue extends StatsPercentValueBase {
  /// Stats Percent Value constructor.
  const StatsPercentValue({
    required this.part,
    required this.total,
  }) : super._();

  /// Deserialize.
  factory StatsPercentValue.deserialize(BinaryReader reader) {
    // Read [StatsPercentValue] fields.
    final part = reader.readFloat64();
    final total = reader.readFloat64();

    // Construct [StatsPercentValue] object.
    final returnValue = StatsPercentValue(
      part: part,
      total: total,
    );

    // Now return the deserialized [StatsPercentValue].
    return returnValue;
  }

  /// Part.
  final double part;

  /// Total.
  final double total;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcbce2fe0.
    buffer.writeInt32(0xcbce2fe0);

    // Write fields.
    buffer.writeDouble(part);
    buffer.writeDouble(total);

    // Finished serialization.
  }
}

/// Stats Graph Async.
///
/// ID: `4a27eb2d`.
class StatsGraphAsync extends StatsGraphBase {
  /// Stats Graph Async constructor.
  const StatsGraphAsync({
    required this.token,
  }) : super._();

  /// Deserialize.
  factory StatsGraphAsync.deserialize(BinaryReader reader) {
    // Read [StatsGraphAsync] fields.
    final token = reader.readString();

    // Construct [StatsGraphAsync] object.
    final returnValue = StatsGraphAsync(
      token: token,
    );

    // Now return the deserialized [StatsGraphAsync].
    return returnValue;
  }

  /// Token.
  final String token;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4a27eb2d.
    buffer.writeInt32(0x4a27eb2d);

    // Write fields.
    buffer.writeString(token);

    // Finished serialization.
  }
}

/// Stats Graph Error.
///
/// ID: `bedc9822`.
class StatsGraphError extends StatsGraphBase {
  /// Stats Graph Error constructor.
  const StatsGraphError({
    required this.error,
  }) : super._();

  /// Deserialize.
  factory StatsGraphError.deserialize(BinaryReader reader) {
    // Read [StatsGraphError] fields.
    final error = reader.readString();

    // Construct [StatsGraphError] object.
    final returnValue = StatsGraphError(
      error: error,
    );

    // Now return the deserialized [StatsGraphError].
    return returnValue;
  }

  /// Error.
  final String error;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbedc9822.
    buffer.writeInt32(0xbedc9822);

    // Write fields.
    buffer.writeString(error);

    // Finished serialization.
  }
}

/// Stats Graph.
///
/// ID: `8ea464b6`.
class StatsGraph extends StatsGraphBase {
  /// Stats Graph constructor.
  const StatsGraph({
    required this.json,
    this.zoomToken,
  }) : super._();

  /// Deserialize.
  factory StatsGraph.deserialize(BinaryReader reader) {
    // Read [StatsGraph] fields.
    final flags = reader.readInt32();
    final json = reader.readObject() as DataJSONBase;
    final hasZoomTokenField = (flags & 1) != 0;
    final zoomToken = hasZoomTokenField ? reader.readString() : null;

    // Construct [StatsGraph] object.
    final returnValue = StatsGraph(
      json: json,
      zoomToken: zoomToken,
    );

    // Now return the deserialized [StatsGraph].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: zoomToken != null,
    );

    return v;
  }

  /// Json.
  final DataJSONBase json;

  /// Zoom Token.
  final String? zoomToken;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8ea464b6.
    buffer.writeInt32(0x8ea464b6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(json);
    final localZoomTokenCopy = zoomToken;
    if (localZoomTokenCopy != null) {
      buffer.writeString(localZoomTokenCopy);
    }

    // Finished serialization.
  }
}

/// Stats Broadcast Stats.
///
/// ID: `396ca5fc`.
class StatsBroadcastStats extends StatsBroadcastStatsBase {
  /// Stats Broadcast Stats constructor.
  const StatsBroadcastStats({
    required this.period,
    required this.followers,
    required this.viewsPerPost,
    required this.sharesPerPost,
    required this.reactionsPerPost,
    required this.viewsPerStory,
    required this.sharesPerStory,
    required this.reactionsPerStory,
    required this.enabledNotifications,
    required this.growthGraph,
    required this.followersGraph,
    required this.muteGraph,
    required this.topHoursGraph,
    required this.interactionsGraph,
    required this.ivInteractionsGraph,
    required this.viewsBySourceGraph,
    required this.newFollowersBySourceGraph,
    required this.languagesGraph,
    required this.reactionsByEmotionGraph,
    required this.storyInteractionsGraph,
    required this.storyReactionsByEmotionGraph,
    required this.recentPostsInteractions,
  }) : super._();

  /// Deserialize.
  factory StatsBroadcastStats.deserialize(BinaryReader reader) {
    // Read [StatsBroadcastStats] fields.
    final period = reader.readObject() as StatsDateRangeDaysBase;
    final followers = reader.readObject() as StatsAbsValueAndPrevBase;
    final viewsPerPost = reader.readObject() as StatsAbsValueAndPrevBase;
    final sharesPerPost = reader.readObject() as StatsAbsValueAndPrevBase;
    final reactionsPerPost = reader.readObject() as StatsAbsValueAndPrevBase;
    final viewsPerStory = reader.readObject() as StatsAbsValueAndPrevBase;
    final sharesPerStory = reader.readObject() as StatsAbsValueAndPrevBase;
    final reactionsPerStory = reader.readObject() as StatsAbsValueAndPrevBase;
    final enabledNotifications = reader.readObject() as StatsPercentValueBase;
    final growthGraph = reader.readObject() as StatsGraphBase;
    final followersGraph = reader.readObject() as StatsGraphBase;
    final muteGraph = reader.readObject() as StatsGraphBase;
    final topHoursGraph = reader.readObject() as StatsGraphBase;
    final interactionsGraph = reader.readObject() as StatsGraphBase;
    final ivInteractionsGraph = reader.readObject() as StatsGraphBase;
    final viewsBySourceGraph = reader.readObject() as StatsGraphBase;
    final newFollowersBySourceGraph = reader.readObject() as StatsGraphBase;
    final languagesGraph = reader.readObject() as StatsGraphBase;
    final reactionsByEmotionGraph = reader.readObject() as StatsGraphBase;
    final storyInteractionsGraph = reader.readObject() as StatsGraphBase;
    final storyReactionsByEmotionGraph = reader.readObject() as StatsGraphBase;
    final recentPostsInteractions =
        reader.readVectorObject<PostInteractionCountersBase>();

    // Construct [StatsBroadcastStats] object.
    final returnValue = StatsBroadcastStats(
      period: period,
      followers: followers,
      viewsPerPost: viewsPerPost,
      sharesPerPost: sharesPerPost,
      reactionsPerPost: reactionsPerPost,
      viewsPerStory: viewsPerStory,
      sharesPerStory: sharesPerStory,
      reactionsPerStory: reactionsPerStory,
      enabledNotifications: enabledNotifications,
      growthGraph: growthGraph,
      followersGraph: followersGraph,
      muteGraph: muteGraph,
      topHoursGraph: topHoursGraph,
      interactionsGraph: interactionsGraph,
      ivInteractionsGraph: ivInteractionsGraph,
      viewsBySourceGraph: viewsBySourceGraph,
      newFollowersBySourceGraph: newFollowersBySourceGraph,
      languagesGraph: languagesGraph,
      reactionsByEmotionGraph: reactionsByEmotionGraph,
      storyInteractionsGraph: storyInteractionsGraph,
      storyReactionsByEmotionGraph: storyReactionsByEmotionGraph,
      recentPostsInteractions: recentPostsInteractions,
    );

    // Now return the deserialized [StatsBroadcastStats].
    return returnValue;
  }

  /// Period.
  final StatsDateRangeDaysBase period;

  /// Followers.
  final StatsAbsValueAndPrevBase followers;

  /// Views Per Post.
  final StatsAbsValueAndPrevBase viewsPerPost;

  /// Shares Per Post.
  final StatsAbsValueAndPrevBase sharesPerPost;

  /// Reactions Per Post.
  final StatsAbsValueAndPrevBase reactionsPerPost;

  /// Views Per Story.
  final StatsAbsValueAndPrevBase viewsPerStory;

  /// Shares Per Story.
  final StatsAbsValueAndPrevBase sharesPerStory;

  /// Reactions Per Story.
  final StatsAbsValueAndPrevBase reactionsPerStory;

  /// Enabled Notifications.
  final StatsPercentValueBase enabledNotifications;

  /// Growth Graph.
  final StatsGraphBase growthGraph;

  /// Followers Graph.
  final StatsGraphBase followersGraph;

  /// Mute Graph.
  final StatsGraphBase muteGraph;

  /// Top Hours Graph.
  final StatsGraphBase topHoursGraph;

  /// Interactions Graph.
  final StatsGraphBase interactionsGraph;

  /// Iv Interactions Graph.
  final StatsGraphBase ivInteractionsGraph;

  /// Views By Source Graph.
  final StatsGraphBase viewsBySourceGraph;

  /// New Followers By Source Graph.
  final StatsGraphBase newFollowersBySourceGraph;

  /// Languages Graph.
  final StatsGraphBase languagesGraph;

  /// Reactions By Emotion Graph.
  final StatsGraphBase reactionsByEmotionGraph;

  /// Story Interactions Graph.
  final StatsGraphBase storyInteractionsGraph;

  /// Story Reactions By Emotion Graph.
  final StatsGraphBase storyReactionsByEmotionGraph;

  /// Recent Posts Interactions.
  final List<PostInteractionCountersBase> recentPostsInteractions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x396ca5fc.
    buffer.writeInt32(0x396ca5fc);

    // Write fields.
    buffer.writeObject(period);
    buffer.writeObject(followers);
    buffer.writeObject(viewsPerPost);
    buffer.writeObject(sharesPerPost);
    buffer.writeObject(reactionsPerPost);
    buffer.writeObject(viewsPerStory);
    buffer.writeObject(sharesPerStory);
    buffer.writeObject(reactionsPerStory);
    buffer.writeObject(enabledNotifications);
    buffer.writeObject(growthGraph);
    buffer.writeObject(followersGraph);
    buffer.writeObject(muteGraph);
    buffer.writeObject(topHoursGraph);
    buffer.writeObject(interactionsGraph);
    buffer.writeObject(ivInteractionsGraph);
    buffer.writeObject(viewsBySourceGraph);
    buffer.writeObject(newFollowersBySourceGraph);
    buffer.writeObject(languagesGraph);
    buffer.writeObject(reactionsByEmotionGraph);
    buffer.writeObject(storyInteractionsGraph);
    buffer.writeObject(storyReactionsByEmotionGraph);
    buffer.writeVectorObject(recentPostsInteractions);

    // Finished serialization.
  }
}

/// Help Promo Data Empty.
///
/// ID: `98f6ac75`.
class HelpPromoDataEmpty extends HelpPromoDataBase {
  /// Help Promo Data Empty constructor.
  const HelpPromoDataEmpty({
    required this.expires,
  }) : super._();

  /// Deserialize.
  factory HelpPromoDataEmpty.deserialize(BinaryReader reader) {
    // Read [HelpPromoDataEmpty] fields.
    final expires = reader.readInt32();

    // Construct [HelpPromoDataEmpty] object.
    final returnValue = HelpPromoDataEmpty(
      expires: expires,
    );

    // Now return the deserialized [HelpPromoDataEmpty].
    return returnValue;
  }

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x98f6ac75.
    buffer.writeInt32(0x98f6ac75);

    // Write fields.
    buffer.writeInt32(expires);

    // Finished serialization.
  }
}

/// Help Promo Data.
///
/// ID: `8c39793f`.
class HelpPromoData extends HelpPromoDataBase {
  /// Help Promo Data constructor.
  const HelpPromoData({
    required this.proxy,
    required this.expires,
    required this.peer,
    required this.chats,
    required this.users,
    this.psaType,
    this.psaMessage,
  }) : super._();

  /// Deserialize.
  factory HelpPromoData.deserialize(BinaryReader reader) {
    // Read [HelpPromoData] fields.
    final flags = reader.readInt32();
    final proxy = (flags & 1) != 0;
    final expires = reader.readInt32();
    final peer = reader.readObject() as PeerBase;
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final hasPsaTypeField = (flags & 2) != 0;
    final psaType = hasPsaTypeField ? reader.readString() : null;
    final hasPsaMessageField = (flags & 4) != 0;
    final psaMessage = hasPsaMessageField ? reader.readString() : null;

    // Construct [HelpPromoData] object.
    final returnValue = HelpPromoData(
      proxy: proxy,
      expires: expires,
      peer: peer,
      chats: chats,
      users: users,
      psaType: psaType,
      psaMessage: psaMessage,
    );

    // Now return the deserialized [HelpPromoData].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: proxy,
      b01: psaType != null,
      b02: psaMessage != null,
    );

    return v;
  }

  /// proxy: bit 0 of flags.0?true
  final bool proxy;

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Peer.
  final PeerBase peer;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Psa Type.
  final String? psaType;

  /// Psa Message.
  final String? psaMessage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8c39793f.
    buffer.writeInt32(0x8c39793f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(expires);
    buffer.writeObject(peer);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    final localPsaTypeCopy = psaType;
    if (localPsaTypeCopy != null) {
      buffer.writeString(localPsaTypeCopy);
    }
    final localPsaMessageCopy = psaMessage;
    if (localPsaMessageCopy != null) {
      buffer.writeString(localPsaMessageCopy);
    }

    // Finished serialization.
  }
}

/// Video Size.
///
/// ID: `de33b094`.
class VideoSize extends VideoSizeBase {
  /// Video Size constructor.
  const VideoSize({
    required this.type,
    required this.w,
    required this.h,
    required this.size,
    this.videoStartTs,
  }) : super._();

  /// Deserialize.
  factory VideoSize.deserialize(BinaryReader reader) {
    // Read [VideoSize] fields.
    final flags = reader.readInt32();
    final type = reader.readString();
    final w = reader.readInt32();
    final h = reader.readInt32();
    final size = reader.readInt32();
    final hasVideoStartTsField = (flags & 1) != 0;
    final videoStartTs = hasVideoStartTsField ? reader.readFloat64() : null;

    // Construct [VideoSize] object.
    final returnValue = VideoSize(
      type: type,
      w: w,
      h: h,
      size: size,
      videoStartTs: videoStartTs,
    );

    // Now return the deserialized [VideoSize].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: videoStartTs != null,
    );

    return v;
  }

  /// Type.
  final String type;

  /// W.
  ///
  /// Field type is Int32.
  final int w;

  /// H.
  ///
  /// Field type is Int32.
  final int h;

  /// Size.
  ///
  /// Field type is Int32.
  final int size;

  /// Video Start Ts.
  final double? videoStartTs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xde33b094.
    buffer.writeInt32(0xde33b094);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(type);
    buffer.writeInt32(w);
    buffer.writeInt32(h);
    buffer.writeInt32(size);
    final localVideoStartTsCopy = videoStartTs;
    if (localVideoStartTsCopy != null) {
      buffer.writeDouble(localVideoStartTsCopy);
    }

    // Finished serialization.
  }
}

/// Video Size Emoji Markup.
///
/// ID: `f85c413c`.
class VideoSizeEmojiMarkup extends VideoSizeBase {
  /// Video Size Emoji Markup constructor.
  const VideoSizeEmojiMarkup({
    required this.emojiId,
    required this.backgroundColors,
  }) : super._();

  /// Deserialize.
  factory VideoSizeEmojiMarkup.deserialize(BinaryReader reader) {
    // Read [VideoSizeEmojiMarkup] fields.
    final emojiId = reader.readInt64();
    final backgroundColors = reader.readVectorInt32();

    // Construct [VideoSizeEmojiMarkup] object.
    final returnValue = VideoSizeEmojiMarkup(
      emojiId: emojiId,
      backgroundColors: backgroundColors,
    );

    // Now return the deserialized [VideoSizeEmojiMarkup].
    return returnValue;
  }

  /// Emoji Id.
  ///
  /// Field type is Int64.
  final int emojiId;

  /// Background Colors.
  final List<int> backgroundColors;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf85c413c.
    buffer.writeInt32(0xf85c413c);

    // Write fields.
    buffer.writeInt64(emojiId);
    buffer.writeVectorInt32(backgroundColors);

    // Finished serialization.
  }
}

/// Video Size Sticker Markup.
///
/// ID: `0da082fe`.
class VideoSizeStickerMarkup extends VideoSizeBase {
  /// Video Size Sticker Markup constructor.
  const VideoSizeStickerMarkup({
    required this.stickerset,
    required this.stickerId,
    required this.backgroundColors,
  }) : super._();

  /// Deserialize.
  factory VideoSizeStickerMarkup.deserialize(BinaryReader reader) {
    // Read [VideoSizeStickerMarkup] fields.
    final stickerset = reader.readObject() as InputStickerSetBase;
    final stickerId = reader.readInt64();
    final backgroundColors = reader.readVectorInt32();

    // Construct [VideoSizeStickerMarkup] object.
    final returnValue = VideoSizeStickerMarkup(
      stickerset: stickerset,
      stickerId: stickerId,
      backgroundColors: backgroundColors,
    );

    // Now return the deserialized [VideoSizeStickerMarkup].
    return returnValue;
  }

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Sticker Id.
  ///
  /// Field type is Int64.
  final int stickerId;

  /// Background Colors.
  final List<int> backgroundColors;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0da082fe.
    buffer.writeInt32(0x0da082fe);

    // Write fields.
    buffer.writeObject(stickerset);
    buffer.writeInt64(stickerId);
    buffer.writeVectorInt32(backgroundColors);

    // Finished serialization.
  }
}

/// Stats Group Top Poster.
///
/// ID: `9d04af9b`.
class StatsGroupTopPoster extends StatsGroupTopPosterBase {
  /// Stats Group Top Poster constructor.
  const StatsGroupTopPoster({
    required this.userId,
    required this.messages,
    required this.avgChars,
  }) : super._();

  /// Deserialize.
  factory StatsGroupTopPoster.deserialize(BinaryReader reader) {
    // Read [StatsGroupTopPoster] fields.
    final userId = reader.readInt64();
    final messages = reader.readInt32();
    final avgChars = reader.readInt32();

    // Construct [StatsGroupTopPoster] object.
    final returnValue = StatsGroupTopPoster(
      userId: userId,
      messages: messages,
      avgChars: avgChars,
    );

    // Now return the deserialized [StatsGroupTopPoster].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Messages.
  ///
  /// Field type is Int32.
  final int messages;

  /// Avg Chars.
  ///
  /// Field type is Int32.
  final int avgChars;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9d04af9b.
    buffer.writeInt32(0x9d04af9b);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeInt32(messages);
    buffer.writeInt32(avgChars);

    // Finished serialization.
  }
}

/// Stats Group Top Admin.
///
/// ID: `d7584c87`.
class StatsGroupTopAdmin extends StatsGroupTopAdminBase {
  /// Stats Group Top Admin constructor.
  const StatsGroupTopAdmin({
    required this.userId,
    required this.deleted,
    required this.kicked,
    required this.banned,
  }) : super._();

  /// Deserialize.
  factory StatsGroupTopAdmin.deserialize(BinaryReader reader) {
    // Read [StatsGroupTopAdmin] fields.
    final userId = reader.readInt64();
    final deleted = reader.readInt32();
    final kicked = reader.readInt32();
    final banned = reader.readInt32();

    // Construct [StatsGroupTopAdmin] object.
    final returnValue = StatsGroupTopAdmin(
      userId: userId,
      deleted: deleted,
      kicked: kicked,
      banned: banned,
    );

    // Now return the deserialized [StatsGroupTopAdmin].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Deleted.
  ///
  /// Field type is Int32.
  final int deleted;

  /// Kicked.
  ///
  /// Field type is Int32.
  final int kicked;

  /// Banned.
  ///
  /// Field type is Int32.
  final int banned;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd7584c87.
    buffer.writeInt32(0xd7584c87);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeInt32(deleted);
    buffer.writeInt32(kicked);
    buffer.writeInt32(banned);

    // Finished serialization.
  }
}

/// Stats Group Top Inviter.
///
/// ID: `535f779d`.
class StatsGroupTopInviter extends StatsGroupTopInviterBase {
  /// Stats Group Top Inviter constructor.
  const StatsGroupTopInviter({
    required this.userId,
    required this.invitations,
  }) : super._();

  /// Deserialize.
  factory StatsGroupTopInviter.deserialize(BinaryReader reader) {
    // Read [StatsGroupTopInviter] fields.
    final userId = reader.readInt64();
    final invitations = reader.readInt32();

    // Construct [StatsGroupTopInviter] object.
    final returnValue = StatsGroupTopInviter(
      userId: userId,
      invitations: invitations,
    );

    // Now return the deserialized [StatsGroupTopInviter].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Invitations.
  ///
  /// Field type is Int32.
  final int invitations;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x535f779d.
    buffer.writeInt32(0x535f779d);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeInt32(invitations);

    // Finished serialization.
  }
}

/// Stats Megagroup Stats.
///
/// ID: `ef7ff916`.
class StatsMegagroupStats extends StatsMegagroupStatsBase {
  /// Stats Megagroup Stats constructor.
  const StatsMegagroupStats({
    required this.period,
    required this.members,
    required this.messages,
    required this.viewers,
    required this.posters,
    required this.growthGraph,
    required this.membersGraph,
    required this.newMembersBySourceGraph,
    required this.languagesGraph,
    required this.messagesGraph,
    required this.actionsGraph,
    required this.topHoursGraph,
    required this.weekdaysGraph,
    required this.topPosters,
    required this.topAdmins,
    required this.topInviters,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory StatsMegagroupStats.deserialize(BinaryReader reader) {
    // Read [StatsMegagroupStats] fields.
    final period = reader.readObject() as StatsDateRangeDaysBase;
    final members = reader.readObject() as StatsAbsValueAndPrevBase;
    final messages = reader.readObject() as StatsAbsValueAndPrevBase;
    final viewers = reader.readObject() as StatsAbsValueAndPrevBase;
    final posters = reader.readObject() as StatsAbsValueAndPrevBase;
    final growthGraph = reader.readObject() as StatsGraphBase;
    final membersGraph = reader.readObject() as StatsGraphBase;
    final newMembersBySourceGraph = reader.readObject() as StatsGraphBase;
    final languagesGraph = reader.readObject() as StatsGraphBase;
    final messagesGraph = reader.readObject() as StatsGraphBase;
    final actionsGraph = reader.readObject() as StatsGraphBase;
    final topHoursGraph = reader.readObject() as StatsGraphBase;
    final weekdaysGraph = reader.readObject() as StatsGraphBase;
    final topPosters = reader.readVectorObject<StatsGroupTopPosterBase>();
    final topAdmins = reader.readVectorObject<StatsGroupTopAdminBase>();
    final topInviters = reader.readVectorObject<StatsGroupTopInviterBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [StatsMegagroupStats] object.
    final returnValue = StatsMegagroupStats(
      period: period,
      members: members,
      messages: messages,
      viewers: viewers,
      posters: posters,
      growthGraph: growthGraph,
      membersGraph: membersGraph,
      newMembersBySourceGraph: newMembersBySourceGraph,
      languagesGraph: languagesGraph,
      messagesGraph: messagesGraph,
      actionsGraph: actionsGraph,
      topHoursGraph: topHoursGraph,
      weekdaysGraph: weekdaysGraph,
      topPosters: topPosters,
      topAdmins: topAdmins,
      topInviters: topInviters,
      users: users,
    );

    // Now return the deserialized [StatsMegagroupStats].
    return returnValue;
  }

  /// Period.
  final StatsDateRangeDaysBase period;

  /// Members.
  final StatsAbsValueAndPrevBase members;

  /// Messages.
  final StatsAbsValueAndPrevBase messages;

  /// Viewers.
  final StatsAbsValueAndPrevBase viewers;

  /// Posters.
  final StatsAbsValueAndPrevBase posters;

  /// Growth Graph.
  final StatsGraphBase growthGraph;

  /// Members Graph.
  final StatsGraphBase membersGraph;

  /// New Members By Source Graph.
  final StatsGraphBase newMembersBySourceGraph;

  /// Languages Graph.
  final StatsGraphBase languagesGraph;

  /// Messages Graph.
  final StatsGraphBase messagesGraph;

  /// Actions Graph.
  final StatsGraphBase actionsGraph;

  /// Top Hours Graph.
  final StatsGraphBase topHoursGraph;

  /// Weekdays Graph.
  final StatsGraphBase weekdaysGraph;

  /// Top Posters.
  final List<StatsGroupTopPosterBase> topPosters;

  /// Top Admins.
  final List<StatsGroupTopAdminBase> topAdmins;

  /// Top Inviters.
  final List<StatsGroupTopInviterBase> topInviters;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xef7ff916.
    buffer.writeInt32(0xef7ff916);

    // Write fields.
    buffer.writeObject(period);
    buffer.writeObject(members);
    buffer.writeObject(messages);
    buffer.writeObject(viewers);
    buffer.writeObject(posters);
    buffer.writeObject(growthGraph);
    buffer.writeObject(membersGraph);
    buffer.writeObject(newMembersBySourceGraph);
    buffer.writeObject(languagesGraph);
    buffer.writeObject(messagesGraph);
    buffer.writeObject(actionsGraph);
    buffer.writeObject(topHoursGraph);
    buffer.writeObject(weekdaysGraph);
    buffer.writeVectorObject(topPosters);
    buffer.writeVectorObject(topAdmins);
    buffer.writeVectorObject(topInviters);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Global Privacy Settings.
///
/// ID: `734c4ccb`.
class GlobalPrivacySettings extends GlobalPrivacySettingsBase {
  /// Global Privacy Settings constructor.
  const GlobalPrivacySettings({
    required this.archiveAndMuteNewNoncontactPeers,
    required this.keepArchivedUnmuted,
    required this.keepArchivedFolders,
  }) : super._();

  /// Deserialize.
  factory GlobalPrivacySettings.deserialize(BinaryReader reader) {
    // Read [GlobalPrivacySettings] fields.
    final flags = reader.readInt32();
    final archiveAndMuteNewNoncontactPeers = (flags & 1) != 0;
    final keepArchivedUnmuted = (flags & 2) != 0;
    final keepArchivedFolders = (flags & 4) != 0;

    // Construct [GlobalPrivacySettings] object.
    final returnValue = GlobalPrivacySettings(
      archiveAndMuteNewNoncontactPeers: archiveAndMuteNewNoncontactPeers,
      keepArchivedUnmuted: keepArchivedUnmuted,
      keepArchivedFolders: keepArchivedFolders,
    );

    // Now return the deserialized [GlobalPrivacySettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: archiveAndMuteNewNoncontactPeers,
      b01: keepArchivedUnmuted,
      b02: keepArchivedFolders,
    );

    return v;
  }

  /// archive_and_mute_new_noncontact_peers: bit 0 of flags.0?true
  final bool archiveAndMuteNewNoncontactPeers;

  /// keep_archived_unmuted: bit 1 of flags.1?true
  final bool keepArchivedUnmuted;

  /// keep_archived_folders: bit 2 of flags.2?true
  final bool keepArchivedFolders;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x734c4ccb.
    buffer.writeInt32(0x734c4ccb);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Help Country Code.
///
/// ID: `4203c5ef`.
class HelpCountryCode extends HelpCountryCodeBase {
  /// Help Country Code constructor.
  const HelpCountryCode({
    required this.countryCode,
    this.prefixes,
    this.patterns,
  }) : super._();

  /// Deserialize.
  factory HelpCountryCode.deserialize(BinaryReader reader) {
    // Read [HelpCountryCode] fields.
    final flags = reader.readInt32();
    final countryCode = reader.readString();
    final hasPrefixesField = (flags & 1) != 0;
    final prefixes = hasPrefixesField ? reader.readVectorString() : null;
    final hasPatternsField = (flags & 2) != 0;
    final patterns = hasPatternsField ? reader.readVectorString() : null;

    // Construct [HelpCountryCode] object.
    final returnValue = HelpCountryCode(
      countryCode: countryCode,
      prefixes: prefixes,
      patterns: patterns,
    );

    // Now return the deserialized [HelpCountryCode].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: prefixes != null,
      b01: patterns != null,
    );

    return v;
  }

  /// Country Code.
  final String countryCode;

  /// Prefixes.
  final List<String>? prefixes;

  /// Patterns.
  final List<String>? patterns;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4203c5ef.
    buffer.writeInt32(0x4203c5ef);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(countryCode);
    final localPrefixesCopy = prefixes;
    if (localPrefixesCopy != null) {
      buffer.writeVectorString(localPrefixesCopy);
    }
    final localPatternsCopy = patterns;
    if (localPatternsCopy != null) {
      buffer.writeVectorString(localPatternsCopy);
    }

    // Finished serialization.
  }
}

/// Help Country.
///
/// ID: `c3878e23`.
class HelpCountry extends HelpCountryBase {
  /// Help Country constructor.
  const HelpCountry({
    required this.hidden,
    required this.iso2,
    required this.defaultName,
    this.name,
    required this.countryCodes,
  }) : super._();

  /// Deserialize.
  factory HelpCountry.deserialize(BinaryReader reader) {
    // Read [HelpCountry] fields.
    final flags = reader.readInt32();
    final hidden = (flags & 1) != 0;
    final iso2 = reader.readString();
    final defaultName = reader.readString();
    final hasNameField = (flags & 2) != 0;
    final name = hasNameField ? reader.readString() : null;
    final countryCodes = reader.readVectorObject<HelpCountryCodeBase>();

    // Construct [HelpCountry] object.
    final returnValue = HelpCountry(
      hidden: hidden,
      iso2: iso2,
      defaultName: defaultName,
      name: name,
      countryCodes: countryCodes,
    );

    // Now return the deserialized [HelpCountry].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: hidden,
      b01: name != null,
    );

    return v;
  }

  /// hidden: bit 0 of flags.0?true
  final bool hidden;

  /// Iso2.
  final String iso2;

  /// Default Name.
  final String defaultName;

  /// Name.
  final String? name;

  /// Country Codes.
  final List<HelpCountryCodeBase> countryCodes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc3878e23.
    buffer.writeInt32(0xc3878e23);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(iso2);
    buffer.writeString(defaultName);
    final localNameCopy = name;
    if (localNameCopy != null) {
      buffer.writeString(localNameCopy);
    }
    buffer.writeVectorObject(countryCodes);

    // Finished serialization.
  }
}

/// Help Countries List Not Modified.
///
/// ID: `93cc1f32`.
class HelpCountriesListNotModified extends HelpCountriesListBase {
  /// Help Countries List Not Modified constructor.
  const HelpCountriesListNotModified() : super._();

  /// Deserialize.
  factory HelpCountriesListNotModified.deserialize(BinaryReader reader) {
    // Construct [HelpCountriesListNotModified] object.
    final returnValue = HelpCountriesListNotModified();

    // Now return the deserialized [HelpCountriesListNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x93cc1f32.
    buffer.writeInt32(0x93cc1f32);

    // Finished serialization.
  }
}

/// Help Countries List.
///
/// ID: `87d0759e`.
class HelpCountriesList extends HelpCountriesListBase {
  /// Help Countries List constructor.
  const HelpCountriesList({
    required this.countries,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory HelpCountriesList.deserialize(BinaryReader reader) {
    // Read [HelpCountriesList] fields.
    final countries = reader.readVectorObject<HelpCountryBase>();
    final hash = reader.readInt32();

    // Construct [HelpCountriesList] object.
    final returnValue = HelpCountriesList(
      countries: countries,
      hash: hash,
    );

    // Now return the deserialized [HelpCountriesList].
    return returnValue;
  }

  /// Countries.
  final List<HelpCountryBase> countries;

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x87d0759e.
    buffer.writeInt32(0x87d0759e);

    // Write fields.
    buffer.writeVectorObject(countries);
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Message Views.
///
/// ID: `455b853d`.
class MessageViews extends MessageViewsBase {
  /// Message Views constructor.
  const MessageViews({
    this.views,
    this.forwards,
    this.replies,
  }) : super._();

  /// Deserialize.
  factory MessageViews.deserialize(BinaryReader reader) {
    // Read [MessageViews] fields.
    final flags = reader.readInt32();
    final hasViewsField = (flags & 1) != 0;
    final views = hasViewsField ? reader.readInt32() : null;
    final hasForwardsField = (flags & 2) != 0;
    final forwards = hasForwardsField ? reader.readInt32() : null;
    final hasRepliesField = (flags & 4) != 0;
    final replies =
        hasRepliesField ? reader.readObject() as MessageRepliesBase : null;

    // Construct [MessageViews] object.
    final returnValue = MessageViews(
      views: views,
      forwards: forwards,
      replies: replies,
    );

    // Now return the deserialized [MessageViews].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: views != null,
      b01: forwards != null,
      b02: replies != null,
    );

    return v;
  }

  /// Views.
  final int? views;

  /// Forwards.
  final int? forwards;

  /// Replies.
  final MessageRepliesBase? replies;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x455b853d.
    buffer.writeInt32(0x455b853d);

    // Write fields.
    buffer.writeInt32(flags);
    final localViewsCopy = views;
    if (localViewsCopy != null) {
      buffer.writeInt32(localViewsCopy);
    }
    final localForwardsCopy = forwards;
    if (localForwardsCopy != null) {
      buffer.writeInt32(localForwardsCopy);
    }
    final localRepliesCopy = replies;
    if (localRepliesCopy != null) {
      buffer.writeObject(localRepliesCopy);
    }

    // Finished serialization.
  }
}

/// Messages Message Views.
///
/// ID: `b6c4f543`.
class MessagesMessageViews extends MessagesMessageViewsBase {
  /// Messages Message Views constructor.
  const MessagesMessageViews({
    required this.views,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesMessageViews.deserialize(BinaryReader reader) {
    // Read [MessagesMessageViews] fields.
    final views = reader.readVectorObject<MessageViewsBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesMessageViews] object.
    final returnValue = MessagesMessageViews(
      views: views,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesMessageViews].
    return returnValue;
  }

  /// Views.
  final List<MessageViewsBase> views;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb6c4f543.
    buffer.writeInt32(0xb6c4f543);

    // Write fields.
    buffer.writeVectorObject(views);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Discussion Message.
///
/// ID: `a6341782`.
class MessagesDiscussionMessage extends MessagesDiscussionMessageBase {
  /// Messages Discussion Message constructor.
  const MessagesDiscussionMessage({
    required this.messages,
    this.maxId,
    this.readInboxMaxId,
    this.readOutboxMaxId,
    required this.unreadCount,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesDiscussionMessage.deserialize(BinaryReader reader) {
    // Read [MessagesDiscussionMessage] fields.
    final flags = reader.readInt32();
    final messages = reader.readVectorObject<MessageBase>();
    final hasMaxIdField = (flags & 1) != 0;
    final maxId = hasMaxIdField ? reader.readInt32() : null;
    final hasReadInboxMaxIdField = (flags & 2) != 0;
    final readInboxMaxId = hasReadInboxMaxIdField ? reader.readInt32() : null;
    final hasReadOutboxMaxIdField = (flags & 4) != 0;
    final readOutboxMaxId = hasReadOutboxMaxIdField ? reader.readInt32() : null;
    final unreadCount = reader.readInt32();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesDiscussionMessage] object.
    final returnValue = MessagesDiscussionMessage(
      messages: messages,
      maxId: maxId,
      readInboxMaxId: readInboxMaxId,
      readOutboxMaxId: readOutboxMaxId,
      unreadCount: unreadCount,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesDiscussionMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: maxId != null,
      b01: readInboxMaxId != null,
      b02: readOutboxMaxId != null,
    );

    return v;
  }

  /// Messages.
  final List<MessageBase> messages;

  /// Max Id.
  final int? maxId;

  /// Read Inbox Max Id.
  final int? readInboxMaxId;

  /// Read Outbox Max Id.
  final int? readOutboxMaxId;

  /// Unread Count.
  ///
  /// Field type is Int32.
  final int unreadCount;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa6341782.
    buffer.writeInt32(0xa6341782);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(messages);
    final localMaxIdCopy = maxId;
    if (localMaxIdCopy != null) {
      buffer.writeInt32(localMaxIdCopy);
    }
    final localReadInboxMaxIdCopy = readInboxMaxId;
    if (localReadInboxMaxIdCopy != null) {
      buffer.writeInt32(localReadInboxMaxIdCopy);
    }
    final localReadOutboxMaxIdCopy = readOutboxMaxId;
    if (localReadOutboxMaxIdCopy != null) {
      buffer.writeInt32(localReadOutboxMaxIdCopy);
    }
    buffer.writeInt32(unreadCount);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Message Reply Header.
///
/// ID: `afbc09db`.
class MessageReplyHeader extends MessageReplyHeaderBase {
  /// Message Reply Header constructor.
  const MessageReplyHeader({
    required this.replyToScheduled,
    required this.forumTopic,
    required this.quote,
    this.replyToMsgId,
    this.replyToPeerId,
    this.replyFrom,
    this.replyMedia,
    this.replyToTopId,
    this.quoteText,
    this.quoteEntities,
    this.quoteOffset,
  }) : super._();

  /// Deserialize.
  factory MessageReplyHeader.deserialize(BinaryReader reader) {
    // Read [MessageReplyHeader] fields.
    final flags = reader.readInt32();
    final replyToScheduled = (flags & 4) != 0;
    final forumTopic = (flags & 8) != 0;
    final quote = (flags & 512) != 0;
    final hasReplyToMsgIdField = (flags & 16) != 0;
    final replyToMsgId = hasReplyToMsgIdField ? reader.readInt32() : null;
    final hasReplyToPeerIdField = (flags & 1) != 0;
    final replyToPeerId =
        hasReplyToPeerIdField ? reader.readObject() as PeerBase : null;
    final hasReplyFromField = (flags & 32) != 0;
    final replyFrom =
        hasReplyFromField ? reader.readObject() as MessageFwdHeaderBase : null;
    final hasReplyMediaField = (flags & 256) != 0;
    final replyMedia =
        hasReplyMediaField ? reader.readObject() as MessageMediaBase : null;
    final hasReplyToTopIdField = (flags & 2) != 0;
    final replyToTopId = hasReplyToTopIdField ? reader.readInt32() : null;
    final hasQuoteTextField = (flags & 64) != 0;
    final quoteText = hasQuoteTextField ? reader.readString() : null;
    final hasQuoteEntitiesField = (flags & 128) != 0;
    final quoteEntities = hasQuoteEntitiesField
        ? reader.readVectorObject<MessageEntityBase>()
        : null;
    final hasQuoteOffsetField = (flags & 1024) != 0;
    final quoteOffset = hasQuoteOffsetField ? reader.readInt32() : null;

    // Construct [MessageReplyHeader] object.
    final returnValue = MessageReplyHeader(
      replyToScheduled: replyToScheduled,
      forumTopic: forumTopic,
      quote: quote,
      replyToMsgId: replyToMsgId,
      replyToPeerId: replyToPeerId,
      replyFrom: replyFrom,
      replyMedia: replyMedia,
      replyToTopId: replyToTopId,
      quoteText: quoteText,
      quoteEntities: quoteEntities,
      quoteOffset: quoteOffset,
    );

    // Now return the deserialized [MessageReplyHeader].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: replyToScheduled,
      b03: forumTopic,
      b09: quote,
      b04: replyToMsgId != null,
      b00: replyToPeerId != null,
      b05: replyFrom != null,
      b08: replyMedia != null,
      b01: replyToTopId != null,
      b06: quoteText != null,
      b07: quoteEntities != null,
      b10: quoteOffset != null,
    );

    return v;
  }

  /// reply_to_scheduled: bit 2 of flags.2?true
  final bool replyToScheduled;

  /// forum_topic: bit 3 of flags.3?true
  final bool forumTopic;

  /// quote: bit 9 of flags.9?true
  final bool quote;

  /// Reply To Msg Id.
  final int? replyToMsgId;

  /// Reply To Peer Id.
  final PeerBase? replyToPeerId;

  /// Reply From.
  final MessageFwdHeaderBase? replyFrom;

  /// Reply Media.
  final MessageMediaBase? replyMedia;

  /// Reply To Top Id.
  final int? replyToTopId;

  /// Quote Text.
  final String? quoteText;

  /// Quote Entities.
  final List<MessageEntityBase>? quoteEntities;

  /// Quote Offset.
  final int? quoteOffset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xafbc09db.
    buffer.writeInt32(0xafbc09db);

    // Write fields.
    buffer.writeInt32(flags);
    final localReplyToMsgIdCopy = replyToMsgId;
    if (localReplyToMsgIdCopy != null) {
      buffer.writeInt32(localReplyToMsgIdCopy);
    }
    final localReplyToPeerIdCopy = replyToPeerId;
    if (localReplyToPeerIdCopy != null) {
      buffer.writeObject(localReplyToPeerIdCopy);
    }
    final localReplyFromCopy = replyFrom;
    if (localReplyFromCopy != null) {
      buffer.writeObject(localReplyFromCopy);
    }
    final localReplyMediaCopy = replyMedia;
    if (localReplyMediaCopy != null) {
      buffer.writeObject(localReplyMediaCopy);
    }
    final localReplyToTopIdCopy = replyToTopId;
    if (localReplyToTopIdCopy != null) {
      buffer.writeInt32(localReplyToTopIdCopy);
    }
    final localQuoteTextCopy = quoteText;
    if (localQuoteTextCopy != null) {
      buffer.writeString(localQuoteTextCopy);
    }
    final localQuoteEntitiesCopy = quoteEntities;
    if (localQuoteEntitiesCopy != null) {
      buffer.writeVectorObject(localQuoteEntitiesCopy);
    }
    final localQuoteOffsetCopy = quoteOffset;
    if (localQuoteOffsetCopy != null) {
      buffer.writeInt32(localQuoteOffsetCopy);
    }

    // Finished serialization.
  }
}

/// Message Reply Story Header.
///
/// ID: `9c98bfc1`.
class MessageReplyStoryHeader extends MessageReplyHeaderBase {
  /// Message Reply Story Header constructor.
  const MessageReplyStoryHeader({
    required this.userId,
    required this.storyId,
  }) : super._();

  /// Deserialize.
  factory MessageReplyStoryHeader.deserialize(BinaryReader reader) {
    // Read [MessageReplyStoryHeader] fields.
    final userId = reader.readInt64();
    final storyId = reader.readInt32();

    // Construct [MessageReplyStoryHeader] object.
    final returnValue = MessageReplyStoryHeader(
      userId: userId,
      storyId: storyId,
    );

    // Now return the deserialized [MessageReplyStoryHeader].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Story Id.
  ///
  /// Field type is Int32.
  final int storyId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9c98bfc1.
    buffer.writeInt32(0x9c98bfc1);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeInt32(storyId);

    // Finished serialization.
  }
}

/// Message Replies.
///
/// ID: `83d60fc2`.
class MessageReplies extends MessageRepliesBase {
  /// Message Replies constructor.
  const MessageReplies({
    required this.comments,
    required this.replies,
    required this.repliesPts,
    this.recentRepliers,
    this.channelId,
    this.maxId,
    this.readMaxId,
  }) : super._();

  /// Deserialize.
  factory MessageReplies.deserialize(BinaryReader reader) {
    // Read [MessageReplies] fields.
    final flags = reader.readInt32();
    final comments = (flags & 1) != 0;
    final replies = reader.readInt32();
    final repliesPts = reader.readInt32();
    final hasRecentRepliersField = (flags & 2) != 0;
    final recentRepliers =
        hasRecentRepliersField ? reader.readVectorObject<PeerBase>() : null;
    final hasChannelIdField = (flags & 1) != 0;
    final channelId = hasChannelIdField ? reader.readInt64() : null;
    final hasMaxIdField = (flags & 4) != 0;
    final maxId = hasMaxIdField ? reader.readInt32() : null;
    final hasReadMaxIdField = (flags & 8) != 0;
    final readMaxId = hasReadMaxIdField ? reader.readInt32() : null;

    // Construct [MessageReplies] object.
    final returnValue = MessageReplies(
      comments: comments,
      replies: replies,
      repliesPts: repliesPts,
      recentRepliers: recentRepliers,
      channelId: channelId,
      maxId: maxId,
      readMaxId: readMaxId,
    );

    // Now return the deserialized [MessageReplies].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: comments || channelId != null,
      b01: recentRepliers != null,
      b02: maxId != null,
      b03: readMaxId != null,
    );

    return v;
  }

  /// comments: bit 0 of flags.0?true
  final bool comments;

  /// Replies.
  ///
  /// Field type is Int32.
  final int replies;

  /// Replies Pts.
  ///
  /// Field type is Int32.
  final int repliesPts;

  /// Recent Repliers.
  final List<PeerBase>? recentRepliers;

  /// Channel Id.
  final int? channelId;

  /// Max Id.
  final int? maxId;

  /// Read Max Id.
  final int? readMaxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x83d60fc2.
    buffer.writeInt32(0x83d60fc2);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(replies);
    buffer.writeInt32(repliesPts);
    final localRecentRepliersCopy = recentRepliers;
    if (localRecentRepliersCopy != null) {
      buffer.writeVectorObject(localRecentRepliersCopy);
    }
    final localChannelIdCopy = channelId;
    if (localChannelIdCopy != null) {
      buffer.writeInt64(localChannelIdCopy);
    }
    final localMaxIdCopy = maxId;
    if (localMaxIdCopy != null) {
      buffer.writeInt32(localMaxIdCopy);
    }
    final localReadMaxIdCopy = readMaxId;
    if (localReadMaxIdCopy != null) {
      buffer.writeInt32(localReadMaxIdCopy);
    }

    // Finished serialization.
  }
}

/// Peer Blocked.
///
/// ID: `e8fd8014`.
class PeerBlocked extends PeerBlockedBase {
  /// Peer Blocked constructor.
  const PeerBlocked({
    required this.peerId,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory PeerBlocked.deserialize(BinaryReader reader) {
    // Read [PeerBlocked] fields.
    final peerId = reader.readObject() as PeerBase;
    final date = reader.readDateTime();

    // Construct [PeerBlocked] object.
    final returnValue = PeerBlocked(
      peerId: peerId,
      date: date,
    );

    // Now return the deserialized [PeerBlocked].
    return returnValue;
  }

  /// Peer Id.
  final PeerBase peerId;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe8fd8014.
    buffer.writeInt32(0xe8fd8014);

    // Write fields.
    buffer.writeObject(peerId);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Stats Message Stats.
///
/// ID: `7fe91c14`.
class StatsMessageStats extends StatsMessageStatsBase {
  /// Stats Message Stats constructor.
  const StatsMessageStats({
    required this.viewsGraph,
    required this.reactionsByEmotionGraph,
  }) : super._();

  /// Deserialize.
  factory StatsMessageStats.deserialize(BinaryReader reader) {
    // Read [StatsMessageStats] fields.
    final viewsGraph = reader.readObject() as StatsGraphBase;
    final reactionsByEmotionGraph = reader.readObject() as StatsGraphBase;

    // Construct [StatsMessageStats] object.
    final returnValue = StatsMessageStats(
      viewsGraph: viewsGraph,
      reactionsByEmotionGraph: reactionsByEmotionGraph,
    );

    // Now return the deserialized [StatsMessageStats].
    return returnValue;
  }

  /// Views Graph.
  final StatsGraphBase viewsGraph;

  /// Reactions By Emotion Graph.
  final StatsGraphBase reactionsByEmotionGraph;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7fe91c14.
    buffer.writeInt32(0x7fe91c14);

    // Write fields.
    buffer.writeObject(viewsGraph);
    buffer.writeObject(reactionsByEmotionGraph);

    // Finished serialization.
  }
}

/// Group Call Discarded.
///
/// ID: `7780bcb4`.
class GroupCallDiscarded extends GroupCallBase {
  /// Group Call Discarded constructor.
  const GroupCallDiscarded({
    required this.id,
    required this.accessHash,
    required this.duration,
  }) : super._();

  /// Deserialize.
  factory GroupCallDiscarded.deserialize(BinaryReader reader) {
    // Read [GroupCallDiscarded] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final duration = reader.readInt32();

    // Construct [GroupCallDiscarded] object.
    final returnValue = GroupCallDiscarded(
      id: id,
      accessHash: accessHash,
      duration: duration,
    );

    // Now return the deserialized [GroupCallDiscarded].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Duration.
  ///
  /// Field type is Int32.
  final int duration;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7780bcb4.
    buffer.writeInt32(0x7780bcb4);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeInt32(duration);

    // Finished serialization.
  }
}

/// Group Call.
///
/// ID: `d597650c`.
class GroupCall extends GroupCallBase {
  /// Group Call constructor.
  const GroupCall({
    required this.joinMuted,
    required this.canChangeJoinMuted,
    required this.joinDateAsc,
    required this.scheduleStartSubscribed,
    required this.canStartVideo,
    required this.recordVideoActive,
    required this.rtmpStream,
    required this.listenersHidden,
    required this.id,
    required this.accessHash,
    required this.participantsCount,
    this.title,
    this.streamDcId,
    this.recordStartDate,
    this.scheduleDate,
    this.unmutedVideoCount,
    required this.unmutedVideoLimit,
    required this.version,
  }) : super._();

  /// Deserialize.
  factory GroupCall.deserialize(BinaryReader reader) {
    // Read [GroupCall] fields.
    final flags = reader.readInt32();
    final joinMuted = (flags & 2) != 0;
    final canChangeJoinMuted = (flags & 4) != 0;
    final joinDateAsc = (flags & 64) != 0;
    final scheduleStartSubscribed = (flags & 256) != 0;
    final canStartVideo = (flags & 512) != 0;
    final recordVideoActive = (flags & 2048) != 0;
    final rtmpStream = (flags & 4096) != 0;
    final listenersHidden = (flags & 8192) != 0;
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final participantsCount = reader.readInt32();
    final hasTitleField = (flags & 8) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasStreamDcIdField = (flags & 16) != 0;
    final streamDcId = hasStreamDcIdField ? reader.readInt32() : null;
    final hasRecordStartDateField = (flags & 32) != 0;
    final recordStartDate =
        hasRecordStartDateField ? reader.readDateTime() : null;
    final hasScheduleDateField = (flags & 128) != 0;
    final scheduleDate = hasScheduleDateField ? reader.readDateTime() : null;
    final hasUnmutedVideoCountField = (flags & 1024) != 0;
    final unmutedVideoCount =
        hasUnmutedVideoCountField ? reader.readInt32() : null;
    final unmutedVideoLimit = reader.readInt32();
    final version = reader.readInt32();

    // Construct [GroupCall] object.
    final returnValue = GroupCall(
      joinMuted: joinMuted,
      canChangeJoinMuted: canChangeJoinMuted,
      joinDateAsc: joinDateAsc,
      scheduleStartSubscribed: scheduleStartSubscribed,
      canStartVideo: canStartVideo,
      recordVideoActive: recordVideoActive,
      rtmpStream: rtmpStream,
      listenersHidden: listenersHidden,
      id: id,
      accessHash: accessHash,
      participantsCount: participantsCount,
      title: title,
      streamDcId: streamDcId,
      recordStartDate: recordStartDate,
      scheduleDate: scheduleDate,
      unmutedVideoCount: unmutedVideoCount,
      unmutedVideoLimit: unmutedVideoLimit,
      version: version,
    );

    // Now return the deserialized [GroupCall].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: joinMuted,
      b02: canChangeJoinMuted,
      b06: joinDateAsc,
      b08: scheduleStartSubscribed,
      b09: canStartVideo,
      b11: recordVideoActive,
      b12: rtmpStream,
      b13: listenersHidden,
      b03: title != null,
      b04: streamDcId != null,
      b05: recordStartDate != null,
      b07: scheduleDate != null,
      b10: unmutedVideoCount != null,
    );

    return v;
  }

  /// join_muted: bit 1 of flags.1?true
  final bool joinMuted;

  /// can_change_join_muted: bit 2 of flags.2?true
  final bool canChangeJoinMuted;

  /// join_date_asc: bit 6 of flags.6?true
  final bool joinDateAsc;

  /// schedule_start_subscribed: bit 8 of flags.8?true
  final bool scheduleStartSubscribed;

  /// can_start_video: bit 9 of flags.9?true
  final bool canStartVideo;

  /// record_video_active: bit 11 of flags.11?true
  final bool recordVideoActive;

  /// rtmp_stream: bit 12 of flags.12?true
  final bool rtmpStream;

  /// listeners_hidden: bit 13 of flags.13?true
  final bool listenersHidden;

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Participants Count.
  ///
  /// Field type is Int32.
  final int participantsCount;

  /// Title.
  final String? title;

  /// Stream Dc Id.
  final int? streamDcId;

  /// Record Start Date.
  final DateTime? recordStartDate;

  /// Schedule Date.
  final DateTime? scheduleDate;

  /// Unmuted Video Count.
  final int? unmutedVideoCount;

  /// Unmuted Video Limit.
  ///
  /// Field type is Int32.
  final int unmutedVideoLimit;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd597650c.
    buffer.writeInt32(0xd597650c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeInt32(participantsCount);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localStreamDcIdCopy = streamDcId;
    if (localStreamDcIdCopy != null) {
      buffer.writeInt32(localStreamDcIdCopy);
    }
    final localRecordStartDateCopy = recordStartDate;
    if (localRecordStartDateCopy != null) {
      buffer.writeDateTime(localRecordStartDateCopy);
    }
    final localScheduleDateCopy = scheduleDate;
    if (localScheduleDateCopy != null) {
      buffer.writeDateTime(localScheduleDateCopy);
    }
    final localUnmutedVideoCountCopy = unmutedVideoCount;
    if (localUnmutedVideoCountCopy != null) {
      buffer.writeInt32(localUnmutedVideoCountCopy);
    }
    buffer.writeInt32(unmutedVideoLimit);
    buffer.writeInt32(version);

    // Finished serialization.
  }
}

/// Input Group Call.
///
/// ID: `d8aa840f`.
class InputGroupCall extends InputGroupCallBase {
  /// Input Group Call constructor.
  const InputGroupCall({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputGroupCall.deserialize(BinaryReader reader) {
    // Read [InputGroupCall] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputGroupCall] object.
    final returnValue = InputGroupCall(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputGroupCall].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd8aa840f.
    buffer.writeInt32(0xd8aa840f);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Group Call Participant.
///
/// ID: `eba636fe`.
class GroupCallParticipant extends GroupCallParticipantBase {
  /// Group Call Participant constructor.
  const GroupCallParticipant({
    required this.muted,
    required this.left,
    required this.canSelfUnmute,
    required this.justJoined,
    required this.versioned,
    required this.min,
    required this.mutedByYou,
    required this.volumeByAdmin,
    required this.self,
    required this.videoJoined,
    required this.peer,
    required this.date,
    this.activeDate,
    required this.source,
    this.volume,
    this.about,
    this.raiseHandRating,
    this.video,
    this.presentation,
  }) : super._();

  /// Deserialize.
  factory GroupCallParticipant.deserialize(BinaryReader reader) {
    // Read [GroupCallParticipant] fields.
    final flags = reader.readInt32();
    final muted = (flags & 1) != 0;
    final left = (flags & 2) != 0;
    final canSelfUnmute = (flags & 4) != 0;
    final justJoined = (flags & 16) != 0;
    final versioned = (flags & 32) != 0;
    final min = (flags & 256) != 0;
    final mutedByYou = (flags & 512) != 0;
    final volumeByAdmin = (flags & 1024) != 0;
    final self = (flags & 4096) != 0;
    final videoJoined = (flags & 32768) != 0;
    final peer = reader.readObject() as PeerBase;
    final date = reader.readDateTime();
    final hasActiveDateField = (flags & 8) != 0;
    final activeDate = hasActiveDateField ? reader.readDateTime() : null;
    final source = reader.readInt32();
    final hasVolumeField = (flags & 128) != 0;
    final volume = hasVolumeField ? reader.readInt32() : null;
    final hasAboutField = (flags & 2048) != 0;
    final about = hasAboutField ? reader.readString() : null;
    final hasRaiseHandRatingField = (flags & 8192) != 0;
    final raiseHandRating = hasRaiseHandRatingField ? reader.readInt64() : null;
    final hasVideoField = (flags & 64) != 0;
    final video = hasVideoField
        ? reader.readObject() as GroupCallParticipantVideoBase
        : null;
    final hasPresentationField = (flags & 16384) != 0;
    final presentation = hasPresentationField
        ? reader.readObject() as GroupCallParticipantVideoBase
        : null;

    // Construct [GroupCallParticipant] object.
    final returnValue = GroupCallParticipant(
      muted: muted,
      left: left,
      canSelfUnmute: canSelfUnmute,
      justJoined: justJoined,
      versioned: versioned,
      min: min,
      mutedByYou: mutedByYou,
      volumeByAdmin: volumeByAdmin,
      self: self,
      videoJoined: videoJoined,
      peer: peer,
      date: date,
      activeDate: activeDate,
      source: source,
      volume: volume,
      about: about,
      raiseHandRating: raiseHandRating,
      video: video,
      presentation: presentation,
    );

    // Now return the deserialized [GroupCallParticipant].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: muted,
      b01: left,
      b02: canSelfUnmute,
      b04: justJoined,
      b05: versioned,
      b08: min,
      b09: mutedByYou,
      b10: volumeByAdmin,
      b12: self,
      b15: videoJoined,
      b03: activeDate != null,
      b07: volume != null,
      b11: about != null,
      b13: raiseHandRating != null,
      b06: video != null,
      b14: presentation != null,
    );

    return v;
  }

  /// muted: bit 0 of flags.0?true
  final bool muted;

  /// left: bit 1 of flags.1?true
  final bool left;

  /// can_self_unmute: bit 2 of flags.2?true
  final bool canSelfUnmute;

  /// just_joined: bit 4 of flags.4?true
  final bool justJoined;

  /// versioned: bit 5 of flags.5?true
  final bool versioned;

  /// min: bit 8 of flags.8?true
  final bool min;

  /// muted_by_you: bit 9 of flags.9?true
  final bool mutedByYou;

  /// volume_by_admin: bit 10 of flags.10?true
  final bool volumeByAdmin;

  /// self: bit 12 of flags.12?true
  final bool self;

  /// video_joined: bit 15 of flags.15?true
  final bool videoJoined;

  /// Peer.
  final PeerBase peer;

  /// Date.
  final DateTime date;

  /// Active Date.
  final DateTime? activeDate;

  /// Source.
  ///
  /// Field type is Int32.
  final int source;

  /// Volume.
  final int? volume;

  /// About.
  final String? about;

  /// Raise Hand Rating.
  final int? raiseHandRating;

  /// Video.
  final GroupCallParticipantVideoBase? video;

  /// Presentation.
  final GroupCallParticipantVideoBase? presentation;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeba636fe.
    buffer.writeInt32(0xeba636fe);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeDateTime(date);
    final localActiveDateCopy = activeDate;
    if (localActiveDateCopy != null) {
      buffer.writeDateTime(localActiveDateCopy);
    }
    buffer.writeInt32(source);
    final localVolumeCopy = volume;
    if (localVolumeCopy != null) {
      buffer.writeInt32(localVolumeCopy);
    }
    final localAboutCopy = about;
    if (localAboutCopy != null) {
      buffer.writeString(localAboutCopy);
    }
    final localRaiseHandRatingCopy = raiseHandRating;
    if (localRaiseHandRatingCopy != null) {
      buffer.writeInt64(localRaiseHandRatingCopy);
    }
    final localVideoCopy = video;
    if (localVideoCopy != null) {
      buffer.writeObject(localVideoCopy);
    }
    final localPresentationCopy = presentation;
    if (localPresentationCopy != null) {
      buffer.writeObject(localPresentationCopy);
    }

    // Finished serialization.
  }
}

/// Phone Group Call.
///
/// ID: `9e727aad`.
class PhoneGroupCall extends PhoneGroupCallBase {
  /// Phone Group Call constructor.
  const PhoneGroupCall({
    required this.call,
    required this.participants,
    required this.participantsNextOffset,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PhoneGroupCall.deserialize(BinaryReader reader) {
    // Read [PhoneGroupCall] fields.
    final call = reader.readObject() as GroupCallBase;
    final participants = reader.readVectorObject<GroupCallParticipantBase>();
    final participantsNextOffset = reader.readString();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [PhoneGroupCall] object.
    final returnValue = PhoneGroupCall(
      call: call,
      participants: participants,
      participantsNextOffset: participantsNextOffset,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [PhoneGroupCall].
    return returnValue;
  }

  /// Call.
  final GroupCallBase call;

  /// Participants.
  final List<GroupCallParticipantBase> participants;

  /// Participants Next Offset.
  final String participantsNextOffset;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9e727aad.
    buffer.writeInt32(0x9e727aad);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeVectorObject(participants);
    buffer.writeString(participantsNextOffset);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Phone Group Participants.
///
/// ID: `f47751b6`.
class PhoneGroupParticipants extends PhoneGroupParticipantsBase {
  /// Phone Group Participants constructor.
  const PhoneGroupParticipants({
    required this.count,
    required this.participants,
    required this.nextOffset,
    required this.chats,
    required this.users,
    required this.version,
  }) : super._();

  /// Deserialize.
  factory PhoneGroupParticipants.deserialize(BinaryReader reader) {
    // Read [PhoneGroupParticipants] fields.
    final count = reader.readInt32();
    final participants = reader.readVectorObject<GroupCallParticipantBase>();
    final nextOffset = reader.readString();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final version = reader.readInt32();

    // Construct [PhoneGroupParticipants] object.
    final returnValue = PhoneGroupParticipants(
      count: count,
      participants: participants,
      nextOffset: nextOffset,
      chats: chats,
      users: users,
      version: version,
    );

    // Now return the deserialized [PhoneGroupParticipants].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Participants.
  final List<GroupCallParticipantBase> participants;

  /// Next Offset.
  final String nextOffset;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf47751b6.
    buffer.writeInt32(0xf47751b6);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(participants);
    buffer.writeString(nextOffset);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    buffer.writeInt32(version);

    // Finished serialization.
  }
}

/// Inline Query Peer Type Same Bot P M.
///
/// ID: `3081ed9d`.
class InlineQueryPeerTypeSameBotPM extends InlineQueryPeerTypeBase {
  /// Inline Query Peer Type Same Bot P M constructor.
  const InlineQueryPeerTypeSameBotPM() : super._();

  /// Deserialize.
  factory InlineQueryPeerTypeSameBotPM.deserialize(BinaryReader reader) {
    // Construct [InlineQueryPeerTypeSameBotPM] object.
    final returnValue = InlineQueryPeerTypeSameBotPM();

    // Now return the deserialized [InlineQueryPeerTypeSameBotPM].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3081ed9d.
    buffer.writeInt32(0x3081ed9d);

    // Finished serialization.
  }
}

/// Inline Query Peer Type P M.
///
/// ID: `833c0fac`.
class InlineQueryPeerTypePM extends InlineQueryPeerTypeBase {
  /// Inline Query Peer Type P M constructor.
  const InlineQueryPeerTypePM() : super._();

  /// Deserialize.
  factory InlineQueryPeerTypePM.deserialize(BinaryReader reader) {
    // Construct [InlineQueryPeerTypePM] object.
    final returnValue = InlineQueryPeerTypePM();

    // Now return the deserialized [InlineQueryPeerTypePM].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x833c0fac.
    buffer.writeInt32(0x833c0fac);

    // Finished serialization.
  }
}

/// Inline Query Peer Type Chat.
///
/// ID: `d766c50a`.
class InlineQueryPeerTypeChat extends InlineQueryPeerTypeBase {
  /// Inline Query Peer Type Chat constructor.
  const InlineQueryPeerTypeChat() : super._();

  /// Deserialize.
  factory InlineQueryPeerTypeChat.deserialize(BinaryReader reader) {
    // Construct [InlineQueryPeerTypeChat] object.
    final returnValue = InlineQueryPeerTypeChat();

    // Now return the deserialized [InlineQueryPeerTypeChat].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd766c50a.
    buffer.writeInt32(0xd766c50a);

    // Finished serialization.
  }
}

/// Inline Query Peer Type Megagroup.
///
/// ID: `5ec4be43`.
class InlineQueryPeerTypeMegagroup extends InlineQueryPeerTypeBase {
  /// Inline Query Peer Type Megagroup constructor.
  const InlineQueryPeerTypeMegagroup() : super._();

  /// Deserialize.
  factory InlineQueryPeerTypeMegagroup.deserialize(BinaryReader reader) {
    // Construct [InlineQueryPeerTypeMegagroup] object.
    final returnValue = InlineQueryPeerTypeMegagroup();

    // Now return the deserialized [InlineQueryPeerTypeMegagroup].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5ec4be43.
    buffer.writeInt32(0x5ec4be43);

    // Finished serialization.
  }
}

/// Inline Query Peer Type Broadcast.
///
/// ID: `6334ee9a`.
class InlineQueryPeerTypeBroadcast extends InlineQueryPeerTypeBase {
  /// Inline Query Peer Type Broadcast constructor.
  const InlineQueryPeerTypeBroadcast() : super._();

  /// Deserialize.
  factory InlineQueryPeerTypeBroadcast.deserialize(BinaryReader reader) {
    // Construct [InlineQueryPeerTypeBroadcast] object.
    final returnValue = InlineQueryPeerTypeBroadcast();

    // Now return the deserialized [InlineQueryPeerTypeBroadcast].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6334ee9a.
    buffer.writeInt32(0x6334ee9a);

    // Finished serialization.
  }
}

/// Inline Query Peer Type Bot P M.
///
/// ID: `0e3b2d0c`.
class InlineQueryPeerTypeBotPM extends InlineQueryPeerTypeBase {
  /// Inline Query Peer Type Bot P M constructor.
  const InlineQueryPeerTypeBotPM() : super._();

  /// Deserialize.
  factory InlineQueryPeerTypeBotPM.deserialize(BinaryReader reader) {
    // Construct [InlineQueryPeerTypeBotPM] object.
    final returnValue = InlineQueryPeerTypeBotPM();

    // Now return the deserialized [InlineQueryPeerTypeBotPM].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0e3b2d0c.
    buffer.writeInt32(0x0e3b2d0c);

    // Finished serialization.
  }
}

/// Messages History Import.
///
/// ID: `1662af0b`.
class MessagesHistoryImport extends MessagesHistoryImportBase {
  /// Messages History Import constructor.
  const MessagesHistoryImport({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesHistoryImport.deserialize(BinaryReader reader) {
    // Read [MessagesHistoryImport] fields.
    final id = reader.readInt64();

    // Construct [MessagesHistoryImport] object.
    final returnValue = MessagesHistoryImport(
      id: id,
    );

    // Now return the deserialized [MessagesHistoryImport].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1662af0b.
    buffer.writeInt32(0x1662af0b);

    // Write fields.
    buffer.writeInt64(id);

    // Finished serialization.
  }
}

/// Messages History Import Parsed.
///
/// ID: `5e0fb7b9`.
class MessagesHistoryImportParsed extends MessagesHistoryImportParsedBase {
  /// Messages History Import Parsed constructor.
  const MessagesHistoryImportParsed({
    required this.pm,
    required this.group,
    this.title,
  }) : super._();

  /// Deserialize.
  factory MessagesHistoryImportParsed.deserialize(BinaryReader reader) {
    // Read [MessagesHistoryImportParsed] fields.
    final flags = reader.readInt32();
    final pm = (flags & 1) != 0;
    final group = (flags & 2) != 0;
    final hasTitleField = (flags & 4) != 0;
    final title = hasTitleField ? reader.readString() : null;

    // Construct [MessagesHistoryImportParsed] object.
    final returnValue = MessagesHistoryImportParsed(
      pm: pm,
      group: group,
      title: title,
    );

    // Now return the deserialized [MessagesHistoryImportParsed].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pm,
      b01: group,
      b02: title != null,
    );

    return v;
  }

  /// pm: bit 0 of flags.0?true
  final bool pm;

  /// group: bit 1 of flags.1?true
  final bool group;

  /// Title.
  final String? title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5e0fb7b9.
    buffer.writeInt32(0x5e0fb7b9);

    // Write fields.
    buffer.writeInt32(flags);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }

    // Finished serialization.
  }
}

/// Messages Affected Found Messages.
///
/// ID: `ef8d3e6c`.
class MessagesAffectedFoundMessages extends MessagesAffectedFoundMessagesBase {
  /// Messages Affected Found Messages constructor.
  const MessagesAffectedFoundMessages({
    required this.pts,
    required this.ptsCount,
    required this.offset,
    required this.messages,
  }) : super._();

  /// Deserialize.
  factory MessagesAffectedFoundMessages.deserialize(BinaryReader reader) {
    // Read [MessagesAffectedFoundMessages] fields.
    final pts = reader.readInt32();
    final ptsCount = reader.readInt32();
    final offset = reader.readInt32();
    final messages = reader.readVectorInt32();

    // Construct [MessagesAffectedFoundMessages] object.
    final returnValue = MessagesAffectedFoundMessages(
      pts: pts,
      ptsCount: ptsCount,
      offset: offset,
      messages: messages,
    );

    // Now return the deserialized [MessagesAffectedFoundMessages].
    return returnValue;
  }

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Count.
  ///
  /// Field type is Int32.
  final int ptsCount;

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Messages.
  final List<int> messages;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xef8d3e6c.
    buffer.writeInt32(0xef8d3e6c);

    // Write fields.
    buffer.writeInt32(pts);
    buffer.writeInt32(ptsCount);
    buffer.writeInt32(offset);
    buffer.writeVectorInt32(messages);

    // Finished serialization.
  }
}

/// Chat Invite Importer.
///
/// ID: `8c5adfd9`.
class ChatInviteImporter extends ChatInviteImporterBase {
  /// Chat Invite Importer constructor.
  const ChatInviteImporter({
    required this.requested,
    required this.viaChatlist,
    required this.userId,
    required this.date,
    this.about,
    this.approvedBy,
  }) : super._();

  /// Deserialize.
  factory ChatInviteImporter.deserialize(BinaryReader reader) {
    // Read [ChatInviteImporter] fields.
    final flags = reader.readInt32();
    final requested = (flags & 1) != 0;
    final viaChatlist = (flags & 8) != 0;
    final userId = reader.readInt64();
    final date = reader.readDateTime();
    final hasAboutField = (flags & 4) != 0;
    final about = hasAboutField ? reader.readString() : null;
    final hasApprovedByField = (flags & 2) != 0;
    final approvedBy = hasApprovedByField ? reader.readInt64() : null;

    // Construct [ChatInviteImporter] object.
    final returnValue = ChatInviteImporter(
      requested: requested,
      viaChatlist: viaChatlist,
      userId: userId,
      date: date,
      about: about,
      approvedBy: approvedBy,
    );

    // Now return the deserialized [ChatInviteImporter].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: requested,
      b03: viaChatlist,
      b02: about != null,
      b01: approvedBy != null,
    );

    return v;
  }

  /// requested: bit 0 of flags.0?true
  final bool requested;

  /// via_chatlist: bit 3 of flags.3?true
  final bool viaChatlist;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Date.
  final DateTime date;

  /// About.
  final String? about;

  /// Approved By.
  final int? approvedBy;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8c5adfd9.
    buffer.writeInt32(0x8c5adfd9);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(userId);
    buffer.writeDateTime(date);
    final localAboutCopy = about;
    if (localAboutCopy != null) {
      buffer.writeString(localAboutCopy);
    }
    final localApprovedByCopy = approvedBy;
    if (localApprovedByCopy != null) {
      buffer.writeInt64(localApprovedByCopy);
    }

    // Finished serialization.
  }
}

/// Messages Exported Chat Invites.
///
/// ID: `bdc62dcc`.
class MessagesExportedChatInvites extends MessagesExportedChatInvitesBase {
  /// Messages Exported Chat Invites constructor.
  const MessagesExportedChatInvites({
    required this.count,
    required this.invites,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesExportedChatInvites.deserialize(BinaryReader reader) {
    // Read [MessagesExportedChatInvites] fields.
    final count = reader.readInt32();
    final invites = reader.readVectorObject<ExportedChatInviteBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesExportedChatInvites] object.
    final returnValue = MessagesExportedChatInvites(
      count: count,
      invites: invites,
      users: users,
    );

    // Now return the deserialized [MessagesExportedChatInvites].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Invites.
  final List<ExportedChatInviteBase> invites;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbdc62dcc.
    buffer.writeInt32(0xbdc62dcc);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(invites);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Exported Chat Invite.
///
/// ID: `1871be50`.
class MessagesExportedChatInvite extends MessagesExportedChatInviteBase {
  /// Messages Exported Chat Invite constructor.
  const MessagesExportedChatInvite({
    required this.invite,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesExportedChatInvite.deserialize(BinaryReader reader) {
    // Read [MessagesExportedChatInvite] fields.
    final invite = reader.readObject() as ExportedChatInviteBase;
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesExportedChatInvite] object.
    final returnValue = MessagesExportedChatInvite(
      invite: invite,
      users: users,
    );

    // Now return the deserialized [MessagesExportedChatInvite].
    return returnValue;
  }

  /// Invite.
  final ExportedChatInviteBase invite;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1871be50.
    buffer.writeInt32(0x1871be50);

    // Write fields.
    buffer.writeObject(invite);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Exported Chat Invite Replaced.
///
/// ID: `222600ef`.
class MessagesExportedChatInviteReplaced
    extends MessagesExportedChatInviteBase {
  /// Messages Exported Chat Invite Replaced constructor.
  const MessagesExportedChatInviteReplaced({
    required this.invite,
    required this.newInvite,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesExportedChatInviteReplaced.deserialize(BinaryReader reader) {
    // Read [MessagesExportedChatInviteReplaced] fields.
    final invite = reader.readObject() as ExportedChatInviteBase;
    final newInvite = reader.readObject() as ExportedChatInviteBase;
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesExportedChatInviteReplaced] object.
    final returnValue = MessagesExportedChatInviteReplaced(
      invite: invite,
      newInvite: newInvite,
      users: users,
    );

    // Now return the deserialized [MessagesExportedChatInviteReplaced].
    return returnValue;
  }

  /// Invite.
  final ExportedChatInviteBase invite;

  /// New Invite.
  final ExportedChatInviteBase newInvite;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x222600ef.
    buffer.writeInt32(0x222600ef);

    // Write fields.
    buffer.writeObject(invite);
    buffer.writeObject(newInvite);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Chat Invite Importers.
///
/// ID: `81b6b00a`.
class MessagesChatInviteImporters extends MessagesChatInviteImportersBase {
  /// Messages Chat Invite Importers constructor.
  const MessagesChatInviteImporters({
    required this.count,
    required this.importers,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesChatInviteImporters.deserialize(BinaryReader reader) {
    // Read [MessagesChatInviteImporters] fields.
    final count = reader.readInt32();
    final importers = reader.readVectorObject<ChatInviteImporterBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesChatInviteImporters] object.
    final returnValue = MessagesChatInviteImporters(
      count: count,
      importers: importers,
      users: users,
    );

    // Now return the deserialized [MessagesChatInviteImporters].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Importers.
  final List<ChatInviteImporterBase> importers;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x81b6b00a.
    buffer.writeInt32(0x81b6b00a);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(importers);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Chat Admin With Invites.
///
/// ID: `f2ecef23`.
class ChatAdminWithInvites extends ChatAdminWithInvitesBase {
  /// Chat Admin With Invites constructor.
  const ChatAdminWithInvites({
    required this.adminId,
    required this.invitesCount,
    required this.revokedInvitesCount,
  }) : super._();

  /// Deserialize.
  factory ChatAdminWithInvites.deserialize(BinaryReader reader) {
    // Read [ChatAdminWithInvites] fields.
    final adminId = reader.readInt64();
    final invitesCount = reader.readInt32();
    final revokedInvitesCount = reader.readInt32();

    // Construct [ChatAdminWithInvites] object.
    final returnValue = ChatAdminWithInvites(
      adminId: adminId,
      invitesCount: invitesCount,
      revokedInvitesCount: revokedInvitesCount,
    );

    // Now return the deserialized [ChatAdminWithInvites].
    return returnValue;
  }

  /// Admin Id.
  ///
  /// Field type is Int64.
  final int adminId;

  /// Invites Count.
  ///
  /// Field type is Int32.
  final int invitesCount;

  /// Revoked Invites Count.
  ///
  /// Field type is Int32.
  final int revokedInvitesCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf2ecef23.
    buffer.writeInt32(0xf2ecef23);

    // Write fields.
    buffer.writeInt64(adminId);
    buffer.writeInt32(invitesCount);
    buffer.writeInt32(revokedInvitesCount);

    // Finished serialization.
  }
}

/// Messages Chat Admins With Invites.
///
/// ID: `b69b72d7`.
class MessagesChatAdminsWithInvites extends MessagesChatAdminsWithInvitesBase {
  /// Messages Chat Admins With Invites constructor.
  const MessagesChatAdminsWithInvites({
    required this.admins,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesChatAdminsWithInvites.deserialize(BinaryReader reader) {
    // Read [MessagesChatAdminsWithInvites] fields.
    final admins = reader.readVectorObject<ChatAdminWithInvitesBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesChatAdminsWithInvites] object.
    final returnValue = MessagesChatAdminsWithInvites(
      admins: admins,
      users: users,
    );

    // Now return the deserialized [MessagesChatAdminsWithInvites].
    return returnValue;
  }

  /// Admins.
  final List<ChatAdminWithInvitesBase> admins;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb69b72d7.
    buffer.writeInt32(0xb69b72d7);

    // Write fields.
    buffer.writeVectorObject(admins);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Checked History Import Peer.
///
/// ID: `a24de717`.
class MessagesCheckedHistoryImportPeer
    extends MessagesCheckedHistoryImportPeerBase {
  /// Messages Checked History Import Peer constructor.
  const MessagesCheckedHistoryImportPeer({
    required this.confirmText,
  }) : super._();

  /// Deserialize.
  factory MessagesCheckedHistoryImportPeer.deserialize(BinaryReader reader) {
    // Read [MessagesCheckedHistoryImportPeer] fields.
    final confirmText = reader.readString();

    // Construct [MessagesCheckedHistoryImportPeer] object.
    final returnValue = MessagesCheckedHistoryImportPeer(
      confirmText: confirmText,
    );

    // Now return the deserialized [MessagesCheckedHistoryImportPeer].
    return returnValue;
  }

  /// Confirm Text.
  final String confirmText;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa24de717.
    buffer.writeInt32(0xa24de717);

    // Write fields.
    buffer.writeString(confirmText);

    // Finished serialization.
  }
}

/// Phone Join As Peers.
///
/// ID: `afe5623f`.
class PhoneJoinAsPeers extends PhoneJoinAsPeersBase {
  /// Phone Join As Peers constructor.
  const PhoneJoinAsPeers({
    required this.peers,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PhoneJoinAsPeers.deserialize(BinaryReader reader) {
    // Read [PhoneJoinAsPeers] fields.
    final peers = reader.readVectorObject<PeerBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [PhoneJoinAsPeers] object.
    final returnValue = PhoneJoinAsPeers(
      peers: peers,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [PhoneJoinAsPeers].
    return returnValue;
  }

  /// Peers.
  final List<PeerBase> peers;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xafe5623f.
    buffer.writeInt32(0xafe5623f);

    // Write fields.
    buffer.writeVectorObject(peers);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Phone Exported Group Call Invite.
///
/// ID: `204bd158`.
class PhoneExportedGroupCallInvite extends PhoneExportedGroupCallInviteBase {
  /// Phone Exported Group Call Invite constructor.
  const PhoneExportedGroupCallInvite({
    required this.link,
  }) : super._();

  /// Deserialize.
  factory PhoneExportedGroupCallInvite.deserialize(BinaryReader reader) {
    // Read [PhoneExportedGroupCallInvite] fields.
    final link = reader.readString();

    // Construct [PhoneExportedGroupCallInvite] object.
    final returnValue = PhoneExportedGroupCallInvite(
      link: link,
    );

    // Now return the deserialized [PhoneExportedGroupCallInvite].
    return returnValue;
  }

  /// Link.
  final String link;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x204bd158.
    buffer.writeInt32(0x204bd158);

    // Write fields.
    buffer.writeString(link);

    // Finished serialization.
  }
}

/// Group Call Participant Video Source Group.
///
/// ID: `dcb118b7`.
class GroupCallParticipantVideoSourceGroup
    extends GroupCallParticipantVideoSourceGroupBase {
  /// Group Call Participant Video Source Group constructor.
  const GroupCallParticipantVideoSourceGroup({
    required this.semantics,
    required this.sources,
  }) : super._();

  /// Deserialize.
  factory GroupCallParticipantVideoSourceGroup.deserialize(
      BinaryReader reader) {
    // Read [GroupCallParticipantVideoSourceGroup] fields.
    final semantics = reader.readString();
    final sources = reader.readVectorInt32();

    // Construct [GroupCallParticipantVideoSourceGroup] object.
    final returnValue = GroupCallParticipantVideoSourceGroup(
      semantics: semantics,
      sources: sources,
    );

    // Now return the deserialized [GroupCallParticipantVideoSourceGroup].
    return returnValue;
  }

  /// Semantics.
  final String semantics;

  /// Sources.
  final List<int> sources;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdcb118b7.
    buffer.writeInt32(0xdcb118b7);

    // Write fields.
    buffer.writeString(semantics);
    buffer.writeVectorInt32(sources);

    // Finished serialization.
  }
}

/// Group Call Participant Video.
///
/// ID: `67753ac8`.
class GroupCallParticipantVideo extends GroupCallParticipantVideoBase {
  /// Group Call Participant Video constructor.
  const GroupCallParticipantVideo({
    required this.paused,
    required this.endpoint,
    required this.sourceGroups,
    this.audioSource,
  }) : super._();

  /// Deserialize.
  factory GroupCallParticipantVideo.deserialize(BinaryReader reader) {
    // Read [GroupCallParticipantVideo] fields.
    final flags = reader.readInt32();
    final paused = (flags & 1) != 0;
    final endpoint = reader.readString();
    final sourceGroups =
        reader.readVectorObject<GroupCallParticipantVideoSourceGroupBase>();
    final hasAudioSourceField = (flags & 2) != 0;
    final audioSource = hasAudioSourceField ? reader.readInt32() : null;

    // Construct [GroupCallParticipantVideo] object.
    final returnValue = GroupCallParticipantVideo(
      paused: paused,
      endpoint: endpoint,
      sourceGroups: sourceGroups,
      audioSource: audioSource,
    );

    // Now return the deserialized [GroupCallParticipantVideo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: paused,
      b01: audioSource != null,
    );

    return v;
  }

  /// paused: bit 0 of flags.0?true
  final bool paused;

  /// Endpoint.
  final String endpoint;

  /// Source Groups.
  final List<GroupCallParticipantVideoSourceGroupBase> sourceGroups;

  /// Audio Source.
  final int? audioSource;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x67753ac8.
    buffer.writeInt32(0x67753ac8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(endpoint);
    buffer.writeVectorObject(sourceGroups);
    final localAudioSourceCopy = audioSource;
    if (localAudioSourceCopy != null) {
      buffer.writeInt32(localAudioSourceCopy);
    }

    // Finished serialization.
  }
}

/// Stickers Suggested Short Name.
///
/// ID: `85fea03f`.
class StickersSuggestedShortName extends StickersSuggestedShortNameBase {
  /// Stickers Suggested Short Name constructor.
  const StickersSuggestedShortName({
    required this.shortName,
  }) : super._();

  /// Deserialize.
  factory StickersSuggestedShortName.deserialize(BinaryReader reader) {
    // Read [StickersSuggestedShortName] fields.
    final shortName = reader.readString();

    // Construct [StickersSuggestedShortName] object.
    final returnValue = StickersSuggestedShortName(
      shortName: shortName,
    );

    // Now return the deserialized [StickersSuggestedShortName].
    return returnValue;
  }

  /// Short Name.
  final String shortName;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x85fea03f.
    buffer.writeInt32(0x85fea03f);

    // Write fields.
    buffer.writeString(shortName);

    // Finished serialization.
  }
}

/// Bot Command Scope Default.
///
/// ID: `2f6cb2ab`.
class BotCommandScopeDefault extends BotCommandScopeBase {
  /// Bot Command Scope Default constructor.
  const BotCommandScopeDefault() : super._();

  /// Deserialize.
  factory BotCommandScopeDefault.deserialize(BinaryReader reader) {
    // Construct [BotCommandScopeDefault] object.
    final returnValue = BotCommandScopeDefault();

    // Now return the deserialized [BotCommandScopeDefault].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2f6cb2ab.
    buffer.writeInt32(0x2f6cb2ab);

    // Finished serialization.
  }
}

/// Bot Command Scope Users.
///
/// ID: `3c4f04d8`.
class BotCommandScopeUsers extends BotCommandScopeBase {
  /// Bot Command Scope Users constructor.
  const BotCommandScopeUsers() : super._();

  /// Deserialize.
  factory BotCommandScopeUsers.deserialize(BinaryReader reader) {
    // Construct [BotCommandScopeUsers] object.
    final returnValue = BotCommandScopeUsers();

    // Now return the deserialized [BotCommandScopeUsers].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3c4f04d8.
    buffer.writeInt32(0x3c4f04d8);

    // Finished serialization.
  }
}

/// Bot Command Scope Chats.
///
/// ID: `6fe1a881`.
class BotCommandScopeChats extends BotCommandScopeBase {
  /// Bot Command Scope Chats constructor.
  const BotCommandScopeChats() : super._();

  /// Deserialize.
  factory BotCommandScopeChats.deserialize(BinaryReader reader) {
    // Construct [BotCommandScopeChats] object.
    final returnValue = BotCommandScopeChats();

    // Now return the deserialized [BotCommandScopeChats].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6fe1a881.
    buffer.writeInt32(0x6fe1a881);

    // Finished serialization.
  }
}

/// Bot Command Scope Chat Admins.
///
/// ID: `b9aa606a`.
class BotCommandScopeChatAdmins extends BotCommandScopeBase {
  /// Bot Command Scope Chat Admins constructor.
  const BotCommandScopeChatAdmins() : super._();

  /// Deserialize.
  factory BotCommandScopeChatAdmins.deserialize(BinaryReader reader) {
    // Construct [BotCommandScopeChatAdmins] object.
    final returnValue = BotCommandScopeChatAdmins();

    // Now return the deserialized [BotCommandScopeChatAdmins].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb9aa606a.
    buffer.writeInt32(0xb9aa606a);

    // Finished serialization.
  }
}

/// Bot Command Scope Peer.
///
/// ID: `db9d897d`.
class BotCommandScopePeer extends BotCommandScopeBase {
  /// Bot Command Scope Peer constructor.
  const BotCommandScopePeer({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory BotCommandScopePeer.deserialize(BinaryReader reader) {
    // Read [BotCommandScopePeer] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [BotCommandScopePeer] object.
    final returnValue = BotCommandScopePeer(
      peer: peer,
    );

    // Now return the deserialized [BotCommandScopePeer].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdb9d897d.
    buffer.writeInt32(0xdb9d897d);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Bot Command Scope Peer Admins.
///
/// ID: `3fd863d1`.
class BotCommandScopePeerAdmins extends BotCommandScopeBase {
  /// Bot Command Scope Peer Admins constructor.
  const BotCommandScopePeerAdmins({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory BotCommandScopePeerAdmins.deserialize(BinaryReader reader) {
    // Read [BotCommandScopePeerAdmins] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [BotCommandScopePeerAdmins] object.
    final returnValue = BotCommandScopePeerAdmins(
      peer: peer,
    );

    // Now return the deserialized [BotCommandScopePeerAdmins].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3fd863d1.
    buffer.writeInt32(0x3fd863d1);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Bot Command Scope Peer User.
///
/// ID: `0a1321f3`.
class BotCommandScopePeerUser extends BotCommandScopeBase {
  /// Bot Command Scope Peer User constructor.
  const BotCommandScopePeerUser({
    required this.peer,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory BotCommandScopePeerUser.deserialize(BinaryReader reader) {
    // Read [BotCommandScopePeerUser] fields.
    final peer = reader.readObject() as InputPeerBase;
    final userId = reader.readObject() as InputUserBase;

    // Construct [BotCommandScopePeerUser] object.
    final returnValue = BotCommandScopePeerUser(
      peer: peer,
      userId: userId,
    );

    // Now return the deserialized [BotCommandScopePeerUser].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// User Id.
  final InputUserBase userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0a1321f3.
    buffer.writeInt32(0x0a1321f3);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(userId);

    // Finished serialization.
  }
}

/// Account Reset Password Failed Wait.
///
/// ID: `e3779861`.
class AccountResetPasswordFailedWait extends AccountResetPasswordResultBase {
  /// Account Reset Password Failed Wait constructor.
  const AccountResetPasswordFailedWait({
    required this.retryDate,
  }) : super._();

  /// Deserialize.
  factory AccountResetPasswordFailedWait.deserialize(BinaryReader reader) {
    // Read [AccountResetPasswordFailedWait] fields.
    final retryDate = reader.readDateTime();

    // Construct [AccountResetPasswordFailedWait] object.
    final returnValue = AccountResetPasswordFailedWait(
      retryDate: retryDate,
    );

    // Now return the deserialized [AccountResetPasswordFailedWait].
    return returnValue;
  }

  /// Retry Date.
  final DateTime retryDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe3779861.
    buffer.writeInt32(0xe3779861);

    // Write fields.
    buffer.writeDateTime(retryDate);

    // Finished serialization.
  }
}

/// Account Reset Password Requested Wait.
///
/// ID: `e9effc7d`.
class AccountResetPasswordRequestedWait extends AccountResetPasswordResultBase {
  /// Account Reset Password Requested Wait constructor.
  const AccountResetPasswordRequestedWait({
    required this.untilDate,
  }) : super._();

  /// Deserialize.
  factory AccountResetPasswordRequestedWait.deserialize(BinaryReader reader) {
    // Read [AccountResetPasswordRequestedWait] fields.
    final untilDate = reader.readDateTime();

    // Construct [AccountResetPasswordRequestedWait] object.
    final returnValue = AccountResetPasswordRequestedWait(
      untilDate: untilDate,
    );

    // Now return the deserialized [AccountResetPasswordRequestedWait].
    return returnValue;
  }

  /// Until Date.
  final DateTime untilDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe9effc7d.
    buffer.writeInt32(0xe9effc7d);

    // Write fields.
    buffer.writeDateTime(untilDate);

    // Finished serialization.
  }
}

/// Account Reset Password Ok.
///
/// ID: `e926d63e`.
class AccountResetPasswordOk extends AccountResetPasswordResultBase {
  /// Account Reset Password Ok constructor.
  const AccountResetPasswordOk() : super._();

  /// Deserialize.
  factory AccountResetPasswordOk.deserialize(BinaryReader reader) {
    // Construct [AccountResetPasswordOk] object.
    final returnValue = AccountResetPasswordOk();

    // Now return the deserialized [AccountResetPasswordOk].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe926d63e.
    buffer.writeInt32(0xe926d63e);

    // Finished serialization.
  }
}

/// Sponsored Message.
///
/// ID: `ed5383f7`.
class SponsoredMessage extends SponsoredMessageBase {
  /// Sponsored Message constructor.
  const SponsoredMessage({
    required this.recommended,
    required this.showPeerPhoto,
    required this.randomId,
    this.fromId,
    this.chatInvite,
    this.chatInviteHash,
    this.channelPost,
    this.startParam,
    this.webpage,
    this.app,
    required this.message,
    this.entities,
    this.buttonText,
    this.sponsorInfo,
    this.additionalInfo,
  }) : super._();

  /// Deserialize.
  factory SponsoredMessage.deserialize(BinaryReader reader) {
    // Read [SponsoredMessage] fields.
    final flags = reader.readInt32();
    final recommended = (flags & 32) != 0;
    final showPeerPhoto = (flags & 64) != 0;
    final randomId = reader.readBytes();
    final hasFromIdField = (flags & 8) != 0;
    final fromId = hasFromIdField ? reader.readObject() as PeerBase : null;
    final hasChatInviteField = (flags & 16) != 0;
    final chatInvite =
        hasChatInviteField ? reader.readObject() as ChatInviteBase : null;
    final hasChatInviteHashField = (flags & 16) != 0;
    final chatInviteHash = hasChatInviteHashField ? reader.readString() : null;
    final hasChannelPostField = (flags & 4) != 0;
    final channelPost = hasChannelPostField ? reader.readInt32() : null;
    final hasStartParamField = (flags & 1) != 0;
    final startParam = hasStartParamField ? reader.readString() : null;
    final hasWebpageField = (flags & 512) != 0;
    final webpage =
        hasWebpageField ? reader.readObject() as SponsoredWebPageBase : null;
    final hasAppField = (flags & 1024) != 0;
    final app = hasAppField ? reader.readObject() as BotAppBase : null;
    final message = reader.readString();
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasButtonTextField = (flags & 2048) != 0;
    final buttonText = hasButtonTextField ? reader.readString() : null;
    final hasSponsorInfoField = (flags & 128) != 0;
    final sponsorInfo = hasSponsorInfoField ? reader.readString() : null;
    final hasAdditionalInfoField = (flags & 256) != 0;
    final additionalInfo = hasAdditionalInfoField ? reader.readString() : null;

    // Construct [SponsoredMessage] object.
    final returnValue = SponsoredMessage(
      recommended: recommended,
      showPeerPhoto: showPeerPhoto,
      randomId: randomId,
      fromId: fromId,
      chatInvite: chatInvite,
      chatInviteHash: chatInviteHash,
      channelPost: channelPost,
      startParam: startParam,
      webpage: webpage,
      app: app,
      message: message,
      entities: entities,
      buttonText: buttonText,
      sponsorInfo: sponsorInfo,
      additionalInfo: additionalInfo,
    );

    // Now return the deserialized [SponsoredMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b05: recommended,
      b06: showPeerPhoto,
      b03: fromId != null,
      b04: chatInvite != null || chatInviteHash != null,
      b02: channelPost != null,
      b00: startParam != null,
      b09: webpage != null,
      b10: app != null,
      b01: entities != null,
      b11: buttonText != null,
      b07: sponsorInfo != null,
      b08: additionalInfo != null,
    );

    return v;
  }

  /// recommended: bit 5 of flags.5?true
  final bool recommended;

  /// show_peer_photo: bit 6 of flags.6?true
  final bool showPeerPhoto;

  /// Random Id.
  final Uint8List randomId;

  /// From Id.
  final PeerBase? fromId;

  /// Chat Invite.
  final ChatInviteBase? chatInvite;

  /// Chat Invite Hash.
  final String? chatInviteHash;

  /// Channel Post.
  final int? channelPost;

  /// Start Param.
  final String? startParam;

  /// Webpage.
  final SponsoredWebPageBase? webpage;

  /// App.
  final BotAppBase? app;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Button Text.
  final String? buttonText;

  /// Sponsor Info.
  final String? sponsorInfo;

  /// Additional Info.
  final String? additionalInfo;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xed5383f7.
    buffer.writeInt32(0xed5383f7);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeBytes(randomId);
    final localFromIdCopy = fromId;
    if (localFromIdCopy != null) {
      buffer.writeObject(localFromIdCopy);
    }
    final localChatInviteCopy = chatInvite;
    if (localChatInviteCopy != null) {
      buffer.writeObject(localChatInviteCopy);
    }
    final localChatInviteHashCopy = chatInviteHash;
    if (localChatInviteHashCopy != null) {
      buffer.writeString(localChatInviteHashCopy);
    }
    final localChannelPostCopy = channelPost;
    if (localChannelPostCopy != null) {
      buffer.writeInt32(localChannelPostCopy);
    }
    final localStartParamCopy = startParam;
    if (localStartParamCopy != null) {
      buffer.writeString(localStartParamCopy);
    }
    final localWebpageCopy = webpage;
    if (localWebpageCopy != null) {
      buffer.writeObject(localWebpageCopy);
    }
    final localAppCopy = app;
    if (localAppCopy != null) {
      buffer.writeObject(localAppCopy);
    }
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localButtonTextCopy = buttonText;
    if (localButtonTextCopy != null) {
      buffer.writeString(localButtonTextCopy);
    }
    final localSponsorInfoCopy = sponsorInfo;
    if (localSponsorInfoCopy != null) {
      buffer.writeString(localSponsorInfoCopy);
    }
    final localAdditionalInfoCopy = additionalInfo;
    if (localAdditionalInfoCopy != null) {
      buffer.writeString(localAdditionalInfoCopy);
    }

    // Finished serialization.
  }
}

/// Messages Sponsored Messages.
///
/// ID: `c9ee1d87`.
class MessagesSponsoredMessages extends MessagesSponsoredMessagesBase {
  /// Messages Sponsored Messages constructor.
  const MessagesSponsoredMessages({
    this.postsBetween,
    required this.messages,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesSponsoredMessages.deserialize(BinaryReader reader) {
    // Read [MessagesSponsoredMessages] fields.
    final flags = reader.readInt32();
    final hasPostsBetweenField = (flags & 1) != 0;
    final postsBetween = hasPostsBetweenField ? reader.readInt32() : null;
    final messages = reader.readVectorObject<SponsoredMessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesSponsoredMessages] object.
    final returnValue = MessagesSponsoredMessages(
      postsBetween: postsBetween,
      messages: messages,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesSponsoredMessages].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: postsBetween != null,
    );

    return v;
  }

  /// Posts Between.
  final int? postsBetween;

  /// Messages.
  final List<SponsoredMessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc9ee1d87.
    buffer.writeInt32(0xc9ee1d87);

    // Write fields.
    buffer.writeInt32(flags);
    final localPostsBetweenCopy = postsBetween;
    if (localPostsBetweenCopy != null) {
      buffer.writeInt32(localPostsBetweenCopy);
    }
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Sponsored Messages Empty.
///
/// ID: `1839490f`.
class MessagesSponsoredMessagesEmpty extends MessagesSponsoredMessagesBase {
  /// Messages Sponsored Messages Empty constructor.
  const MessagesSponsoredMessagesEmpty() : super._();

  /// Deserialize.
  factory MessagesSponsoredMessagesEmpty.deserialize(BinaryReader reader) {
    // Construct [MessagesSponsoredMessagesEmpty] object.
    final returnValue = MessagesSponsoredMessagesEmpty();

    // Now return the deserialized [MessagesSponsoredMessagesEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1839490f.
    buffer.writeInt32(0x1839490f);

    // Finished serialization.
  }
}

/// Search Results Calendar Period.
///
/// ID: `c9b0539f`.
class SearchResultsCalendarPeriod extends SearchResultsCalendarPeriodBase {
  /// Search Results Calendar Period constructor.
  const SearchResultsCalendarPeriod({
    required this.date,
    required this.minMsgId,
    required this.maxMsgId,
    required this.count,
  }) : super._();

  /// Deserialize.
  factory SearchResultsCalendarPeriod.deserialize(BinaryReader reader) {
    // Read [SearchResultsCalendarPeriod] fields.
    final date = reader.readDateTime();
    final minMsgId = reader.readInt32();
    final maxMsgId = reader.readInt32();
    final count = reader.readInt32();

    // Construct [SearchResultsCalendarPeriod] object.
    final returnValue = SearchResultsCalendarPeriod(
      date: date,
      minMsgId: minMsgId,
      maxMsgId: maxMsgId,
      count: count,
    );

    // Now return the deserialized [SearchResultsCalendarPeriod].
    return returnValue;
  }

  /// Date.
  final DateTime date;

  /// Min Msg Id.
  ///
  /// Field type is Int32.
  final int minMsgId;

  /// Max Msg Id.
  ///
  /// Field type is Int32.
  final int maxMsgId;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc9b0539f.
    buffer.writeInt32(0xc9b0539f);

    // Write fields.
    buffer.writeDateTime(date);
    buffer.writeInt32(minMsgId);
    buffer.writeInt32(maxMsgId);
    buffer.writeInt32(count);

    // Finished serialization.
  }
}

/// Messages Search Results Calendar.
///
/// ID: `147ee23c`.
class MessagesSearchResultsCalendar extends MessagesSearchResultsCalendarBase {
  /// Messages Search Results Calendar constructor.
  const MessagesSearchResultsCalendar({
    required this.inexact,
    required this.count,
    required this.minDate,
    required this.minMsgId,
    this.offsetIdOffset,
    required this.periods,
    required this.messages,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesSearchResultsCalendar.deserialize(BinaryReader reader) {
    // Read [MessagesSearchResultsCalendar] fields.
    final flags = reader.readInt32();
    final inexact = (flags & 1) != 0;
    final count = reader.readInt32();
    final minDate = reader.readDateTime();
    final minMsgId = reader.readInt32();
    final hasOffsetIdOffsetField = (flags & 2) != 0;
    final offsetIdOffset = hasOffsetIdOffsetField ? reader.readInt32() : null;
    final periods = reader.readVectorObject<SearchResultsCalendarPeriodBase>();
    final messages = reader.readVectorObject<MessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesSearchResultsCalendar] object.
    final returnValue = MessagesSearchResultsCalendar(
      inexact: inexact,
      count: count,
      minDate: minDate,
      minMsgId: minMsgId,
      offsetIdOffset: offsetIdOffset,
      periods: periods,
      messages: messages,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesSearchResultsCalendar].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: inexact,
      b01: offsetIdOffset != null,
    );

    return v;
  }

  /// inexact: bit 0 of flags.0?true
  final bool inexact;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Min Date.
  final DateTime minDate;

  /// Min Msg Id.
  ///
  /// Field type is Int32.
  final int minMsgId;

  /// Offset Id Offset.
  final int? offsetIdOffset;

  /// Periods.
  final List<SearchResultsCalendarPeriodBase> periods;

  /// Messages.
  final List<MessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x147ee23c.
    buffer.writeInt32(0x147ee23c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(count);
    buffer.writeDateTime(minDate);
    buffer.writeInt32(minMsgId);
    final localOffsetIdOffsetCopy = offsetIdOffset;
    if (localOffsetIdOffsetCopy != null) {
      buffer.writeInt32(localOffsetIdOffsetCopy);
    }
    buffer.writeVectorObject(periods);
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Search Result Position.
///
/// ID: `7f648b67`.
class SearchResultPosition extends SearchResultsPositionBase {
  /// Search Result Position constructor.
  const SearchResultPosition({
    required this.msgId,
    required this.date,
    required this.offset,
  }) : super._();

  /// Deserialize.
  factory SearchResultPosition.deserialize(BinaryReader reader) {
    // Read [SearchResultPosition] fields.
    final msgId = reader.readInt32();
    final date = reader.readDateTime();
    final offset = reader.readInt32();

    // Construct [SearchResultPosition] object.
    final returnValue = SearchResultPosition(
      msgId: msgId,
      date: date,
      offset: offset,
    );

    // Now return the deserialized [SearchResultPosition].
    return returnValue;
  }

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Date.
  final DateTime date;

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7f648b67.
    buffer.writeInt32(0x7f648b67);

    // Write fields.
    buffer.writeInt32(msgId);
    buffer.writeDateTime(date);
    buffer.writeInt32(offset);

    // Finished serialization.
  }
}

/// Messages Search Results Positions.
///
/// ID: `53b22baf`.
class MessagesSearchResultsPositions
    extends MessagesSearchResultsPositionsBase {
  /// Messages Search Results Positions constructor.
  const MessagesSearchResultsPositions({
    required this.count,
    required this.positions,
  }) : super._();

  /// Deserialize.
  factory MessagesSearchResultsPositions.deserialize(BinaryReader reader) {
    // Read [MessagesSearchResultsPositions] fields.
    final count = reader.readInt32();
    final positions = reader.readVectorObject<SearchResultsPositionBase>();

    // Construct [MessagesSearchResultsPositions] object.
    final returnValue = MessagesSearchResultsPositions(
      count: count,
      positions: positions,
    );

    // Now return the deserialized [MessagesSearchResultsPositions].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Positions.
  final List<SearchResultsPositionBase> positions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x53b22baf.
    buffer.writeInt32(0x53b22baf);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(positions);

    // Finished serialization.
  }
}

/// Channels Send As Peers.
///
/// ID: `f496b0c6`.
class ChannelsSendAsPeers extends ChannelsSendAsPeersBase {
  /// Channels Send As Peers constructor.
  const ChannelsSendAsPeers({
    required this.peers,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ChannelsSendAsPeers.deserialize(BinaryReader reader) {
    // Read [ChannelsSendAsPeers] fields.
    final peers = reader.readVectorObject<SendAsPeerBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ChannelsSendAsPeers] object.
    final returnValue = ChannelsSendAsPeers(
      peers: peers,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ChannelsSendAsPeers].
    return returnValue;
  }

  /// Peers.
  final List<SendAsPeerBase> peers;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf496b0c6.
    buffer.writeInt32(0xf496b0c6);

    // Write fields.
    buffer.writeVectorObject(peers);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Users User Full.
///
/// ID: `3b6d152e`.
class UsersUserFull extends UsersUserFullBase {
  /// Users User Full constructor.
  const UsersUserFull({
    required this.fullUser,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory UsersUserFull.deserialize(BinaryReader reader) {
    // Read [UsersUserFull] fields.
    final fullUser = reader.readObject() as UserFullBase;
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [UsersUserFull] object.
    final returnValue = UsersUserFull(
      fullUser: fullUser,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [UsersUserFull].
    return returnValue;
  }

  /// Full User.
  final UserFullBase fullUser;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3b6d152e.
    buffer.writeInt32(0x3b6d152e);

    // Write fields.
    buffer.writeObject(fullUser);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Peer Settings.
///
/// ID: `6880b94d`.
class MessagesPeerSettings extends MessagesPeerSettingsBase {
  /// Messages Peer Settings constructor.
  const MessagesPeerSettings({
    required this.settings,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesPeerSettings.deserialize(BinaryReader reader) {
    // Read [MessagesPeerSettings] fields.
    final settings = reader.readObject() as PeerSettingsBase;
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesPeerSettings] object.
    final returnValue = MessagesPeerSettings(
      settings: settings,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesPeerSettings].
    return returnValue;
  }

  /// Settings.
  final PeerSettingsBase settings;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6880b94d.
    buffer.writeInt32(0x6880b94d);

    // Write fields.
    buffer.writeObject(settings);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Auth Logged Out.
///
/// ID: `c3a2835f`.
class AuthLoggedOut extends AuthLoggedOutBase {
  /// Auth Logged Out constructor.
  const AuthLoggedOut({
    this.futureAuthToken,
  }) : super._();

  /// Deserialize.
  factory AuthLoggedOut.deserialize(BinaryReader reader) {
    // Read [AuthLoggedOut] fields.
    final flags = reader.readInt32();
    final hasFutureAuthTokenField = (flags & 1) != 0;
    final futureAuthToken = hasFutureAuthTokenField ? reader.readBytes() : null;

    // Construct [AuthLoggedOut] object.
    final returnValue = AuthLoggedOut(
      futureAuthToken: futureAuthToken,
    );

    // Now return the deserialized [AuthLoggedOut].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: futureAuthToken != null,
    );

    return v;
  }

  /// Future Auth Token.
  final Uint8List? futureAuthToken;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc3a2835f.
    buffer.writeInt32(0xc3a2835f);

    // Write fields.
    buffer.writeInt32(flags);
    final localFutureAuthTokenCopy = futureAuthToken;
    if (localFutureAuthTokenCopy != null) {
      buffer.writeBytes(localFutureAuthTokenCopy);
    }

    // Finished serialization.
  }
}

/// Reaction Count.
///
/// ID: `a3d1cb80`.
class ReactionCount extends ReactionCountBase {
  /// Reaction Count constructor.
  const ReactionCount({
    this.chosenOrder,
    required this.reaction,
    required this.count,
  }) : super._();

  /// Deserialize.
  factory ReactionCount.deserialize(BinaryReader reader) {
    // Read [ReactionCount] fields.
    final flags = reader.readInt32();
    final hasChosenOrderField = (flags & 1) != 0;
    final chosenOrder = hasChosenOrderField ? reader.readInt32() : null;
    final reaction = reader.readObject() as ReactionBase;
    final count = reader.readInt32();

    // Construct [ReactionCount] object.
    final returnValue = ReactionCount(
      chosenOrder: chosenOrder,
      reaction: reaction,
      count: count,
    );

    // Now return the deserialized [ReactionCount].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: chosenOrder != null,
    );

    return v;
  }

  /// Chosen Order.
  final int? chosenOrder;

  /// Reaction.
  final ReactionBase reaction;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa3d1cb80.
    buffer.writeInt32(0xa3d1cb80);

    // Write fields.
    buffer.writeInt32(flags);
    final localChosenOrderCopy = chosenOrder;
    if (localChosenOrderCopy != null) {
      buffer.writeInt32(localChosenOrderCopy);
    }
    buffer.writeObject(reaction);
    buffer.writeInt32(count);

    // Finished serialization.
  }
}

/// Message Reactions.
///
/// ID: `4f2b9479`.
class MessageReactions extends MessageReactionsBase {
  /// Message Reactions constructor.
  const MessageReactions({
    required this.min,
    required this.canSeeList,
    required this.results,
    this.recentReactions,
  }) : super._();

  /// Deserialize.
  factory MessageReactions.deserialize(BinaryReader reader) {
    // Read [MessageReactions] fields.
    final flags = reader.readInt32();
    final min = (flags & 1) != 0;
    final canSeeList = (flags & 4) != 0;
    final results = reader.readVectorObject<ReactionCountBase>();
    final hasRecentReactionsField = (flags & 2) != 0;
    final recentReactions = hasRecentReactionsField
        ? reader.readVectorObject<MessagePeerReactionBase>()
        : null;

    // Construct [MessageReactions] object.
    final returnValue = MessageReactions(
      min: min,
      canSeeList: canSeeList,
      results: results,
      recentReactions: recentReactions,
    );

    // Now return the deserialized [MessageReactions].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: min,
      b02: canSeeList,
      b01: recentReactions != null,
    );

    return v;
  }

  /// min: bit 0 of flags.0?true
  final bool min;

  /// can_see_list: bit 2 of flags.2?true
  final bool canSeeList;

  /// Results.
  final List<ReactionCountBase> results;

  /// Recent Reactions.
  final List<MessagePeerReactionBase>? recentReactions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4f2b9479.
    buffer.writeInt32(0x4f2b9479);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(results);
    final localRecentReactionsCopy = recentReactions;
    if (localRecentReactionsCopy != null) {
      buffer.writeVectorObject(localRecentReactionsCopy);
    }

    // Finished serialization.
  }
}

/// Messages Message Reactions List.
///
/// ID: `31bd492d`.
class MessagesMessageReactionsList extends MessagesMessageReactionsListBase {
  /// Messages Message Reactions List constructor.
  const MessagesMessageReactionsList({
    required this.count,
    required this.reactions,
    required this.chats,
    required this.users,
    this.nextOffset,
  }) : super._();

  /// Deserialize.
  factory MessagesMessageReactionsList.deserialize(BinaryReader reader) {
    // Read [MessagesMessageReactionsList] fields.
    final flags = reader.readInt32();
    final count = reader.readInt32();
    final reactions = reader.readVectorObject<MessagePeerReactionBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final hasNextOffsetField = (flags & 1) != 0;
    final nextOffset = hasNextOffsetField ? reader.readString() : null;

    // Construct [MessagesMessageReactionsList] object.
    final returnValue = MessagesMessageReactionsList(
      count: count,
      reactions: reactions,
      chats: chats,
      users: users,
      nextOffset: nextOffset,
    );

    // Now return the deserialized [MessagesMessageReactionsList].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: nextOffset != null,
    );

    return v;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Reactions.
  final List<MessagePeerReactionBase> reactions;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Next Offset.
  final String? nextOffset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x31bd492d.
    buffer.writeInt32(0x31bd492d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(count);
    buffer.writeVectorObject(reactions);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    final localNextOffsetCopy = nextOffset;
    if (localNextOffsetCopy != null) {
      buffer.writeString(localNextOffsetCopy);
    }

    // Finished serialization.
  }
}

/// Available Reaction.
///
/// ID: `c077ec01`.
class AvailableReaction extends AvailableReactionBase {
  /// Available Reaction constructor.
  const AvailableReaction({
    required this.inactive,
    required this.premium,
    required this.reaction,
    required this.title,
    required this.staticIcon,
    required this.appearAnimation,
    required this.selectAnimation,
    required this.activateAnimation,
    required this.effectAnimation,
    this.aroundAnimation,
    this.centerIcon,
  }) : super._();

  /// Deserialize.
  factory AvailableReaction.deserialize(BinaryReader reader) {
    // Read [AvailableReaction] fields.
    final flags = reader.readInt32();
    final inactive = (flags & 1) != 0;
    final premium = (flags & 4) != 0;
    final reaction = reader.readString();
    final title = reader.readString();
    final staticIcon = reader.readObject() as DocumentBase;
    final appearAnimation = reader.readObject() as DocumentBase;
    final selectAnimation = reader.readObject() as DocumentBase;
    final activateAnimation = reader.readObject() as DocumentBase;
    final effectAnimation = reader.readObject() as DocumentBase;
    final hasAroundAnimationField = (flags & 2) != 0;
    final aroundAnimation =
        hasAroundAnimationField ? reader.readObject() as DocumentBase : null;
    final hasCenterIconField = (flags & 2) != 0;
    final centerIcon =
        hasCenterIconField ? reader.readObject() as DocumentBase : null;

    // Construct [AvailableReaction] object.
    final returnValue = AvailableReaction(
      inactive: inactive,
      premium: premium,
      reaction: reaction,
      title: title,
      staticIcon: staticIcon,
      appearAnimation: appearAnimation,
      selectAnimation: selectAnimation,
      activateAnimation: activateAnimation,
      effectAnimation: effectAnimation,
      aroundAnimation: aroundAnimation,
      centerIcon: centerIcon,
    );

    // Now return the deserialized [AvailableReaction].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: inactive,
      b02: premium,
      b01: aroundAnimation != null || centerIcon != null,
    );

    return v;
  }

  /// inactive: bit 0 of flags.0?true
  final bool inactive;

  /// premium: bit 2 of flags.2?true
  final bool premium;

  /// Reaction.
  final String reaction;

  /// Title.
  final String title;

  /// Static Icon.
  final DocumentBase staticIcon;

  /// Appear Animation.
  final DocumentBase appearAnimation;

  /// Select Animation.
  final DocumentBase selectAnimation;

  /// Activate Animation.
  final DocumentBase activateAnimation;

  /// Effect Animation.
  final DocumentBase effectAnimation;

  /// Around Animation.
  final DocumentBase? aroundAnimation;

  /// Center Icon.
  final DocumentBase? centerIcon;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc077ec01.
    buffer.writeInt32(0xc077ec01);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(reaction);
    buffer.writeString(title);
    buffer.writeObject(staticIcon);
    buffer.writeObject(appearAnimation);
    buffer.writeObject(selectAnimation);
    buffer.writeObject(activateAnimation);
    buffer.writeObject(effectAnimation);
    final localAroundAnimationCopy = aroundAnimation;
    if (localAroundAnimationCopy != null) {
      buffer.writeObject(localAroundAnimationCopy);
    }
    final localCenterIconCopy = centerIcon;
    if (localCenterIconCopy != null) {
      buffer.writeObject(localCenterIconCopy);
    }

    // Finished serialization.
  }
}

/// Messages Available Reactions Not Modified.
///
/// ID: `9f071957`.
class MessagesAvailableReactionsNotModified
    extends MessagesAvailableReactionsBase {
  /// Messages Available Reactions Not Modified constructor.
  const MessagesAvailableReactionsNotModified() : super._();

  /// Deserialize.
  factory MessagesAvailableReactionsNotModified.deserialize(
      BinaryReader reader) {
    // Construct [MessagesAvailableReactionsNotModified] object.
    final returnValue = MessagesAvailableReactionsNotModified();

    // Now return the deserialized [MessagesAvailableReactionsNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9f071957.
    buffer.writeInt32(0x9f071957);

    // Finished serialization.
  }
}

/// Messages Available Reactions.
///
/// ID: `768e3aad`.
class MessagesAvailableReactions extends MessagesAvailableReactionsBase {
  /// Messages Available Reactions constructor.
  const MessagesAvailableReactions({
    required this.hash,
    required this.reactions,
  }) : super._();

  /// Deserialize.
  factory MessagesAvailableReactions.deserialize(BinaryReader reader) {
    // Read [MessagesAvailableReactions] fields.
    final hash = reader.readInt32();
    final reactions = reader.readVectorObject<AvailableReactionBase>();

    // Construct [MessagesAvailableReactions] object.
    final returnValue = MessagesAvailableReactions(
      hash: hash,
      reactions: reactions,
    );

    // Now return the deserialized [MessagesAvailableReactions].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Reactions.
  final List<AvailableReactionBase> reactions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x768e3aad.
    buffer.writeInt32(0x768e3aad);

    // Write fields.
    buffer.writeInt32(hash);
    buffer.writeVectorObject(reactions);

    // Finished serialization.
  }
}

/// Message Peer Reaction.
///
/// ID: `8c79b63c`.
class MessagePeerReaction extends MessagePeerReactionBase {
  /// Message Peer Reaction constructor.
  const MessagePeerReaction({
    required this.big,
    required this.unread,
    required this.my,
    required this.peerId,
    required this.date,
    required this.reaction,
  }) : super._();

  /// Deserialize.
  factory MessagePeerReaction.deserialize(BinaryReader reader) {
    // Read [MessagePeerReaction] fields.
    final flags = reader.readInt32();
    final big = (flags & 1) != 0;
    final unread = (flags & 2) != 0;
    final my = (flags & 4) != 0;
    final peerId = reader.readObject() as PeerBase;
    final date = reader.readDateTime();
    final reaction = reader.readObject() as ReactionBase;

    // Construct [MessagePeerReaction] object.
    final returnValue = MessagePeerReaction(
      big: big,
      unread: unread,
      my: my,
      peerId: peerId,
      date: date,
      reaction: reaction,
    );

    // Now return the deserialized [MessagePeerReaction].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: big,
      b01: unread,
      b02: my,
    );

    return v;
  }

  /// big: bit 0 of flags.0?true
  final bool big;

  /// unread: bit 1 of flags.1?true
  final bool unread;

  /// my: bit 2 of flags.2?true
  final bool my;

  /// Peer Id.
  final PeerBase peerId;

  /// Date.
  final DateTime date;

  /// Reaction.
  final ReactionBase reaction;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8c79b63c.
    buffer.writeInt32(0x8c79b63c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peerId);
    buffer.writeDateTime(date);
    buffer.writeObject(reaction);

    // Finished serialization.
  }
}

/// Group Call Stream Channel.
///
/// ID: `80eb48af`.
class GroupCallStreamChannel extends GroupCallStreamChannelBase {
  /// Group Call Stream Channel constructor.
  const GroupCallStreamChannel({
    required this.channel,
    required this.scale,
    required this.lastTimestampMs,
  }) : super._();

  /// Deserialize.
  factory GroupCallStreamChannel.deserialize(BinaryReader reader) {
    // Read [GroupCallStreamChannel] fields.
    final channel = reader.readInt32();
    final scale = reader.readInt32();
    final lastTimestampMs = reader.readInt64();

    // Construct [GroupCallStreamChannel] object.
    final returnValue = GroupCallStreamChannel(
      channel: channel,
      scale: scale,
      lastTimestampMs: lastTimestampMs,
    );

    // Now return the deserialized [GroupCallStreamChannel].
    return returnValue;
  }

  /// Channel.
  ///
  /// Field type is Int32.
  final int channel;

  /// Scale.
  ///
  /// Field type is Int32.
  final int scale;

  /// Last Timestamp Ms.
  ///
  /// Field type is Int64.
  final int lastTimestampMs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x80eb48af.
    buffer.writeInt32(0x80eb48af);

    // Write fields.
    buffer.writeInt32(channel);
    buffer.writeInt32(scale);
    buffer.writeInt64(lastTimestampMs);

    // Finished serialization.
  }
}

/// Phone Group Call Stream Channels.
///
/// ID: `d0e482b2`.
class PhoneGroupCallStreamChannels extends PhoneGroupCallStreamChannelsBase {
  /// Phone Group Call Stream Channels constructor.
  const PhoneGroupCallStreamChannels({
    required this.channels,
  }) : super._();

  /// Deserialize.
  factory PhoneGroupCallStreamChannels.deserialize(BinaryReader reader) {
    // Read [PhoneGroupCallStreamChannels] fields.
    final channels = reader.readVectorObject<GroupCallStreamChannelBase>();

    // Construct [PhoneGroupCallStreamChannels] object.
    final returnValue = PhoneGroupCallStreamChannels(
      channels: channels,
    );

    // Now return the deserialized [PhoneGroupCallStreamChannels].
    return returnValue;
  }

  /// Channels.
  final List<GroupCallStreamChannelBase> channels;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd0e482b2.
    buffer.writeInt32(0xd0e482b2);

    // Write fields.
    buffer.writeVectorObject(channels);

    // Finished serialization.
  }
}

/// Phone Group Call Stream Rtmp Url.
///
/// ID: `2dbf3432`.
class PhoneGroupCallStreamRtmpUrl extends PhoneGroupCallStreamRtmpUrlBase {
  /// Phone Group Call Stream Rtmp Url constructor.
  const PhoneGroupCallStreamRtmpUrl({
    required this.url,
    required this.key,
  }) : super._();

  /// Deserialize.
  factory PhoneGroupCallStreamRtmpUrl.deserialize(BinaryReader reader) {
    // Read [PhoneGroupCallStreamRtmpUrl] fields.
    final url = reader.readString();
    final key = reader.readString();

    // Construct [PhoneGroupCallStreamRtmpUrl] object.
    final returnValue = PhoneGroupCallStreamRtmpUrl(
      url: url,
      key: key,
    );

    // Now return the deserialized [PhoneGroupCallStreamRtmpUrl].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Key.
  final String key;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2dbf3432.
    buffer.writeInt32(0x2dbf3432);

    // Write fields.
    buffer.writeString(url);
    buffer.writeString(key);

    // Finished serialization.
  }
}

/// Attach Menu Bot Icon Color.
///
/// ID: `4576f3f0`.
class AttachMenuBotIconColor extends AttachMenuBotIconColorBase {
  /// Attach Menu Bot Icon Color constructor.
  const AttachMenuBotIconColor({
    required this.name,
    required this.color,
  }) : super._();

  /// Deserialize.
  factory AttachMenuBotIconColor.deserialize(BinaryReader reader) {
    // Read [AttachMenuBotIconColor] fields.
    final name = reader.readString();
    final color = reader.readInt32();

    // Construct [AttachMenuBotIconColor] object.
    final returnValue = AttachMenuBotIconColor(
      name: name,
      color: color,
    );

    // Now return the deserialized [AttachMenuBotIconColor].
    return returnValue;
  }

  /// Name.
  final String name;

  /// Color.
  ///
  /// Field type is Int32.
  final int color;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4576f3f0.
    buffer.writeInt32(0x4576f3f0);

    // Write fields.
    buffer.writeString(name);
    buffer.writeInt32(color);

    // Finished serialization.
  }
}

/// Attach Menu Bot Icon.
///
/// ID: `b2a7386b`.
class AttachMenuBotIcon extends AttachMenuBotIconBase {
  /// Attach Menu Bot Icon constructor.
  const AttachMenuBotIcon({
    required this.name,
    required this.icon,
    this.colors,
  }) : super._();

  /// Deserialize.
  factory AttachMenuBotIcon.deserialize(BinaryReader reader) {
    // Read [AttachMenuBotIcon] fields.
    final flags = reader.readInt32();
    final name = reader.readString();
    final icon = reader.readObject() as DocumentBase;
    final hasColorsField = (flags & 1) != 0;
    final colors = hasColorsField
        ? reader.readVectorObject<AttachMenuBotIconColorBase>()
        : null;

    // Construct [AttachMenuBotIcon] object.
    final returnValue = AttachMenuBotIcon(
      name: name,
      icon: icon,
      colors: colors,
    );

    // Now return the deserialized [AttachMenuBotIcon].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: colors != null,
    );

    return v;
  }

  /// Name.
  final String name;

  /// Icon.
  final DocumentBase icon;

  /// Colors.
  final List<AttachMenuBotIconColorBase>? colors;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb2a7386b.
    buffer.writeInt32(0xb2a7386b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(name);
    buffer.writeObject(icon);
    final localColorsCopy = colors;
    if (localColorsCopy != null) {
      buffer.writeVectorObject(localColorsCopy);
    }

    // Finished serialization.
  }
}

/// Attach Menu Bot.
///
/// ID: `d90d8dfe`.
class AttachMenuBot extends AttachMenuBotBase {
  /// Attach Menu Bot constructor.
  const AttachMenuBot({
    required this.inactive,
    required this.hasSettings,
    required this.requestWriteAccess,
    required this.showInAttachMenu,
    required this.showInSideMenu,
    required this.sideMenuDisclaimerNeeded,
    required this.botId,
    required this.shortName,
    this.peerTypes,
    required this.icons,
  }) : super._();

  /// Deserialize.
  factory AttachMenuBot.deserialize(BinaryReader reader) {
    // Read [AttachMenuBot] fields.
    final flags = reader.readInt32();
    final inactive = (flags & 1) != 0;
    final hasSettings = (flags & 2) != 0;
    final requestWriteAccess = (flags & 4) != 0;
    final showInAttachMenu = (flags & 8) != 0;
    final showInSideMenu = (flags & 16) != 0;
    final sideMenuDisclaimerNeeded = (flags & 32) != 0;
    final botId = reader.readInt64();
    final shortName = reader.readString();
    final hasPeerTypesField = (flags & 8) != 0;
    final peerTypes = hasPeerTypesField
        ? reader.readVectorObject<AttachMenuPeerTypeBase>()
        : null;
    final icons = reader.readVectorObject<AttachMenuBotIconBase>();

    // Construct [AttachMenuBot] object.
    final returnValue = AttachMenuBot(
      inactive: inactive,
      hasSettings: hasSettings,
      requestWriteAccess: requestWriteAccess,
      showInAttachMenu: showInAttachMenu,
      showInSideMenu: showInSideMenu,
      sideMenuDisclaimerNeeded: sideMenuDisclaimerNeeded,
      botId: botId,
      shortName: shortName,
      peerTypes: peerTypes,
      icons: icons,
    );

    // Now return the deserialized [AttachMenuBot].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: inactive,
      b01: hasSettings,
      b02: requestWriteAccess,
      b03: showInAttachMenu || peerTypes != null,
      b04: showInSideMenu,
      b05: sideMenuDisclaimerNeeded,
    );

    return v;
  }

  /// inactive: bit 0 of flags.0?true
  final bool inactive;

  /// has_settings: bit 1 of flags.1?true
  final bool hasSettings;

  /// request_write_access: bit 2 of flags.2?true
  final bool requestWriteAccess;

  /// show_in_attach_menu: bit 3 of flags.3?true
  final bool showInAttachMenu;

  /// show_in_side_menu: bit 4 of flags.4?true
  final bool showInSideMenu;

  /// side_menu_disclaimer_needed: bit 5 of flags.5?true
  final bool sideMenuDisclaimerNeeded;

  /// Bot Id.
  ///
  /// Field type is Int64.
  final int botId;

  /// Short Name.
  final String shortName;

  /// Peer Types.
  final List<AttachMenuPeerTypeBase>? peerTypes;

  /// Icons.
  final List<AttachMenuBotIconBase> icons;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd90d8dfe.
    buffer.writeInt32(0xd90d8dfe);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(botId);
    buffer.writeString(shortName);
    final localPeerTypesCopy = peerTypes;
    if (localPeerTypesCopy != null) {
      buffer.writeVectorObject(localPeerTypesCopy);
    }
    buffer.writeVectorObject(icons);

    // Finished serialization.
  }
}

/// Attach Menu Bots Not Modified.
///
/// ID: `f1d88a5c`.
class AttachMenuBotsNotModified extends AttachMenuBotsBase {
  /// Attach Menu Bots Not Modified constructor.
  const AttachMenuBotsNotModified() : super._();

  /// Deserialize.
  factory AttachMenuBotsNotModified.deserialize(BinaryReader reader) {
    // Construct [AttachMenuBotsNotModified] object.
    final returnValue = AttachMenuBotsNotModified();

    // Now return the deserialized [AttachMenuBotsNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf1d88a5c.
    buffer.writeInt32(0xf1d88a5c);

    // Finished serialization.
  }
}

/// Attach Menu Bots.
///
/// ID: `3c4301c0`.
class AttachMenuBots extends AttachMenuBotsBase {
  /// Attach Menu Bots constructor.
  const AttachMenuBots({
    required this.hash,
    required this.bots,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory AttachMenuBots.deserialize(BinaryReader reader) {
    // Read [AttachMenuBots] fields.
    final hash = reader.readInt64();
    final bots = reader.readVectorObject<AttachMenuBotBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [AttachMenuBots] object.
    final returnValue = AttachMenuBots(
      hash: hash,
      bots: bots,
      users: users,
    );

    // Now return the deserialized [AttachMenuBots].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Bots.
  final List<AttachMenuBotBase> bots;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3c4301c0.
    buffer.writeInt32(0x3c4301c0);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(bots);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Attach Menu Bots Bot.
///
/// ID: `93bf667f`.
class AttachMenuBotsBot extends AttachMenuBotsBotBase {
  /// Attach Menu Bots Bot constructor.
  const AttachMenuBotsBot({
    required this.bot,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory AttachMenuBotsBot.deserialize(BinaryReader reader) {
    // Read [AttachMenuBotsBot] fields.
    final bot = reader.readObject() as AttachMenuBotBase;
    final users = reader.readVectorObject<UserBase>();

    // Construct [AttachMenuBotsBot] object.
    final returnValue = AttachMenuBotsBot(
      bot: bot,
      users: users,
    );

    // Now return the deserialized [AttachMenuBotsBot].
    return returnValue;
  }

  /// Bot.
  final AttachMenuBotBase bot;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x93bf667f.
    buffer.writeInt32(0x93bf667f);

    // Write fields.
    buffer.writeObject(bot);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Web View Result Url.
///
/// ID: `0c14557c`.
class WebViewResultUrl extends WebViewResultBase {
  /// Web View Result Url constructor.
  const WebViewResultUrl({
    required this.queryId,
    required this.url,
  }) : super._();

  /// Deserialize.
  factory WebViewResultUrl.deserialize(BinaryReader reader) {
    // Read [WebViewResultUrl] fields.
    final queryId = reader.readInt64();
    final url = reader.readString();

    // Construct [WebViewResultUrl] object.
    final returnValue = WebViewResultUrl(
      queryId: queryId,
      url: url,
    );

    // Now return the deserialized [WebViewResultUrl].
    return returnValue;
  }

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0c14557c.
    buffer.writeInt32(0x0c14557c);

    // Write fields.
    buffer.writeInt64(queryId);
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Simple Web View Result Url.
///
/// ID: `882f76bb`.
class SimpleWebViewResultUrl extends SimpleWebViewResultBase {
  /// Simple Web View Result Url constructor.
  const SimpleWebViewResultUrl({
    required this.url,
  }) : super._();

  /// Deserialize.
  factory SimpleWebViewResultUrl.deserialize(BinaryReader reader) {
    // Read [SimpleWebViewResultUrl] fields.
    final url = reader.readString();

    // Construct [SimpleWebViewResultUrl] object.
    final returnValue = SimpleWebViewResultUrl(
      url: url,
    );

    // Now return the deserialized [SimpleWebViewResultUrl].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x882f76bb.
    buffer.writeInt32(0x882f76bb);

    // Write fields.
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Web View Message Sent.
///
/// ID: `0c94511c`.
class WebViewMessageSent extends WebViewMessageSentBase {
  /// Web View Message Sent constructor.
  const WebViewMessageSent({
    this.msgId,
  }) : super._();

  /// Deserialize.
  factory WebViewMessageSent.deserialize(BinaryReader reader) {
    // Read [WebViewMessageSent] fields.
    final flags = reader.readInt32();
    final hasMsgIdField = (flags & 1) != 0;
    final msgId = hasMsgIdField
        ? reader.readObject() as InputBotInlineMessageIDBase
        : null;

    // Construct [WebViewMessageSent] object.
    final returnValue = WebViewMessageSent(
      msgId: msgId,
    );

    // Now return the deserialized [WebViewMessageSent].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: msgId != null,
    );

    return v;
  }

  /// Msg Id.
  final InputBotInlineMessageIDBase? msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0c94511c.
    buffer.writeInt32(0x0c94511c);

    // Write fields.
    buffer.writeInt32(flags);
    final localMsgIdCopy = msgId;
    if (localMsgIdCopy != null) {
      buffer.writeObject(localMsgIdCopy);
    }

    // Finished serialization.
  }
}

/// Bot Menu Button Default.
///
/// ID: `7533a588`.
class BotMenuButtonDefault extends BotMenuButtonBase {
  /// Bot Menu Button Default constructor.
  const BotMenuButtonDefault() : super._();

  /// Deserialize.
  factory BotMenuButtonDefault.deserialize(BinaryReader reader) {
    // Construct [BotMenuButtonDefault] object.
    final returnValue = BotMenuButtonDefault();

    // Now return the deserialized [BotMenuButtonDefault].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7533a588.
    buffer.writeInt32(0x7533a588);

    // Finished serialization.
  }
}

/// Bot Menu Button Commands.
///
/// ID: `4258c205`.
class BotMenuButtonCommands extends BotMenuButtonBase {
  /// Bot Menu Button Commands constructor.
  const BotMenuButtonCommands() : super._();

  /// Deserialize.
  factory BotMenuButtonCommands.deserialize(BinaryReader reader) {
    // Construct [BotMenuButtonCommands] object.
    final returnValue = BotMenuButtonCommands();

    // Now return the deserialized [BotMenuButtonCommands].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4258c205.
    buffer.writeInt32(0x4258c205);

    // Finished serialization.
  }
}

/// Bot Menu Button.
///
/// ID: `c7b57ce6`.
class BotMenuButton extends BotMenuButtonBase {
  /// Bot Menu Button constructor.
  const BotMenuButton({
    required this.text,
    required this.url,
  }) : super._();

  /// Deserialize.
  factory BotMenuButton.deserialize(BinaryReader reader) {
    // Read [BotMenuButton] fields.
    final text = reader.readString();
    final url = reader.readString();

    // Construct [BotMenuButton] object.
    final returnValue = BotMenuButton(
      text: text,
      url: url,
    );

    // Now return the deserialized [BotMenuButton].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc7b57ce6.
    buffer.writeInt32(0xc7b57ce6);

    // Write fields.
    buffer.writeString(text);
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Account Saved Ringtones Not Modified.
///
/// ID: `fbf6e8b1`.
class AccountSavedRingtonesNotModified extends AccountSavedRingtonesBase {
  /// Account Saved Ringtones Not Modified constructor.
  const AccountSavedRingtonesNotModified() : super._();

  /// Deserialize.
  factory AccountSavedRingtonesNotModified.deserialize(BinaryReader reader) {
    // Construct [AccountSavedRingtonesNotModified] object.
    final returnValue = AccountSavedRingtonesNotModified();

    // Now return the deserialized [AccountSavedRingtonesNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfbf6e8b1.
    buffer.writeInt32(0xfbf6e8b1);

    // Finished serialization.
  }
}

/// Account Saved Ringtones.
///
/// ID: `c1e92cc5`.
class AccountSavedRingtones extends AccountSavedRingtonesBase {
  /// Account Saved Ringtones constructor.
  const AccountSavedRingtones({
    required this.hash,
    required this.ringtones,
  }) : super._();

  /// Deserialize.
  factory AccountSavedRingtones.deserialize(BinaryReader reader) {
    // Read [AccountSavedRingtones] fields.
    final hash = reader.readInt64();
    final ringtones = reader.readVectorObject<DocumentBase>();

    // Construct [AccountSavedRingtones] object.
    final returnValue = AccountSavedRingtones(
      hash: hash,
      ringtones: ringtones,
    );

    // Now return the deserialized [AccountSavedRingtones].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Ringtones.
  final List<DocumentBase> ringtones;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc1e92cc5.
    buffer.writeInt32(0xc1e92cc5);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(ringtones);

    // Finished serialization.
  }
}

/// Notification Sound Default.
///
/// ID: `97e8bebe`.
class NotificationSoundDefault extends NotificationSoundBase {
  /// Notification Sound Default constructor.
  const NotificationSoundDefault() : super._();

  /// Deserialize.
  factory NotificationSoundDefault.deserialize(BinaryReader reader) {
    // Construct [NotificationSoundDefault] object.
    final returnValue = NotificationSoundDefault();

    // Now return the deserialized [NotificationSoundDefault].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x97e8bebe.
    buffer.writeInt32(0x97e8bebe);

    // Finished serialization.
  }
}

/// Notification Sound None.
///
/// ID: `6f0c34df`.
class NotificationSoundNone extends NotificationSoundBase {
  /// Notification Sound None constructor.
  const NotificationSoundNone() : super._();

  /// Deserialize.
  factory NotificationSoundNone.deserialize(BinaryReader reader) {
    // Construct [NotificationSoundNone] object.
    final returnValue = NotificationSoundNone();

    // Now return the deserialized [NotificationSoundNone].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6f0c34df.
    buffer.writeInt32(0x6f0c34df);

    // Finished serialization.
  }
}

/// Notification Sound Local.
///
/// ID: `830b9ae4`.
class NotificationSoundLocal extends NotificationSoundBase {
  /// Notification Sound Local constructor.
  const NotificationSoundLocal({
    required this.title,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory NotificationSoundLocal.deserialize(BinaryReader reader) {
    // Read [NotificationSoundLocal] fields.
    final title = reader.readString();
    final data = reader.readString();

    // Construct [NotificationSoundLocal] object.
    final returnValue = NotificationSoundLocal(
      title: title,
      data: data,
    );

    // Now return the deserialized [NotificationSoundLocal].
    return returnValue;
  }

  /// Title.
  final String title;

  /// Data.
  final String data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x830b9ae4.
    buffer.writeInt32(0x830b9ae4);

    // Write fields.
    buffer.writeString(title);
    buffer.writeString(data);

    // Finished serialization.
  }
}

/// Notification Sound Ringtone.
///
/// ID: `ff6c8049`.
class NotificationSoundRingtone extends NotificationSoundBase {
  /// Notification Sound Ringtone constructor.
  const NotificationSoundRingtone({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory NotificationSoundRingtone.deserialize(BinaryReader reader) {
    // Read [NotificationSoundRingtone] fields.
    final id = reader.readInt64();

    // Construct [NotificationSoundRingtone] object.
    final returnValue = NotificationSoundRingtone(
      id: id,
    );

    // Now return the deserialized [NotificationSoundRingtone].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xff6c8049.
    buffer.writeInt32(0xff6c8049);

    // Write fields.
    buffer.writeInt64(id);

    // Finished serialization.
  }
}

/// Account Saved Ringtone.
///
/// ID: `b7263f6d`.
class AccountSavedRingtone extends AccountSavedRingtoneBase {
  /// Account Saved Ringtone constructor.
  const AccountSavedRingtone() : super._();

  /// Deserialize.
  factory AccountSavedRingtone.deserialize(BinaryReader reader) {
    // Construct [AccountSavedRingtone] object.
    final returnValue = AccountSavedRingtone();

    // Now return the deserialized [AccountSavedRingtone].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb7263f6d.
    buffer.writeInt32(0xb7263f6d);

    // Finished serialization.
  }
}

/// Account Saved Ringtone Converted.
///
/// ID: `1f307eb7`.
class AccountSavedRingtoneConverted extends AccountSavedRingtoneBase {
  /// Account Saved Ringtone Converted constructor.
  const AccountSavedRingtoneConverted({
    required this.document,
  }) : super._();

  /// Deserialize.
  factory AccountSavedRingtoneConverted.deserialize(BinaryReader reader) {
    // Read [AccountSavedRingtoneConverted] fields.
    final document = reader.readObject() as DocumentBase;

    // Construct [AccountSavedRingtoneConverted] object.
    final returnValue = AccountSavedRingtoneConverted(
      document: document,
    );

    // Now return the deserialized [AccountSavedRingtoneConverted].
    return returnValue;
  }

  /// Document.
  final DocumentBase document;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1f307eb7.
    buffer.writeInt32(0x1f307eb7);

    // Write fields.
    buffer.writeObject(document);

    // Finished serialization.
  }
}

/// Attach Menu Peer Type Same Bot P M.
///
/// ID: `7d6be90e`.
class AttachMenuPeerTypeSameBotPM extends AttachMenuPeerTypeBase {
  /// Attach Menu Peer Type Same Bot P M constructor.
  const AttachMenuPeerTypeSameBotPM() : super._();

  /// Deserialize.
  factory AttachMenuPeerTypeSameBotPM.deserialize(BinaryReader reader) {
    // Construct [AttachMenuPeerTypeSameBotPM] object.
    final returnValue = AttachMenuPeerTypeSameBotPM();

    // Now return the deserialized [AttachMenuPeerTypeSameBotPM].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7d6be90e.
    buffer.writeInt32(0x7d6be90e);

    // Finished serialization.
  }
}

/// Attach Menu Peer Type Bot P M.
///
/// ID: `c32bfa1a`.
class AttachMenuPeerTypeBotPM extends AttachMenuPeerTypeBase {
  /// Attach Menu Peer Type Bot P M constructor.
  const AttachMenuPeerTypeBotPM() : super._();

  /// Deserialize.
  factory AttachMenuPeerTypeBotPM.deserialize(BinaryReader reader) {
    // Construct [AttachMenuPeerTypeBotPM] object.
    final returnValue = AttachMenuPeerTypeBotPM();

    // Now return the deserialized [AttachMenuPeerTypeBotPM].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc32bfa1a.
    buffer.writeInt32(0xc32bfa1a);

    // Finished serialization.
  }
}

/// Attach Menu Peer Type P M.
///
/// ID: `f146d31f`.
class AttachMenuPeerTypePM extends AttachMenuPeerTypeBase {
  /// Attach Menu Peer Type P M constructor.
  const AttachMenuPeerTypePM() : super._();

  /// Deserialize.
  factory AttachMenuPeerTypePM.deserialize(BinaryReader reader) {
    // Construct [AttachMenuPeerTypePM] object.
    final returnValue = AttachMenuPeerTypePM();

    // Now return the deserialized [AttachMenuPeerTypePM].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf146d31f.
    buffer.writeInt32(0xf146d31f);

    // Finished serialization.
  }
}

/// Attach Menu Peer Type Chat.
///
/// ID: `0509113f`.
class AttachMenuPeerTypeChat extends AttachMenuPeerTypeBase {
  /// Attach Menu Peer Type Chat constructor.
  const AttachMenuPeerTypeChat() : super._();

  /// Deserialize.
  factory AttachMenuPeerTypeChat.deserialize(BinaryReader reader) {
    // Construct [AttachMenuPeerTypeChat] object.
    final returnValue = AttachMenuPeerTypeChat();

    // Now return the deserialized [AttachMenuPeerTypeChat].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0509113f.
    buffer.writeInt32(0x0509113f);

    // Finished serialization.
  }
}

/// Attach Menu Peer Type Broadcast.
///
/// ID: `7bfbdefc`.
class AttachMenuPeerTypeBroadcast extends AttachMenuPeerTypeBase {
  /// Attach Menu Peer Type Broadcast constructor.
  const AttachMenuPeerTypeBroadcast() : super._();

  /// Deserialize.
  factory AttachMenuPeerTypeBroadcast.deserialize(BinaryReader reader) {
    // Construct [AttachMenuPeerTypeBroadcast] object.
    final returnValue = AttachMenuPeerTypeBroadcast();

    // Now return the deserialized [AttachMenuPeerTypeBroadcast].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7bfbdefc.
    buffer.writeInt32(0x7bfbdefc);

    // Finished serialization.
  }
}

/// Input Invoice Message.
///
/// ID: `c5b56859`.
class InputInvoiceMessage extends InputInvoiceBase {
  /// Input Invoice Message constructor.
  const InputInvoiceMessage({
    required this.peer,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory InputInvoiceMessage.deserialize(BinaryReader reader) {
    // Read [InputInvoiceMessage] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();

    // Construct [InputInvoiceMessage] object.
    final returnValue = InputInvoiceMessage(
      peer: peer,
      msgId: msgId,
    );

    // Now return the deserialized [InputInvoiceMessage].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc5b56859.
    buffer.writeInt32(0xc5b56859);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Input Invoice Slug.
///
/// ID: `c326caef`.
class InputInvoiceSlug extends InputInvoiceBase {
  /// Input Invoice Slug constructor.
  const InputInvoiceSlug({
    required this.slug,
  }) : super._();

  /// Deserialize.
  factory InputInvoiceSlug.deserialize(BinaryReader reader) {
    // Read [InputInvoiceSlug] fields.
    final slug = reader.readString();

    // Construct [InputInvoiceSlug] object.
    final returnValue = InputInvoiceSlug(
      slug: slug,
    );

    // Now return the deserialized [InputInvoiceSlug].
    return returnValue;
  }

  /// Slug.
  final String slug;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc326caef.
    buffer.writeInt32(0xc326caef);

    // Write fields.
    buffer.writeString(slug);

    // Finished serialization.
  }
}

/// Input Invoice Premium Gift Code.
///
/// ID: `98986c0d`.
class InputInvoicePremiumGiftCode extends InputInvoiceBase {
  /// Input Invoice Premium Gift Code constructor.
  const InputInvoicePremiumGiftCode({
    required this.purpose,
    required this.option,
  }) : super._();

  /// Deserialize.
  factory InputInvoicePremiumGiftCode.deserialize(BinaryReader reader) {
    // Read [InputInvoicePremiumGiftCode] fields.
    final purpose = reader.readObject() as InputStorePaymentPurposeBase;
    final option = reader.readObject() as PremiumGiftCodeOptionBase;

    // Construct [InputInvoicePremiumGiftCode] object.
    final returnValue = InputInvoicePremiumGiftCode(
      purpose: purpose,
      option: option,
    );

    // Now return the deserialized [InputInvoicePremiumGiftCode].
    return returnValue;
  }

  /// Purpose.
  final InputStorePaymentPurposeBase purpose;

  /// Option.
  final PremiumGiftCodeOptionBase option;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x98986c0d.
    buffer.writeInt32(0x98986c0d);

    // Write fields.
    buffer.writeObject(purpose);
    buffer.writeObject(option);

    // Finished serialization.
  }
}

/// Payments Exported Invoice.
///
/// ID: `aed0cbd9`.
class PaymentsExportedInvoice extends PaymentsExportedInvoiceBase {
  /// Payments Exported Invoice constructor.
  const PaymentsExportedInvoice({
    required this.url,
  }) : super._();

  /// Deserialize.
  factory PaymentsExportedInvoice.deserialize(BinaryReader reader) {
    // Read [PaymentsExportedInvoice] fields.
    final url = reader.readString();

    // Construct [PaymentsExportedInvoice] object.
    final returnValue = PaymentsExportedInvoice(
      url: url,
    );

    // Now return the deserialized [PaymentsExportedInvoice].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaed0cbd9.
    buffer.writeInt32(0xaed0cbd9);

    // Write fields.
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Messages Transcribed Audio.
///
/// ID: `cfb9d957`.
class MessagesTranscribedAudio extends MessagesTranscribedAudioBase {
  /// Messages Transcribed Audio constructor.
  const MessagesTranscribedAudio({
    required this.pending,
    required this.transcriptionId,
    required this.text,
    this.trialRemainsNum,
    this.trialRemainsUntilDate,
  }) : super._();

  /// Deserialize.
  factory MessagesTranscribedAudio.deserialize(BinaryReader reader) {
    // Read [MessagesTranscribedAudio] fields.
    final flags = reader.readInt32();
    final pending = (flags & 1) != 0;
    final transcriptionId = reader.readInt64();
    final text = reader.readString();
    final hasTrialRemainsNumField = (flags & 2) != 0;
    final trialRemainsNum = hasTrialRemainsNumField ? reader.readInt32() : null;
    final hasTrialRemainsUntilDateField = (flags & 2) != 0;
    final trialRemainsUntilDate =
        hasTrialRemainsUntilDateField ? reader.readDateTime() : null;

    // Construct [MessagesTranscribedAudio] object.
    final returnValue = MessagesTranscribedAudio(
      pending: pending,
      transcriptionId: transcriptionId,
      text: text,
      trialRemainsNum: trialRemainsNum,
      trialRemainsUntilDate: trialRemainsUntilDate,
    );

    // Now return the deserialized [MessagesTranscribedAudio].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pending,
      b01: trialRemainsNum != null || trialRemainsUntilDate != null,
    );

    return v;
  }

  /// pending: bit 0 of flags.0?true
  final bool pending;

  /// Transcription Id.
  ///
  /// Field type is Int64.
  final int transcriptionId;

  /// Text.
  final String text;

  /// Trial Remains Num.
  final int? trialRemainsNum;

  /// Trial Remains Until Date.
  final DateTime? trialRemainsUntilDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcfb9d957.
    buffer.writeInt32(0xcfb9d957);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(transcriptionId);
    buffer.writeString(text);
    final localTrialRemainsNumCopy = trialRemainsNum;
    if (localTrialRemainsNumCopy != null) {
      buffer.writeInt32(localTrialRemainsNumCopy);
    }
    final localTrialRemainsUntilDateCopy = trialRemainsUntilDate;
    if (localTrialRemainsUntilDateCopy != null) {
      buffer.writeDateTime(localTrialRemainsUntilDateCopy);
    }

    // Finished serialization.
  }
}

/// Help Premium Promo.
///
/// ID: `5334759c`.
class HelpPremiumPromo extends HelpPremiumPromoBase {
  /// Help Premium Promo constructor.
  const HelpPremiumPromo({
    required this.statusText,
    required this.statusEntities,
    required this.videoSections,
    required this.videos,
    required this.periodOptions,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory HelpPremiumPromo.deserialize(BinaryReader reader) {
    // Read [HelpPremiumPromo] fields.
    final statusText = reader.readString();
    final statusEntities = reader.readVectorObject<MessageEntityBase>();
    final videoSections = reader.readVectorString();
    final videos = reader.readVectorObject<DocumentBase>();
    final periodOptions =
        reader.readVectorObject<PremiumSubscriptionOptionBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [HelpPremiumPromo] object.
    final returnValue = HelpPremiumPromo(
      statusText: statusText,
      statusEntities: statusEntities,
      videoSections: videoSections,
      videos: videos,
      periodOptions: periodOptions,
      users: users,
    );

    // Now return the deserialized [HelpPremiumPromo].
    return returnValue;
  }

  /// Status Text.
  final String statusText;

  /// Status Entities.
  final List<MessageEntityBase> statusEntities;

  /// Video Sections.
  final List<String> videoSections;

  /// Videos.
  final List<DocumentBase> videos;

  /// Period Options.
  final List<PremiumSubscriptionOptionBase> periodOptions;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5334759c.
    buffer.writeInt32(0x5334759c);

    // Write fields.
    buffer.writeString(statusText);
    buffer.writeVectorObject(statusEntities);
    buffer.writeVectorString(videoSections);
    buffer.writeVectorObject(videos);
    buffer.writeVectorObject(periodOptions);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Input Store Payment Premium Subscription.
///
/// ID: `a6751e66`.
class InputStorePaymentPremiumSubscription
    extends InputStorePaymentPurposeBase {
  /// Input Store Payment Premium Subscription constructor.
  const InputStorePaymentPremiumSubscription({
    required this.restore,
    required this.upgrade,
  }) : super._();

  /// Deserialize.
  factory InputStorePaymentPremiumSubscription.deserialize(
      BinaryReader reader) {
    // Read [InputStorePaymentPremiumSubscription] fields.
    final flags = reader.readInt32();
    final restore = (flags & 1) != 0;
    final upgrade = (flags & 2) != 0;

    // Construct [InputStorePaymentPremiumSubscription] object.
    final returnValue = InputStorePaymentPremiumSubscription(
      restore: restore,
      upgrade: upgrade,
    );

    // Now return the deserialized [InputStorePaymentPremiumSubscription].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: restore,
      b01: upgrade,
    );

    return v;
  }

  /// restore: bit 0 of flags.0?true
  final bool restore;

  /// upgrade: bit 1 of flags.1?true
  final bool upgrade;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa6751e66.
    buffer.writeInt32(0xa6751e66);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Input Store Payment Gift Premium.
///
/// ID: `616f7fe8`.
class InputStorePaymentGiftPremium extends InputStorePaymentPurposeBase {
  /// Input Store Payment Gift Premium constructor.
  const InputStorePaymentGiftPremium({
    required this.userId,
    required this.currency,
    required this.amount,
  }) : super._();

  /// Deserialize.
  factory InputStorePaymentGiftPremium.deserialize(BinaryReader reader) {
    // Read [InputStorePaymentGiftPremium] fields.
    final userId = reader.readObject() as InputUserBase;
    final currency = reader.readString();
    final amount = reader.readInt64();

    // Construct [InputStorePaymentGiftPremium] object.
    final returnValue = InputStorePaymentGiftPremium(
      userId: userId,
      currency: currency,
      amount: amount,
    );

    // Now return the deserialized [InputStorePaymentGiftPremium].
    return returnValue;
  }

  /// User Id.
  final InputUserBase userId;

  /// Currency.
  final String currency;

  /// Amount.
  ///
  /// Field type is Int64.
  final int amount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x616f7fe8.
    buffer.writeInt32(0x616f7fe8);

    // Write fields.
    buffer.writeObject(userId);
    buffer.writeString(currency);
    buffer.writeInt64(amount);

    // Finished serialization.
  }
}

/// Input Store Payment Premium Gift Code.
///
/// ID: `a3805f3f`.
class InputStorePaymentPremiumGiftCode extends InputStorePaymentPurposeBase {
  /// Input Store Payment Premium Gift Code constructor.
  const InputStorePaymentPremiumGiftCode({
    required this.users,
    this.boostPeer,
    required this.currency,
    required this.amount,
  }) : super._();

  /// Deserialize.
  factory InputStorePaymentPremiumGiftCode.deserialize(BinaryReader reader) {
    // Read [InputStorePaymentPremiumGiftCode] fields.
    final flags = reader.readInt32();
    final users = reader.readVectorObject<InputUserBase>();
    final hasBoostPeerField = (flags & 1) != 0;
    final boostPeer =
        hasBoostPeerField ? reader.readObject() as InputPeerBase : null;
    final currency = reader.readString();
    final amount = reader.readInt64();

    // Construct [InputStorePaymentPremiumGiftCode] object.
    final returnValue = InputStorePaymentPremiumGiftCode(
      users: users,
      boostPeer: boostPeer,
      currency: currency,
      amount: amount,
    );

    // Now return the deserialized [InputStorePaymentPremiumGiftCode].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: boostPeer != null,
    );

    return v;
  }

  /// Users.
  final List<InputUserBase> users;

  /// Boost Peer.
  final InputPeerBase? boostPeer;

  /// Currency.
  final String currency;

  /// Amount.
  ///
  /// Field type is Int64.
  final int amount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa3805f3f.
    buffer.writeInt32(0xa3805f3f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(users);
    final localBoostPeerCopy = boostPeer;
    if (localBoostPeerCopy != null) {
      buffer.writeObject(localBoostPeerCopy);
    }
    buffer.writeString(currency);
    buffer.writeInt64(amount);

    // Finished serialization.
  }
}

/// Input Store Payment Premium Giveaway.
///
/// ID: `160544ca`.
class InputStorePaymentPremiumGiveaway extends InputStorePaymentPurposeBase {
  /// Input Store Payment Premium Giveaway constructor.
  const InputStorePaymentPremiumGiveaway({
    required this.onlyNewSubscribers,
    required this.winnersAreVisible,
    required this.boostPeer,
    this.additionalPeers,
    this.countriesIso2,
    this.prizeDescription,
    required this.randomId,
    required this.untilDate,
    required this.currency,
    required this.amount,
  }) : super._();

  /// Deserialize.
  factory InputStorePaymentPremiumGiveaway.deserialize(BinaryReader reader) {
    // Read [InputStorePaymentPremiumGiveaway] fields.
    final flags = reader.readInt32();
    final onlyNewSubscribers = (flags & 1) != 0;
    final winnersAreVisible = (flags & 8) != 0;
    final boostPeer = reader.readObject() as InputPeerBase;
    final hasAdditionalPeersField = (flags & 2) != 0;
    final additionalPeers = hasAdditionalPeersField
        ? reader.readVectorObject<InputPeerBase>()
        : null;
    final hasCountriesIso2Field = (flags & 4) != 0;
    final countriesIso2 =
        hasCountriesIso2Field ? reader.readVectorString() : null;
    final hasPrizeDescriptionField = (flags & 16) != 0;
    final prizeDescription =
        hasPrizeDescriptionField ? reader.readString() : null;
    final randomId = reader.readInt64();
    final untilDate = reader.readDateTime();
    final currency = reader.readString();
    final amount = reader.readInt64();

    // Construct [InputStorePaymentPremiumGiveaway] object.
    final returnValue = InputStorePaymentPremiumGiveaway(
      onlyNewSubscribers: onlyNewSubscribers,
      winnersAreVisible: winnersAreVisible,
      boostPeer: boostPeer,
      additionalPeers: additionalPeers,
      countriesIso2: countriesIso2,
      prizeDescription: prizeDescription,
      randomId: randomId,
      untilDate: untilDate,
      currency: currency,
      amount: amount,
    );

    // Now return the deserialized [InputStorePaymentPremiumGiveaway].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: onlyNewSubscribers,
      b03: winnersAreVisible,
      b01: additionalPeers != null,
      b02: countriesIso2 != null,
      b04: prizeDescription != null,
    );

    return v;
  }

  /// only_new_subscribers: bit 0 of flags.0?true
  final bool onlyNewSubscribers;

  /// winners_are_visible: bit 3 of flags.3?true
  final bool winnersAreVisible;

  /// Boost Peer.
  final InputPeerBase boostPeer;

  /// Additional Peers.
  final List<InputPeerBase>? additionalPeers;

  /// Countries Iso2.
  final List<String>? countriesIso2;

  /// Prize Description.
  final String? prizeDescription;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Until Date.
  final DateTime untilDate;

  /// Currency.
  final String currency;

  /// Amount.
  ///
  /// Field type is Int64.
  final int amount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x160544ca.
    buffer.writeInt32(0x160544ca);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(boostPeer);
    final localAdditionalPeersCopy = additionalPeers;
    if (localAdditionalPeersCopy != null) {
      buffer.writeVectorObject(localAdditionalPeersCopy);
    }
    final localCountriesIso2Copy = countriesIso2;
    if (localCountriesIso2Copy != null) {
      buffer.writeVectorString(localCountriesIso2Copy);
    }
    final localPrizeDescriptionCopy = prizeDescription;
    if (localPrizeDescriptionCopy != null) {
      buffer.writeString(localPrizeDescriptionCopy);
    }
    buffer.writeInt64(randomId);
    buffer.writeDateTime(untilDate);
    buffer.writeString(currency);
    buffer.writeInt64(amount);

    // Finished serialization.
  }
}

/// Premium Gift Option.
///
/// ID: `74c34319`.
class PremiumGiftOption extends PremiumGiftOptionBase {
  /// Premium Gift Option constructor.
  const PremiumGiftOption({
    required this.months,
    required this.currency,
    required this.amount,
    required this.botUrl,
    this.storeProduct,
  }) : super._();

  /// Deserialize.
  factory PremiumGiftOption.deserialize(BinaryReader reader) {
    // Read [PremiumGiftOption] fields.
    final flags = reader.readInt32();
    final months = reader.readInt32();
    final currency = reader.readString();
    final amount = reader.readInt64();
    final botUrl = reader.readString();
    final hasStoreProductField = (flags & 1) != 0;
    final storeProduct = hasStoreProductField ? reader.readString() : null;

    // Construct [PremiumGiftOption] object.
    final returnValue = PremiumGiftOption(
      months: months,
      currency: currency,
      amount: amount,
      botUrl: botUrl,
      storeProduct: storeProduct,
    );

    // Now return the deserialized [PremiumGiftOption].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: storeProduct != null,
    );

    return v;
  }

  /// Months.
  ///
  /// Field type is Int32.
  final int months;

  /// Currency.
  final String currency;

  /// Amount.
  ///
  /// Field type is Int64.
  final int amount;

  /// Bot Url.
  final String botUrl;

  /// Store Product.
  final String? storeProduct;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x74c34319.
    buffer.writeInt32(0x74c34319);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(months);
    buffer.writeString(currency);
    buffer.writeInt64(amount);
    buffer.writeString(botUrl);
    final localStoreProductCopy = storeProduct;
    if (localStoreProductCopy != null) {
      buffer.writeString(localStoreProductCopy);
    }

    // Finished serialization.
  }
}

/// Payment Form Method.
///
/// ID: `88f8f21b`.
class PaymentFormMethod extends PaymentFormMethodBase {
  /// Payment Form Method constructor.
  const PaymentFormMethod({
    required this.url,
    required this.title,
  }) : super._();

  /// Deserialize.
  factory PaymentFormMethod.deserialize(BinaryReader reader) {
    // Read [PaymentFormMethod] fields.
    final url = reader.readString();
    final title = reader.readString();

    // Construct [PaymentFormMethod] object.
    final returnValue = PaymentFormMethod(
      url: url,
      title: title,
    );

    // Now return the deserialized [PaymentFormMethod].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Title.
  final String title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x88f8f21b.
    buffer.writeInt32(0x88f8f21b);

    // Write fields.
    buffer.writeString(url);
    buffer.writeString(title);

    // Finished serialization.
  }
}

/// Emoji Status Empty.
///
/// ID: `2de11aae`.
class EmojiStatusEmpty extends EmojiStatusBase {
  /// Emoji Status Empty constructor.
  const EmojiStatusEmpty() : super._();

  /// Deserialize.
  factory EmojiStatusEmpty.deserialize(BinaryReader reader) {
    // Construct [EmojiStatusEmpty] object.
    final returnValue = EmojiStatusEmpty();

    // Now return the deserialized [EmojiStatusEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2de11aae.
    buffer.writeInt32(0x2de11aae);

    // Finished serialization.
  }
}

/// Emoji Status.
///
/// ID: `929b619d`.
class EmojiStatus extends EmojiStatusBase {
  /// Emoji Status constructor.
  const EmojiStatus({
    required this.documentId,
  }) : super._();

  /// Deserialize.
  factory EmojiStatus.deserialize(BinaryReader reader) {
    // Read [EmojiStatus] fields.
    final documentId = reader.readInt64();

    // Construct [EmojiStatus] object.
    final returnValue = EmojiStatus(
      documentId: documentId,
    );

    // Now return the deserialized [EmojiStatus].
    return returnValue;
  }

  /// Document Id.
  ///
  /// Field type is Int64.
  final int documentId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x929b619d.
    buffer.writeInt32(0x929b619d);

    // Write fields.
    buffer.writeInt64(documentId);

    // Finished serialization.
  }
}

/// Emoji Status Until.
///
/// ID: `fa30a8c7`.
class EmojiStatusUntil extends EmojiStatusBase {
  /// Emoji Status Until constructor.
  const EmojiStatusUntil({
    required this.documentId,
    required this.until,
  }) : super._();

  /// Deserialize.
  factory EmojiStatusUntil.deserialize(BinaryReader reader) {
    // Read [EmojiStatusUntil] fields.
    final documentId = reader.readInt64();
    final until = reader.readInt32();

    // Construct [EmojiStatusUntil] object.
    final returnValue = EmojiStatusUntil(
      documentId: documentId,
      until: until,
    );

    // Now return the deserialized [EmojiStatusUntil].
    return returnValue;
  }

  /// Document Id.
  ///
  /// Field type is Int64.
  final int documentId;

  /// Until.
  ///
  /// Field type is Int32.
  final int until;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfa30a8c7.
    buffer.writeInt32(0xfa30a8c7);

    // Write fields.
    buffer.writeInt64(documentId);
    buffer.writeInt32(until);

    // Finished serialization.
  }
}

/// Account Emoji Statuses Not Modified.
///
/// ID: `d08ce645`.
class AccountEmojiStatusesNotModified extends AccountEmojiStatusesBase {
  /// Account Emoji Statuses Not Modified constructor.
  const AccountEmojiStatusesNotModified() : super._();

  /// Deserialize.
  factory AccountEmojiStatusesNotModified.deserialize(BinaryReader reader) {
    // Construct [AccountEmojiStatusesNotModified] object.
    final returnValue = AccountEmojiStatusesNotModified();

    // Now return the deserialized [AccountEmojiStatusesNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd08ce645.
    buffer.writeInt32(0xd08ce645);

    // Finished serialization.
  }
}

/// Account Emoji Statuses.
///
/// ID: `90c467d1`.
class AccountEmojiStatuses extends AccountEmojiStatusesBase {
  /// Account Emoji Statuses constructor.
  const AccountEmojiStatuses({
    required this.hash,
    required this.statuses,
  }) : super._();

  /// Deserialize.
  factory AccountEmojiStatuses.deserialize(BinaryReader reader) {
    // Read [AccountEmojiStatuses] fields.
    final hash = reader.readInt64();
    final statuses = reader.readVectorObject<EmojiStatusBase>();

    // Construct [AccountEmojiStatuses] object.
    final returnValue = AccountEmojiStatuses(
      hash: hash,
      statuses: statuses,
    );

    // Now return the deserialized [AccountEmojiStatuses].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Statuses.
  final List<EmojiStatusBase> statuses;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x90c467d1.
    buffer.writeInt32(0x90c467d1);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(statuses);

    // Finished serialization.
  }
}

/// Reaction Empty.
///
/// ID: `79f5d419`.
class ReactionEmpty extends ReactionBase {
  /// Reaction Empty constructor.
  const ReactionEmpty() : super._();

  /// Deserialize.
  factory ReactionEmpty.deserialize(BinaryReader reader) {
    // Construct [ReactionEmpty] object.
    final returnValue = ReactionEmpty();

    // Now return the deserialized [ReactionEmpty].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x79f5d419.
    buffer.writeInt32(0x79f5d419);

    // Finished serialization.
  }
}

/// Reaction Emoji.
///
/// ID: `1b2286b8`.
class ReactionEmoji extends ReactionBase {
  /// Reaction Emoji constructor.
  const ReactionEmoji({
    required this.emoticon,
  }) : super._();

  /// Deserialize.
  factory ReactionEmoji.deserialize(BinaryReader reader) {
    // Read [ReactionEmoji] fields.
    final emoticon = reader.readString();

    // Construct [ReactionEmoji] object.
    final returnValue = ReactionEmoji(
      emoticon: emoticon,
    );

    // Now return the deserialized [ReactionEmoji].
    return returnValue;
  }

  /// Emoticon.
  final String emoticon;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1b2286b8.
    buffer.writeInt32(0x1b2286b8);

    // Write fields.
    buffer.writeString(emoticon);

    // Finished serialization.
  }
}

/// Reaction Custom Emoji.
///
/// ID: `8935fc73`.
class ReactionCustomEmoji extends ReactionBase {
  /// Reaction Custom Emoji constructor.
  const ReactionCustomEmoji({
    required this.documentId,
  }) : super._();

  /// Deserialize.
  factory ReactionCustomEmoji.deserialize(BinaryReader reader) {
    // Read [ReactionCustomEmoji] fields.
    final documentId = reader.readInt64();

    // Construct [ReactionCustomEmoji] object.
    final returnValue = ReactionCustomEmoji(
      documentId: documentId,
    );

    // Now return the deserialized [ReactionCustomEmoji].
    return returnValue;
  }

  /// Document Id.
  ///
  /// Field type is Int64.
  final int documentId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8935fc73.
    buffer.writeInt32(0x8935fc73);

    // Write fields.
    buffer.writeInt64(documentId);

    // Finished serialization.
  }
}

/// Chat Reactions None.
///
/// ID: `eafc32bc`.
class ChatReactionsNone extends ChatReactionsBase {
  /// Chat Reactions None constructor.
  const ChatReactionsNone() : super._();

  /// Deserialize.
  factory ChatReactionsNone.deserialize(BinaryReader reader) {
    // Construct [ChatReactionsNone] object.
    final returnValue = ChatReactionsNone();

    // Now return the deserialized [ChatReactionsNone].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeafc32bc.
    buffer.writeInt32(0xeafc32bc);

    // Finished serialization.
  }
}

/// Chat Reactions All.
///
/// ID: `52928bca`.
class ChatReactionsAll extends ChatReactionsBase {
  /// Chat Reactions All constructor.
  const ChatReactionsAll({
    required this.allowCustom,
  }) : super._();

  /// Deserialize.
  factory ChatReactionsAll.deserialize(BinaryReader reader) {
    // Read [ChatReactionsAll] fields.
    final flags = reader.readInt32();
    final allowCustom = (flags & 1) != 0;

    // Construct [ChatReactionsAll] object.
    final returnValue = ChatReactionsAll(
      allowCustom: allowCustom,
    );

    // Now return the deserialized [ChatReactionsAll].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: allowCustom,
    );

    return v;
  }

  /// allow_custom: bit 0 of flags.0?true
  final bool allowCustom;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x52928bca.
    buffer.writeInt32(0x52928bca);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Chat Reactions Some.
///
/// ID: `661d4037`.
class ChatReactionsSome extends ChatReactionsBase {
  /// Chat Reactions Some constructor.
  const ChatReactionsSome({
    required this.reactions,
  }) : super._();

  /// Deserialize.
  factory ChatReactionsSome.deserialize(BinaryReader reader) {
    // Read [ChatReactionsSome] fields.
    final reactions = reader.readVectorObject<ReactionBase>();

    // Construct [ChatReactionsSome] object.
    final returnValue = ChatReactionsSome(
      reactions: reactions,
    );

    // Now return the deserialized [ChatReactionsSome].
    return returnValue;
  }

  /// Reactions.
  final List<ReactionBase> reactions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x661d4037.
    buffer.writeInt32(0x661d4037);

    // Write fields.
    buffer.writeVectorObject(reactions);

    // Finished serialization.
  }
}

/// Messages Reactions Not Modified.
///
/// ID: `b06fdbdf`.
class MessagesReactionsNotModified extends MessagesReactionsBase {
  /// Messages Reactions Not Modified constructor.
  const MessagesReactionsNotModified() : super._();

  /// Deserialize.
  factory MessagesReactionsNotModified.deserialize(BinaryReader reader) {
    // Construct [MessagesReactionsNotModified] object.
    final returnValue = MessagesReactionsNotModified();

    // Now return the deserialized [MessagesReactionsNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb06fdbdf.
    buffer.writeInt32(0xb06fdbdf);

    // Finished serialization.
  }
}

/// Messages Reactions.
///
/// ID: `eafdf716`.
class MessagesReactions extends MessagesReactionsBase {
  /// Messages Reactions constructor.
  const MessagesReactions({
    required this.hash,
    required this.reactions,
  }) : super._();

  /// Deserialize.
  factory MessagesReactions.deserialize(BinaryReader reader) {
    // Read [MessagesReactions] fields.
    final hash = reader.readInt64();
    final reactions = reader.readVectorObject<ReactionBase>();

    // Construct [MessagesReactions] object.
    final returnValue = MessagesReactions(
      hash: hash,
      reactions: reactions,
    );

    // Now return the deserialized [MessagesReactions].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Reactions.
  final List<ReactionBase> reactions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeafdf716.
    buffer.writeInt32(0xeafdf716);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorObject(reactions);

    // Finished serialization.
  }
}

/// Email Verify Purpose Login Setup.
///
/// ID: `4345be73`.
class EmailVerifyPurposeLoginSetup extends EmailVerifyPurposeBase {
  /// Email Verify Purpose Login Setup constructor.
  const EmailVerifyPurposeLoginSetup({
    required this.phoneNumber,
    required this.phoneCodeHash,
  }) : super._();

  /// Deserialize.
  factory EmailVerifyPurposeLoginSetup.deserialize(BinaryReader reader) {
    // Read [EmailVerifyPurposeLoginSetup] fields.
    final phoneNumber = reader.readString();
    final phoneCodeHash = reader.readString();

    // Construct [EmailVerifyPurposeLoginSetup] object.
    final returnValue = EmailVerifyPurposeLoginSetup(
      phoneNumber: phoneNumber,
      phoneCodeHash: phoneCodeHash,
    );

    // Now return the deserialized [EmailVerifyPurposeLoginSetup].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4345be73.
    buffer.writeInt32(0x4345be73);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeString(phoneCodeHash);

    // Finished serialization.
  }
}

/// Email Verify Purpose Login Change.
///
/// ID: `527d22eb`.
class EmailVerifyPurposeLoginChange extends EmailVerifyPurposeBase {
  /// Email Verify Purpose Login Change constructor.
  const EmailVerifyPurposeLoginChange() : super._();

  /// Deserialize.
  factory EmailVerifyPurposeLoginChange.deserialize(BinaryReader reader) {
    // Construct [EmailVerifyPurposeLoginChange] object.
    final returnValue = EmailVerifyPurposeLoginChange();

    // Now return the deserialized [EmailVerifyPurposeLoginChange].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x527d22eb.
    buffer.writeInt32(0x527d22eb);

    // Finished serialization.
  }
}

/// Email Verify Purpose Passport.
///
/// ID: `bbf51685`.
class EmailVerifyPurposePassport extends EmailVerifyPurposeBase {
  /// Email Verify Purpose Passport constructor.
  const EmailVerifyPurposePassport() : super._();

  /// Deserialize.
  factory EmailVerifyPurposePassport.deserialize(BinaryReader reader) {
    // Construct [EmailVerifyPurposePassport] object.
    final returnValue = EmailVerifyPurposePassport();

    // Now return the deserialized [EmailVerifyPurposePassport].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbbf51685.
    buffer.writeInt32(0xbbf51685);

    // Finished serialization.
  }
}

/// Email Verification Code.
///
/// ID: `922e55a9`.
class EmailVerificationCode extends EmailVerificationBase {
  /// Email Verification Code constructor.
  const EmailVerificationCode({
    required this.code,
  }) : super._();

  /// Deserialize.
  factory EmailVerificationCode.deserialize(BinaryReader reader) {
    // Read [EmailVerificationCode] fields.
    final code = reader.readString();

    // Construct [EmailVerificationCode] object.
    final returnValue = EmailVerificationCode(
      code: code,
    );

    // Now return the deserialized [EmailVerificationCode].
    return returnValue;
  }

  /// Code.
  final String code;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x922e55a9.
    buffer.writeInt32(0x922e55a9);

    // Write fields.
    buffer.writeString(code);

    // Finished serialization.
  }
}

/// Email Verification Google.
///
/// ID: `db909ec2`.
class EmailVerificationGoogle extends EmailVerificationBase {
  /// Email Verification Google constructor.
  const EmailVerificationGoogle({
    required this.token,
  }) : super._();

  /// Deserialize.
  factory EmailVerificationGoogle.deserialize(BinaryReader reader) {
    // Read [EmailVerificationGoogle] fields.
    final token = reader.readString();

    // Construct [EmailVerificationGoogle] object.
    final returnValue = EmailVerificationGoogle(
      token: token,
    );

    // Now return the deserialized [EmailVerificationGoogle].
    return returnValue;
  }

  /// Token.
  final String token;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdb909ec2.
    buffer.writeInt32(0xdb909ec2);

    // Write fields.
    buffer.writeString(token);

    // Finished serialization.
  }
}

/// Email Verification Apple.
///
/// ID: `96d074fd`.
class EmailVerificationApple extends EmailVerificationBase {
  /// Email Verification Apple constructor.
  const EmailVerificationApple({
    required this.token,
  }) : super._();

  /// Deserialize.
  factory EmailVerificationApple.deserialize(BinaryReader reader) {
    // Read [EmailVerificationApple] fields.
    final token = reader.readString();

    // Construct [EmailVerificationApple] object.
    final returnValue = EmailVerificationApple(
      token: token,
    );

    // Now return the deserialized [EmailVerificationApple].
    return returnValue;
  }

  /// Token.
  final String token;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x96d074fd.
    buffer.writeInt32(0x96d074fd);

    // Write fields.
    buffer.writeString(token);

    // Finished serialization.
  }
}

/// Account Email Verified.
///
/// ID: `2b96cd1b`.
class AccountEmailVerified extends AccountEmailVerifiedBase {
  /// Account Email Verified constructor.
  const AccountEmailVerified({
    required this.email,
  }) : super._();

  /// Deserialize.
  factory AccountEmailVerified.deserialize(BinaryReader reader) {
    // Read [AccountEmailVerified] fields.
    final email = reader.readString();

    // Construct [AccountEmailVerified] object.
    final returnValue = AccountEmailVerified(
      email: email,
    );

    // Now return the deserialized [AccountEmailVerified].
    return returnValue;
  }

  /// Email.
  final String email;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2b96cd1b.
    buffer.writeInt32(0x2b96cd1b);

    // Write fields.
    buffer.writeString(email);

    // Finished serialization.
  }
}

/// Account Email Verified Login.
///
/// ID: `e1bb0d61`.
class AccountEmailVerifiedLogin extends AccountEmailVerifiedBase {
  /// Account Email Verified Login constructor.
  const AccountEmailVerifiedLogin({
    required this.email,
    required this.sentCode,
  }) : super._();

  /// Deserialize.
  factory AccountEmailVerifiedLogin.deserialize(BinaryReader reader) {
    // Read [AccountEmailVerifiedLogin] fields.
    final email = reader.readString();
    final sentCode = reader.readObject() as AuthSentCodeBase;

    // Construct [AccountEmailVerifiedLogin] object.
    final returnValue = AccountEmailVerifiedLogin(
      email: email,
      sentCode: sentCode,
    );

    // Now return the deserialized [AccountEmailVerifiedLogin].
    return returnValue;
  }

  /// Email.
  final String email;

  /// Sent Code.
  final AuthSentCodeBase sentCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe1bb0d61.
    buffer.writeInt32(0xe1bb0d61);

    // Write fields.
    buffer.writeString(email);
    buffer.writeObject(sentCode);

    // Finished serialization.
  }
}

/// Premium Subscription Option.
///
/// ID: `5f2d1df2`.
class PremiumSubscriptionOption extends PremiumSubscriptionOptionBase {
  /// Premium Subscription Option constructor.
  const PremiumSubscriptionOption({
    required this.current,
    required this.canPurchaseUpgrade,
    this.transaction,
    required this.months,
    required this.currency,
    required this.amount,
    required this.botUrl,
    this.storeProduct,
  }) : super._();

  /// Deserialize.
  factory PremiumSubscriptionOption.deserialize(BinaryReader reader) {
    // Read [PremiumSubscriptionOption] fields.
    final flags = reader.readInt32();
    final current = (flags & 2) != 0;
    final canPurchaseUpgrade = (flags & 4) != 0;
    final hasTransactionField = (flags & 8) != 0;
    final transaction = hasTransactionField ? reader.readString() : null;
    final months = reader.readInt32();
    final currency = reader.readString();
    final amount = reader.readInt64();
    final botUrl = reader.readString();
    final hasStoreProductField = (flags & 1) != 0;
    final storeProduct = hasStoreProductField ? reader.readString() : null;

    // Construct [PremiumSubscriptionOption] object.
    final returnValue = PremiumSubscriptionOption(
      current: current,
      canPurchaseUpgrade: canPurchaseUpgrade,
      transaction: transaction,
      months: months,
      currency: currency,
      amount: amount,
      botUrl: botUrl,
      storeProduct: storeProduct,
    );

    // Now return the deserialized [PremiumSubscriptionOption].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: current,
      b02: canPurchaseUpgrade,
      b03: transaction != null,
      b00: storeProduct != null,
    );

    return v;
  }

  /// current: bit 1 of flags.1?true
  final bool current;

  /// can_purchase_upgrade: bit 2 of flags.2?true
  final bool canPurchaseUpgrade;

  /// Transaction.
  final String? transaction;

  /// Months.
  ///
  /// Field type is Int32.
  final int months;

  /// Currency.
  final String currency;

  /// Amount.
  ///
  /// Field type is Int64.
  final int amount;

  /// Bot Url.
  final String botUrl;

  /// Store Product.
  final String? storeProduct;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5f2d1df2.
    buffer.writeInt32(0x5f2d1df2);

    // Write fields.
    buffer.writeInt32(flags);
    final localTransactionCopy = transaction;
    if (localTransactionCopy != null) {
      buffer.writeString(localTransactionCopy);
    }
    buffer.writeInt32(months);
    buffer.writeString(currency);
    buffer.writeInt64(amount);
    buffer.writeString(botUrl);
    final localStoreProductCopy = storeProduct;
    if (localStoreProductCopy != null) {
      buffer.writeString(localStoreProductCopy);
    }

    // Finished serialization.
  }
}

/// Send As Peer.
///
/// ID: `b81c7034`.
class SendAsPeer extends SendAsPeerBase {
  /// Send As Peer constructor.
  const SendAsPeer({
    required this.premiumRequired,
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory SendAsPeer.deserialize(BinaryReader reader) {
    // Read [SendAsPeer] fields.
    final flags = reader.readInt32();
    final premiumRequired = (flags & 1) != 0;
    final peer = reader.readObject() as PeerBase;

    // Construct [SendAsPeer] object.
    final returnValue = SendAsPeer(
      premiumRequired: premiumRequired,
      peer: peer,
    );

    // Now return the deserialized [SendAsPeer].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: premiumRequired,
    );

    return v;
  }

  /// premium_required: bit 0 of flags.0?true
  final bool premiumRequired;

  /// Peer.
  final PeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb81c7034.
    buffer.writeInt32(0xb81c7034);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Message Extended Media Preview.
///
/// ID: `ad628cc8`.
class MessageExtendedMediaPreview extends MessageExtendedMediaBase {
  /// Message Extended Media Preview constructor.
  const MessageExtendedMediaPreview({
    this.w,
    this.h,
    this.thumb,
    this.videoDuration,
  }) : super._();

  /// Deserialize.
  factory MessageExtendedMediaPreview.deserialize(BinaryReader reader) {
    // Read [MessageExtendedMediaPreview] fields.
    final flags = reader.readInt32();
    final hasWField = (flags & 1) != 0;
    final w = hasWField ? reader.readInt32() : null;
    final hasHField = (flags & 1) != 0;
    final h = hasHField ? reader.readInt32() : null;
    final hasThumbField = (flags & 2) != 0;
    final thumb = hasThumbField ? reader.readObject() as PhotoSizeBase : null;
    final hasVideoDurationField = (flags & 4) != 0;
    final videoDuration = hasVideoDurationField ? reader.readInt32() : null;

    // Construct [MessageExtendedMediaPreview] object.
    final returnValue = MessageExtendedMediaPreview(
      w: w,
      h: h,
      thumb: thumb,
      videoDuration: videoDuration,
    );

    // Now return the deserialized [MessageExtendedMediaPreview].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: w != null || h != null,
      b01: thumb != null,
      b02: videoDuration != null,
    );

    return v;
  }

  /// W.
  final int? w;

  /// H.
  final int? h;

  /// Thumb.
  final PhotoSizeBase? thumb;

  /// Video Duration.
  final int? videoDuration;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xad628cc8.
    buffer.writeInt32(0xad628cc8);

    // Write fields.
    buffer.writeInt32(flags);
    final localWCopy = w;
    if (localWCopy != null) {
      buffer.writeInt32(localWCopy);
    }
    final localHCopy = h;
    if (localHCopy != null) {
      buffer.writeInt32(localHCopy);
    }
    final localThumbCopy = thumb;
    if (localThumbCopy != null) {
      buffer.writeObject(localThumbCopy);
    }
    final localVideoDurationCopy = videoDuration;
    if (localVideoDurationCopy != null) {
      buffer.writeInt32(localVideoDurationCopy);
    }

    // Finished serialization.
  }
}

/// Message Extended Media.
///
/// ID: `ee479c64`.
class MessageExtendedMedia extends MessageExtendedMediaBase {
  /// Message Extended Media constructor.
  const MessageExtendedMedia({
    required this.media,
  }) : super._();

  /// Deserialize.
  factory MessageExtendedMedia.deserialize(BinaryReader reader) {
    // Read [MessageExtendedMedia] fields.
    final media = reader.readObject() as MessageMediaBase;

    // Construct [MessageExtendedMedia] object.
    final returnValue = MessageExtendedMedia(
      media: media,
    );

    // Now return the deserialized [MessageExtendedMedia].
    return returnValue;
  }

  /// Media.
  final MessageMediaBase media;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xee479c64.
    buffer.writeInt32(0xee479c64);

    // Write fields.
    buffer.writeObject(media);

    // Finished serialization.
  }
}

/// Sticker Keyword.
///
/// ID: `fcfeb29c`.
class StickerKeyword extends StickerKeywordBase {
  /// Sticker Keyword constructor.
  const StickerKeyword({
    required this.documentId,
    required this.keyword,
  }) : super._();

  /// Deserialize.
  factory StickerKeyword.deserialize(BinaryReader reader) {
    // Read [StickerKeyword] fields.
    final documentId = reader.readInt64();
    final keyword = reader.readVectorString();

    // Construct [StickerKeyword] object.
    final returnValue = StickerKeyword(
      documentId: documentId,
      keyword: keyword,
    );

    // Now return the deserialized [StickerKeyword].
    return returnValue;
  }

  /// Document Id.
  ///
  /// Field type is Int64.
  final int documentId;

  /// Keyword.
  final List<String> keyword;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfcfeb29c.
    buffer.writeInt32(0xfcfeb29c);

    // Write fields.
    buffer.writeInt64(documentId);
    buffer.writeVectorString(keyword);

    // Finished serialization.
  }
}

/// Username.
///
/// ID: `b4073647`.
class Username extends UsernameBase {
  /// Username constructor.
  const Username({
    required this.editable,
    required this.active,
    required this.username,
  }) : super._();

  /// Deserialize.
  factory Username.deserialize(BinaryReader reader) {
    // Read [Username] fields.
    final flags = reader.readInt32();
    final editable = (flags & 1) != 0;
    final active = (flags & 2) != 0;
    final username = reader.readString();

    // Construct [Username] object.
    final returnValue = Username(
      editable: editable,
      active: active,
      username: username,
    );

    // Now return the deserialized [Username].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: editable,
      b01: active,
    );

    return v;
  }

  /// editable: bit 0 of flags.0?true
  final bool editable;

  /// active: bit 1 of flags.1?true
  final bool active;

  /// Username.
  final String username;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb4073647.
    buffer.writeInt32(0xb4073647);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(username);

    // Finished serialization.
  }
}

/// Forum Topic Deleted.
///
/// ID: `023f109b`.
class ForumTopicDeleted extends ForumTopicBase {
  /// Forum Topic Deleted constructor.
  const ForumTopicDeleted({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ForumTopicDeleted.deserialize(BinaryReader reader) {
    // Read [ForumTopicDeleted] fields.
    final id = reader.readInt32();

    // Construct [ForumTopicDeleted] object.
    final returnValue = ForumTopicDeleted(
      id: id,
    );

    // Now return the deserialized [ForumTopicDeleted].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x023f109b.
    buffer.writeInt32(0x023f109b);

    // Write fields.
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Forum Topic.
///
/// ID: `71701da9`.
class ForumTopic extends ForumTopicBase {
  /// Forum Topic constructor.
  const ForumTopic({
    required this.my,
    required this.closed,
    required this.pinned,
    required this.short,
    required this.hidden,
    required this.id,
    required this.date,
    required this.title,
    required this.iconColor,
    this.iconEmojiId,
    required this.topMessage,
    required this.readInboxMaxId,
    required this.readOutboxMaxId,
    required this.unreadCount,
    required this.unreadMentionsCount,
    required this.unreadReactionsCount,
    required this.fromId,
    required this.notifySettings,
    this.draft,
  }) : super._();

  /// Deserialize.
  factory ForumTopic.deserialize(BinaryReader reader) {
    // Read [ForumTopic] fields.
    final flags = reader.readInt32();
    final my = (flags & 2) != 0;
    final closed = (flags & 4) != 0;
    final pinned = (flags & 8) != 0;
    final short = (flags & 32) != 0;
    final hidden = (flags & 64) != 0;
    final id = reader.readInt32();
    final date = reader.readDateTime();
    final title = reader.readString();
    final iconColor = reader.readInt32();
    final hasIconEmojiIdField = (flags & 1) != 0;
    final iconEmojiId = hasIconEmojiIdField ? reader.readInt64() : null;
    final topMessage = reader.readInt32();
    final readInboxMaxId = reader.readInt32();
    final readOutboxMaxId = reader.readInt32();
    final unreadCount = reader.readInt32();
    final unreadMentionsCount = reader.readInt32();
    final unreadReactionsCount = reader.readInt32();
    final fromId = reader.readObject() as PeerBase;
    final notifySettings = reader.readObject() as PeerNotifySettingsBase;
    final hasDraftField = (flags & 16) != 0;
    final draft =
        hasDraftField ? reader.readObject() as DraftMessageBase : null;

    // Construct [ForumTopic] object.
    final returnValue = ForumTopic(
      my: my,
      closed: closed,
      pinned: pinned,
      short: short,
      hidden: hidden,
      id: id,
      date: date,
      title: title,
      iconColor: iconColor,
      iconEmojiId: iconEmojiId,
      topMessage: topMessage,
      readInboxMaxId: readInboxMaxId,
      readOutboxMaxId: readOutboxMaxId,
      unreadCount: unreadCount,
      unreadMentionsCount: unreadMentionsCount,
      unreadReactionsCount: unreadReactionsCount,
      fromId: fromId,
      notifySettings: notifySettings,
      draft: draft,
    );

    // Now return the deserialized [ForumTopic].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: my,
      b02: closed,
      b03: pinned,
      b05: short,
      b06: hidden,
      b00: iconEmojiId != null,
      b04: draft != null,
    );

    return v;
  }

  /// my: bit 1 of flags.1?true
  final bool my;

  /// closed: bit 2 of flags.2?true
  final bool closed;

  /// pinned: bit 3 of flags.3?true
  final bool pinned;

  /// short: bit 5 of flags.5?true
  final bool short;

  /// hidden: bit 6 of flags.6?true
  final bool hidden;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Date.
  final DateTime date;

  /// Title.
  final String title;

  /// Icon Color.
  ///
  /// Field type is Int32.
  final int iconColor;

  /// Icon Emoji Id.
  final int? iconEmojiId;

  /// Top Message.
  ///
  /// Field type is Int32.
  final int topMessage;

  /// Read Inbox Max Id.
  ///
  /// Field type is Int32.
  final int readInboxMaxId;

  /// Read Outbox Max Id.
  ///
  /// Field type is Int32.
  final int readOutboxMaxId;

  /// Unread Count.
  ///
  /// Field type is Int32.
  final int unreadCount;

  /// Unread Mentions Count.
  ///
  /// Field type is Int32.
  final int unreadMentionsCount;

  /// Unread Reactions Count.
  ///
  /// Field type is Int32.
  final int unreadReactionsCount;

  /// From Id.
  final PeerBase fromId;

  /// Notify Settings.
  final PeerNotifySettingsBase notifySettings;

  /// Draft.
  final DraftMessageBase? draft;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x71701da9.
    buffer.writeInt32(0x71701da9);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeDateTime(date);
    buffer.writeString(title);
    buffer.writeInt32(iconColor);
    final localIconEmojiIdCopy = iconEmojiId;
    if (localIconEmojiIdCopy != null) {
      buffer.writeInt64(localIconEmojiIdCopy);
    }
    buffer.writeInt32(topMessage);
    buffer.writeInt32(readInboxMaxId);
    buffer.writeInt32(readOutboxMaxId);
    buffer.writeInt32(unreadCount);
    buffer.writeInt32(unreadMentionsCount);
    buffer.writeInt32(unreadReactionsCount);
    buffer.writeObject(fromId);
    buffer.writeObject(notifySettings);
    final localDraftCopy = draft;
    if (localDraftCopy != null) {
      buffer.writeObject(localDraftCopy);
    }

    // Finished serialization.
  }
}

/// Messages Forum Topics.
///
/// ID: `367617d3`.
class MessagesForumTopics extends MessagesForumTopicsBase {
  /// Messages Forum Topics constructor.
  const MessagesForumTopics({
    required this.orderByCreateDate,
    required this.count,
    required this.topics,
    required this.messages,
    required this.chats,
    required this.users,
    required this.pts,
  }) : super._();

  /// Deserialize.
  factory MessagesForumTopics.deserialize(BinaryReader reader) {
    // Read [MessagesForumTopics] fields.
    final flags = reader.readInt32();
    final orderByCreateDate = (flags & 1) != 0;
    final count = reader.readInt32();
    final topics = reader.readVectorObject<ForumTopicBase>();
    final messages = reader.readVectorObject<MessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final pts = reader.readInt32();

    // Construct [MessagesForumTopics] object.
    final returnValue = MessagesForumTopics(
      orderByCreateDate: orderByCreateDate,
      count: count,
      topics: topics,
      messages: messages,
      chats: chats,
      users: users,
      pts: pts,
    );

    // Now return the deserialized [MessagesForumTopics].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: orderByCreateDate,
    );

    return v;
  }

  /// order_by_create_date: bit 0 of flags.0?true
  final bool orderByCreateDate;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Topics.
  final List<ForumTopicBase> topics;

  /// Messages.
  final List<MessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x367617d3.
    buffer.writeInt32(0x367617d3);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(count);
    buffer.writeVectorObject(topics);
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    buffer.writeInt32(pts);

    // Finished serialization.
  }
}

/// Default History T T L.
///
/// ID: `43b46b20`.
class DefaultHistoryTTL extends DefaultHistoryTTLBase {
  /// Default History T T L constructor.
  const DefaultHistoryTTL({
    required this.period,
  }) : super._();

  /// Deserialize.
  factory DefaultHistoryTTL.deserialize(BinaryReader reader) {
    // Read [DefaultHistoryTTL] fields.
    final period = reader.readInt32();

    // Construct [DefaultHistoryTTL] object.
    final returnValue = DefaultHistoryTTL(
      period: period,
    );

    // Now return the deserialized [DefaultHistoryTTL].
    return returnValue;
  }

  /// Period.
  ///
  /// Field type is Int32.
  final int period;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x43b46b20.
    buffer.writeInt32(0x43b46b20);

    // Write fields.
    buffer.writeInt32(period);

    // Finished serialization.
  }
}

/// Exported Contact Token.
///
/// ID: `41bf109b`.
class ExportedContactToken extends ExportedContactTokenBase {
  /// Exported Contact Token constructor.
  const ExportedContactToken({
    required this.url,
    required this.expires,
  }) : super._();

  /// Deserialize.
  factory ExportedContactToken.deserialize(BinaryReader reader) {
    // Read [ExportedContactToken] fields.
    final url = reader.readString();
    final expires = reader.readInt32();

    // Construct [ExportedContactToken] object.
    final returnValue = ExportedContactToken(
      url: url,
      expires: expires,
    );

    // Now return the deserialized [ExportedContactToken].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x41bf109b.
    buffer.writeInt32(0x41bf109b);

    // Write fields.
    buffer.writeString(url);
    buffer.writeInt32(expires);

    // Finished serialization.
  }
}

/// Request Peer Type User.
///
/// ID: `5f3b8a00`.
class RequestPeerTypeUser extends RequestPeerTypeBase {
  /// Request Peer Type User constructor.
  const RequestPeerTypeUser({
    required this.bot,
    required this.premium,
  }) : super._();

  /// Deserialize.
  factory RequestPeerTypeUser.deserialize(BinaryReader reader) {
    // Read [RequestPeerTypeUser] fields.
    final flags = reader.readInt32();
    final bot = (flags & 1) != 0;
    final premium = (flags & 2) != 0;

    // Construct [RequestPeerTypeUser] object.
    final returnValue = RequestPeerTypeUser(
      bot: bot,
      premium: premium,
    );

    // Now return the deserialized [RequestPeerTypeUser].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: bot,
      b01: premium,
    );

    return v;
  }

  /// bot: bit 0 of flags.0?Bool
  final bool bot;

  /// premium: bit 1 of flags.1?Bool
  final bool premium;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5f3b8a00.
    buffer.writeInt32(0x5f3b8a00);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Request Peer Type Chat.
///
/// ID: `c9f06e1b`.
class RequestPeerTypeChat extends RequestPeerTypeBase {
  /// Request Peer Type Chat constructor.
  const RequestPeerTypeChat({
    required this.creator,
    required this.botParticipant,
    required this.hasUsername,
    required this.forum,
    this.userAdminRights,
    this.botAdminRights,
  }) : super._();

  /// Deserialize.
  factory RequestPeerTypeChat.deserialize(BinaryReader reader) {
    // Read [RequestPeerTypeChat] fields.
    final flags = reader.readInt32();
    final creator = (flags & 1) != 0;
    final botParticipant = (flags & 32) != 0;
    final hasUsername = (flags & 8) != 0;
    final forum = (flags & 16) != 0;
    final hasUserAdminRightsField = (flags & 2) != 0;
    final userAdminRights = hasUserAdminRightsField
        ? reader.readObject() as ChatAdminRightsBase
        : null;
    final hasBotAdminRightsField = (flags & 4) != 0;
    final botAdminRights = hasBotAdminRightsField
        ? reader.readObject() as ChatAdminRightsBase
        : null;

    // Construct [RequestPeerTypeChat] object.
    final returnValue = RequestPeerTypeChat(
      creator: creator,
      botParticipant: botParticipant,
      hasUsername: hasUsername,
      forum: forum,
      userAdminRights: userAdminRights,
      botAdminRights: botAdminRights,
    );

    // Now return the deserialized [RequestPeerTypeChat].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: creator,
      b05: botParticipant,
      b03: hasUsername,
      b04: forum,
      b01: userAdminRights != null,
      b02: botAdminRights != null,
    );

    return v;
  }

  /// creator: bit 0 of flags.0?true
  final bool creator;

  /// bot_participant: bit 5 of flags.5?true
  final bool botParticipant;

  /// has_username: bit 3 of flags.3?Bool
  final bool hasUsername;

  /// forum: bit 4 of flags.4?Bool
  final bool forum;

  /// User Admin Rights.
  final ChatAdminRightsBase? userAdminRights;

  /// Bot Admin Rights.
  final ChatAdminRightsBase? botAdminRights;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc9f06e1b.
    buffer.writeInt32(0xc9f06e1b);

    // Write fields.
    buffer.writeInt32(flags);
    final localUserAdminRightsCopy = userAdminRights;
    if (localUserAdminRightsCopy != null) {
      buffer.writeObject(localUserAdminRightsCopy);
    }
    final localBotAdminRightsCopy = botAdminRights;
    if (localBotAdminRightsCopy != null) {
      buffer.writeObject(localBotAdminRightsCopy);
    }

    // Finished serialization.
  }
}

/// Request Peer Type Broadcast.
///
/// ID: `339bef6c`.
class RequestPeerTypeBroadcast extends RequestPeerTypeBase {
  /// Request Peer Type Broadcast constructor.
  const RequestPeerTypeBroadcast({
    required this.creator,
    required this.hasUsername,
    this.userAdminRights,
    this.botAdminRights,
  }) : super._();

  /// Deserialize.
  factory RequestPeerTypeBroadcast.deserialize(BinaryReader reader) {
    // Read [RequestPeerTypeBroadcast] fields.
    final flags = reader.readInt32();
    final creator = (flags & 1) != 0;
    final hasUsername = (flags & 8) != 0;
    final hasUserAdminRightsField = (flags & 2) != 0;
    final userAdminRights = hasUserAdminRightsField
        ? reader.readObject() as ChatAdminRightsBase
        : null;
    final hasBotAdminRightsField = (flags & 4) != 0;
    final botAdminRights = hasBotAdminRightsField
        ? reader.readObject() as ChatAdminRightsBase
        : null;

    // Construct [RequestPeerTypeBroadcast] object.
    final returnValue = RequestPeerTypeBroadcast(
      creator: creator,
      hasUsername: hasUsername,
      userAdminRights: userAdminRights,
      botAdminRights: botAdminRights,
    );

    // Now return the deserialized [RequestPeerTypeBroadcast].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: creator,
      b03: hasUsername,
      b01: userAdminRights != null,
      b02: botAdminRights != null,
    );

    return v;
  }

  /// creator: bit 0 of flags.0?true
  final bool creator;

  /// has_username: bit 3 of flags.3?Bool
  final bool hasUsername;

  /// User Admin Rights.
  final ChatAdminRightsBase? userAdminRights;

  /// Bot Admin Rights.
  final ChatAdminRightsBase? botAdminRights;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x339bef6c.
    buffer.writeInt32(0x339bef6c);

    // Write fields.
    buffer.writeInt32(flags);
    final localUserAdminRightsCopy = userAdminRights;
    if (localUserAdminRightsCopy != null) {
      buffer.writeObject(localUserAdminRightsCopy);
    }
    final localBotAdminRightsCopy = botAdminRights;
    if (localBotAdminRightsCopy != null) {
      buffer.writeObject(localBotAdminRightsCopy);
    }

    // Finished serialization.
  }
}

/// Emoji List Not Modified.
///
/// ID: `481eadfa`.
class EmojiListNotModified extends EmojiListBase {
  /// Emoji List Not Modified constructor.
  const EmojiListNotModified() : super._();

  /// Deserialize.
  factory EmojiListNotModified.deserialize(BinaryReader reader) {
    // Construct [EmojiListNotModified] object.
    final returnValue = EmojiListNotModified();

    // Now return the deserialized [EmojiListNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x481eadfa.
    buffer.writeInt32(0x481eadfa);

    // Finished serialization.
  }
}

/// Emoji List.
///
/// ID: `7a1e11d1`.
class EmojiList extends EmojiListBase {
  /// Emoji List constructor.
  const EmojiList({
    required this.hash,
    required this.documentId,
  }) : super._();

  /// Deserialize.
  factory EmojiList.deserialize(BinaryReader reader) {
    // Read [EmojiList] fields.
    final hash = reader.readInt64();
    final documentId = reader.readVectorInt64();

    // Construct [EmojiList] object.
    final returnValue = EmojiList(
      hash: hash,
      documentId: documentId,
    );

    // Now return the deserialized [EmojiList].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Document Id.
  final List<int> documentId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7a1e11d1.
    buffer.writeInt32(0x7a1e11d1);

    // Write fields.
    buffer.writeInt64(hash);
    buffer.writeVectorInt64(documentId);

    // Finished serialization.
  }
}

/// Emoji Group.
///
/// ID: `7a9abda9`.
class EmojiGroup extends EmojiGroupBase {
  /// Emoji Group constructor.
  const EmojiGroup({
    required this.title,
    required this.iconEmojiId,
    required this.emoticons,
  }) : super._();

  /// Deserialize.
  factory EmojiGroup.deserialize(BinaryReader reader) {
    // Read [EmojiGroup] fields.
    final title = reader.readString();
    final iconEmojiId = reader.readInt64();
    final emoticons = reader.readVectorString();

    // Construct [EmojiGroup] object.
    final returnValue = EmojiGroup(
      title: title,
      iconEmojiId: iconEmojiId,
      emoticons: emoticons,
    );

    // Now return the deserialized [EmojiGroup].
    return returnValue;
  }

  /// Title.
  final String title;

  /// Icon Emoji Id.
  ///
  /// Field type is Int64.
  final int iconEmojiId;

  /// Emoticons.
  final List<String> emoticons;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7a9abda9.
    buffer.writeInt32(0x7a9abda9);

    // Write fields.
    buffer.writeString(title);
    buffer.writeInt64(iconEmojiId);
    buffer.writeVectorString(emoticons);

    // Finished serialization.
  }
}

/// Messages Emoji Groups Not Modified.
///
/// ID: `6fb4ad87`.
class MessagesEmojiGroupsNotModified extends MessagesEmojiGroupsBase {
  /// Messages Emoji Groups Not Modified constructor.
  const MessagesEmojiGroupsNotModified() : super._();

  /// Deserialize.
  factory MessagesEmojiGroupsNotModified.deserialize(BinaryReader reader) {
    // Construct [MessagesEmojiGroupsNotModified] object.
    final returnValue = MessagesEmojiGroupsNotModified();

    // Now return the deserialized [MessagesEmojiGroupsNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6fb4ad87.
    buffer.writeInt32(0x6fb4ad87);

    // Finished serialization.
  }
}

/// Messages Emoji Groups.
///
/// ID: `881fb94b`.
class MessagesEmojiGroups extends MessagesEmojiGroupsBase {
  /// Messages Emoji Groups constructor.
  const MessagesEmojiGroups({
    required this.hash,
    required this.groups,
  }) : super._();

  /// Deserialize.
  factory MessagesEmojiGroups.deserialize(BinaryReader reader) {
    // Read [MessagesEmojiGroups] fields.
    final hash = reader.readInt32();
    final groups = reader.readVectorObject<EmojiGroupBase>();

    // Construct [MessagesEmojiGroups] object.
    final returnValue = MessagesEmojiGroups(
      hash: hash,
      groups: groups,
    );

    // Now return the deserialized [MessagesEmojiGroups].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Groups.
  final List<EmojiGroupBase> groups;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x881fb94b.
    buffer.writeInt32(0x881fb94b);

    // Write fields.
    buffer.writeInt32(hash);
    buffer.writeVectorObject(groups);

    // Finished serialization.
  }
}

/// Text With Entities.
///
/// ID: `751f3146`.
class TextWithEntities extends TextWithEntitiesBase {
  /// Text With Entities constructor.
  const TextWithEntities({
    required this.text,
    required this.entities,
  }) : super._();

  /// Deserialize.
  factory TextWithEntities.deserialize(BinaryReader reader) {
    // Read [TextWithEntities] fields.
    final text = reader.readString();
    final entities = reader.readVectorObject<MessageEntityBase>();

    // Construct [TextWithEntities] object.
    final returnValue = TextWithEntities(
      text: text,
      entities: entities,
    );

    // Now return the deserialized [TextWithEntities].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Entities.
  final List<MessageEntityBase> entities;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x751f3146.
    buffer.writeInt32(0x751f3146);

    // Write fields.
    buffer.writeString(text);
    buffer.writeVectorObject(entities);

    // Finished serialization.
  }
}

/// Messages Translate Result.
///
/// ID: `33db32f8`.
class MessagesTranslateResult extends MessagesTranslatedTextBase {
  /// Messages Translate Result constructor.
  const MessagesTranslateResult({
    required this.result,
  }) : super._();

  /// Deserialize.
  factory MessagesTranslateResult.deserialize(BinaryReader reader) {
    // Read [MessagesTranslateResult] fields.
    final result = reader.readVectorObject<TextWithEntitiesBase>();

    // Construct [MessagesTranslateResult] object.
    final returnValue = MessagesTranslateResult(
      result: result,
    );

    // Now return the deserialized [MessagesTranslateResult].
    return returnValue;
  }

  /// Result.
  final List<TextWithEntitiesBase> result;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x33db32f8.
    buffer.writeInt32(0x33db32f8);

    // Write fields.
    buffer.writeVectorObject(result);

    // Finished serialization.
  }
}

/// Auto Save Settings.
///
/// ID: `c84834ce`.
class AutoSaveSettings extends AutoSaveSettingsBase {
  /// Auto Save Settings constructor.
  const AutoSaveSettings({
    required this.photos,
    required this.videos,
    this.videoMaxSize,
  }) : super._();

  /// Deserialize.
  factory AutoSaveSettings.deserialize(BinaryReader reader) {
    // Read [AutoSaveSettings] fields.
    final flags = reader.readInt32();
    final photos = (flags & 1) != 0;
    final videos = (flags & 2) != 0;
    final hasVideoMaxSizeField = (flags & 4) != 0;
    final videoMaxSize = hasVideoMaxSizeField ? reader.readInt64() : null;

    // Construct [AutoSaveSettings] object.
    final returnValue = AutoSaveSettings(
      photos: photos,
      videos: videos,
      videoMaxSize: videoMaxSize,
    );

    // Now return the deserialized [AutoSaveSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: photos,
      b01: videos,
      b02: videoMaxSize != null,
    );

    return v;
  }

  /// photos: bit 0 of flags.0?true
  final bool photos;

  /// videos: bit 1 of flags.1?true
  final bool videos;

  /// Video Max Size.
  final int? videoMaxSize;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc84834ce.
    buffer.writeInt32(0xc84834ce);

    // Write fields.
    buffer.writeInt32(flags);
    final localVideoMaxSizeCopy = videoMaxSize;
    if (localVideoMaxSizeCopy != null) {
      buffer.writeInt64(localVideoMaxSizeCopy);
    }

    // Finished serialization.
  }
}

/// Auto Save Exception.
///
/// ID: `81602d47`.
class AutoSaveException extends AutoSaveExceptionBase {
  /// Auto Save Exception constructor.
  const AutoSaveException({
    required this.peer,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AutoSaveException.deserialize(BinaryReader reader) {
    // Read [AutoSaveException] fields.
    final peer = reader.readObject() as PeerBase;
    final settings = reader.readObject() as AutoSaveSettingsBase;

    // Construct [AutoSaveException] object.
    final returnValue = AutoSaveException(
      peer: peer,
      settings: settings,
    );

    // Now return the deserialized [AutoSaveException].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Settings.
  final AutoSaveSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x81602d47.
    buffer.writeInt32(0x81602d47);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Account Auto Save Settings.
///
/// ID: `4c3e069d`.
class AccountAutoSaveSettings extends AccountAutoSaveSettingsBase {
  /// Account Auto Save Settings constructor.
  const AccountAutoSaveSettings({
    required this.usersSettings,
    required this.chatsSettings,
    required this.broadcastsSettings,
    required this.exceptions,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory AccountAutoSaveSettings.deserialize(BinaryReader reader) {
    // Read [AccountAutoSaveSettings] fields.
    final usersSettings = reader.readObject() as AutoSaveSettingsBase;
    final chatsSettings = reader.readObject() as AutoSaveSettingsBase;
    final broadcastsSettings = reader.readObject() as AutoSaveSettingsBase;
    final exceptions = reader.readVectorObject<AutoSaveExceptionBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [AccountAutoSaveSettings] object.
    final returnValue = AccountAutoSaveSettings(
      usersSettings: usersSettings,
      chatsSettings: chatsSettings,
      broadcastsSettings: broadcastsSettings,
      exceptions: exceptions,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [AccountAutoSaveSettings].
    return returnValue;
  }

  /// Users Settings.
  final AutoSaveSettingsBase usersSettings;

  /// Chats Settings.
  final AutoSaveSettingsBase chatsSettings;

  /// Broadcasts Settings.
  final AutoSaveSettingsBase broadcastsSettings;

  /// Exceptions.
  final List<AutoSaveExceptionBase> exceptions;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4c3e069d.
    buffer.writeInt32(0x4c3e069d);

    // Write fields.
    buffer.writeObject(usersSettings);
    buffer.writeObject(chatsSettings);
    buffer.writeObject(broadcastsSettings);
    buffer.writeVectorObject(exceptions);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Help App Config Not Modified.
///
/// ID: `7cde641d`.
class HelpAppConfigNotModified extends HelpAppConfigBase {
  /// Help App Config Not Modified constructor.
  const HelpAppConfigNotModified() : super._();

  /// Deserialize.
  factory HelpAppConfigNotModified.deserialize(BinaryReader reader) {
    // Construct [HelpAppConfigNotModified] object.
    final returnValue = HelpAppConfigNotModified();

    // Now return the deserialized [HelpAppConfigNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7cde641d.
    buffer.writeInt32(0x7cde641d);

    // Finished serialization.
  }
}

/// Help App Config.
///
/// ID: `dd18782e`.
class HelpAppConfig extends HelpAppConfigBase {
  /// Help App Config constructor.
  const HelpAppConfig({
    required this.hash,
    required this.config,
  }) : super._();

  /// Deserialize.
  factory HelpAppConfig.deserialize(BinaryReader reader) {
    // Read [HelpAppConfig] fields.
    final hash = reader.readInt32();
    final config = reader.readObject() as JSONValueBase;

    // Construct [HelpAppConfig] object.
    final returnValue = HelpAppConfig(
      hash: hash,
      config: config,
    );

    // Now return the deserialized [HelpAppConfig].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Config.
  final JSONValueBase config;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdd18782e.
    buffer.writeInt32(0xdd18782e);

    // Write fields.
    buffer.writeInt32(hash);
    buffer.writeObject(config);

    // Finished serialization.
  }
}

/// Input Bot App I D.
///
/// ID: `a920bd7a`.
class InputBotAppID extends InputBotAppBase {
  /// Input Bot App I D constructor.
  const InputBotAppID({
    required this.id,
    required this.accessHash,
  }) : super._();

  /// Deserialize.
  factory InputBotAppID.deserialize(BinaryReader reader) {
    // Read [InputBotAppID] fields.
    final id = reader.readInt64();
    final accessHash = reader.readInt64();

    // Construct [InputBotAppID] object.
    final returnValue = InputBotAppID(
      id: id,
      accessHash: accessHash,
    );

    // Now return the deserialized [InputBotAppID].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa920bd7a.
    buffer.writeInt32(0xa920bd7a);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);

    // Finished serialization.
  }
}

/// Input Bot App Short Name.
///
/// ID: `908c0407`.
class InputBotAppShortName extends InputBotAppBase {
  /// Input Bot App Short Name constructor.
  const InputBotAppShortName({
    required this.botId,
    required this.shortName,
  }) : super._();

  /// Deserialize.
  factory InputBotAppShortName.deserialize(BinaryReader reader) {
    // Read [InputBotAppShortName] fields.
    final botId = reader.readObject() as InputUserBase;
    final shortName = reader.readString();

    // Construct [InputBotAppShortName] object.
    final returnValue = InputBotAppShortName(
      botId: botId,
      shortName: shortName,
    );

    // Now return the deserialized [InputBotAppShortName].
    return returnValue;
  }

  /// Bot Id.
  final InputUserBase botId;

  /// Short Name.
  final String shortName;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x908c0407.
    buffer.writeInt32(0x908c0407);

    // Write fields.
    buffer.writeObject(botId);
    buffer.writeString(shortName);

    // Finished serialization.
  }
}

/// Bot App Not Modified.
///
/// ID: `5da674b7`.
class BotAppNotModified extends BotAppBase {
  /// Bot App Not Modified constructor.
  const BotAppNotModified() : super._();

  /// Deserialize.
  factory BotAppNotModified.deserialize(BinaryReader reader) {
    // Construct [BotAppNotModified] object.
    final returnValue = BotAppNotModified();

    // Now return the deserialized [BotAppNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5da674b7.
    buffer.writeInt32(0x5da674b7);

    // Finished serialization.
  }
}

/// Bot App.
///
/// ID: `95fcd1d6`.
class BotApp extends BotAppBase {
  /// Bot App constructor.
  const BotApp({
    required this.id,
    required this.accessHash,
    required this.shortName,
    required this.title,
    required this.description,
    required this.photo,
    this.document,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory BotApp.deserialize(BinaryReader reader) {
    // Read [BotApp] fields.
    final flags = reader.readInt32();
    final id = reader.readInt64();
    final accessHash = reader.readInt64();
    final shortName = reader.readString();
    final title = reader.readString();
    final description = reader.readString();
    final photo = reader.readObject() as PhotoBase;
    final hasDocumentField = (flags & 1) != 0;
    final document =
        hasDocumentField ? reader.readObject() as DocumentBase : null;
    final hash = reader.readInt64();

    // Construct [BotApp] object.
    final returnValue = BotApp(
      id: id,
      accessHash: accessHash,
      shortName: shortName,
      title: title,
      description: description,
      photo: photo,
      document: document,
      hash: hash,
    );

    // Now return the deserialized [BotApp].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: document != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Access Hash.
  ///
  /// Field type is Int64.
  final int accessHash;

  /// Short Name.
  final String shortName;

  /// Title.
  final String title;

  /// Description.
  final String description;

  /// Photo.
  final PhotoBase photo;

  /// Document.
  final DocumentBase? document;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x95fcd1d6.
    buffer.writeInt32(0x95fcd1d6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(id);
    buffer.writeInt64(accessHash);
    buffer.writeString(shortName);
    buffer.writeString(title);
    buffer.writeString(description);
    buffer.writeObject(photo);
    final localDocumentCopy = document;
    if (localDocumentCopy != null) {
      buffer.writeObject(localDocumentCopy);
    }
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Bot App.
///
/// ID: `eb50adf5`.
class MessagesBotApp extends MessagesBotAppBase {
  /// Messages Bot App constructor.
  const MessagesBotApp({
    required this.inactive,
    required this.requestWriteAccess,
    required this.hasSettings,
    required this.app,
  }) : super._();

  /// Deserialize.
  factory MessagesBotApp.deserialize(BinaryReader reader) {
    // Read [MessagesBotApp] fields.
    final flags = reader.readInt32();
    final inactive = (flags & 1) != 0;
    final requestWriteAccess = (flags & 2) != 0;
    final hasSettings = (flags & 4) != 0;
    final app = reader.readObject() as BotAppBase;

    // Construct [MessagesBotApp] object.
    final returnValue = MessagesBotApp(
      inactive: inactive,
      requestWriteAccess: requestWriteAccess,
      hasSettings: hasSettings,
      app: app,
    );

    // Now return the deserialized [MessagesBotApp].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: inactive,
      b01: requestWriteAccess,
      b02: hasSettings,
    );

    return v;
  }

  /// inactive: bit 0 of flags.0?true
  final bool inactive;

  /// request_write_access: bit 1 of flags.1?true
  final bool requestWriteAccess;

  /// has_settings: bit 2 of flags.2?true
  final bool hasSettings;

  /// App.
  final BotAppBase app;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeb50adf5.
    buffer.writeInt32(0xeb50adf5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(app);

    // Finished serialization.
  }
}

/// App Web View Result Url.
///
/// ID: `3c1b4f0d`.
class AppWebViewResultUrl extends AppWebViewResultBase {
  /// App Web View Result Url constructor.
  const AppWebViewResultUrl({
    required this.url,
  }) : super._();

  /// Deserialize.
  factory AppWebViewResultUrl.deserialize(BinaryReader reader) {
    // Read [AppWebViewResultUrl] fields.
    final url = reader.readString();

    // Construct [AppWebViewResultUrl] object.
    final returnValue = AppWebViewResultUrl(
      url: url,
    );

    // Now return the deserialized [AppWebViewResultUrl].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3c1b4f0d.
    buffer.writeInt32(0x3c1b4f0d);

    // Write fields.
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Inline Bot Web View.
///
/// ID: `b57295d5`.
class InlineBotWebView extends InlineBotWebViewBase {
  /// Inline Bot Web View constructor.
  const InlineBotWebView({
    required this.text,
    required this.url,
  }) : super._();

  /// Deserialize.
  factory InlineBotWebView.deserialize(BinaryReader reader) {
    // Read [InlineBotWebView] fields.
    final text = reader.readString();
    final url = reader.readString();

    // Construct [InlineBotWebView] object.
    final returnValue = InlineBotWebView(
      text: text,
      url: url,
    );

    // Now return the deserialized [InlineBotWebView].
    return returnValue;
  }

  /// Text.
  final String text;

  /// Url.
  final String url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb57295d5.
    buffer.writeInt32(0xb57295d5);

    // Write fields.
    buffer.writeString(text);
    buffer.writeString(url);

    // Finished serialization.
  }
}

/// Read Participant Date.
///
/// ID: `4a4ff172`.
class ReadParticipantDate extends ReadParticipantDateBase {
  /// Read Participant Date constructor.
  const ReadParticipantDate({
    required this.userId,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory ReadParticipantDate.deserialize(BinaryReader reader) {
    // Read [ReadParticipantDate] fields.
    final userId = reader.readInt64();
    final date = reader.readDateTime();

    // Construct [ReadParticipantDate] object.
    final returnValue = ReadParticipantDate(
      userId: userId,
      date: date,
    );

    // Now return the deserialized [ReadParticipantDate].
    return returnValue;
  }

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4a4ff172.
    buffer.writeInt32(0x4a4ff172);

    // Write fields.
    buffer.writeInt64(userId);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Input Chatlist Dialog Filter.
///
/// ID: `f3e0da33`.
class InputChatlistDialogFilter extends InputChatlistBase {
  /// Input Chatlist Dialog Filter constructor.
  const InputChatlistDialogFilter({
    required this.filterId,
  }) : super._();

  /// Deserialize.
  factory InputChatlistDialogFilter.deserialize(BinaryReader reader) {
    // Read [InputChatlistDialogFilter] fields.
    final filterId = reader.readInt32();

    // Construct [InputChatlistDialogFilter] object.
    final returnValue = InputChatlistDialogFilter(
      filterId: filterId,
    );

    // Now return the deserialized [InputChatlistDialogFilter].
    return returnValue;
  }

  /// Filter Id.
  ///
  /// Field type is Int32.
  final int filterId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf3e0da33.
    buffer.writeInt32(0xf3e0da33);

    // Write fields.
    buffer.writeInt32(filterId);

    // Finished serialization.
  }
}

/// Exported Chatlist Invite.
///
/// ID: `0c5181ac`.
class ExportedChatlistInvite extends ExportedChatlistInviteBase {
  /// Exported Chatlist Invite constructor.
  const ExportedChatlistInvite({
    required this.title,
    required this.url,
    required this.peers,
  }) : super._();

  /// Deserialize.
  factory ExportedChatlistInvite.deserialize(BinaryReader reader) {
    // Read [ExportedChatlistInvite] fields.
    final _ = reader.readInt32(); // flags.
    final title = reader.readString();
    final url = reader.readString();
    final peers = reader.readVectorObject<PeerBase>();

    // Construct [ExportedChatlistInvite] object.
    final returnValue = ExportedChatlistInvite(
      title: title,
      url: url,
      peers: peers,
    );

    // Now return the deserialized [ExportedChatlistInvite].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag();

    return v;
  }

  /// Title.
  final String title;

  /// Url.
  final String url;

  /// Peers.
  final List<PeerBase> peers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0c5181ac.
    buffer.writeInt32(0x0c5181ac);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(title);
    buffer.writeString(url);
    buffer.writeVectorObject(peers);

    // Finished serialization.
  }
}

/// Chatlists Exported Chatlist Invite.
///
/// ID: `10e6e3a6`.
class ChatlistsExportedChatlistInvite
    extends ChatlistsExportedChatlistInviteBase {
  /// Chatlists Exported Chatlist Invite constructor.
  const ChatlistsExportedChatlistInvite({
    required this.filter,
    required this.invite,
  }) : super._();

  /// Deserialize.
  factory ChatlistsExportedChatlistInvite.deserialize(BinaryReader reader) {
    // Read [ChatlistsExportedChatlistInvite] fields.
    final filter = reader.readObject() as DialogFilterBase;
    final invite = reader.readObject() as ExportedChatlistInviteBase;

    // Construct [ChatlistsExportedChatlistInvite] object.
    final returnValue = ChatlistsExportedChatlistInvite(
      filter: filter,
      invite: invite,
    );

    // Now return the deserialized [ChatlistsExportedChatlistInvite].
    return returnValue;
  }

  /// Filter.
  final DialogFilterBase filter;

  /// Invite.
  final ExportedChatlistInviteBase invite;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x10e6e3a6.
    buffer.writeInt32(0x10e6e3a6);

    // Write fields.
    buffer.writeObject(filter);
    buffer.writeObject(invite);

    // Finished serialization.
  }
}

/// Chatlists Exported Invites.
///
/// ID: `10ab6dc7`.
class ChatlistsExportedInvites extends ChatlistsExportedInvitesBase {
  /// Chatlists Exported Invites constructor.
  const ChatlistsExportedInvites({
    required this.invites,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ChatlistsExportedInvites.deserialize(BinaryReader reader) {
    // Read [ChatlistsExportedInvites] fields.
    final invites = reader.readVectorObject<ExportedChatlistInviteBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ChatlistsExportedInvites] object.
    final returnValue = ChatlistsExportedInvites(
      invites: invites,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ChatlistsExportedInvites].
    return returnValue;
  }

  /// Invites.
  final List<ExportedChatlistInviteBase> invites;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x10ab6dc7.
    buffer.writeInt32(0x10ab6dc7);

    // Write fields.
    buffer.writeVectorObject(invites);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Chatlists Chatlist Invite Already.
///
/// ID: `fa87f659`.
class ChatlistsChatlistInviteAlready extends ChatlistsChatlistInviteBase {
  /// Chatlists Chatlist Invite Already constructor.
  const ChatlistsChatlistInviteAlready({
    required this.filterId,
    required this.missingPeers,
    required this.alreadyPeers,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ChatlistsChatlistInviteAlready.deserialize(BinaryReader reader) {
    // Read [ChatlistsChatlistInviteAlready] fields.
    final filterId = reader.readInt32();
    final missingPeers = reader.readVectorObject<PeerBase>();
    final alreadyPeers = reader.readVectorObject<PeerBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ChatlistsChatlistInviteAlready] object.
    final returnValue = ChatlistsChatlistInviteAlready(
      filterId: filterId,
      missingPeers: missingPeers,
      alreadyPeers: alreadyPeers,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ChatlistsChatlistInviteAlready].
    return returnValue;
  }

  /// Filter Id.
  ///
  /// Field type is Int32.
  final int filterId;

  /// Missing Peers.
  final List<PeerBase> missingPeers;

  /// Already Peers.
  final List<PeerBase> alreadyPeers;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfa87f659.
    buffer.writeInt32(0xfa87f659);

    // Write fields.
    buffer.writeInt32(filterId);
    buffer.writeVectorObject(missingPeers);
    buffer.writeVectorObject(alreadyPeers);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Chatlists Chatlist Invite.
///
/// ID: `1dcd839d`.
class ChatlistsChatlistInvite extends ChatlistsChatlistInviteBase {
  /// Chatlists Chatlist Invite constructor.
  const ChatlistsChatlistInvite({
    required this.title,
    this.emoticon,
    required this.peers,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ChatlistsChatlistInvite.deserialize(BinaryReader reader) {
    // Read [ChatlistsChatlistInvite] fields.
    final flags = reader.readInt32();
    final title = reader.readString();
    final hasEmoticonField = (flags & 1) != 0;
    final emoticon = hasEmoticonField ? reader.readString() : null;
    final peers = reader.readVectorObject<PeerBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ChatlistsChatlistInvite] object.
    final returnValue = ChatlistsChatlistInvite(
      title: title,
      emoticon: emoticon,
      peers: peers,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ChatlistsChatlistInvite].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: emoticon != null,
    );

    return v;
  }

  /// Title.
  final String title;

  /// Emoticon.
  final String? emoticon;

  /// Peers.
  final List<PeerBase> peers;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1dcd839d.
    buffer.writeInt32(0x1dcd839d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(title);
    final localEmoticonCopy = emoticon;
    if (localEmoticonCopy != null) {
      buffer.writeString(localEmoticonCopy);
    }
    buffer.writeVectorObject(peers);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Chatlists Chatlist Updates.
///
/// ID: `93bd878d`.
class ChatlistsChatlistUpdates extends ChatlistsChatlistUpdatesBase {
  /// Chatlists Chatlist Updates constructor.
  const ChatlistsChatlistUpdates({
    required this.missingPeers,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ChatlistsChatlistUpdates.deserialize(BinaryReader reader) {
    // Read [ChatlistsChatlistUpdates] fields.
    final missingPeers = reader.readVectorObject<PeerBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [ChatlistsChatlistUpdates] object.
    final returnValue = ChatlistsChatlistUpdates(
      missingPeers: missingPeers,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [ChatlistsChatlistUpdates].
    return returnValue;
  }

  /// Missing Peers.
  final List<PeerBase> missingPeers;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x93bd878d.
    buffer.writeInt32(0x93bd878d);

    // Write fields.
    buffer.writeVectorObject(missingPeers);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Bots Bot Info.
///
/// ID: `e8a775b0`.
class BotsBotInfo extends BotsBotInfoBase {
  /// Bots Bot Info constructor.
  const BotsBotInfo({
    required this.name,
    required this.about,
    required this.description,
  }) : super._();

  /// Deserialize.
  factory BotsBotInfo.deserialize(BinaryReader reader) {
    // Read [BotsBotInfo] fields.
    final name = reader.readString();
    final about = reader.readString();
    final description = reader.readString();

    // Construct [BotsBotInfo] object.
    final returnValue = BotsBotInfo(
      name: name,
      about: about,
      description: description,
    );

    // Now return the deserialized [BotsBotInfo].
    return returnValue;
  }

  /// Name.
  final String name;

  /// About.
  final String about;

  /// Description.
  final String description;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe8a775b0.
    buffer.writeInt32(0xe8a775b0);

    // Write fields.
    buffer.writeString(name);
    buffer.writeString(about);
    buffer.writeString(description);

    // Finished serialization.
  }
}

/// Message Peer Vote.
///
/// ID: `b6cc2d5c`.
class MessagePeerVote extends MessagePeerVoteBase {
  /// Message Peer Vote constructor.
  const MessagePeerVote({
    required this.peer,
    required this.option,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory MessagePeerVote.deserialize(BinaryReader reader) {
    // Read [MessagePeerVote] fields.
    final peer = reader.readObject() as PeerBase;
    final option = reader.readBytes();
    final date = reader.readDateTime();

    // Construct [MessagePeerVote] object.
    final returnValue = MessagePeerVote(
      peer: peer,
      option: option,
      date: date,
    );

    // Now return the deserialized [MessagePeerVote].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Option.
  final Uint8List option;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb6cc2d5c.
    buffer.writeInt32(0xb6cc2d5c);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeBytes(option);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Message Peer Vote Input Option.
///
/// ID: `74cda504`.
class MessagePeerVoteInputOption extends MessagePeerVoteBase {
  /// Message Peer Vote Input Option constructor.
  const MessagePeerVoteInputOption({
    required this.peer,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory MessagePeerVoteInputOption.deserialize(BinaryReader reader) {
    // Read [MessagePeerVoteInputOption] fields.
    final peer = reader.readObject() as PeerBase;
    final date = reader.readDateTime();

    // Construct [MessagePeerVoteInputOption] object.
    final returnValue = MessagePeerVoteInputOption(
      peer: peer,
      date: date,
    );

    // Now return the deserialized [MessagePeerVoteInputOption].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x74cda504.
    buffer.writeInt32(0x74cda504);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Message Peer Vote Multiple.
///
/// ID: `4628f6e6`.
class MessagePeerVoteMultiple extends MessagePeerVoteBase {
  /// Message Peer Vote Multiple constructor.
  const MessagePeerVoteMultiple({
    required this.peer,
    required this.options,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory MessagePeerVoteMultiple.deserialize(BinaryReader reader) {
    // Read [MessagePeerVoteMultiple] fields.
    final peer = reader.readObject() as PeerBase;
    final options = reader.readVectorBytes();
    final date = reader.readDateTime();

    // Construct [MessagePeerVoteMultiple] object.
    final returnValue = MessagePeerVoteMultiple(
      peer: peer,
      options: options,
      date: date,
    );

    // Now return the deserialized [MessagePeerVoteMultiple].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Options.
  final List<Uint8List> options;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4628f6e6.
    buffer.writeInt32(0x4628f6e6);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorBytes(options);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Sponsored Web Page.
///
/// ID: `3db8ec63`.
class SponsoredWebPage extends SponsoredWebPageBase {
  /// Sponsored Web Page constructor.
  const SponsoredWebPage({
    required this.url,
    required this.siteName,
    this.photo,
  }) : super._();

  /// Deserialize.
  factory SponsoredWebPage.deserialize(BinaryReader reader) {
    // Read [SponsoredWebPage] fields.
    final flags = reader.readInt32();
    final url = reader.readString();
    final siteName = reader.readString();
    final hasPhotoField = (flags & 1) != 0;
    final photo = hasPhotoField ? reader.readObject() as PhotoBase : null;

    // Construct [SponsoredWebPage] object.
    final returnValue = SponsoredWebPage(
      url: url,
      siteName: siteName,
      photo: photo,
    );

    // Now return the deserialized [SponsoredWebPage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: photo != null,
    );

    return v;
  }

  /// Url.
  final String url;

  /// Site Name.
  final String siteName;

  /// Photo.
  final PhotoBase? photo;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3db8ec63.
    buffer.writeInt32(0x3db8ec63);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(url);
    buffer.writeString(siteName);
    final localPhotoCopy = photo;
    if (localPhotoCopy != null) {
      buffer.writeObject(localPhotoCopy);
    }

    // Finished serialization.
  }
}

/// Story Views.
///
/// ID: `8d595cd6`.
class StoryViews extends StoryViewsBase {
  /// Story Views constructor.
  const StoryViews({
    required this.hasViewers,
    required this.viewsCount,
    this.forwardsCount,
    this.reactions,
    this.reactionsCount,
    this.recentViewers,
  }) : super._();

  /// Deserialize.
  factory StoryViews.deserialize(BinaryReader reader) {
    // Read [StoryViews] fields.
    final flags = reader.readInt32();
    final hasViewers = (flags & 2) != 0;
    final viewsCount = reader.readInt32();
    final hasForwardsCountField = (flags & 4) != 0;
    final forwardsCount = hasForwardsCountField ? reader.readInt32() : null;
    final hasReactionsField = (flags & 8) != 0;
    final reactions =
        hasReactionsField ? reader.readVectorObject<ReactionCountBase>() : null;
    final hasReactionsCountField = (flags & 16) != 0;
    final reactionsCount = hasReactionsCountField ? reader.readInt32() : null;
    final hasRecentViewersField = (flags & 1) != 0;
    final recentViewers =
        hasRecentViewersField ? reader.readVectorInt64() : null;

    // Construct [StoryViews] object.
    final returnValue = StoryViews(
      hasViewers: hasViewers,
      viewsCount: viewsCount,
      forwardsCount: forwardsCount,
      reactions: reactions,
      reactionsCount: reactionsCount,
      recentViewers: recentViewers,
    );

    // Now return the deserialized [StoryViews].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: hasViewers,
      b02: forwardsCount != null,
      b03: reactions != null,
      b04: reactionsCount != null,
      b00: recentViewers != null,
    );

    return v;
  }

  /// has_viewers: bit 1 of flags.1?true
  final bool hasViewers;

  /// Views Count.
  ///
  /// Field type is Int32.
  final int viewsCount;

  /// Forwards Count.
  final int? forwardsCount;

  /// Reactions.
  final List<ReactionCountBase>? reactions;

  /// Reactions Count.
  final int? reactionsCount;

  /// Recent Viewers.
  final List<int>? recentViewers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8d595cd6.
    buffer.writeInt32(0x8d595cd6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(viewsCount);
    final localForwardsCountCopy = forwardsCount;
    if (localForwardsCountCopy != null) {
      buffer.writeInt32(localForwardsCountCopy);
    }
    final localReactionsCopy = reactions;
    if (localReactionsCopy != null) {
      buffer.writeVectorObject(localReactionsCopy);
    }
    final localReactionsCountCopy = reactionsCount;
    if (localReactionsCountCopy != null) {
      buffer.writeInt32(localReactionsCountCopy);
    }
    final localRecentViewersCopy = recentViewers;
    if (localRecentViewersCopy != null) {
      buffer.writeVectorInt64(localRecentViewersCopy);
    }

    // Finished serialization.
  }
}

/// Story Item Deleted.
///
/// ID: `51e6ee4f`.
class StoryItemDeleted extends StoryItemBase {
  /// Story Item Deleted constructor.
  const StoryItemDeleted({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory StoryItemDeleted.deserialize(BinaryReader reader) {
    // Read [StoryItemDeleted] fields.
    final id = reader.readInt32();

    // Construct [StoryItemDeleted] object.
    final returnValue = StoryItemDeleted(
      id: id,
    );

    // Now return the deserialized [StoryItemDeleted].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x51e6ee4f.
    buffer.writeInt32(0x51e6ee4f);

    // Write fields.
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Story Item Skipped.
///
/// ID: `ffadc913`.
class StoryItemSkipped extends StoryItemBase {
  /// Story Item Skipped constructor.
  const StoryItemSkipped({
    required this.closeFriends,
    required this.id,
    required this.date,
    required this.expireDate,
  }) : super._();

  /// Deserialize.
  factory StoryItemSkipped.deserialize(BinaryReader reader) {
    // Read [StoryItemSkipped] fields.
    final flags = reader.readInt32();
    final closeFriends = (flags & 256) != 0;
    final id = reader.readInt32();
    final date = reader.readDateTime();
    final expireDate = reader.readDateTime();

    // Construct [StoryItemSkipped] object.
    final returnValue = StoryItemSkipped(
      closeFriends: closeFriends,
      id: id,
      date: date,
      expireDate: expireDate,
    );

    // Now return the deserialized [StoryItemSkipped].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b08: closeFriends,
    );

    return v;
  }

  /// close_friends: bit 8 of flags.8?true
  final bool closeFriends;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Date.
  final DateTime date;

  /// Expire Date.
  final DateTime expireDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xffadc913.
    buffer.writeInt32(0xffadc913);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeDateTime(date);
    buffer.writeDateTime(expireDate);

    // Finished serialization.
  }
}

/// Story Item.
///
/// ID: `af6365a1`.
class StoryItem extends StoryItemBase {
  /// Story Item constructor.
  const StoryItem({
    required this.pinned,
    required this.public,
    required this.closeFriends,
    required this.min,
    required this.noforwards,
    required this.edited,
    required this.contacts,
    required this.selectedContacts,
    required this.out,
    required this.id,
    required this.date,
    this.fwdFrom,
    required this.expireDate,
    this.caption,
    this.entities,
    required this.media,
    this.mediaAreas,
    this.privacy,
    this.views,
    this.sentReaction,
  }) : super._();

  /// Deserialize.
  factory StoryItem.deserialize(BinaryReader reader) {
    // Read [StoryItem] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 32) != 0;
    final public = (flags & 128) != 0;
    final closeFriends = (flags & 256) != 0;
    final min = (flags & 512) != 0;
    final noforwards = (flags & 1024) != 0;
    final edited = (flags & 2048) != 0;
    final contacts = (flags & 4096) != 0;
    final selectedContacts = (flags & 8192) != 0;
    final out = (flags & 65536) != 0;
    final id = reader.readInt32();
    final date = reader.readDateTime();
    final hasFwdFromField = (flags & 131072) != 0;
    final fwdFrom =
        hasFwdFromField ? reader.readObject() as StoryFwdHeaderBase : null;
    final expireDate = reader.readDateTime();
    final hasCaptionField = (flags & 1) != 0;
    final caption = hasCaptionField ? reader.readString() : null;
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final media = reader.readObject() as MessageMediaBase;
    final hasMediaAreasField = (flags & 16384) != 0;
    final mediaAreas =
        hasMediaAreasField ? reader.readVectorObject<MediaAreaBase>() : null;
    final hasPrivacyField = (flags & 4) != 0;
    final privacy =
        hasPrivacyField ? reader.readVectorObject<PrivacyRuleBase>() : null;
    final hasViewsField = (flags & 8) != 0;
    final views = hasViewsField ? reader.readObject() as StoryViewsBase : null;
    final hasSentReactionField = (flags & 32768) != 0;
    final sentReaction =
        hasSentReactionField ? reader.readObject() as ReactionBase : null;

    // Construct [StoryItem] object.
    final returnValue = StoryItem(
      pinned: pinned,
      public: public,
      closeFriends: closeFriends,
      min: min,
      noforwards: noforwards,
      edited: edited,
      contacts: contacts,
      selectedContacts: selectedContacts,
      out: out,
      id: id,
      date: date,
      fwdFrom: fwdFrom,
      expireDate: expireDate,
      caption: caption,
      entities: entities,
      media: media,
      mediaAreas: mediaAreas,
      privacy: privacy,
      views: views,
      sentReaction: sentReaction,
    );

    // Now return the deserialized [StoryItem].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b05: pinned,
      b07: public,
      b08: closeFriends,
      b09: min,
      b10: noforwards,
      b11: edited,
      b12: contacts,
      b13: selectedContacts,
      b16: out,
      b17: fwdFrom != null,
      b00: caption != null,
      b01: entities != null,
      b14: mediaAreas != null,
      b02: privacy != null,
      b03: views != null,
      b15: sentReaction != null,
    );

    return v;
  }

  /// pinned: bit 5 of flags.5?true
  final bool pinned;

  /// public: bit 7 of flags.7?true
  final bool public;

  /// close_friends: bit 8 of flags.8?true
  final bool closeFriends;

  /// min: bit 9 of flags.9?true
  final bool min;

  /// noforwards: bit 10 of flags.10?true
  final bool noforwards;

  /// edited: bit 11 of flags.11?true
  final bool edited;

  /// contacts: bit 12 of flags.12?true
  final bool contacts;

  /// selected_contacts: bit 13 of flags.13?true
  final bool selectedContacts;

  /// out: bit 16 of flags.16?true
  final bool out;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Date.
  final DateTime date;

  /// Fwd From.
  final StoryFwdHeaderBase? fwdFrom;

  /// Expire Date.
  final DateTime expireDate;

  /// Caption.
  final String? caption;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Media.
  final MessageMediaBase media;

  /// Media Areas.
  final List<MediaAreaBase>? mediaAreas;

  /// Privacy.
  final List<PrivacyRuleBase>? privacy;

  /// Views.
  final StoryViewsBase? views;

  /// Sent Reaction.
  final ReactionBase? sentReaction;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaf6365a1.
    buffer.writeInt32(0xaf6365a1);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    buffer.writeDateTime(date);
    final localFwdFromCopy = fwdFrom;
    if (localFwdFromCopy != null) {
      buffer.writeObject(localFwdFromCopy);
    }
    buffer.writeDateTime(expireDate);
    final localCaptionCopy = caption;
    if (localCaptionCopy != null) {
      buffer.writeString(localCaptionCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    buffer.writeObject(media);
    final localMediaAreasCopy = mediaAreas;
    if (localMediaAreasCopy != null) {
      buffer.writeVectorObject(localMediaAreasCopy);
    }
    final localPrivacyCopy = privacy;
    if (localPrivacyCopy != null) {
      buffer.writeVectorObject(localPrivacyCopy);
    }
    final localViewsCopy = views;
    if (localViewsCopy != null) {
      buffer.writeObject(localViewsCopy);
    }
    final localSentReactionCopy = sentReaction;
    if (localSentReactionCopy != null) {
      buffer.writeObject(localSentReactionCopy);
    }

    // Finished serialization.
  }
}

/// Stories All Stories Not Modified.
///
/// ID: `1158fe3e`.
class StoriesAllStoriesNotModified extends StoriesAllStoriesBase {
  /// Stories All Stories Not Modified constructor.
  const StoriesAllStoriesNotModified({
    required this.state,
    required this.stealthMode,
  }) : super._();

  /// Deserialize.
  factory StoriesAllStoriesNotModified.deserialize(BinaryReader reader) {
    // Read [StoriesAllStoriesNotModified] fields.
    final _ = reader.readInt32(); // flags.
    final state = reader.readString();
    final stealthMode = reader.readObject() as StoriesStealthModeBase;

    // Construct [StoriesAllStoriesNotModified] object.
    final returnValue = StoriesAllStoriesNotModified(
      state: state,
      stealthMode: stealthMode,
    );

    // Now return the deserialized [StoriesAllStoriesNotModified].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag();

    return v;
  }

  /// State.
  final String state;

  /// Stealth Mode.
  final StoriesStealthModeBase stealthMode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1158fe3e.
    buffer.writeInt32(0x1158fe3e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(state);
    buffer.writeObject(stealthMode);

    // Finished serialization.
  }
}

/// Stories All Stories.
///
/// ID: `6efc5e81`.
class StoriesAllStories extends StoriesAllStoriesBase {
  /// Stories All Stories constructor.
  const StoriesAllStories({
    required this.hasMore,
    required this.count,
    required this.state,
    required this.peerStories,
    required this.chats,
    required this.users,
    required this.stealthMode,
  }) : super._();

  /// Deserialize.
  factory StoriesAllStories.deserialize(BinaryReader reader) {
    // Read [StoriesAllStories] fields.
    final flags = reader.readInt32();
    final hasMore = (flags & 1) != 0;
    final count = reader.readInt32();
    final state = reader.readString();
    final peerStories = reader.readVectorObject<PeerStoriesBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final stealthMode = reader.readObject() as StoriesStealthModeBase;

    // Construct [StoriesAllStories] object.
    final returnValue = StoriesAllStories(
      hasMore: hasMore,
      count: count,
      state: state,
      peerStories: peerStories,
      chats: chats,
      users: users,
      stealthMode: stealthMode,
    );

    // Now return the deserialized [StoriesAllStories].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: hasMore,
    );

    return v;
  }

  /// has_more: bit 0 of flags.0?true
  final bool hasMore;

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// State.
  final String state;

  /// Peer Stories.
  final List<PeerStoriesBase> peerStories;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Stealth Mode.
  final StoriesStealthModeBase stealthMode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6efc5e81.
    buffer.writeInt32(0x6efc5e81);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(count);
    buffer.writeString(state);
    buffer.writeVectorObject(peerStories);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    buffer.writeObject(stealthMode);

    // Finished serialization.
  }
}

/// Stories Stories.
///
/// ID: `5dd8c3c8`.
class StoriesStories extends StoriesStoriesBase {
  /// Stories Stories constructor.
  const StoriesStories({
    required this.count,
    required this.stories,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory StoriesStories.deserialize(BinaryReader reader) {
    // Read [StoriesStories] fields.
    final count = reader.readInt32();
    final stories = reader.readVectorObject<StoryItemBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [StoriesStories] object.
    final returnValue = StoriesStories(
      count: count,
      stories: stories,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [StoriesStories].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Stories.
  final List<StoryItemBase> stories;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5dd8c3c8.
    buffer.writeInt32(0x5dd8c3c8);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(stories);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Story View.
///
/// ID: `b0bdeac5`.
class StoryView extends StoryViewBase {
  /// Story View constructor.
  const StoryView({
    required this.blocked,
    required this.blockedMyStoriesFrom,
    required this.userId,
    required this.date,
    this.reaction,
  }) : super._();

  /// Deserialize.
  factory StoryView.deserialize(BinaryReader reader) {
    // Read [StoryView] fields.
    final flags = reader.readInt32();
    final blocked = (flags & 1) != 0;
    final blockedMyStoriesFrom = (flags & 2) != 0;
    final userId = reader.readInt64();
    final date = reader.readDateTime();
    final hasReactionField = (flags & 4) != 0;
    final reaction =
        hasReactionField ? reader.readObject() as ReactionBase : null;

    // Construct [StoryView] object.
    final returnValue = StoryView(
      blocked: blocked,
      blockedMyStoriesFrom: blockedMyStoriesFrom,
      userId: userId,
      date: date,
      reaction: reaction,
    );

    // Now return the deserialized [StoryView].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: blocked,
      b01: blockedMyStoriesFrom,
      b02: reaction != null,
    );

    return v;
  }

  /// blocked: bit 0 of flags.0?true
  final bool blocked;

  /// blocked_my_stories_from: bit 1 of flags.1?true
  final bool blockedMyStoriesFrom;

  /// User Id.
  ///
  /// Field type is Int64.
  final int userId;

  /// Date.
  final DateTime date;

  /// Reaction.
  final ReactionBase? reaction;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb0bdeac5.
    buffer.writeInt32(0xb0bdeac5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(userId);
    buffer.writeDateTime(date);
    final localReactionCopy = reaction;
    if (localReactionCopy != null) {
      buffer.writeObject(localReactionCopy);
    }

    // Finished serialization.
  }
}

/// Story View Public Forward.
///
/// ID: `9083670b`.
class StoryViewPublicForward extends StoryViewBase {
  /// Story View Public Forward constructor.
  const StoryViewPublicForward({
    required this.blocked,
    required this.blockedMyStoriesFrom,
    required this.message,
  }) : super._();

  /// Deserialize.
  factory StoryViewPublicForward.deserialize(BinaryReader reader) {
    // Read [StoryViewPublicForward] fields.
    final flags = reader.readInt32();
    final blocked = (flags & 1) != 0;
    final blockedMyStoriesFrom = (flags & 2) != 0;
    final message = reader.readObject() as MessageBase;

    // Construct [StoryViewPublicForward] object.
    final returnValue = StoryViewPublicForward(
      blocked: blocked,
      blockedMyStoriesFrom: blockedMyStoriesFrom,
      message: message,
    );

    // Now return the deserialized [StoryViewPublicForward].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: blocked,
      b01: blockedMyStoriesFrom,
    );

    return v;
  }

  /// blocked: bit 0 of flags.0?true
  final bool blocked;

  /// blocked_my_stories_from: bit 1 of flags.1?true
  final bool blockedMyStoriesFrom;

  /// Message.
  final MessageBase message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9083670b.
    buffer.writeInt32(0x9083670b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(message);

    // Finished serialization.
  }
}

/// Story View Public Repost.
///
/// ID: `bd74cf49`.
class StoryViewPublicRepost extends StoryViewBase {
  /// Story View Public Repost constructor.
  const StoryViewPublicRepost({
    required this.blocked,
    required this.blockedMyStoriesFrom,
    required this.peerId,
    required this.story,
  }) : super._();

  /// Deserialize.
  factory StoryViewPublicRepost.deserialize(BinaryReader reader) {
    // Read [StoryViewPublicRepost] fields.
    final flags = reader.readInt32();
    final blocked = (flags & 1) != 0;
    final blockedMyStoriesFrom = (flags & 2) != 0;
    final peerId = reader.readObject() as PeerBase;
    final story = reader.readObject() as StoryItemBase;

    // Construct [StoryViewPublicRepost] object.
    final returnValue = StoryViewPublicRepost(
      blocked: blocked,
      blockedMyStoriesFrom: blockedMyStoriesFrom,
      peerId: peerId,
      story: story,
    );

    // Now return the deserialized [StoryViewPublicRepost].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: blocked,
      b01: blockedMyStoriesFrom,
    );

    return v;
  }

  /// blocked: bit 0 of flags.0?true
  final bool blocked;

  /// blocked_my_stories_from: bit 1 of flags.1?true
  final bool blockedMyStoriesFrom;

  /// Peer Id.
  final PeerBase peerId;

  /// Story.
  final StoryItemBase story;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbd74cf49.
    buffer.writeInt32(0xbd74cf49);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peerId);
    buffer.writeObject(story);

    // Finished serialization.
  }
}

/// Stories Story Views List.
///
/// ID: `59d78fc5`.
class StoriesStoryViewsList extends StoriesStoryViewsListBase {
  /// Stories Story Views List constructor.
  const StoriesStoryViewsList({
    required this.count,
    required this.viewsCount,
    required this.forwardsCount,
    required this.reactionsCount,
    required this.views,
    required this.chats,
    required this.users,
    this.nextOffset,
  }) : super._();

  /// Deserialize.
  factory StoriesStoryViewsList.deserialize(BinaryReader reader) {
    // Read [StoriesStoryViewsList] fields.
    final flags = reader.readInt32();
    final count = reader.readInt32();
    final viewsCount = reader.readInt32();
    final forwardsCount = reader.readInt32();
    final reactionsCount = reader.readInt32();
    final views = reader.readVectorObject<StoryViewBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final hasNextOffsetField = (flags & 1) != 0;
    final nextOffset = hasNextOffsetField ? reader.readString() : null;

    // Construct [StoriesStoryViewsList] object.
    final returnValue = StoriesStoryViewsList(
      count: count,
      viewsCount: viewsCount,
      forwardsCount: forwardsCount,
      reactionsCount: reactionsCount,
      views: views,
      chats: chats,
      users: users,
      nextOffset: nextOffset,
    );

    // Now return the deserialized [StoriesStoryViewsList].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: nextOffset != null,
    );

    return v;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Views Count.
  ///
  /// Field type is Int32.
  final int viewsCount;

  /// Forwards Count.
  ///
  /// Field type is Int32.
  final int forwardsCount;

  /// Reactions Count.
  ///
  /// Field type is Int32.
  final int reactionsCount;

  /// Views.
  final List<StoryViewBase> views;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Next Offset.
  final String? nextOffset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x59d78fc5.
    buffer.writeInt32(0x59d78fc5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(count);
    buffer.writeInt32(viewsCount);
    buffer.writeInt32(forwardsCount);
    buffer.writeInt32(reactionsCount);
    buffer.writeVectorObject(views);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    final localNextOffsetCopy = nextOffset;
    if (localNextOffsetCopy != null) {
      buffer.writeString(localNextOffsetCopy);
    }

    // Finished serialization.
  }
}

/// Stories Story Views.
///
/// ID: `de9eed1d`.
class StoriesStoryViews extends StoriesStoryViewsBase {
  /// Stories Story Views constructor.
  const StoriesStoryViews({
    required this.views,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory StoriesStoryViews.deserialize(BinaryReader reader) {
    // Read [StoriesStoryViews] fields.
    final views = reader.readVectorObject<StoryViewsBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [StoriesStoryViews] object.
    final returnValue = StoriesStoryViews(
      views: views,
      users: users,
    );

    // Now return the deserialized [StoriesStoryViews].
    return returnValue;
  }

  /// Views.
  final List<StoryViewsBase> views;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xde9eed1d.
    buffer.writeInt32(0xde9eed1d);

    // Write fields.
    buffer.writeVectorObject(views);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Input Reply To Message.
///
/// ID: `22c0f6d5`.
class InputReplyToMessage extends InputReplyToBase {
  /// Input Reply To Message constructor.
  const InputReplyToMessage({
    required this.replyToMsgId,
    this.topMsgId,
    this.replyToPeerId,
    this.quoteText,
    this.quoteEntities,
    this.quoteOffset,
  }) : super._();

  /// Deserialize.
  factory InputReplyToMessage.deserialize(BinaryReader reader) {
    // Read [InputReplyToMessage] fields.
    final flags = reader.readInt32();
    final replyToMsgId = reader.readInt32();
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final hasReplyToPeerIdField = (flags & 2) != 0;
    final replyToPeerId =
        hasReplyToPeerIdField ? reader.readObject() as InputPeerBase : null;
    final hasQuoteTextField = (flags & 4) != 0;
    final quoteText = hasQuoteTextField ? reader.readString() : null;
    final hasQuoteEntitiesField = (flags & 8) != 0;
    final quoteEntities = hasQuoteEntitiesField
        ? reader.readVectorObject<MessageEntityBase>()
        : null;
    final hasQuoteOffsetField = (flags & 16) != 0;
    final quoteOffset = hasQuoteOffsetField ? reader.readInt32() : null;

    // Construct [InputReplyToMessage] object.
    final returnValue = InputReplyToMessage(
      replyToMsgId: replyToMsgId,
      topMsgId: topMsgId,
      replyToPeerId: replyToPeerId,
      quoteText: quoteText,
      quoteEntities: quoteEntities,
      quoteOffset: quoteOffset,
    );

    // Now return the deserialized [InputReplyToMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
      b01: replyToPeerId != null,
      b02: quoteText != null,
      b03: quoteEntities != null,
      b04: quoteOffset != null,
    );

    return v;
  }

  /// Reply To Msg Id.
  ///
  /// Field type is Int32.
  final int replyToMsgId;

  /// Top Msg Id.
  final int? topMsgId;

  /// Reply To Peer Id.
  final InputPeerBase? replyToPeerId;

  /// Quote Text.
  final String? quoteText;

  /// Quote Entities.
  final List<MessageEntityBase>? quoteEntities;

  /// Quote Offset.
  final int? quoteOffset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x22c0f6d5.
    buffer.writeInt32(0x22c0f6d5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(replyToMsgId);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    final localReplyToPeerIdCopy = replyToPeerId;
    if (localReplyToPeerIdCopy != null) {
      buffer.writeObject(localReplyToPeerIdCopy);
    }
    final localQuoteTextCopy = quoteText;
    if (localQuoteTextCopy != null) {
      buffer.writeString(localQuoteTextCopy);
    }
    final localQuoteEntitiesCopy = quoteEntities;
    if (localQuoteEntitiesCopy != null) {
      buffer.writeVectorObject(localQuoteEntitiesCopy);
    }
    final localQuoteOffsetCopy = quoteOffset;
    if (localQuoteOffsetCopy != null) {
      buffer.writeInt32(localQuoteOffsetCopy);
    }

    // Finished serialization.
  }
}

/// Input Reply To Story.
///
/// ID: `15b0f283`.
class InputReplyToStory extends InputReplyToBase {
  /// Input Reply To Story constructor.
  const InputReplyToStory({
    required this.userId,
    required this.storyId,
  }) : super._();

  /// Deserialize.
  factory InputReplyToStory.deserialize(BinaryReader reader) {
    // Read [InputReplyToStory] fields.
    final userId = reader.readObject() as InputUserBase;
    final storyId = reader.readInt32();

    // Construct [InputReplyToStory] object.
    final returnValue = InputReplyToStory(
      userId: userId,
      storyId: storyId,
    );

    // Now return the deserialized [InputReplyToStory].
    return returnValue;
  }

  /// User Id.
  final InputUserBase userId;

  /// Story Id.
  ///
  /// Field type is Int32.
  final int storyId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x15b0f283.
    buffer.writeInt32(0x15b0f283);

    // Write fields.
    buffer.writeObject(userId);
    buffer.writeInt32(storyId);

    // Finished serialization.
  }
}

/// Exported Story Link.
///
/// ID: `3fc9053b`.
class ExportedStoryLink extends ExportedStoryLinkBase {
  /// Exported Story Link constructor.
  const ExportedStoryLink({
    required this.link,
  }) : super._();

  /// Deserialize.
  factory ExportedStoryLink.deserialize(BinaryReader reader) {
    // Read [ExportedStoryLink] fields.
    final link = reader.readString();

    // Construct [ExportedStoryLink] object.
    final returnValue = ExportedStoryLink(
      link: link,
    );

    // Now return the deserialized [ExportedStoryLink].
    return returnValue;
  }

  /// Link.
  final String link;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3fc9053b.
    buffer.writeInt32(0x3fc9053b);

    // Write fields.
    buffer.writeString(link);

    // Finished serialization.
  }
}

/// Stories Stealth Mode.
///
/// ID: `712e27fd`.
class StoriesStealthMode extends StoriesStealthModeBase {
  /// Stories Stealth Mode constructor.
  const StoriesStealthMode({
    this.activeUntilDate,
    this.cooldownUntilDate,
  }) : super._();

  /// Deserialize.
  factory StoriesStealthMode.deserialize(BinaryReader reader) {
    // Read [StoriesStealthMode] fields.
    final flags = reader.readInt32();
    final hasActiveUntilDateField = (flags & 1) != 0;
    final activeUntilDate =
        hasActiveUntilDateField ? reader.readDateTime() : null;
    final hasCooldownUntilDateField = (flags & 2) != 0;
    final cooldownUntilDate =
        hasCooldownUntilDateField ? reader.readDateTime() : null;

    // Construct [StoriesStealthMode] object.
    final returnValue = StoriesStealthMode(
      activeUntilDate: activeUntilDate,
      cooldownUntilDate: cooldownUntilDate,
    );

    // Now return the deserialized [StoriesStealthMode].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: activeUntilDate != null,
      b01: cooldownUntilDate != null,
    );

    return v;
  }

  /// Active Until Date.
  final DateTime? activeUntilDate;

  /// Cooldown Until Date.
  final DateTime? cooldownUntilDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x712e27fd.
    buffer.writeInt32(0x712e27fd);

    // Write fields.
    buffer.writeInt32(flags);
    final localActiveUntilDateCopy = activeUntilDate;
    if (localActiveUntilDateCopy != null) {
      buffer.writeDateTime(localActiveUntilDateCopy);
    }
    final localCooldownUntilDateCopy = cooldownUntilDate;
    if (localCooldownUntilDateCopy != null) {
      buffer.writeDateTime(localCooldownUntilDateCopy);
    }

    // Finished serialization.
  }
}

/// Media Area Coordinates.
///
/// ID: `03d1ea4e`.
class MediaAreaCoordinates extends MediaAreaCoordinatesBase {
  /// Media Area Coordinates constructor.
  const MediaAreaCoordinates({
    required this.x,
    required this.y,
    required this.w,
    required this.h,
    required this.rotation,
  }) : super._();

  /// Deserialize.
  factory MediaAreaCoordinates.deserialize(BinaryReader reader) {
    // Read [MediaAreaCoordinates] fields.
    final x = reader.readFloat64();
    final y = reader.readFloat64();
    final w = reader.readFloat64();
    final h = reader.readFloat64();
    final rotation = reader.readFloat64();

    // Construct [MediaAreaCoordinates] object.
    final returnValue = MediaAreaCoordinates(
      x: x,
      y: y,
      w: w,
      h: h,
      rotation: rotation,
    );

    // Now return the deserialized [MediaAreaCoordinates].
    return returnValue;
  }

  /// X.
  final double x;

  /// Y.
  final double y;

  /// W.
  final double w;

  /// H.
  final double h;

  /// Rotation.
  final double rotation;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x03d1ea4e.
    buffer.writeInt32(0x03d1ea4e);

    // Write fields.
    buffer.writeDouble(x);
    buffer.writeDouble(y);
    buffer.writeDouble(w);
    buffer.writeDouble(h);
    buffer.writeDouble(rotation);

    // Finished serialization.
  }
}

/// Media Area Venue.
///
/// ID: `be82db9c`.
class MediaAreaVenue extends MediaAreaBase {
  /// Media Area Venue constructor.
  const MediaAreaVenue({
    required this.coordinates,
    required this.geo,
    required this.title,
    required this.address,
    required this.provider,
    required this.venueId,
    required this.venueType,
  }) : super._();

  /// Deserialize.
  factory MediaAreaVenue.deserialize(BinaryReader reader) {
    // Read [MediaAreaVenue] fields.
    final coordinates = reader.readObject() as MediaAreaCoordinatesBase;
    final geo = reader.readObject() as GeoPointBase;
    final title = reader.readString();
    final address = reader.readString();
    final provider = reader.readString();
    final venueId = reader.readString();
    final venueType = reader.readString();

    // Construct [MediaAreaVenue] object.
    final returnValue = MediaAreaVenue(
      coordinates: coordinates,
      geo: geo,
      title: title,
      address: address,
      provider: provider,
      venueId: venueId,
      venueType: venueType,
    );

    // Now return the deserialized [MediaAreaVenue].
    return returnValue;
  }

  /// Coordinates.
  final MediaAreaCoordinatesBase coordinates;

  /// Geo.
  final GeoPointBase geo;

  /// Title.
  final String title;

  /// Address.
  final String address;

  /// Provider.
  final String provider;

  /// Venue Id.
  final String venueId;

  /// Venue Type.
  final String venueType;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbe82db9c.
    buffer.writeInt32(0xbe82db9c);

    // Write fields.
    buffer.writeObject(coordinates);
    buffer.writeObject(geo);
    buffer.writeString(title);
    buffer.writeString(address);
    buffer.writeString(provider);
    buffer.writeString(venueId);
    buffer.writeString(venueType);

    // Finished serialization.
  }
}

/// Input Media Area Venue.
///
/// ID: `b282217f`.
class InputMediaAreaVenue extends MediaAreaBase {
  /// Input Media Area Venue constructor.
  const InputMediaAreaVenue({
    required this.coordinates,
    required this.queryId,
    required this.resultId,
  }) : super._();

  /// Deserialize.
  factory InputMediaAreaVenue.deserialize(BinaryReader reader) {
    // Read [InputMediaAreaVenue] fields.
    final coordinates = reader.readObject() as MediaAreaCoordinatesBase;
    final queryId = reader.readInt64();
    final resultId = reader.readString();

    // Construct [InputMediaAreaVenue] object.
    final returnValue = InputMediaAreaVenue(
      coordinates: coordinates,
      queryId: queryId,
      resultId: resultId,
    );

    // Now return the deserialized [InputMediaAreaVenue].
    return returnValue;
  }

  /// Coordinates.
  final MediaAreaCoordinatesBase coordinates;

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Result Id.
  final String resultId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb282217f.
    buffer.writeInt32(0xb282217f);

    // Write fields.
    buffer.writeObject(coordinates);
    buffer.writeInt64(queryId);
    buffer.writeString(resultId);

    // Finished serialization.
  }
}

/// Media Area Geo Point.
///
/// ID: `df8b3b22`.
class MediaAreaGeoPoint extends MediaAreaBase {
  /// Media Area Geo Point constructor.
  const MediaAreaGeoPoint({
    required this.coordinates,
    required this.geo,
  }) : super._();

  /// Deserialize.
  factory MediaAreaGeoPoint.deserialize(BinaryReader reader) {
    // Read [MediaAreaGeoPoint] fields.
    final coordinates = reader.readObject() as MediaAreaCoordinatesBase;
    final geo = reader.readObject() as GeoPointBase;

    // Construct [MediaAreaGeoPoint] object.
    final returnValue = MediaAreaGeoPoint(
      coordinates: coordinates,
      geo: geo,
    );

    // Now return the deserialized [MediaAreaGeoPoint].
    return returnValue;
  }

  /// Coordinates.
  final MediaAreaCoordinatesBase coordinates;

  /// Geo.
  final GeoPointBase geo;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdf8b3b22.
    buffer.writeInt32(0xdf8b3b22);

    // Write fields.
    buffer.writeObject(coordinates);
    buffer.writeObject(geo);

    // Finished serialization.
  }
}

/// Media Area Suggested Reaction.
///
/// ID: `14455871`.
class MediaAreaSuggestedReaction extends MediaAreaBase {
  /// Media Area Suggested Reaction constructor.
  const MediaAreaSuggestedReaction({
    required this.dark,
    required this.flipped,
    required this.coordinates,
    required this.reaction,
  }) : super._();

  /// Deserialize.
  factory MediaAreaSuggestedReaction.deserialize(BinaryReader reader) {
    // Read [MediaAreaSuggestedReaction] fields.
    final flags = reader.readInt32();
    final dark = (flags & 1) != 0;
    final flipped = (flags & 2) != 0;
    final coordinates = reader.readObject() as MediaAreaCoordinatesBase;
    final reaction = reader.readObject() as ReactionBase;

    // Construct [MediaAreaSuggestedReaction] object.
    final returnValue = MediaAreaSuggestedReaction(
      dark: dark,
      flipped: flipped,
      coordinates: coordinates,
      reaction: reaction,
    );

    // Now return the deserialized [MediaAreaSuggestedReaction].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: dark,
      b01: flipped,
    );

    return v;
  }

  /// dark: bit 0 of flags.0?true
  final bool dark;

  /// flipped: bit 1 of flags.1?true
  final bool flipped;

  /// Coordinates.
  final MediaAreaCoordinatesBase coordinates;

  /// Reaction.
  final ReactionBase reaction;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x14455871.
    buffer.writeInt32(0x14455871);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(coordinates);
    buffer.writeObject(reaction);

    // Finished serialization.
  }
}

/// Media Area Channel Post.
///
/// ID: `770416af`.
class MediaAreaChannelPost extends MediaAreaBase {
  /// Media Area Channel Post constructor.
  const MediaAreaChannelPost({
    required this.coordinates,
    required this.channelId,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory MediaAreaChannelPost.deserialize(BinaryReader reader) {
    // Read [MediaAreaChannelPost] fields.
    final coordinates = reader.readObject() as MediaAreaCoordinatesBase;
    final channelId = reader.readInt64();
    final msgId = reader.readInt32();

    // Construct [MediaAreaChannelPost] object.
    final returnValue = MediaAreaChannelPost(
      coordinates: coordinates,
      channelId: channelId,
      msgId: msgId,
    );

    // Now return the deserialized [MediaAreaChannelPost].
    return returnValue;
  }

  /// Coordinates.
  final MediaAreaCoordinatesBase coordinates;

  /// Channel Id.
  ///
  /// Field type is Int64.
  final int channelId;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x770416af.
    buffer.writeInt32(0x770416af);

    // Write fields.
    buffer.writeObject(coordinates);
    buffer.writeInt64(channelId);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Input Media Area Channel Post.
///
/// ID: `2271f2bf`.
class InputMediaAreaChannelPost extends MediaAreaBase {
  /// Input Media Area Channel Post constructor.
  const InputMediaAreaChannelPost({
    required this.coordinates,
    required this.channel,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory InputMediaAreaChannelPost.deserialize(BinaryReader reader) {
    // Read [InputMediaAreaChannelPost] fields.
    final coordinates = reader.readObject() as MediaAreaCoordinatesBase;
    final channel = reader.readObject() as InputChannelBase;
    final msgId = reader.readInt32();

    // Construct [InputMediaAreaChannelPost] object.
    final returnValue = InputMediaAreaChannelPost(
      coordinates: coordinates,
      channel: channel,
      msgId: msgId,
    );

    // Now return the deserialized [InputMediaAreaChannelPost].
    return returnValue;
  }

  /// Coordinates.
  final MediaAreaCoordinatesBase coordinates;

  /// Channel.
  final InputChannelBase channel;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2271f2bf.
    buffer.writeInt32(0x2271f2bf);

    // Write fields.
    buffer.writeObject(coordinates);
    buffer.writeObject(channel);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Peer Stories.
///
/// ID: `9a35e999`.
class PeerStories extends PeerStoriesBase {
  /// Peer Stories constructor.
  const PeerStories({
    required this.peer,
    this.maxReadId,
    required this.stories,
  }) : super._();

  /// Deserialize.
  factory PeerStories.deserialize(BinaryReader reader) {
    // Read [PeerStories] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as PeerBase;
    final hasMaxReadIdField = (flags & 1) != 0;
    final maxReadId = hasMaxReadIdField ? reader.readInt32() : null;
    final stories = reader.readVectorObject<StoryItemBase>();

    // Construct [PeerStories] object.
    final returnValue = PeerStories(
      peer: peer,
      maxReadId: maxReadId,
      stories: stories,
    );

    // Now return the deserialized [PeerStories].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: maxReadId != null,
    );

    return v;
  }

  /// Peer.
  final PeerBase peer;

  /// Max Read Id.
  final int? maxReadId;

  /// Stories.
  final List<StoryItemBase> stories;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9a35e999.
    buffer.writeInt32(0x9a35e999);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localMaxReadIdCopy = maxReadId;
    if (localMaxReadIdCopy != null) {
      buffer.writeInt32(localMaxReadIdCopy);
    }
    buffer.writeVectorObject(stories);

    // Finished serialization.
  }
}

/// Stories Peer Stories.
///
/// ID: `cae68768`.
class StoriesPeerStories extends StoriesPeerStoriesBase {
  /// Stories Peer Stories constructor.
  const StoriesPeerStories({
    required this.stories,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory StoriesPeerStories.deserialize(BinaryReader reader) {
    // Read [StoriesPeerStories] fields.
    final stories = reader.readObject() as PeerStoriesBase;
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [StoriesPeerStories] object.
    final returnValue = StoriesPeerStories(
      stories: stories,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [StoriesPeerStories].
    return returnValue;
  }

  /// Stories.
  final PeerStoriesBase stories;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcae68768.
    buffer.writeInt32(0xcae68768);

    // Write fields.
    buffer.writeObject(stories);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Web Page.
///
/// ID: `fd5e12bd`.
class MessagesWebPage extends MessagesWebPageBase {
  /// Messages Web Page constructor.
  const MessagesWebPage({
    required this.webpage,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesWebPage.deserialize(BinaryReader reader) {
    // Read [MessagesWebPage] fields.
    final webpage = reader.readObject() as WebPageBase;
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesWebPage] object.
    final returnValue = MessagesWebPage(
      webpage: webpage,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesWebPage].
    return returnValue;
  }

  /// Webpage.
  final WebPageBase webpage;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfd5e12bd.
    buffer.writeInt32(0xfd5e12bd);

    // Write fields.
    buffer.writeObject(webpage);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Premium Gift Code Option.
///
/// ID: `257e962b`.
class PremiumGiftCodeOption extends PremiumGiftCodeOptionBase {
  /// Premium Gift Code Option constructor.
  const PremiumGiftCodeOption({
    required this.users,
    required this.months,
    this.storeProduct,
    this.storeQuantity,
    required this.currency,
    required this.amount,
  }) : super._();

  /// Deserialize.
  factory PremiumGiftCodeOption.deserialize(BinaryReader reader) {
    // Read [PremiumGiftCodeOption] fields.
    final flags = reader.readInt32();
    final users = reader.readInt32();
    final months = reader.readInt32();
    final hasStoreProductField = (flags & 1) != 0;
    final storeProduct = hasStoreProductField ? reader.readString() : null;
    final hasStoreQuantityField = (flags & 2) != 0;
    final storeQuantity = hasStoreQuantityField ? reader.readInt32() : null;
    final currency = reader.readString();
    final amount = reader.readInt64();

    // Construct [PremiumGiftCodeOption] object.
    final returnValue = PremiumGiftCodeOption(
      users: users,
      months: months,
      storeProduct: storeProduct,
      storeQuantity: storeQuantity,
      currency: currency,
      amount: amount,
    );

    // Now return the deserialized [PremiumGiftCodeOption].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: storeProduct != null,
      b01: storeQuantity != null,
    );

    return v;
  }

  /// Users.
  ///
  /// Field type is Int32.
  final int users;

  /// Months.
  ///
  /// Field type is Int32.
  final int months;

  /// Store Product.
  final String? storeProduct;

  /// Store Quantity.
  final int? storeQuantity;

  /// Currency.
  final String currency;

  /// Amount.
  ///
  /// Field type is Int64.
  final int amount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x257e962b.
    buffer.writeInt32(0x257e962b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(users);
    buffer.writeInt32(months);
    final localStoreProductCopy = storeProduct;
    if (localStoreProductCopy != null) {
      buffer.writeString(localStoreProductCopy);
    }
    final localStoreQuantityCopy = storeQuantity;
    if (localStoreQuantityCopy != null) {
      buffer.writeInt32(localStoreQuantityCopy);
    }
    buffer.writeString(currency);
    buffer.writeInt64(amount);

    // Finished serialization.
  }
}

/// Payments Checked Gift Code.
///
/// ID: `284a1096`.
class PaymentsCheckedGiftCode extends PaymentsCheckedGiftCodeBase {
  /// Payments Checked Gift Code constructor.
  const PaymentsCheckedGiftCode({
    required this.viaGiveaway,
    this.fromId,
    this.giveawayMsgId,
    this.toId,
    required this.date,
    required this.months,
    this.usedDate,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PaymentsCheckedGiftCode.deserialize(BinaryReader reader) {
    // Read [PaymentsCheckedGiftCode] fields.
    final flags = reader.readInt32();
    final viaGiveaway = (flags & 4) != 0;
    final hasFromIdField = (flags & 16) != 0;
    final fromId = hasFromIdField ? reader.readObject() as PeerBase : null;
    final hasGiveawayMsgIdField = (flags & 8) != 0;
    final giveawayMsgId = hasGiveawayMsgIdField ? reader.readInt32() : null;
    final hasToIdField = (flags & 1) != 0;
    final toId = hasToIdField ? reader.readInt64() : null;
    final date = reader.readDateTime();
    final months = reader.readInt32();
    final hasUsedDateField = (flags & 2) != 0;
    final usedDate = hasUsedDateField ? reader.readDateTime() : null;
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [PaymentsCheckedGiftCode] object.
    final returnValue = PaymentsCheckedGiftCode(
      viaGiveaway: viaGiveaway,
      fromId: fromId,
      giveawayMsgId: giveawayMsgId,
      toId: toId,
      date: date,
      months: months,
      usedDate: usedDate,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [PaymentsCheckedGiftCode].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: viaGiveaway,
      b04: fromId != null,
      b03: giveawayMsgId != null,
      b00: toId != null,
      b01: usedDate != null,
    );

    return v;
  }

  /// via_giveaway: bit 2 of flags.2?true
  final bool viaGiveaway;

  /// From Id.
  final PeerBase? fromId;

  /// Giveaway Msg Id.
  final int? giveawayMsgId;

  /// To Id.
  final int? toId;

  /// Date.
  final DateTime date;

  /// Months.
  ///
  /// Field type is Int32.
  final int months;

  /// Used Date.
  final DateTime? usedDate;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x284a1096.
    buffer.writeInt32(0x284a1096);

    // Write fields.
    buffer.writeInt32(flags);
    final localFromIdCopy = fromId;
    if (localFromIdCopy != null) {
      buffer.writeObject(localFromIdCopy);
    }
    final localGiveawayMsgIdCopy = giveawayMsgId;
    if (localGiveawayMsgIdCopy != null) {
      buffer.writeInt32(localGiveawayMsgIdCopy);
    }
    final localToIdCopy = toId;
    if (localToIdCopy != null) {
      buffer.writeInt64(localToIdCopy);
    }
    buffer.writeDateTime(date);
    buffer.writeInt32(months);
    final localUsedDateCopy = usedDate;
    if (localUsedDateCopy != null) {
      buffer.writeDateTime(localUsedDateCopy);
    }
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Payments Giveaway Info.
///
/// ID: `4367daa0`.
class PaymentsGiveawayInfo extends PaymentsGiveawayInfoBase {
  /// Payments Giveaway Info constructor.
  const PaymentsGiveawayInfo({
    required this.participating,
    required this.preparingResults,
    required this.startDate,
    this.joinedTooEarlyDate,
    this.adminDisallowedChatId,
    this.disallowedCountry,
  }) : super._();

  /// Deserialize.
  factory PaymentsGiveawayInfo.deserialize(BinaryReader reader) {
    // Read [PaymentsGiveawayInfo] fields.
    final flags = reader.readInt32();
    final participating = (flags & 1) != 0;
    final preparingResults = (flags & 8) != 0;
    final startDate = reader.readDateTime();
    final hasJoinedTooEarlyDateField = (flags & 2) != 0;
    final joinedTooEarlyDate =
        hasJoinedTooEarlyDateField ? reader.readDateTime() : null;
    final hasAdminDisallowedChatIdField = (flags & 4) != 0;
    final adminDisallowedChatId =
        hasAdminDisallowedChatIdField ? reader.readInt64() : null;
    final hasDisallowedCountryField = (flags & 16) != 0;
    final disallowedCountry =
        hasDisallowedCountryField ? reader.readString() : null;

    // Construct [PaymentsGiveawayInfo] object.
    final returnValue = PaymentsGiveawayInfo(
      participating: participating,
      preparingResults: preparingResults,
      startDate: startDate,
      joinedTooEarlyDate: joinedTooEarlyDate,
      adminDisallowedChatId: adminDisallowedChatId,
      disallowedCountry: disallowedCountry,
    );

    // Now return the deserialized [PaymentsGiveawayInfo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: participating,
      b03: preparingResults,
      b01: joinedTooEarlyDate != null,
      b02: adminDisallowedChatId != null,
      b04: disallowedCountry != null,
    );

    return v;
  }

  /// participating: bit 0 of flags.0?true
  final bool participating;

  /// preparing_results: bit 3 of flags.3?true
  final bool preparingResults;

  /// Start Date.
  final DateTime startDate;

  /// Joined Too Early Date.
  final DateTime? joinedTooEarlyDate;

  /// Admin Disallowed Chat Id.
  final int? adminDisallowedChatId;

  /// Disallowed Country.
  final String? disallowedCountry;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4367daa0.
    buffer.writeInt32(0x4367daa0);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeDateTime(startDate);
    final localJoinedTooEarlyDateCopy = joinedTooEarlyDate;
    if (localJoinedTooEarlyDateCopy != null) {
      buffer.writeDateTime(localJoinedTooEarlyDateCopy);
    }
    final localAdminDisallowedChatIdCopy = adminDisallowedChatId;
    if (localAdminDisallowedChatIdCopy != null) {
      buffer.writeInt64(localAdminDisallowedChatIdCopy);
    }
    final localDisallowedCountryCopy = disallowedCountry;
    if (localDisallowedCountryCopy != null) {
      buffer.writeString(localDisallowedCountryCopy);
    }

    // Finished serialization.
  }
}

/// Payments Giveaway Info Results.
///
/// ID: `00cd5570`.
class PaymentsGiveawayInfoResults extends PaymentsGiveawayInfoBase {
  /// Payments Giveaway Info Results constructor.
  const PaymentsGiveawayInfoResults({
    required this.winner,
    required this.refunded,
    required this.startDate,
    this.giftCodeSlug,
    required this.finishDate,
    required this.winnersCount,
    required this.activatedCount,
  }) : super._();

  /// Deserialize.
  factory PaymentsGiveawayInfoResults.deserialize(BinaryReader reader) {
    // Read [PaymentsGiveawayInfoResults] fields.
    final flags = reader.readInt32();
    final winner = (flags & 1) != 0;
    final refunded = (flags & 2) != 0;
    final startDate = reader.readDateTime();
    final hasGiftCodeSlugField = (flags & 1) != 0;
    final giftCodeSlug = hasGiftCodeSlugField ? reader.readString() : null;
    final finishDate = reader.readDateTime();
    final winnersCount = reader.readInt32();
    final activatedCount = reader.readInt32();

    // Construct [PaymentsGiveawayInfoResults] object.
    final returnValue = PaymentsGiveawayInfoResults(
      winner: winner,
      refunded: refunded,
      startDate: startDate,
      giftCodeSlug: giftCodeSlug,
      finishDate: finishDate,
      winnersCount: winnersCount,
      activatedCount: activatedCount,
    );

    // Now return the deserialized [PaymentsGiveawayInfoResults].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: winner || giftCodeSlug != null,
      b01: refunded,
    );

    return v;
  }

  /// winner: bit 0 of flags.0?true
  final bool winner;

  /// refunded: bit 1 of flags.1?true
  final bool refunded;

  /// Start Date.
  final DateTime startDate;

  /// Gift Code Slug.
  final String? giftCodeSlug;

  /// Finish Date.
  final DateTime finishDate;

  /// Winners Count.
  ///
  /// Field type is Int32.
  final int winnersCount;

  /// Activated Count.
  ///
  /// Field type is Int32.
  final int activatedCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x00cd5570.
    buffer.writeInt32(0x00cd5570);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeDateTime(startDate);
    final localGiftCodeSlugCopy = giftCodeSlug;
    if (localGiftCodeSlugCopy != null) {
      buffer.writeString(localGiftCodeSlugCopy);
    }
    buffer.writeDateTime(finishDate);
    buffer.writeInt32(winnersCount);
    buffer.writeInt32(activatedCount);

    // Finished serialization.
  }
}

/// Prepaid Giveaway.
///
/// ID: `b2539d54`.
class PrepaidGiveaway extends PrepaidGiveawayBase {
  /// Prepaid Giveaway constructor.
  const PrepaidGiveaway({
    required this.id,
    required this.months,
    required this.quantity,
    required this.date,
  }) : super._();

  /// Deserialize.
  factory PrepaidGiveaway.deserialize(BinaryReader reader) {
    // Read [PrepaidGiveaway] fields.
    final id = reader.readInt64();
    final months = reader.readInt32();
    final quantity = reader.readInt32();
    final date = reader.readDateTime();

    // Construct [PrepaidGiveaway] object.
    final returnValue = PrepaidGiveaway(
      id: id,
      months: months,
      quantity: quantity,
      date: date,
    );

    // Now return the deserialized [PrepaidGiveaway].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Months.
  ///
  /// Field type is Int32.
  final int months;

  /// Quantity.
  ///
  /// Field type is Int32.
  final int quantity;

  /// Date.
  final DateTime date;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb2539d54.
    buffer.writeInt32(0xb2539d54);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeInt32(months);
    buffer.writeInt32(quantity);
    buffer.writeDateTime(date);

    // Finished serialization.
  }
}

/// Boost.
///
/// ID: `2a1c8c71`.
class Boost extends BoostBase {
  /// Boost constructor.
  const Boost({
    required this.gift,
    required this.giveaway,
    required this.unclaimed,
    required this.id,
    this.userId,
    this.giveawayMsgId,
    required this.date,
    required this.expires,
    this.usedGiftSlug,
    this.multiplier,
  }) : super._();

  /// Deserialize.
  factory Boost.deserialize(BinaryReader reader) {
    // Read [Boost] fields.
    final flags = reader.readInt32();
    final gift = (flags & 2) != 0;
    final giveaway = (flags & 4) != 0;
    final unclaimed = (flags & 8) != 0;
    final id = reader.readString();
    final hasUserIdField = (flags & 1) != 0;
    final userId = hasUserIdField ? reader.readInt64() : null;
    final hasGiveawayMsgIdField = (flags & 4) != 0;
    final giveawayMsgId = hasGiveawayMsgIdField ? reader.readInt32() : null;
    final date = reader.readDateTime();
    final expires = reader.readInt32();
    final hasUsedGiftSlugField = (flags & 16) != 0;
    final usedGiftSlug = hasUsedGiftSlugField ? reader.readString() : null;
    final hasMultiplierField = (flags & 32) != 0;
    final multiplier = hasMultiplierField ? reader.readInt32() : null;

    // Construct [Boost] object.
    final returnValue = Boost(
      gift: gift,
      giveaway: giveaway,
      unclaimed: unclaimed,
      id: id,
      userId: userId,
      giveawayMsgId: giveawayMsgId,
      date: date,
      expires: expires,
      usedGiftSlug: usedGiftSlug,
      multiplier: multiplier,
    );

    // Now return the deserialized [Boost].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: gift,
      b02: giveaway || giveawayMsgId != null,
      b03: unclaimed,
      b00: userId != null,
      b04: usedGiftSlug != null,
      b05: multiplier != null,
    );

    return v;
  }

  /// gift: bit 1 of flags.1?true
  final bool gift;

  /// giveaway: bit 2 of flags.2?true
  final bool giveaway;

  /// unclaimed: bit 3 of flags.3?true
  final bool unclaimed;

  /// Id.
  final String id;

  /// User Id.
  final int? userId;

  /// Giveaway Msg Id.
  final int? giveawayMsgId;

  /// Date.
  final DateTime date;

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Used Gift Slug.
  final String? usedGiftSlug;

  /// Multiplier.
  final int? multiplier;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2a1c8c71.
    buffer.writeInt32(0x2a1c8c71);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(id);
    final localUserIdCopy = userId;
    if (localUserIdCopy != null) {
      buffer.writeInt64(localUserIdCopy);
    }
    final localGiveawayMsgIdCopy = giveawayMsgId;
    if (localGiveawayMsgIdCopy != null) {
      buffer.writeInt32(localGiveawayMsgIdCopy);
    }
    buffer.writeDateTime(date);
    buffer.writeInt32(expires);
    final localUsedGiftSlugCopy = usedGiftSlug;
    if (localUsedGiftSlugCopy != null) {
      buffer.writeString(localUsedGiftSlugCopy);
    }
    final localMultiplierCopy = multiplier;
    if (localMultiplierCopy != null) {
      buffer.writeInt32(localMultiplierCopy);
    }

    // Finished serialization.
  }
}

/// Premium Boosts List.
///
/// ID: `86f8613c`.
class PremiumBoostsList extends PremiumBoostsListBase {
  /// Premium Boosts List constructor.
  const PremiumBoostsList({
    required this.count,
    required this.boosts,
    this.nextOffset,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PremiumBoostsList.deserialize(BinaryReader reader) {
    // Read [PremiumBoostsList] fields.
    final flags = reader.readInt32();
    final count = reader.readInt32();
    final boosts = reader.readVectorObject<BoostBase>();
    final hasNextOffsetField = (flags & 1) != 0;
    final nextOffset = hasNextOffsetField ? reader.readString() : null;
    final users = reader.readVectorObject<UserBase>();

    // Construct [PremiumBoostsList] object.
    final returnValue = PremiumBoostsList(
      count: count,
      boosts: boosts,
      nextOffset: nextOffset,
      users: users,
    );

    // Now return the deserialized [PremiumBoostsList].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: nextOffset != null,
    );

    return v;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Boosts.
  final List<BoostBase> boosts;

  /// Next Offset.
  final String? nextOffset;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x86f8613c.
    buffer.writeInt32(0x86f8613c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(count);
    buffer.writeVectorObject(boosts);
    final localNextOffsetCopy = nextOffset;
    if (localNextOffsetCopy != null) {
      buffer.writeString(localNextOffsetCopy);
    }
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// My Boost.
///
/// ID: `c448415c`.
class MyBoost extends MyBoostBase {
  /// My Boost constructor.
  const MyBoost({
    required this.slot,
    this.peer,
    required this.date,
    required this.expires,
    this.cooldownUntilDate,
  }) : super._();

  /// Deserialize.
  factory MyBoost.deserialize(BinaryReader reader) {
    // Read [MyBoost] fields.
    final flags = reader.readInt32();
    final slot = reader.readInt32();
    final hasPeerField = (flags & 1) != 0;
    final peer = hasPeerField ? reader.readObject() as PeerBase : null;
    final date = reader.readDateTime();
    final expires = reader.readInt32();
    final hasCooldownUntilDateField = (flags & 2) != 0;
    final cooldownUntilDate =
        hasCooldownUntilDateField ? reader.readDateTime() : null;

    // Construct [MyBoost] object.
    final returnValue = MyBoost(
      slot: slot,
      peer: peer,
      date: date,
      expires: expires,
      cooldownUntilDate: cooldownUntilDate,
    );

    // Now return the deserialized [MyBoost].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: peer != null,
      b01: cooldownUntilDate != null,
    );

    return v;
  }

  /// Slot.
  ///
  /// Field type is Int32.
  final int slot;

  /// Peer.
  final PeerBase? peer;

  /// Date.
  final DateTime date;

  /// Expires.
  ///
  /// Field type is Int32.
  final int expires;

  /// Cooldown Until Date.
  final DateTime? cooldownUntilDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc448415c.
    buffer.writeInt32(0xc448415c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(slot);
    final localPeerCopy = peer;
    if (localPeerCopy != null) {
      buffer.writeObject(localPeerCopy);
    }
    buffer.writeDateTime(date);
    buffer.writeInt32(expires);
    final localCooldownUntilDateCopy = cooldownUntilDate;
    if (localCooldownUntilDateCopy != null) {
      buffer.writeDateTime(localCooldownUntilDateCopy);
    }

    // Finished serialization.
  }
}

/// Premium My Boosts.
///
/// ID: `9ae228e2`.
class PremiumMyBoosts extends PremiumMyBoostsBase {
  /// Premium My Boosts constructor.
  const PremiumMyBoosts({
    required this.myBoosts,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PremiumMyBoosts.deserialize(BinaryReader reader) {
    // Read [PremiumMyBoosts] fields.
    final myBoosts = reader.readVectorObject<MyBoostBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [PremiumMyBoosts] object.
    final returnValue = PremiumMyBoosts(
      myBoosts: myBoosts,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [PremiumMyBoosts].
    return returnValue;
  }

  /// My Boosts.
  final List<MyBoostBase> myBoosts;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9ae228e2.
    buffer.writeInt32(0x9ae228e2);

    // Write fields.
    buffer.writeVectorObject(myBoosts);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Premium Boosts Status.
///
/// ID: `4959427a`.
class PremiumBoostsStatus extends PremiumBoostsStatusBase {
  /// Premium Boosts Status constructor.
  const PremiumBoostsStatus({
    required this.myBoost,
    required this.level,
    required this.currentLevelBoosts,
    required this.boosts,
    this.giftBoosts,
    this.nextLevelBoosts,
    this.premiumAudience,
    required this.boostUrl,
    this.prepaidGiveaways,
    this.myBoostSlots,
  }) : super._();

  /// Deserialize.
  factory PremiumBoostsStatus.deserialize(BinaryReader reader) {
    // Read [PremiumBoostsStatus] fields.
    final flags = reader.readInt32();
    final myBoost = (flags & 4) != 0;
    final level = reader.readInt32();
    final currentLevelBoosts = reader.readInt32();
    final boosts = reader.readInt32();
    final hasGiftBoostsField = (flags & 16) != 0;
    final giftBoosts = hasGiftBoostsField ? reader.readInt32() : null;
    final hasNextLevelBoostsField = (flags & 1) != 0;
    final nextLevelBoosts = hasNextLevelBoostsField ? reader.readInt32() : null;
    final hasPremiumAudienceField = (flags & 2) != 0;
    final premiumAudience = hasPremiumAudienceField
        ? reader.readObject() as StatsPercentValueBase
        : null;
    final boostUrl = reader.readString();
    final hasPrepaidGiveawaysField = (flags & 8) != 0;
    final prepaidGiveaways = hasPrepaidGiveawaysField
        ? reader.readVectorObject<PrepaidGiveawayBase>()
        : null;
    final hasMyBoostSlotsField = (flags & 4) != 0;
    final myBoostSlots = hasMyBoostSlotsField ? reader.readVectorInt32() : null;

    // Construct [PremiumBoostsStatus] object.
    final returnValue = PremiumBoostsStatus(
      myBoost: myBoost,
      level: level,
      currentLevelBoosts: currentLevelBoosts,
      boosts: boosts,
      giftBoosts: giftBoosts,
      nextLevelBoosts: nextLevelBoosts,
      premiumAudience: premiumAudience,
      boostUrl: boostUrl,
      prepaidGiveaways: prepaidGiveaways,
      myBoostSlots: myBoostSlots,
    );

    // Now return the deserialized [PremiumBoostsStatus].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: myBoost || myBoostSlots != null,
      b04: giftBoosts != null,
      b00: nextLevelBoosts != null,
      b01: premiumAudience != null,
      b03: prepaidGiveaways != null,
    );

    return v;
  }

  /// my_boost: bit 2 of flags.2?true
  final bool myBoost;

  /// Level.
  ///
  /// Field type is Int32.
  final int level;

  /// Current Level Boosts.
  ///
  /// Field type is Int32.
  final int currentLevelBoosts;

  /// Boosts.
  ///
  /// Field type is Int32.
  final int boosts;

  /// Gift Boosts.
  final int? giftBoosts;

  /// Next Level Boosts.
  final int? nextLevelBoosts;

  /// Premium Audience.
  final StatsPercentValueBase? premiumAudience;

  /// Boost Url.
  final String boostUrl;

  /// Prepaid Giveaways.
  final List<PrepaidGiveawayBase>? prepaidGiveaways;

  /// My Boost Slots.
  final List<int>? myBoostSlots;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4959427a.
    buffer.writeInt32(0x4959427a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(level);
    buffer.writeInt32(currentLevelBoosts);
    buffer.writeInt32(boosts);
    final localGiftBoostsCopy = giftBoosts;
    if (localGiftBoostsCopy != null) {
      buffer.writeInt32(localGiftBoostsCopy);
    }
    final localNextLevelBoostsCopy = nextLevelBoosts;
    if (localNextLevelBoostsCopy != null) {
      buffer.writeInt32(localNextLevelBoostsCopy);
    }
    final localPremiumAudienceCopy = premiumAudience;
    if (localPremiumAudienceCopy != null) {
      buffer.writeObject(localPremiumAudienceCopy);
    }
    buffer.writeString(boostUrl);
    final localPrepaidGiveawaysCopy = prepaidGiveaways;
    if (localPrepaidGiveawaysCopy != null) {
      buffer.writeVectorObject(localPrepaidGiveawaysCopy);
    }
    final localMyBoostSlotsCopy = myBoostSlots;
    if (localMyBoostSlotsCopy != null) {
      buffer.writeVectorInt32(localMyBoostSlotsCopy);
    }

    // Finished serialization.
  }
}

/// Story Fwd Header.
///
/// ID: `b826e150`.
class StoryFwdHeader extends StoryFwdHeaderBase {
  /// Story Fwd Header constructor.
  const StoryFwdHeader({
    required this.modified,
    this.from,
    this.fromName,
    this.storyId,
  }) : super._();

  /// Deserialize.
  factory StoryFwdHeader.deserialize(BinaryReader reader) {
    // Read [StoryFwdHeader] fields.
    final flags = reader.readInt32();
    final modified = (flags & 8) != 0;
    final hasFromField = (flags & 1) != 0;
    final from = hasFromField ? reader.readObject() as PeerBase : null;
    final hasFromNameField = (flags & 2) != 0;
    final fromName = hasFromNameField ? reader.readString() : null;
    final hasStoryIdField = (flags & 4) != 0;
    final storyId = hasStoryIdField ? reader.readInt32() : null;

    // Construct [StoryFwdHeader] object.
    final returnValue = StoryFwdHeader(
      modified: modified,
      from: from,
      fromName: fromName,
      storyId: storyId,
    );

    // Now return the deserialized [StoryFwdHeader].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: modified,
      b00: from != null,
      b01: fromName != null,
      b02: storyId != null,
    );

    return v;
  }

  /// modified: bit 3 of flags.3?true
  final bool modified;

  /// From.
  final PeerBase? from;

  /// From Name.
  final String? fromName;

  /// Story Id.
  final int? storyId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb826e150.
    buffer.writeInt32(0xb826e150);

    // Write fields.
    buffer.writeInt32(flags);
    final localFromCopy = from;
    if (localFromCopy != null) {
      buffer.writeObject(localFromCopy);
    }
    final localFromNameCopy = fromName;
    if (localFromNameCopy != null) {
      buffer.writeString(localFromNameCopy);
    }
    final localStoryIdCopy = storyId;
    if (localStoryIdCopy != null) {
      buffer.writeInt32(localStoryIdCopy);
    }

    // Finished serialization.
  }
}

/// Post Interaction Counters Message.
///
/// ID: `e7058e7f`.
class PostInteractionCountersMessage extends PostInteractionCountersBase {
  /// Post Interaction Counters Message constructor.
  const PostInteractionCountersMessage({
    required this.msgId,
    required this.views,
    required this.forwards,
    required this.reactions,
  }) : super._();

  /// Deserialize.
  factory PostInteractionCountersMessage.deserialize(BinaryReader reader) {
    // Read [PostInteractionCountersMessage] fields.
    final msgId = reader.readInt32();
    final views = reader.readInt32();
    final forwards = reader.readInt32();
    final reactions = reader.readInt32();

    // Construct [PostInteractionCountersMessage] object.
    final returnValue = PostInteractionCountersMessage(
      msgId: msgId,
      views: views,
      forwards: forwards,
      reactions: reactions,
    );

    // Now return the deserialized [PostInteractionCountersMessage].
    return returnValue;
  }

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Views.
  ///
  /// Field type is Int32.
  final int views;

  /// Forwards.
  ///
  /// Field type is Int32.
  final int forwards;

  /// Reactions.
  ///
  /// Field type is Int32.
  final int reactions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe7058e7f.
    buffer.writeInt32(0xe7058e7f);

    // Write fields.
    buffer.writeInt32(msgId);
    buffer.writeInt32(views);
    buffer.writeInt32(forwards);
    buffer.writeInt32(reactions);

    // Finished serialization.
  }
}

/// Post Interaction Counters Story.
///
/// ID: `8a480e27`.
class PostInteractionCountersStory extends PostInteractionCountersBase {
  /// Post Interaction Counters Story constructor.
  const PostInteractionCountersStory({
    required this.storyId,
    required this.views,
    required this.forwards,
    required this.reactions,
  }) : super._();

  /// Deserialize.
  factory PostInteractionCountersStory.deserialize(BinaryReader reader) {
    // Read [PostInteractionCountersStory] fields.
    final storyId = reader.readInt32();
    final views = reader.readInt32();
    final forwards = reader.readInt32();
    final reactions = reader.readInt32();

    // Construct [PostInteractionCountersStory] object.
    final returnValue = PostInteractionCountersStory(
      storyId: storyId,
      views: views,
      forwards: forwards,
      reactions: reactions,
    );

    // Now return the deserialized [PostInteractionCountersStory].
    return returnValue;
  }

  /// Story Id.
  ///
  /// Field type is Int32.
  final int storyId;

  /// Views.
  ///
  /// Field type is Int32.
  final int views;

  /// Forwards.
  ///
  /// Field type is Int32.
  final int forwards;

  /// Reactions.
  ///
  /// Field type is Int32.
  final int reactions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8a480e27.
    buffer.writeInt32(0x8a480e27);

    // Write fields.
    buffer.writeInt32(storyId);
    buffer.writeInt32(views);
    buffer.writeInt32(forwards);
    buffer.writeInt32(reactions);

    // Finished serialization.
  }
}

/// Stats Story Stats.
///
/// ID: `50cd067c`.
class StatsStoryStats extends StatsStoryStatsBase {
  /// Stats Story Stats constructor.
  const StatsStoryStats({
    required this.viewsGraph,
    required this.reactionsByEmotionGraph,
  }) : super._();

  /// Deserialize.
  factory StatsStoryStats.deserialize(BinaryReader reader) {
    // Read [StatsStoryStats] fields.
    final viewsGraph = reader.readObject() as StatsGraphBase;
    final reactionsByEmotionGraph = reader.readObject() as StatsGraphBase;

    // Construct [StatsStoryStats] object.
    final returnValue = StatsStoryStats(
      viewsGraph: viewsGraph,
      reactionsByEmotionGraph: reactionsByEmotionGraph,
    );

    // Now return the deserialized [StatsStoryStats].
    return returnValue;
  }

  /// Views Graph.
  final StatsGraphBase viewsGraph;

  /// Reactions By Emotion Graph.
  final StatsGraphBase reactionsByEmotionGraph;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x50cd067c.
    buffer.writeInt32(0x50cd067c);

    // Write fields.
    buffer.writeObject(viewsGraph);
    buffer.writeObject(reactionsByEmotionGraph);

    // Finished serialization.
  }
}

/// Public Forward Message.
///
/// ID: `01f2bf4a`.
class PublicForwardMessage extends PublicForwardBase {
  /// Public Forward Message constructor.
  const PublicForwardMessage({
    required this.message,
  }) : super._();

  /// Deserialize.
  factory PublicForwardMessage.deserialize(BinaryReader reader) {
    // Read [PublicForwardMessage] fields.
    final message = reader.readObject() as MessageBase;

    // Construct [PublicForwardMessage] object.
    final returnValue = PublicForwardMessage(
      message: message,
    );

    // Now return the deserialized [PublicForwardMessage].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x01f2bf4a.
    buffer.writeInt32(0x01f2bf4a);

    // Write fields.
    buffer.writeObject(message);

    // Finished serialization.
  }
}

/// Public Forward Story.
///
/// ID: `edf3add0`.
class PublicForwardStory extends PublicForwardBase {
  /// Public Forward Story constructor.
  const PublicForwardStory({
    required this.peer,
    required this.story,
  }) : super._();

  /// Deserialize.
  factory PublicForwardStory.deserialize(BinaryReader reader) {
    // Read [PublicForwardStory] fields.
    final peer = reader.readObject() as PeerBase;
    final story = reader.readObject() as StoryItemBase;

    // Construct [PublicForwardStory] object.
    final returnValue = PublicForwardStory(
      peer: peer,
      story: story,
    );

    // Now return the deserialized [PublicForwardStory].
    return returnValue;
  }

  /// Peer.
  final PeerBase peer;

  /// Story.
  final StoryItemBase story;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xedf3add0.
    buffer.writeInt32(0xedf3add0);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(story);

    // Finished serialization.
  }
}

/// Stats Public Forwards.
///
/// ID: `93037e20`.
class StatsPublicForwards extends StatsPublicForwardsBase {
  /// Stats Public Forwards constructor.
  const StatsPublicForwards({
    required this.count,
    required this.forwards,
    this.nextOffset,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory StatsPublicForwards.deserialize(BinaryReader reader) {
    // Read [StatsPublicForwards] fields.
    final flags = reader.readInt32();
    final count = reader.readInt32();
    final forwards = reader.readVectorObject<PublicForwardBase>();
    final hasNextOffsetField = (flags & 1) != 0;
    final nextOffset = hasNextOffsetField ? reader.readString() : null;
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [StatsPublicForwards] object.
    final returnValue = StatsPublicForwards(
      count: count,
      forwards: forwards,
      nextOffset: nextOffset,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [StatsPublicForwards].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: nextOffset != null,
    );

    return v;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Forwards.
  final List<PublicForwardBase> forwards;

  /// Next Offset.
  final String? nextOffset;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x93037e20.
    buffer.writeInt32(0x93037e20);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(count);
    buffer.writeVectorObject(forwards);
    final localNextOffsetCopy = nextOffset;
    if (localNextOffsetCopy != null) {
      buffer.writeString(localNextOffsetCopy);
    }
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Peer Color.
///
/// ID: `b54b5acf`.
class PeerColor extends PeerColorBase {
  /// Peer Color constructor.
  const PeerColor({
    this.color,
    this.backgroundEmojiId,
  }) : super._();

  /// Deserialize.
  factory PeerColor.deserialize(BinaryReader reader) {
    // Read [PeerColor] fields.
    final flags = reader.readInt32();
    final hasColorField = (flags & 1) != 0;
    final color = hasColorField ? reader.readInt32() : null;
    final hasBackgroundEmojiIdField = (flags & 2) != 0;
    final backgroundEmojiId =
        hasBackgroundEmojiIdField ? reader.readInt64() : null;

    // Construct [PeerColor] object.
    final returnValue = PeerColor(
      color: color,
      backgroundEmojiId: backgroundEmojiId,
    );

    // Now return the deserialized [PeerColor].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: color != null,
      b01: backgroundEmojiId != null,
    );

    return v;
  }

  /// Color.
  final int? color;

  /// Background Emoji Id.
  final int? backgroundEmojiId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb54b5acf.
    buffer.writeInt32(0xb54b5acf);

    // Write fields.
    buffer.writeInt32(flags);
    final localColorCopy = color;
    if (localColorCopy != null) {
      buffer.writeInt32(localColorCopy);
    }
    final localBackgroundEmojiIdCopy = backgroundEmojiId;
    if (localBackgroundEmojiIdCopy != null) {
      buffer.writeInt64(localBackgroundEmojiIdCopy);
    }

    // Finished serialization.
  }
}

/// Help Peer Color Set.
///
/// ID: `26219a58`.
class HelpPeerColorSet extends HelpPeerColorSetBase {
  /// Help Peer Color Set constructor.
  const HelpPeerColorSet({
    required this.colors,
  }) : super._();

  /// Deserialize.
  factory HelpPeerColorSet.deserialize(BinaryReader reader) {
    // Read [HelpPeerColorSet] fields.
    final colors = reader.readVectorInt32();

    // Construct [HelpPeerColorSet] object.
    final returnValue = HelpPeerColorSet(
      colors: colors,
    );

    // Now return the deserialized [HelpPeerColorSet].
    return returnValue;
  }

  /// Colors.
  final List<int> colors;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x26219a58.
    buffer.writeInt32(0x26219a58);

    // Write fields.
    buffer.writeVectorInt32(colors);

    // Finished serialization.
  }
}

/// Help Peer Color Profile Set.
///
/// ID: `767d61eb`.
class HelpPeerColorProfileSet extends HelpPeerColorSetBase {
  /// Help Peer Color Profile Set constructor.
  const HelpPeerColorProfileSet({
    required this.paletteColors,
    required this.bgColors,
    required this.storyColors,
  }) : super._();

  /// Deserialize.
  factory HelpPeerColorProfileSet.deserialize(BinaryReader reader) {
    // Read [HelpPeerColorProfileSet] fields.
    final paletteColors = reader.readVectorInt32();
    final bgColors = reader.readVectorInt32();
    final storyColors = reader.readVectorInt32();

    // Construct [HelpPeerColorProfileSet] object.
    final returnValue = HelpPeerColorProfileSet(
      paletteColors: paletteColors,
      bgColors: bgColors,
      storyColors: storyColors,
    );

    // Now return the deserialized [HelpPeerColorProfileSet].
    return returnValue;
  }

  /// Palette Colors.
  final List<int> paletteColors;

  /// Bg Colors.
  final List<int> bgColors;

  /// Story Colors.
  final List<int> storyColors;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x767d61eb.
    buffer.writeInt32(0x767d61eb);

    // Write fields.
    buffer.writeVectorInt32(paletteColors);
    buffer.writeVectorInt32(bgColors);
    buffer.writeVectorInt32(storyColors);

    // Finished serialization.
  }
}

/// Help Peer Color Option.
///
/// ID: `ef8430ab`.
class HelpPeerColorOption extends HelpPeerColorOptionBase {
  /// Help Peer Color Option constructor.
  const HelpPeerColorOption({
    required this.hidden,
    required this.colorId,
    this.colors,
    this.darkColors,
    this.channelMinLevel,
  }) : super._();

  /// Deserialize.
  factory HelpPeerColorOption.deserialize(BinaryReader reader) {
    // Read [HelpPeerColorOption] fields.
    final flags = reader.readInt32();
    final hidden = (flags & 1) != 0;
    final colorId = reader.readInt32();
    final hasColorsField = (flags & 2) != 0;
    final colors =
        hasColorsField ? reader.readObject() as HelpPeerColorSetBase : null;
    final hasDarkColorsField = (flags & 4) != 0;
    final darkColors =
        hasDarkColorsField ? reader.readObject() as HelpPeerColorSetBase : null;
    final hasChannelMinLevelField = (flags & 8) != 0;
    final channelMinLevel = hasChannelMinLevelField ? reader.readInt32() : null;

    // Construct [HelpPeerColorOption] object.
    final returnValue = HelpPeerColorOption(
      hidden: hidden,
      colorId: colorId,
      colors: colors,
      darkColors: darkColors,
      channelMinLevel: channelMinLevel,
    );

    // Now return the deserialized [HelpPeerColorOption].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: hidden,
      b01: colors != null,
      b02: darkColors != null,
      b03: channelMinLevel != null,
    );

    return v;
  }

  /// hidden: bit 0 of flags.0?true
  final bool hidden;

  /// Color Id.
  ///
  /// Field type is Int32.
  final int colorId;

  /// Colors.
  final HelpPeerColorSetBase? colors;

  /// Dark Colors.
  final HelpPeerColorSetBase? darkColors;

  /// Channel Min Level.
  final int? channelMinLevel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xef8430ab.
    buffer.writeInt32(0xef8430ab);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(colorId);
    final localColorsCopy = colors;
    if (localColorsCopy != null) {
      buffer.writeObject(localColorsCopy);
    }
    final localDarkColorsCopy = darkColors;
    if (localDarkColorsCopy != null) {
      buffer.writeObject(localDarkColorsCopy);
    }
    final localChannelMinLevelCopy = channelMinLevel;
    if (localChannelMinLevelCopy != null) {
      buffer.writeInt32(localChannelMinLevelCopy);
    }

    // Finished serialization.
  }
}

/// Help Peer Colors Not Modified.
///
/// ID: `2ba1f5ce`.
class HelpPeerColorsNotModified extends HelpPeerColorsBase {
  /// Help Peer Colors Not Modified constructor.
  const HelpPeerColorsNotModified() : super._();

  /// Deserialize.
  factory HelpPeerColorsNotModified.deserialize(BinaryReader reader) {
    // Construct [HelpPeerColorsNotModified] object.
    final returnValue = HelpPeerColorsNotModified();

    // Now return the deserialized [HelpPeerColorsNotModified].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2ba1f5ce.
    buffer.writeInt32(0x2ba1f5ce);

    // Finished serialization.
  }
}

/// Help Peer Colors.
///
/// ID: `00f8ed08`.
class HelpPeerColors extends HelpPeerColorsBase {
  /// Help Peer Colors constructor.
  const HelpPeerColors({
    required this.hash,
    required this.colors,
  }) : super._();

  /// Deserialize.
  factory HelpPeerColors.deserialize(BinaryReader reader) {
    // Read [HelpPeerColors] fields.
    final hash = reader.readInt32();
    final colors = reader.readVectorObject<HelpPeerColorOptionBase>();

    // Construct [HelpPeerColors] object.
    final returnValue = HelpPeerColors(
      hash: hash,
      colors: colors,
    );

    // Now return the deserialized [HelpPeerColors].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Colors.
  final List<HelpPeerColorOptionBase> colors;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x00f8ed08.
    buffer.writeInt32(0x00f8ed08);

    // Write fields.
    buffer.writeInt32(hash);
    buffer.writeVectorObject(colors);

    // Finished serialization.
  }
}

/// Story Reaction.
///
/// ID: `6090d6d5`.
class StoryReaction extends StoryReactionBase {
  /// Story Reaction constructor.
  const StoryReaction({
    required this.peerId,
    required this.date,
    required this.reaction,
  }) : super._();

  /// Deserialize.
  factory StoryReaction.deserialize(BinaryReader reader) {
    // Read [StoryReaction] fields.
    final peerId = reader.readObject() as PeerBase;
    final date = reader.readDateTime();
    final reaction = reader.readObject() as ReactionBase;

    // Construct [StoryReaction] object.
    final returnValue = StoryReaction(
      peerId: peerId,
      date: date,
      reaction: reaction,
    );

    // Now return the deserialized [StoryReaction].
    return returnValue;
  }

  /// Peer Id.
  final PeerBase peerId;

  /// Date.
  final DateTime date;

  /// Reaction.
  final ReactionBase reaction;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6090d6d5.
    buffer.writeInt32(0x6090d6d5);

    // Write fields.
    buffer.writeObject(peerId);
    buffer.writeDateTime(date);
    buffer.writeObject(reaction);

    // Finished serialization.
  }
}

/// Story Reaction Public Forward.
///
/// ID: `bbab2643`.
class StoryReactionPublicForward extends StoryReactionBase {
  /// Story Reaction Public Forward constructor.
  const StoryReactionPublicForward({
    required this.message,
  }) : super._();

  /// Deserialize.
  factory StoryReactionPublicForward.deserialize(BinaryReader reader) {
    // Read [StoryReactionPublicForward] fields.
    final message = reader.readObject() as MessageBase;

    // Construct [StoryReactionPublicForward] object.
    final returnValue = StoryReactionPublicForward(
      message: message,
    );

    // Now return the deserialized [StoryReactionPublicForward].
    return returnValue;
  }

  /// Message.
  final MessageBase message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbbab2643.
    buffer.writeInt32(0xbbab2643);

    // Write fields.
    buffer.writeObject(message);

    // Finished serialization.
  }
}

/// Story Reaction Public Repost.
///
/// ID: `cfcd0f13`.
class StoryReactionPublicRepost extends StoryReactionBase {
  /// Story Reaction Public Repost constructor.
  const StoryReactionPublicRepost({
    required this.peerId,
    required this.story,
  }) : super._();

  /// Deserialize.
  factory StoryReactionPublicRepost.deserialize(BinaryReader reader) {
    // Read [StoryReactionPublicRepost] fields.
    final peerId = reader.readObject() as PeerBase;
    final story = reader.readObject() as StoryItemBase;

    // Construct [StoryReactionPublicRepost] object.
    final returnValue = StoryReactionPublicRepost(
      peerId: peerId,
      story: story,
    );

    // Now return the deserialized [StoryReactionPublicRepost].
    return returnValue;
  }

  /// Peer Id.
  final PeerBase peerId;

  /// Story.
  final StoryItemBase story;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcfcd0f13.
    buffer.writeInt32(0xcfcd0f13);

    // Write fields.
    buffer.writeObject(peerId);
    buffer.writeObject(story);

    // Finished serialization.
  }
}

/// Stories Story Reactions List.
///
/// ID: `aa5f789c`.
class StoriesStoryReactionsList extends StoriesStoryReactionsListBase {
  /// Stories Story Reactions List constructor.
  const StoriesStoryReactionsList({
    required this.count,
    required this.reactions,
    required this.chats,
    required this.users,
    this.nextOffset,
  }) : super._();

  /// Deserialize.
  factory StoriesStoryReactionsList.deserialize(BinaryReader reader) {
    // Read [StoriesStoryReactionsList] fields.
    final flags = reader.readInt32();
    final count = reader.readInt32();
    final reactions = reader.readVectorObject<StoryReactionBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();
    final hasNextOffsetField = (flags & 1) != 0;
    final nextOffset = hasNextOffsetField ? reader.readString() : null;

    // Construct [StoriesStoryReactionsList] object.
    final returnValue = StoriesStoryReactionsList(
      count: count,
      reactions: reactions,
      chats: chats,
      users: users,
      nextOffset: nextOffset,
    );

    // Now return the deserialized [StoriesStoryReactionsList].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: nextOffset != null,
    );

    return v;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Reactions.
  final List<StoryReactionBase> reactions;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Next Offset.
  final String? nextOffset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaa5f789c.
    buffer.writeInt32(0xaa5f789c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(count);
    buffer.writeVectorObject(reactions);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);
    final localNextOffsetCopy = nextOffset;
    if (localNextOffsetCopy != null) {
      buffer.writeString(localNextOffsetCopy);
    }

    // Finished serialization.
  }
}

/// Saved Dialog.
///
/// ID: `bd87cb6c`.
class SavedDialog extends SavedDialogBase {
  /// Saved Dialog constructor.
  const SavedDialog({
    required this.pinned,
    required this.peer,
    required this.topMessage,
  }) : super._();

  /// Deserialize.
  factory SavedDialog.deserialize(BinaryReader reader) {
    // Read [SavedDialog] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 4) != 0;
    final peer = reader.readObject() as PeerBase;
    final topMessage = reader.readInt32();

    // Construct [SavedDialog] object.
    final returnValue = SavedDialog(
      pinned: pinned,
      peer: peer,
      topMessage: topMessage,
    );

    // Now return the deserialized [SavedDialog].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: pinned,
    );

    return v;
  }

  /// pinned: bit 2 of flags.2?true
  final bool pinned;

  /// Peer.
  final PeerBase peer;

  /// Top Message.
  ///
  /// Field type is Int32.
  final int topMessage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbd87cb6c.
    buffer.writeInt32(0xbd87cb6c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(topMessage);

    // Finished serialization.
  }
}

/// Messages Saved Dialogs.
///
/// ID: `f83ae221`.
class MessagesSavedDialogs extends MessagesSavedDialogsBase {
  /// Messages Saved Dialogs constructor.
  const MessagesSavedDialogs({
    required this.dialogs,
    required this.messages,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesSavedDialogs.deserialize(BinaryReader reader) {
    // Read [MessagesSavedDialogs] fields.
    final dialogs = reader.readVectorObject<SavedDialogBase>();
    final messages = reader.readVectorObject<MessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesSavedDialogs] object.
    final returnValue = MessagesSavedDialogs(
      dialogs: dialogs,
      messages: messages,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesSavedDialogs].
    return returnValue;
  }

  /// Dialogs.
  final List<SavedDialogBase> dialogs;

  /// Messages.
  final List<MessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf83ae221.
    buffer.writeInt32(0xf83ae221);

    // Write fields.
    buffer.writeVectorObject(dialogs);
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Saved Dialogs Slice.
///
/// ID: `44ba9dd9`.
class MessagesSavedDialogsSlice extends MessagesSavedDialogsBase {
  /// Messages Saved Dialogs Slice constructor.
  const MessagesSavedDialogsSlice({
    required this.count,
    required this.dialogs,
    required this.messages,
    required this.chats,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory MessagesSavedDialogsSlice.deserialize(BinaryReader reader) {
    // Read [MessagesSavedDialogsSlice] fields.
    final count = reader.readInt32();
    final dialogs = reader.readVectorObject<SavedDialogBase>();
    final messages = reader.readVectorObject<MessageBase>();
    final chats = reader.readVectorObject<ChatBase>();
    final users = reader.readVectorObject<UserBase>();

    // Construct [MessagesSavedDialogsSlice] object.
    final returnValue = MessagesSavedDialogsSlice(
      count: count,
      dialogs: dialogs,
      messages: messages,
      chats: chats,
      users: users,
    );

    // Now return the deserialized [MessagesSavedDialogsSlice].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Dialogs.
  final List<SavedDialogBase> dialogs;

  /// Messages.
  final List<MessageBase> messages;

  /// Chats.
  final List<ChatBase> chats;

  /// Users.
  final List<UserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x44ba9dd9.
    buffer.writeInt32(0x44ba9dd9);

    // Write fields.
    buffer.writeInt32(count);
    buffer.writeVectorObject(dialogs);
    buffer.writeVectorObject(messages);
    buffer.writeVectorObject(chats);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Messages Saved Dialogs Not Modified.
///
/// ID: `c01f6fe8`.
class MessagesSavedDialogsNotModified extends MessagesSavedDialogsBase {
  /// Messages Saved Dialogs Not Modified constructor.
  const MessagesSavedDialogsNotModified({
    required this.count,
  }) : super._();

  /// Deserialize.
  factory MessagesSavedDialogsNotModified.deserialize(BinaryReader reader) {
    // Read [MessagesSavedDialogsNotModified] fields.
    final count = reader.readInt32();

    // Construct [MessagesSavedDialogsNotModified] object.
    final returnValue = MessagesSavedDialogsNotModified(
      count: count,
    );

    // Now return the deserialized [MessagesSavedDialogsNotModified].
    return returnValue;
  }

  /// Count.
  ///
  /// Field type is Int32.
  final int count;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc01f6fe8.
    buffer.writeInt32(0xc01f6fe8);

    // Write fields.
    buffer.writeInt32(count);

    // Finished serialization.
  }
}

/// Invoke After Msg.
///
/// ID: `cb9f372d`.
class InvokeAfterMsg<X> extends TlMethod<X> {
  /// Invoke After Msg constructor.
  const InvokeAfterMsg({
    required this.msgId,
    required this.query,
  }) : super._();

  /// Deserialize.
  factory InvokeAfterMsg.deserialize(BinaryReader reader) {
    // Read [InvokeAfterMsg] fields.
    final msgId = reader.readInt64();
    final query = reader.readObject() as TlMethod<X>;

    // Construct [InvokeAfterMsg] object.
    final returnValue = InvokeAfterMsg(
      msgId: msgId,
      query: query,
    );

    // Now return the deserialized [InvokeAfterMsg].
    return returnValue;
  }

  /// Msg Id.
  ///
  /// Field type is Int64.
  final int msgId;

  /// Query.
  final TlMethod<X> query;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcb9f372d.
    buffer.writeInt32(0xcb9f372d);

    // Write fields.
    buffer.writeInt64(msgId);
    buffer.writeObject(query);

    // Finished serialization.
  }
}

/// Invoke After Msgs.
///
/// ID: `3dc4b4f0`.
class InvokeAfterMsgs<X> extends TlMethod<X> {
  /// Invoke After Msgs constructor.
  const InvokeAfterMsgs({
    required this.msgIds,
    required this.query,
  }) : super._();

  /// Deserialize.
  factory InvokeAfterMsgs.deserialize(BinaryReader reader) {
    // Read [InvokeAfterMsgs] fields.
    final msgIds = reader.readVectorInt64();
    final query = reader.readObject() as TlMethod<X>;

    // Construct [InvokeAfterMsgs] object.
    final returnValue = InvokeAfterMsgs(
      msgIds: msgIds,
      query: query,
    );

    // Now return the deserialized [InvokeAfterMsgs].
    return returnValue;
  }

  /// Msg Ids.
  final List<int> msgIds;

  /// Query.
  final TlMethod<X> query;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3dc4b4f0.
    buffer.writeInt32(0x3dc4b4f0);

    // Write fields.
    buffer.writeVectorInt64(msgIds);
    buffer.writeObject(query);

    // Finished serialization.
  }
}

/// Auth Send Code.
///
/// ID: `a677244f`.
class AuthSendCode extends TlMethod<AuthSentCodeBase> {
  /// Auth Send Code constructor.
  const AuthSendCode({
    required this.phoneNumber,
    required this.apiId,
    required this.apiHash,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AuthSendCode.deserialize(BinaryReader reader) {
    // Read [AuthSendCode] fields.
    final phoneNumber = reader.readString();
    final apiId = reader.readInt32();
    final apiHash = reader.readString();
    final settings = reader.readObject() as CodeSettingsBase;

    // Construct [AuthSendCode] object.
    final returnValue = AuthSendCode(
      phoneNumber: phoneNumber,
      apiId: apiId,
      apiHash: apiHash,
      settings: settings,
    );

    // Now return the deserialized [AuthSendCode].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Api Id.
  ///
  /// Field type is Int32.
  final int apiId;

  /// Api Hash.
  final String apiHash;

  /// Settings.
  final CodeSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa677244f.
    buffer.writeInt32(0xa677244f);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeInt32(apiId);
    buffer.writeString(apiHash);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Auth Sign Up.
///
/// ID: `80eee427`.
class AuthSignUp extends TlMethod<AuthAuthorizationBase> {
  /// Auth Sign Up constructor.
  const AuthSignUp({
    required this.phoneNumber,
    required this.phoneCodeHash,
    required this.firstName,
    required this.lastName,
  }) : super._();

  /// Deserialize.
  factory AuthSignUp.deserialize(BinaryReader reader) {
    // Read [AuthSignUp] fields.
    final phoneNumber = reader.readString();
    final phoneCodeHash = reader.readString();
    final firstName = reader.readString();
    final lastName = reader.readString();

    // Construct [AuthSignUp] object.
    final returnValue = AuthSignUp(
      phoneNumber: phoneNumber,
      phoneCodeHash: phoneCodeHash,
      firstName: firstName,
      lastName: lastName,
    );

    // Now return the deserialized [AuthSignUp].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// First Name.
  final String firstName;

  /// Last Name.
  final String lastName;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x80eee427.
    buffer.writeInt32(0x80eee427);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeString(phoneCodeHash);
    buffer.writeString(firstName);
    buffer.writeString(lastName);

    // Finished serialization.
  }
}

/// Auth Sign In.
///
/// ID: `8d52a951`.
class AuthSignIn extends TlMethod<AuthAuthorizationBase> {
  /// Auth Sign In constructor.
  const AuthSignIn({
    required this.phoneNumber,
    required this.phoneCodeHash,
    this.phoneCode,
    this.emailVerification,
  }) : super._();

  /// Deserialize.
  factory AuthSignIn.deserialize(BinaryReader reader) {
    // Read [AuthSignIn] fields.
    final flags = reader.readInt32();
    final phoneNumber = reader.readString();
    final phoneCodeHash = reader.readString();
    final hasPhoneCodeField = (flags & 1) != 0;
    final phoneCode = hasPhoneCodeField ? reader.readString() : null;
    final hasEmailVerificationField = (flags & 2) != 0;
    final emailVerification = hasEmailVerificationField
        ? reader.readObject() as EmailVerificationBase
        : null;

    // Construct [AuthSignIn] object.
    final returnValue = AuthSignIn(
      phoneNumber: phoneNumber,
      phoneCodeHash: phoneCodeHash,
      phoneCode: phoneCode,
      emailVerification: emailVerification,
    );

    // Now return the deserialized [AuthSignIn].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: phoneCode != null,
      b01: emailVerification != null,
    );

    return v;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// Phone Code.
  final String? phoneCode;

  /// Email Verification.
  final EmailVerificationBase? emailVerification;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8d52a951.
    buffer.writeInt32(0x8d52a951);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(phoneNumber);
    buffer.writeString(phoneCodeHash);
    final localPhoneCodeCopy = phoneCode;
    if (localPhoneCodeCopy != null) {
      buffer.writeString(localPhoneCodeCopy);
    }
    final localEmailVerificationCopy = emailVerification;
    if (localEmailVerificationCopy != null) {
      buffer.writeObject(localEmailVerificationCopy);
    }

    // Finished serialization.
  }
}

/// Auth Log Out.
///
/// ID: `3e72ba19`.
class AuthLogOut extends TlMethod<AuthLoggedOutBase> {
  /// Auth Log Out constructor.
  const AuthLogOut() : super._();

  /// Deserialize.
  factory AuthLogOut.deserialize(BinaryReader reader) {
    // Construct [AuthLogOut] object.
    final returnValue = AuthLogOut();

    // Now return the deserialized [AuthLogOut].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3e72ba19.
    buffer.writeInt32(0x3e72ba19);

    // Finished serialization.
  }
}

/// Auth Reset Authorizations.
///
/// ID: `9fab0d1a`.
class AuthResetAuthorizations extends TlMethod<bool> {
  /// Auth Reset Authorizations constructor.
  const AuthResetAuthorizations() : super._();

  /// Deserialize.
  factory AuthResetAuthorizations.deserialize(BinaryReader reader) {
    // Construct [AuthResetAuthorizations] object.
    final returnValue = AuthResetAuthorizations();

    // Now return the deserialized [AuthResetAuthorizations].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9fab0d1a.
    buffer.writeInt32(0x9fab0d1a);

    // Finished serialization.
  }
}

/// Auth Export Authorization.
///
/// ID: `e5bfffcd`.
class AuthExportAuthorization extends TlMethod<AuthExportedAuthorizationBase> {
  /// Auth Export Authorization constructor.
  const AuthExportAuthorization({
    required this.dcId,
  }) : super._();

  /// Deserialize.
  factory AuthExportAuthorization.deserialize(BinaryReader reader) {
    // Read [AuthExportAuthorization] fields.
    final dcId = reader.readInt32();

    // Construct [AuthExportAuthorization] object.
    final returnValue = AuthExportAuthorization(
      dcId: dcId,
    );

    // Now return the deserialized [AuthExportAuthorization].
    return returnValue;
  }

  /// Dc Id.
  ///
  /// Field type is Int32.
  final int dcId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe5bfffcd.
    buffer.writeInt32(0xe5bfffcd);

    // Write fields.
    buffer.writeInt32(dcId);

    // Finished serialization.
  }
}

/// Auth Import Authorization.
///
/// ID: `a57a7dad`.
class AuthImportAuthorization extends TlMethod<AuthAuthorizationBase> {
  /// Auth Import Authorization constructor.
  const AuthImportAuthorization({
    required this.id,
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory AuthImportAuthorization.deserialize(BinaryReader reader) {
    // Read [AuthImportAuthorization] fields.
    final id = reader.readInt64();
    final bytes = reader.readBytes();

    // Construct [AuthImportAuthorization] object.
    final returnValue = AuthImportAuthorization(
      id: id,
      bytes: bytes,
    );

    // Now return the deserialized [AuthImportAuthorization].
    return returnValue;
  }

  /// Id.
  ///
  /// Field type is Int64.
  final int id;

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa57a7dad.
    buffer.writeInt32(0xa57a7dad);

    // Write fields.
    buffer.writeInt64(id);
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Auth Bind Temp Auth Key.
///
/// ID: `cdd42a05`.
class AuthBindTempAuthKey extends TlMethod<bool> {
  /// Auth Bind Temp Auth Key constructor.
  const AuthBindTempAuthKey({
    required this.permAuthKeyId,
    required this.nonce,
    required this.expiresAt,
    required this.encryptedMessage,
  }) : super._();

  /// Deserialize.
  factory AuthBindTempAuthKey.deserialize(BinaryReader reader) {
    // Read [AuthBindTempAuthKey] fields.
    final permAuthKeyId = reader.readInt64();
    final nonce = reader.readInt64();
    final expiresAt = reader.readInt32();
    final encryptedMessage = reader.readBytes();

    // Construct [AuthBindTempAuthKey] object.
    final returnValue = AuthBindTempAuthKey(
      permAuthKeyId: permAuthKeyId,
      nonce: nonce,
      expiresAt: expiresAt,
      encryptedMessage: encryptedMessage,
    );

    // Now return the deserialized [AuthBindTempAuthKey].
    return returnValue;
  }

  /// Perm Auth Key Id.
  ///
  /// Field type is Int64.
  final int permAuthKeyId;

  /// Nonce.
  ///
  /// Field type is Int64.
  final int nonce;

  /// Expires At.
  ///
  /// Field type is Int32.
  final int expiresAt;

  /// Encrypted Message.
  final Uint8List encryptedMessage;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcdd42a05.
    buffer.writeInt32(0xcdd42a05);

    // Write fields.
    buffer.writeInt64(permAuthKeyId);
    buffer.writeInt64(nonce);
    buffer.writeInt32(expiresAt);
    buffer.writeBytes(encryptedMessage);

    // Finished serialization.
  }
}

/// Account Register Device.
///
/// ID: `ec86017a`.
class AccountRegisterDevice extends TlMethod<bool> {
  /// Account Register Device constructor.
  const AccountRegisterDevice({
    required this.noMuted,
    required this.tokenType,
    required this.token,
    required this.appSandbox,
    required this.secret,
    required this.otherUids,
  }) : super._();

  /// Deserialize.
  factory AccountRegisterDevice.deserialize(BinaryReader reader) {
    // Read [AccountRegisterDevice] fields.
    final flags = reader.readInt32();
    final noMuted = (flags & 1) != 0;
    final tokenType = reader.readInt32();
    final token = reader.readString();
    final appSandbox = reader.readBool();
    final secret = reader.readBytes();
    final otherUids = reader.readVectorInt64();

    // Construct [AccountRegisterDevice] object.
    final returnValue = AccountRegisterDevice(
      noMuted: noMuted,
      tokenType: tokenType,
      token: token,
      appSandbox: appSandbox,
      secret: secret,
      otherUids: otherUids,
    );

    // Now return the deserialized [AccountRegisterDevice].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: noMuted,
    );

    return v;
  }

  /// no_muted: bit 0 of flags.0?true
  final bool noMuted;

  /// Token Type.
  ///
  /// Field type is Int32.
  final int tokenType;

  /// Token.
  final String token;

  /// App Sandbox.
  final bool appSandbox;

  /// Secret.
  final Uint8List secret;

  /// Other Uids.
  final List<int> otherUids;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xec86017a.
    buffer.writeInt32(0xec86017a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(tokenType);
    buffer.writeString(token);
    buffer.writeBool(appSandbox);
    buffer.writeBytes(secret);
    buffer.writeVectorInt64(otherUids);

    // Finished serialization.
  }
}

/// Account Unregister Device.
///
/// ID: `6a0d3206`.
class AccountUnregisterDevice extends TlMethod<bool> {
  /// Account Unregister Device constructor.
  const AccountUnregisterDevice({
    required this.tokenType,
    required this.token,
    required this.otherUids,
  }) : super._();

  /// Deserialize.
  factory AccountUnregisterDevice.deserialize(BinaryReader reader) {
    // Read [AccountUnregisterDevice] fields.
    final tokenType = reader.readInt32();
    final token = reader.readString();
    final otherUids = reader.readVectorInt64();

    // Construct [AccountUnregisterDevice] object.
    final returnValue = AccountUnregisterDevice(
      tokenType: tokenType,
      token: token,
      otherUids: otherUids,
    );

    // Now return the deserialized [AccountUnregisterDevice].
    return returnValue;
  }

  /// Token Type.
  ///
  /// Field type is Int32.
  final int tokenType;

  /// Token.
  final String token;

  /// Other Uids.
  final List<int> otherUids;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6a0d3206.
    buffer.writeInt32(0x6a0d3206);

    // Write fields.
    buffer.writeInt32(tokenType);
    buffer.writeString(token);
    buffer.writeVectorInt64(otherUids);

    // Finished serialization.
  }
}

/// Account Update Notify Settings.
///
/// ID: `84be5b93`.
class AccountUpdateNotifySettings extends TlMethod<bool> {
  /// Account Update Notify Settings constructor.
  const AccountUpdateNotifySettings({
    required this.peer,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountUpdateNotifySettings.deserialize(BinaryReader reader) {
    // Read [AccountUpdateNotifySettings] fields.
    final peer = reader.readObject() as InputNotifyPeerBase;
    final settings = reader.readObject() as InputPeerNotifySettingsBase;

    // Construct [AccountUpdateNotifySettings] object.
    final returnValue = AccountUpdateNotifySettings(
      peer: peer,
      settings: settings,
    );

    // Now return the deserialized [AccountUpdateNotifySettings].
    return returnValue;
  }

  /// Peer.
  final InputNotifyPeerBase peer;

  /// Settings.
  final InputPeerNotifySettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x84be5b93.
    buffer.writeInt32(0x84be5b93);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Account Get Notify Settings.
///
/// ID: `12b3ad31`.
class AccountGetNotifySettings extends TlMethod<PeerNotifySettingsBase> {
  /// Account Get Notify Settings constructor.
  const AccountGetNotifySettings({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory AccountGetNotifySettings.deserialize(BinaryReader reader) {
    // Read [AccountGetNotifySettings] fields.
    final peer = reader.readObject() as InputNotifyPeerBase;

    // Construct [AccountGetNotifySettings] object.
    final returnValue = AccountGetNotifySettings(
      peer: peer,
    );

    // Now return the deserialized [AccountGetNotifySettings].
    return returnValue;
  }

  /// Peer.
  final InputNotifyPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x12b3ad31.
    buffer.writeInt32(0x12b3ad31);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Account Reset Notify Settings.
///
/// ID: `db7e1747`.
class AccountResetNotifySettings extends TlMethod<bool> {
  /// Account Reset Notify Settings constructor.
  const AccountResetNotifySettings() : super._();

  /// Deserialize.
  factory AccountResetNotifySettings.deserialize(BinaryReader reader) {
    // Construct [AccountResetNotifySettings] object.
    final returnValue = AccountResetNotifySettings();

    // Now return the deserialized [AccountResetNotifySettings].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdb7e1747.
    buffer.writeInt32(0xdb7e1747);

    // Finished serialization.
  }
}

/// Account Update Profile.
///
/// ID: `78515775`.
class AccountUpdateProfile extends TlMethod<UserBase> {
  /// Account Update Profile constructor.
  const AccountUpdateProfile({
    this.firstName,
    this.lastName,
    this.about,
  }) : super._();

  /// Deserialize.
  factory AccountUpdateProfile.deserialize(BinaryReader reader) {
    // Read [AccountUpdateProfile] fields.
    final flags = reader.readInt32();
    final hasFirstNameField = (flags & 1) != 0;
    final firstName = hasFirstNameField ? reader.readString() : null;
    final hasLastNameField = (flags & 2) != 0;
    final lastName = hasLastNameField ? reader.readString() : null;
    final hasAboutField = (flags & 4) != 0;
    final about = hasAboutField ? reader.readString() : null;

    // Construct [AccountUpdateProfile] object.
    final returnValue = AccountUpdateProfile(
      firstName: firstName,
      lastName: lastName,
      about: about,
    );

    // Now return the deserialized [AccountUpdateProfile].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: firstName != null,
      b01: lastName != null,
      b02: about != null,
    );

    return v;
  }

  /// First Name.
  final String? firstName;

  /// Last Name.
  final String? lastName;

  /// About.
  final String? about;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x78515775.
    buffer.writeInt32(0x78515775);

    // Write fields.
    buffer.writeInt32(flags);
    final localFirstNameCopy = firstName;
    if (localFirstNameCopy != null) {
      buffer.writeString(localFirstNameCopy);
    }
    final localLastNameCopy = lastName;
    if (localLastNameCopy != null) {
      buffer.writeString(localLastNameCopy);
    }
    final localAboutCopy = about;
    if (localAboutCopy != null) {
      buffer.writeString(localAboutCopy);
    }

    // Finished serialization.
  }
}

/// Account Update Status.
///
/// ID: `6628562c`.
class AccountUpdateStatus extends TlMethod<bool> {
  /// Account Update Status constructor.
  const AccountUpdateStatus({
    required this.offline,
  }) : super._();

  /// Deserialize.
  factory AccountUpdateStatus.deserialize(BinaryReader reader) {
    // Read [AccountUpdateStatus] fields.
    final offline = reader.readBool();

    // Construct [AccountUpdateStatus] object.
    final returnValue = AccountUpdateStatus(
      offline: offline,
    );

    // Now return the deserialized [AccountUpdateStatus].
    return returnValue;
  }

  /// Offline.
  final bool offline;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6628562c.
    buffer.writeInt32(0x6628562c);

    // Write fields.
    buffer.writeBool(offline);

    // Finished serialization.
  }
}

/// Account Get Wall Papers.
///
/// ID: `07967d36`.
class AccountGetWallPapers extends TlMethod<AccountWallPapersBase> {
  /// Account Get Wall Papers constructor.
  const AccountGetWallPapers({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetWallPapers.deserialize(BinaryReader reader) {
    // Read [AccountGetWallPapers] fields.
    final hash = reader.readInt64();

    // Construct [AccountGetWallPapers] object.
    final returnValue = AccountGetWallPapers(
      hash: hash,
    );

    // Now return the deserialized [AccountGetWallPapers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x07967d36.
    buffer.writeInt32(0x07967d36);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Account Report Peer.
///
/// ID: `c5ba3d86`.
class AccountReportPeer extends TlMethod<bool> {
  /// Account Report Peer constructor.
  const AccountReportPeer({
    required this.peer,
    required this.reason,
    required this.message,
  }) : super._();

  /// Deserialize.
  factory AccountReportPeer.deserialize(BinaryReader reader) {
    // Read [AccountReportPeer] fields.
    final peer = reader.readObject() as InputPeerBase;
    final reason = reader.readObject() as ReportReasonBase;
    final message = reader.readString();

    // Construct [AccountReportPeer] object.
    final returnValue = AccountReportPeer(
      peer: peer,
      reason: reason,
      message: message,
    );

    // Now return the deserialized [AccountReportPeer].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Reason.
  final ReportReasonBase reason;

  /// Message.
  final String message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc5ba3d86.
    buffer.writeInt32(0xc5ba3d86);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(reason);
    buffer.writeString(message);

    // Finished serialization.
  }
}

/// Users Get Users.
///
/// ID: `0d91a548`.
class UsersGetUsers extends TlMethod<List<UserBase>> {
  /// Users Get Users constructor.
  const UsersGetUsers({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory UsersGetUsers.deserialize(BinaryReader reader) {
    // Read [UsersGetUsers] fields.
    final id = reader.readVectorObject<InputUserBase>();

    // Construct [UsersGetUsers] object.
    final returnValue = UsersGetUsers(
      id: id,
    );

    // Now return the deserialized [UsersGetUsers].
    return returnValue;
  }

  /// Id.
  final List<InputUserBase> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0d91a548.
    buffer.writeInt32(0x0d91a548);

    // Write fields.
    buffer.writeVectorObject(id);

    // Finished serialization.
  }
}

/// Users Get Full User.
///
/// ID: `b60f5918`.
class UsersGetFullUser extends TlMethod<UsersUserFullBase> {
  /// Users Get Full User constructor.
  const UsersGetFullUser({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory UsersGetFullUser.deserialize(BinaryReader reader) {
    // Read [UsersGetFullUser] fields.
    final id = reader.readObject() as InputUserBase;

    // Construct [UsersGetFullUser] object.
    final returnValue = UsersGetFullUser(
      id: id,
    );

    // Now return the deserialized [UsersGetFullUser].
    return returnValue;
  }

  /// Id.
  final InputUserBase id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb60f5918.
    buffer.writeInt32(0xb60f5918);

    // Write fields.
    buffer.writeObject(id);

    // Finished serialization.
  }
}

/// Contacts Get Contact I Ds.
///
/// ID: `7adc669d`.
class ContactsGetContactIDs extends TlMethod<List<int>> {
  /// Contacts Get Contact I Ds constructor.
  const ContactsGetContactIDs({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory ContactsGetContactIDs.deserialize(BinaryReader reader) {
    // Read [ContactsGetContactIDs] fields.
    final hash = reader.readInt64();

    // Construct [ContactsGetContactIDs] object.
    final returnValue = ContactsGetContactIDs(
      hash: hash,
    );

    // Now return the deserialized [ContactsGetContactIDs].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7adc669d.
    buffer.writeInt32(0x7adc669d);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Contacts Get Statuses.
///
/// ID: `c4a353ee`.
class ContactsGetStatuses extends TlMethod<List<ContactStatusBase>> {
  /// Contacts Get Statuses constructor.
  const ContactsGetStatuses() : super._();

  /// Deserialize.
  factory ContactsGetStatuses.deserialize(BinaryReader reader) {
    // Construct [ContactsGetStatuses] object.
    final returnValue = ContactsGetStatuses();

    // Now return the deserialized [ContactsGetStatuses].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc4a353ee.
    buffer.writeInt32(0xc4a353ee);

    // Finished serialization.
  }
}

/// Contacts Get Contacts.
///
/// ID: `5dd69e12`.
class ContactsGetContacts extends TlMethod<ContactsContactsBase> {
  /// Contacts Get Contacts constructor.
  const ContactsGetContacts({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory ContactsGetContacts.deserialize(BinaryReader reader) {
    // Read [ContactsGetContacts] fields.
    final hash = reader.readInt64();

    // Construct [ContactsGetContacts] object.
    final returnValue = ContactsGetContacts(
      hash: hash,
    );

    // Now return the deserialized [ContactsGetContacts].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5dd69e12.
    buffer.writeInt32(0x5dd69e12);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Contacts Import Contacts.
///
/// ID: `2c800be5`.
class ContactsImportContacts extends TlMethod<ContactsImportedContactsBase> {
  /// Contacts Import Contacts constructor.
  const ContactsImportContacts({
    required this.contacts,
  }) : super._();

  /// Deserialize.
  factory ContactsImportContacts.deserialize(BinaryReader reader) {
    // Read [ContactsImportContacts] fields.
    final contacts = reader.readVectorObject<InputContactBase>();

    // Construct [ContactsImportContacts] object.
    final returnValue = ContactsImportContacts(
      contacts: contacts,
    );

    // Now return the deserialized [ContactsImportContacts].
    return returnValue;
  }

  /// Contacts.
  final List<InputContactBase> contacts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2c800be5.
    buffer.writeInt32(0x2c800be5);

    // Write fields.
    buffer.writeVectorObject(contacts);

    // Finished serialization.
  }
}

/// Contacts Delete Contacts.
///
/// ID: `096a0e00`.
class ContactsDeleteContacts extends TlMethod<UpdatesBase> {
  /// Contacts Delete Contacts constructor.
  const ContactsDeleteContacts({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ContactsDeleteContacts.deserialize(BinaryReader reader) {
    // Read [ContactsDeleteContacts] fields.
    final id = reader.readVectorObject<InputUserBase>();

    // Construct [ContactsDeleteContacts] object.
    final returnValue = ContactsDeleteContacts(
      id: id,
    );

    // Now return the deserialized [ContactsDeleteContacts].
    return returnValue;
  }

  /// Id.
  final List<InputUserBase> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x096a0e00.
    buffer.writeInt32(0x096a0e00);

    // Write fields.
    buffer.writeVectorObject(id);

    // Finished serialization.
  }
}

/// Contacts Delete By Phones.
///
/// ID: `1013fd9e`.
class ContactsDeleteByPhones extends TlMethod<bool> {
  /// Contacts Delete By Phones constructor.
  const ContactsDeleteByPhones({
    required this.phones,
  }) : super._();

  /// Deserialize.
  factory ContactsDeleteByPhones.deserialize(BinaryReader reader) {
    // Read [ContactsDeleteByPhones] fields.
    final phones = reader.readVectorString();

    // Construct [ContactsDeleteByPhones] object.
    final returnValue = ContactsDeleteByPhones(
      phones: phones,
    );

    // Now return the deserialized [ContactsDeleteByPhones].
    return returnValue;
  }

  /// Phones.
  final List<String> phones;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1013fd9e.
    buffer.writeInt32(0x1013fd9e);

    // Write fields.
    buffer.writeVectorString(phones);

    // Finished serialization.
  }
}

/// Contacts Block.
///
/// ID: `2e2e8734`.
class ContactsBlock extends TlMethod<bool> {
  /// Contacts Block constructor.
  const ContactsBlock({
    required this.myStoriesFrom,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ContactsBlock.deserialize(BinaryReader reader) {
    // Read [ContactsBlock] fields.
    final flags = reader.readInt32();
    final myStoriesFrom = (flags & 1) != 0;
    final id = reader.readObject() as InputPeerBase;

    // Construct [ContactsBlock] object.
    final returnValue = ContactsBlock(
      myStoriesFrom: myStoriesFrom,
      id: id,
    );

    // Now return the deserialized [ContactsBlock].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: myStoriesFrom,
    );

    return v;
  }

  /// my_stories_from: bit 0 of flags.0?true
  final bool myStoriesFrom;

  /// Id.
  final InputPeerBase id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2e2e8734.
    buffer.writeInt32(0x2e2e8734);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(id);

    // Finished serialization.
  }
}

/// Contacts Unblock.
///
/// ID: `b550d328`.
class ContactsUnblock extends TlMethod<bool> {
  /// Contacts Unblock constructor.
  const ContactsUnblock({
    required this.myStoriesFrom,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ContactsUnblock.deserialize(BinaryReader reader) {
    // Read [ContactsUnblock] fields.
    final flags = reader.readInt32();
    final myStoriesFrom = (flags & 1) != 0;
    final id = reader.readObject() as InputPeerBase;

    // Construct [ContactsUnblock] object.
    final returnValue = ContactsUnblock(
      myStoriesFrom: myStoriesFrom,
      id: id,
    );

    // Now return the deserialized [ContactsUnblock].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: myStoriesFrom,
    );

    return v;
  }

  /// my_stories_from: bit 0 of flags.0?true
  final bool myStoriesFrom;

  /// Id.
  final InputPeerBase id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb550d328.
    buffer.writeInt32(0xb550d328);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(id);

    // Finished serialization.
  }
}

/// Contacts Get Blocked.
///
/// ID: `9a868f80`.
class ContactsGetBlocked extends TlMethod<ContactsBlockedBase> {
  /// Contacts Get Blocked constructor.
  const ContactsGetBlocked({
    required this.myStoriesFrom,
    required this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory ContactsGetBlocked.deserialize(BinaryReader reader) {
    // Read [ContactsGetBlocked] fields.
    final flags = reader.readInt32();
    final myStoriesFrom = (flags & 1) != 0;
    final offset = reader.readInt32();
    final limit = reader.readInt32();

    // Construct [ContactsGetBlocked] object.
    final returnValue = ContactsGetBlocked(
      myStoriesFrom: myStoriesFrom,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [ContactsGetBlocked].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: myStoriesFrom,
    );

    return v;
  }

  /// my_stories_from: bit 0 of flags.0?true
  final bool myStoriesFrom;

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9a868f80.
    buffer.writeInt32(0x9a868f80);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(offset);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Messages Get Messages.
///
/// ID: `63c66506`.
class MessagesGetMessages extends TlMethod<MessagesMessagesBase> {
  /// Messages Get Messages constructor.
  const MessagesGetMessages({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesGetMessages.deserialize(BinaryReader reader) {
    // Read [MessagesGetMessages] fields.
    final id = reader.readVectorObject<InputMessageBase>();

    // Construct [MessagesGetMessages] object.
    final returnValue = MessagesGetMessages(
      id: id,
    );

    // Now return the deserialized [MessagesGetMessages].
    return returnValue;
  }

  /// Id.
  final List<InputMessageBase> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x63c66506.
    buffer.writeInt32(0x63c66506);

    // Write fields.
    buffer.writeVectorObject(id);

    // Finished serialization.
  }
}

/// Messages Get Dialogs.
///
/// ID: `a0f4cb4f`.
class MessagesGetDialogs extends TlMethod<MessagesDialogsBase> {
  /// Messages Get Dialogs constructor.
  const MessagesGetDialogs({
    required this.excludePinned,
    this.folderId,
    required this.offsetDate,
    required this.offsetId,
    required this.offsetPeer,
    required this.limit,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetDialogs.deserialize(BinaryReader reader) {
    // Read [MessagesGetDialogs] fields.
    final flags = reader.readInt32();
    final excludePinned = (flags & 1) != 0;
    final hasFolderIdField = (flags & 2) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final offsetDate = reader.readDateTime();
    final offsetId = reader.readInt32();
    final offsetPeer = reader.readObject() as InputPeerBase;
    final limit = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [MessagesGetDialogs] object.
    final returnValue = MessagesGetDialogs(
      excludePinned: excludePinned,
      folderId: folderId,
      offsetDate: offsetDate,
      offsetId: offsetId,
      offsetPeer: offsetPeer,
      limit: limit,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetDialogs].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: excludePinned,
      b01: folderId != null,
    );

    return v;
  }

  /// exclude_pinned: bit 0 of flags.0?true
  final bool excludePinned;

  /// Folder Id.
  final int? folderId;

  /// Offset Date.
  final DateTime offsetDate;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Offset Peer.
  final InputPeerBase offsetPeer;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa0f4cb4f.
    buffer.writeInt32(0xa0f4cb4f);

    // Write fields.
    buffer.writeInt32(flags);
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    buffer.writeDateTime(offsetDate);
    buffer.writeInt32(offsetId);
    buffer.writeObject(offsetPeer);
    buffer.writeInt32(limit);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Get History.
///
/// ID: `4423e6c5`.
class MessagesGetHistory extends TlMethod<MessagesMessagesBase> {
  /// Messages Get History constructor.
  const MessagesGetHistory({
    required this.peer,
    required this.offsetId,
    required this.offsetDate,
    required this.addOffset,
    required this.limit,
    required this.maxId,
    required this.minId,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetHistory.deserialize(BinaryReader reader) {
    // Read [MessagesGetHistory] fields.
    final peer = reader.readObject() as InputPeerBase;
    final offsetId = reader.readInt32();
    final offsetDate = reader.readDateTime();
    final addOffset = reader.readInt32();
    final limit = reader.readInt32();
    final maxId = reader.readInt32();
    final minId = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [MessagesGetHistory] object.
    final returnValue = MessagesGetHistory(
      peer: peer,
      offsetId: offsetId,
      offsetDate: offsetDate,
      addOffset: addOffset,
      limit: limit,
      maxId: maxId,
      minId: minId,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetHistory].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Offset Date.
  final DateTime offsetDate;

  /// Add Offset.
  ///
  /// Field type is Int32.
  final int addOffset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Min Id.
  ///
  /// Field type is Int32.
  final int minId;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4423e6c5.
    buffer.writeInt32(0x4423e6c5);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(offsetId);
    buffer.writeDateTime(offsetDate);
    buffer.writeInt32(addOffset);
    buffer.writeInt32(limit);
    buffer.writeInt32(maxId);
    buffer.writeInt32(minId);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Search.
///
/// ID: `a7b4e929`.
class MessagesSearch extends TlMethod<MessagesMessagesBase> {
  /// Messages Search constructor.
  const MessagesSearch({
    required this.peer,
    required this.q,
    this.fromId,
    this.savedPeerId,
    this.topMsgId,
    required this.filter,
    required this.minDate,
    required this.maxDate,
    required this.offsetId,
    required this.addOffset,
    required this.limit,
    required this.maxId,
    required this.minId,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesSearch.deserialize(BinaryReader reader) {
    // Read [MessagesSearch] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final q = reader.readString();
    final hasFromIdField = (flags & 1) != 0;
    final fromId = hasFromIdField ? reader.readObject() as InputPeerBase : null;
    final hasSavedPeerIdField = (flags & 4) != 0;
    final savedPeerId =
        hasSavedPeerIdField ? reader.readObject() as InputPeerBase : null;
    final hasTopMsgIdField = (flags & 2) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final filter = reader.readObject() as MessagesFilterBase;
    final minDate = reader.readDateTime();
    final maxDate = reader.readDateTime();
    final offsetId = reader.readInt32();
    final addOffset = reader.readInt32();
    final limit = reader.readInt32();
    final maxId = reader.readInt32();
    final minId = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [MessagesSearch] object.
    final returnValue = MessagesSearch(
      peer: peer,
      q: q,
      fromId: fromId,
      savedPeerId: savedPeerId,
      topMsgId: topMsgId,
      filter: filter,
      minDate: minDate,
      maxDate: maxDate,
      offsetId: offsetId,
      addOffset: addOffset,
      limit: limit,
      maxId: maxId,
      minId: minId,
      hash: hash,
    );

    // Now return the deserialized [MessagesSearch].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: fromId != null,
      b02: savedPeerId != null,
      b01: topMsgId != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Q.
  final String q;

  /// From Id.
  final InputPeerBase? fromId;

  /// Saved Peer Id.
  final InputPeerBase? savedPeerId;

  /// Top Msg Id.
  final int? topMsgId;

  /// Filter.
  final MessagesFilterBase filter;

  /// Min Date.
  final DateTime minDate;

  /// Max Date.
  final DateTime maxDate;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Add Offset.
  ///
  /// Field type is Int32.
  final int addOffset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Min Id.
  ///
  /// Field type is Int32.
  final int minId;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa7b4e929.
    buffer.writeInt32(0xa7b4e929);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeString(q);
    final localFromIdCopy = fromId;
    if (localFromIdCopy != null) {
      buffer.writeObject(localFromIdCopy);
    }
    final localSavedPeerIdCopy = savedPeerId;
    if (localSavedPeerIdCopy != null) {
      buffer.writeObject(localSavedPeerIdCopy);
    }
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    buffer.writeObject(filter);
    buffer.writeDateTime(minDate);
    buffer.writeDateTime(maxDate);
    buffer.writeInt32(offsetId);
    buffer.writeInt32(addOffset);
    buffer.writeInt32(limit);
    buffer.writeInt32(maxId);
    buffer.writeInt32(minId);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Read History.
///
/// ID: `0e306d3a`.
class MessagesReadHistory extends TlMethod<MessagesAffectedMessagesBase> {
  /// Messages Read History constructor.
  const MessagesReadHistory({
    required this.peer,
    required this.maxId,
  }) : super._();

  /// Deserialize.
  factory MessagesReadHistory.deserialize(BinaryReader reader) {
    // Read [MessagesReadHistory] fields.
    final peer = reader.readObject() as InputPeerBase;
    final maxId = reader.readInt32();

    // Construct [MessagesReadHistory] object.
    final returnValue = MessagesReadHistory(
      peer: peer,
      maxId: maxId,
    );

    // Now return the deserialized [MessagesReadHistory].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0e306d3a.
    buffer.writeInt32(0x0e306d3a);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(maxId);

    // Finished serialization.
  }
}

/// Messages Delete History.
///
/// ID: `b08f922a`.
class MessagesDeleteHistory extends TlMethod<MessagesAffectedHistoryBase> {
  /// Messages Delete History constructor.
  const MessagesDeleteHistory({
    required this.justClear,
    required this.revoke,
    required this.peer,
    required this.maxId,
    this.minDate,
    this.maxDate,
  }) : super._();

  /// Deserialize.
  factory MessagesDeleteHistory.deserialize(BinaryReader reader) {
    // Read [MessagesDeleteHistory] fields.
    final flags = reader.readInt32();
    final justClear = (flags & 1) != 0;
    final revoke = (flags & 2) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final maxId = reader.readInt32();
    final hasMinDateField = (flags & 4) != 0;
    final minDate = hasMinDateField ? reader.readDateTime() : null;
    final hasMaxDateField = (flags & 8) != 0;
    final maxDate = hasMaxDateField ? reader.readDateTime() : null;

    // Construct [MessagesDeleteHistory] object.
    final returnValue = MessagesDeleteHistory(
      justClear: justClear,
      revoke: revoke,
      peer: peer,
      maxId: maxId,
      minDate: minDate,
      maxDate: maxDate,
    );

    // Now return the deserialized [MessagesDeleteHistory].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: justClear,
      b01: revoke,
      b02: minDate != null,
      b03: maxDate != null,
    );

    return v;
  }

  /// just_clear: bit 0 of flags.0?true
  final bool justClear;

  /// revoke: bit 1 of flags.1?true
  final bool revoke;

  /// Peer.
  final InputPeerBase peer;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Min Date.
  final DateTime? minDate;

  /// Max Date.
  final DateTime? maxDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb08f922a.
    buffer.writeInt32(0xb08f922a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(maxId);
    final localMinDateCopy = minDate;
    if (localMinDateCopy != null) {
      buffer.writeDateTime(localMinDateCopy);
    }
    final localMaxDateCopy = maxDate;
    if (localMaxDateCopy != null) {
      buffer.writeDateTime(localMaxDateCopy);
    }

    // Finished serialization.
  }
}

/// Messages Delete Messages.
///
/// ID: `e58e95d2`.
class MessagesDeleteMessages extends TlMethod<MessagesAffectedMessagesBase> {
  /// Messages Delete Messages constructor.
  const MessagesDeleteMessages({
    required this.revoke,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesDeleteMessages.deserialize(BinaryReader reader) {
    // Read [MessagesDeleteMessages] fields.
    final flags = reader.readInt32();
    final revoke = (flags & 1) != 0;
    final id = reader.readVectorInt32();

    // Construct [MessagesDeleteMessages] object.
    final returnValue = MessagesDeleteMessages(
      revoke: revoke,
      id: id,
    );

    // Now return the deserialized [MessagesDeleteMessages].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: revoke,
    );

    return v;
  }

  /// revoke: bit 0 of flags.0?true
  final bool revoke;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe58e95d2.
    buffer.writeInt32(0xe58e95d2);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Messages Received Messages.
///
/// ID: `05a954c0`.
class MessagesReceivedMessages
    extends TlMethod<List<ReceivedNotifyMessageBase>> {
  /// Messages Received Messages constructor.
  const MessagesReceivedMessages({
    required this.maxId,
  }) : super._();

  /// Deserialize.
  factory MessagesReceivedMessages.deserialize(BinaryReader reader) {
    // Read [MessagesReceivedMessages] fields.
    final maxId = reader.readInt32();

    // Construct [MessagesReceivedMessages] object.
    final returnValue = MessagesReceivedMessages(
      maxId: maxId,
    );

    // Now return the deserialized [MessagesReceivedMessages].
    return returnValue;
  }

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x05a954c0.
    buffer.writeInt32(0x05a954c0);

    // Write fields.
    buffer.writeInt32(maxId);

    // Finished serialization.
  }
}

/// Messages Set Typing.
///
/// ID: `58943ee2`.
class MessagesSetTyping extends TlMethod<bool> {
  /// Messages Set Typing constructor.
  const MessagesSetTyping({
    required this.peer,
    this.topMsgId,
    required this.action,
  }) : super._();

  /// Deserialize.
  factory MessagesSetTyping.deserialize(BinaryReader reader) {
    // Read [MessagesSetTyping] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final action = reader.readObject() as SendMessageActionBase;

    // Construct [MessagesSetTyping] object.
    final returnValue = MessagesSetTyping(
      peer: peer,
      topMsgId: topMsgId,
      action: action,
    );

    // Now return the deserialized [MessagesSetTyping].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Top Msg Id.
  final int? topMsgId;

  /// Action.
  final SendMessageActionBase action;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x58943ee2.
    buffer.writeInt32(0x58943ee2);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    buffer.writeObject(action);

    // Finished serialization.
  }
}

/// Messages Send Message.
///
/// ID: `280d096f`.
class MessagesSendMessage extends TlMethod<UpdatesBase> {
  /// Messages Send Message constructor.
  const MessagesSendMessage({
    required this.noWebpage,
    required this.silent,
    required this.background,
    required this.clearDraft,
    required this.noforwards,
    required this.updateStickersetsOrder,
    required this.invertMedia,
    required this.peer,
    this.replyTo,
    required this.message,
    required this.randomId,
    this.replyMarkup,
    this.entities,
    this.scheduleDate,
    this.sendAs,
  }) : super._();

  /// Deserialize.
  factory MessagesSendMessage.deserialize(BinaryReader reader) {
    // Read [MessagesSendMessage] fields.
    final flags = reader.readInt32();
    final noWebpage = (flags & 2) != 0;
    final silent = (flags & 32) != 0;
    final background = (flags & 64) != 0;
    final clearDraft = (flags & 128) != 0;
    final noforwards = (flags & 16384) != 0;
    final updateStickersetsOrder = (flags & 32768) != 0;
    final invertMedia = (flags & 65536) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final hasReplyToField = (flags & 1) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as InputReplyToBase : null;
    final message = reader.readString();
    final randomId = reader.readInt64();
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;
    final hasEntitiesField = (flags & 8) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasScheduleDateField = (flags & 1024) != 0;
    final scheduleDate = hasScheduleDateField ? reader.readDateTime() : null;
    final hasSendAsField = (flags & 8192) != 0;
    final sendAs = hasSendAsField ? reader.readObject() as InputPeerBase : null;

    // Construct [MessagesSendMessage] object.
    final returnValue = MessagesSendMessage(
      noWebpage: noWebpage,
      silent: silent,
      background: background,
      clearDraft: clearDraft,
      noforwards: noforwards,
      updateStickersetsOrder: updateStickersetsOrder,
      invertMedia: invertMedia,
      peer: peer,
      replyTo: replyTo,
      message: message,
      randomId: randomId,
      replyMarkup: replyMarkup,
      entities: entities,
      scheduleDate: scheduleDate,
      sendAs: sendAs,
    );

    // Now return the deserialized [MessagesSendMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: noWebpage,
      b05: silent,
      b06: background,
      b07: clearDraft,
      b14: noforwards,
      b15: updateStickersetsOrder,
      b16: invertMedia,
      b00: replyTo != null,
      b02: replyMarkup != null,
      b03: entities != null,
      b10: scheduleDate != null,
      b13: sendAs != null,
    );

    return v;
  }

  /// no_webpage: bit 1 of flags.1?true
  final bool noWebpage;

  /// silent: bit 5 of flags.5?true
  final bool silent;

  /// background: bit 6 of flags.6?true
  final bool background;

  /// clear_draft: bit 7 of flags.7?true
  final bool clearDraft;

  /// noforwards: bit 14 of flags.14?true
  final bool noforwards;

  /// update_stickersets_order: bit 15 of flags.15?true
  final bool updateStickersetsOrder;

  /// invert_media: bit 16 of flags.16?true
  final bool invertMedia;

  /// Peer.
  final InputPeerBase peer;

  /// Reply To.
  final InputReplyToBase? replyTo;

  /// Message.
  final String message;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Schedule Date.
  final DateTime? scheduleDate;

  /// Send As.
  final InputPeerBase? sendAs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x280d096f.
    buffer.writeInt32(0x280d096f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    buffer.writeString(message);
    buffer.writeInt64(randomId);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localScheduleDateCopy = scheduleDate;
    if (localScheduleDateCopy != null) {
      buffer.writeDateTime(localScheduleDateCopy);
    }
    final localSendAsCopy = sendAs;
    if (localSendAsCopy != null) {
      buffer.writeObject(localSendAsCopy);
    }

    // Finished serialization.
  }
}

/// Messages Send Media.
///
/// ID: `72ccc23d`.
class MessagesSendMedia extends TlMethod<UpdatesBase> {
  /// Messages Send Media constructor.
  const MessagesSendMedia({
    required this.silent,
    required this.background,
    required this.clearDraft,
    required this.noforwards,
    required this.updateStickersetsOrder,
    required this.invertMedia,
    required this.peer,
    this.replyTo,
    required this.media,
    required this.message,
    required this.randomId,
    this.replyMarkup,
    this.entities,
    this.scheduleDate,
    this.sendAs,
  }) : super._();

  /// Deserialize.
  factory MessagesSendMedia.deserialize(BinaryReader reader) {
    // Read [MessagesSendMedia] fields.
    final flags = reader.readInt32();
    final silent = (flags & 32) != 0;
    final background = (flags & 64) != 0;
    final clearDraft = (flags & 128) != 0;
    final noforwards = (flags & 16384) != 0;
    final updateStickersetsOrder = (flags & 32768) != 0;
    final invertMedia = (flags & 65536) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final hasReplyToField = (flags & 1) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as InputReplyToBase : null;
    final media = reader.readObject() as InputMediaBase;
    final message = reader.readString();
    final randomId = reader.readInt64();
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;
    final hasEntitiesField = (flags & 8) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasScheduleDateField = (flags & 1024) != 0;
    final scheduleDate = hasScheduleDateField ? reader.readDateTime() : null;
    final hasSendAsField = (flags & 8192) != 0;
    final sendAs = hasSendAsField ? reader.readObject() as InputPeerBase : null;

    // Construct [MessagesSendMedia] object.
    final returnValue = MessagesSendMedia(
      silent: silent,
      background: background,
      clearDraft: clearDraft,
      noforwards: noforwards,
      updateStickersetsOrder: updateStickersetsOrder,
      invertMedia: invertMedia,
      peer: peer,
      replyTo: replyTo,
      media: media,
      message: message,
      randomId: randomId,
      replyMarkup: replyMarkup,
      entities: entities,
      scheduleDate: scheduleDate,
      sendAs: sendAs,
    );

    // Now return the deserialized [MessagesSendMedia].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b05: silent,
      b06: background,
      b07: clearDraft,
      b14: noforwards,
      b15: updateStickersetsOrder,
      b16: invertMedia,
      b00: replyTo != null,
      b02: replyMarkup != null,
      b03: entities != null,
      b10: scheduleDate != null,
      b13: sendAs != null,
    );

    return v;
  }

  /// silent: bit 5 of flags.5?true
  final bool silent;

  /// background: bit 6 of flags.6?true
  final bool background;

  /// clear_draft: bit 7 of flags.7?true
  final bool clearDraft;

  /// noforwards: bit 14 of flags.14?true
  final bool noforwards;

  /// update_stickersets_order: bit 15 of flags.15?true
  final bool updateStickersetsOrder;

  /// invert_media: bit 16 of flags.16?true
  final bool invertMedia;

  /// Peer.
  final InputPeerBase peer;

  /// Reply To.
  final InputReplyToBase? replyTo;

  /// Media.
  final InputMediaBase media;

  /// Message.
  final String message;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Schedule Date.
  final DateTime? scheduleDate;

  /// Send As.
  final InputPeerBase? sendAs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x72ccc23d.
    buffer.writeInt32(0x72ccc23d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    buffer.writeObject(media);
    buffer.writeString(message);
    buffer.writeInt64(randomId);
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localScheduleDateCopy = scheduleDate;
    if (localScheduleDateCopy != null) {
      buffer.writeDateTime(localScheduleDateCopy);
    }
    final localSendAsCopy = sendAs;
    if (localSendAsCopy != null) {
      buffer.writeObject(localSendAsCopy);
    }

    // Finished serialization.
  }
}

/// Messages Forward Messages.
///
/// ID: `c661bbc4`.
class MessagesForwardMessages extends TlMethod<UpdatesBase> {
  /// Messages Forward Messages constructor.
  const MessagesForwardMessages({
    required this.silent,
    required this.background,
    required this.withMyScore,
    required this.dropAuthor,
    required this.dropMediaCaptions,
    required this.noforwards,
    required this.fromPeer,
    required this.id,
    required this.randomId,
    required this.toPeer,
    this.topMsgId,
    this.scheduleDate,
    this.sendAs,
  }) : super._();

  /// Deserialize.
  factory MessagesForwardMessages.deserialize(BinaryReader reader) {
    // Read [MessagesForwardMessages] fields.
    final flags = reader.readInt32();
    final silent = (flags & 32) != 0;
    final background = (flags & 64) != 0;
    final withMyScore = (flags & 256) != 0;
    final dropAuthor = (flags & 2048) != 0;
    final dropMediaCaptions = (flags & 4096) != 0;
    final noforwards = (flags & 16384) != 0;
    final fromPeer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();
    final randomId = reader.readVectorInt64();
    final toPeer = reader.readObject() as InputPeerBase;
    final hasTopMsgIdField = (flags & 512) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final hasScheduleDateField = (flags & 1024) != 0;
    final scheduleDate = hasScheduleDateField ? reader.readDateTime() : null;
    final hasSendAsField = (flags & 8192) != 0;
    final sendAs = hasSendAsField ? reader.readObject() as InputPeerBase : null;

    // Construct [MessagesForwardMessages] object.
    final returnValue = MessagesForwardMessages(
      silent: silent,
      background: background,
      withMyScore: withMyScore,
      dropAuthor: dropAuthor,
      dropMediaCaptions: dropMediaCaptions,
      noforwards: noforwards,
      fromPeer: fromPeer,
      id: id,
      randomId: randomId,
      toPeer: toPeer,
      topMsgId: topMsgId,
      scheduleDate: scheduleDate,
      sendAs: sendAs,
    );

    // Now return the deserialized [MessagesForwardMessages].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b05: silent,
      b06: background,
      b08: withMyScore,
      b11: dropAuthor,
      b12: dropMediaCaptions,
      b14: noforwards,
      b09: topMsgId != null,
      b10: scheduleDate != null,
      b13: sendAs != null,
    );

    return v;
  }

  /// silent: bit 5 of flags.5?true
  final bool silent;

  /// background: bit 6 of flags.6?true
  final bool background;

  /// with_my_score: bit 8 of flags.8?true
  final bool withMyScore;

  /// drop_author: bit 11 of flags.11?true
  final bool dropAuthor;

  /// drop_media_captions: bit 12 of flags.12?true
  final bool dropMediaCaptions;

  /// noforwards: bit 14 of flags.14?true
  final bool noforwards;

  /// From Peer.
  final InputPeerBase fromPeer;

  /// Id.
  final List<int> id;

  /// Random Id.
  final List<int> randomId;

  /// To Peer.
  final InputPeerBase toPeer;

  /// Top Msg Id.
  final int? topMsgId;

  /// Schedule Date.
  final DateTime? scheduleDate;

  /// Send As.
  final InputPeerBase? sendAs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc661bbc4.
    buffer.writeInt32(0xc661bbc4);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(fromPeer);
    buffer.writeVectorInt32(id);
    buffer.writeVectorInt64(randomId);
    buffer.writeObject(toPeer);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    final localScheduleDateCopy = scheduleDate;
    if (localScheduleDateCopy != null) {
      buffer.writeDateTime(localScheduleDateCopy);
    }
    final localSendAsCopy = sendAs;
    if (localSendAsCopy != null) {
      buffer.writeObject(localSendAsCopy);
    }

    // Finished serialization.
  }
}

/// Messages Report Spam.
///
/// ID: `cf1592db`.
class MessagesReportSpam extends TlMethod<bool> {
  /// Messages Report Spam constructor.
  const MessagesReportSpam({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesReportSpam.deserialize(BinaryReader reader) {
    // Read [MessagesReportSpam] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [MessagesReportSpam] object.
    final returnValue = MessagesReportSpam(
      peer: peer,
    );

    // Now return the deserialized [MessagesReportSpam].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcf1592db.
    buffer.writeInt32(0xcf1592db);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Messages Get Peer Settings.
///
/// ID: `efd9a6a2`.
class MessagesGetPeerSettings extends TlMethod<MessagesPeerSettingsBase> {
  /// Messages Get Peer Settings constructor.
  const MessagesGetPeerSettings({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesGetPeerSettings.deserialize(BinaryReader reader) {
    // Read [MessagesGetPeerSettings] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [MessagesGetPeerSettings] object.
    final returnValue = MessagesGetPeerSettings(
      peer: peer,
    );

    // Now return the deserialized [MessagesGetPeerSettings].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xefd9a6a2.
    buffer.writeInt32(0xefd9a6a2);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Messages Report.
///
/// ID: `8953ab4e`.
class MessagesReport extends TlMethod<bool> {
  /// Messages Report constructor.
  const MessagesReport({
    required this.peer,
    required this.id,
    required this.reason,
    required this.message,
  }) : super._();

  /// Deserialize.
  factory MessagesReport.deserialize(BinaryReader reader) {
    // Read [MessagesReport] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();
    final reason = reader.readObject() as ReportReasonBase;
    final message = reader.readString();

    // Construct [MessagesReport] object.
    final returnValue = MessagesReport(
      peer: peer,
      id: id,
      reason: reason,
      message: message,
    );

    // Now return the deserialized [MessagesReport].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Reason.
  final ReportReasonBase reason;

  /// Message.
  final String message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8953ab4e.
    buffer.writeInt32(0x8953ab4e);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);
    buffer.writeObject(reason);
    buffer.writeString(message);

    // Finished serialization.
  }
}

/// Messages Get Chats.
///
/// ID: `49e9528f`.
class MessagesGetChats extends TlMethod<MessagesChatsBase> {
  /// Messages Get Chats constructor.
  const MessagesGetChats({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesGetChats.deserialize(BinaryReader reader) {
    // Read [MessagesGetChats] fields.
    final id = reader.readVectorInt64();

    // Construct [MessagesGetChats] object.
    final returnValue = MessagesGetChats(
      id: id,
    );

    // Now return the deserialized [MessagesGetChats].
    return returnValue;
  }

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x49e9528f.
    buffer.writeInt32(0x49e9528f);

    // Write fields.
    buffer.writeVectorInt64(id);

    // Finished serialization.
  }
}

/// Messages Get Full Chat.
///
/// ID: `aeb00b34`.
class MessagesGetFullChat extends TlMethod<MessagesChatFullBase> {
  /// Messages Get Full Chat constructor.
  const MessagesGetFullChat({
    required this.chatId,
  }) : super._();

  /// Deserialize.
  factory MessagesGetFullChat.deserialize(BinaryReader reader) {
    // Read [MessagesGetFullChat] fields.
    final chatId = reader.readInt64();

    // Construct [MessagesGetFullChat] object.
    final returnValue = MessagesGetFullChat(
      chatId: chatId,
    );

    // Now return the deserialized [MessagesGetFullChat].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaeb00b34.
    buffer.writeInt32(0xaeb00b34);

    // Write fields.
    buffer.writeInt64(chatId);

    // Finished serialization.
  }
}

/// Messages Edit Chat Title.
///
/// ID: `73783ffd`.
class MessagesEditChatTitle extends TlMethod<UpdatesBase> {
  /// Messages Edit Chat Title constructor.
  const MessagesEditChatTitle({
    required this.chatId,
    required this.title,
  }) : super._();

  /// Deserialize.
  factory MessagesEditChatTitle.deserialize(BinaryReader reader) {
    // Read [MessagesEditChatTitle] fields.
    final chatId = reader.readInt64();
    final title = reader.readString();

    // Construct [MessagesEditChatTitle] object.
    final returnValue = MessagesEditChatTitle(
      chatId: chatId,
      title: title,
    );

    // Now return the deserialized [MessagesEditChatTitle].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Title.
  final String title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x73783ffd.
    buffer.writeInt32(0x73783ffd);

    // Write fields.
    buffer.writeInt64(chatId);
    buffer.writeString(title);

    // Finished serialization.
  }
}

/// Messages Edit Chat Photo.
///
/// ID: `35ddd674`.
class MessagesEditChatPhoto extends TlMethod<UpdatesBase> {
  /// Messages Edit Chat Photo constructor.
  const MessagesEditChatPhoto({
    required this.chatId,
    required this.photo,
  }) : super._();

  /// Deserialize.
  factory MessagesEditChatPhoto.deserialize(BinaryReader reader) {
    // Read [MessagesEditChatPhoto] fields.
    final chatId = reader.readInt64();
    final photo = reader.readObject() as InputChatPhotoBase;

    // Construct [MessagesEditChatPhoto] object.
    final returnValue = MessagesEditChatPhoto(
      chatId: chatId,
      photo: photo,
    );

    // Now return the deserialized [MessagesEditChatPhoto].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Photo.
  final InputChatPhotoBase photo;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x35ddd674.
    buffer.writeInt32(0x35ddd674);

    // Write fields.
    buffer.writeInt64(chatId);
    buffer.writeObject(photo);

    // Finished serialization.
  }
}

/// Messages Add Chat User.
///
/// ID: `f24753e3`.
class MessagesAddChatUser extends TlMethod<UpdatesBase> {
  /// Messages Add Chat User constructor.
  const MessagesAddChatUser({
    required this.chatId,
    required this.userId,
    required this.fwdLimit,
  }) : super._();

  /// Deserialize.
  factory MessagesAddChatUser.deserialize(BinaryReader reader) {
    // Read [MessagesAddChatUser] fields.
    final chatId = reader.readInt64();
    final userId = reader.readObject() as InputUserBase;
    final fwdLimit = reader.readInt32();

    // Construct [MessagesAddChatUser] object.
    final returnValue = MessagesAddChatUser(
      chatId: chatId,
      userId: userId,
      fwdLimit: fwdLimit,
    );

    // Now return the deserialized [MessagesAddChatUser].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// User Id.
  final InputUserBase userId;

  /// Fwd Limit.
  ///
  /// Field type is Int32.
  final int fwdLimit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf24753e3.
    buffer.writeInt32(0xf24753e3);

    // Write fields.
    buffer.writeInt64(chatId);
    buffer.writeObject(userId);
    buffer.writeInt32(fwdLimit);

    // Finished serialization.
  }
}

/// Messages Delete Chat User.
///
/// ID: `a2185cab`.
class MessagesDeleteChatUser extends TlMethod<UpdatesBase> {
  /// Messages Delete Chat User constructor.
  const MessagesDeleteChatUser({
    required this.revokeHistory,
    required this.chatId,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory MessagesDeleteChatUser.deserialize(BinaryReader reader) {
    // Read [MessagesDeleteChatUser] fields.
    final flags = reader.readInt32();
    final revokeHistory = (flags & 1) != 0;
    final chatId = reader.readInt64();
    final userId = reader.readObject() as InputUserBase;

    // Construct [MessagesDeleteChatUser] object.
    final returnValue = MessagesDeleteChatUser(
      revokeHistory: revokeHistory,
      chatId: chatId,
      userId: userId,
    );

    // Now return the deserialized [MessagesDeleteChatUser].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: revokeHistory,
    );

    return v;
  }

  /// revoke_history: bit 0 of flags.0?true
  final bool revokeHistory;

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// User Id.
  final InputUserBase userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa2185cab.
    buffer.writeInt32(0xa2185cab);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(chatId);
    buffer.writeObject(userId);

    // Finished serialization.
  }
}

/// Messages Create Chat.
///
/// ID: `0034a818`.
class MessagesCreateChat extends TlMethod<UpdatesBase> {
  /// Messages Create Chat constructor.
  const MessagesCreateChat({
    required this.users,
    required this.title,
    this.ttlPeriod,
  }) : super._();

  /// Deserialize.
  factory MessagesCreateChat.deserialize(BinaryReader reader) {
    // Read [MessagesCreateChat] fields.
    final flags = reader.readInt32();
    final users = reader.readVectorObject<InputUserBase>();
    final title = reader.readString();
    final hasTtlPeriodField = (flags & 1) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;

    // Construct [MessagesCreateChat] object.
    final returnValue = MessagesCreateChat(
      users: users,
      title: title,
      ttlPeriod: ttlPeriod,
    );

    // Now return the deserialized [MessagesCreateChat].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: ttlPeriod != null,
    );

    return v;
  }

  /// Users.
  final List<InputUserBase> users;

  /// Title.
  final String title;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0034a818.
    buffer.writeInt32(0x0034a818);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(users);
    buffer.writeString(title);
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }

    // Finished serialization.
  }
}

/// Updates Get State.
///
/// ID: `edd4882a`.
class UpdatesGetState extends TlMethod<UpdatesStateBase> {
  /// Updates Get State constructor.
  const UpdatesGetState() : super._();

  /// Deserialize.
  factory UpdatesGetState.deserialize(BinaryReader reader) {
    // Construct [UpdatesGetState] object.
    final returnValue = UpdatesGetState();

    // Now return the deserialized [UpdatesGetState].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xedd4882a.
    buffer.writeInt32(0xedd4882a);

    // Finished serialization.
  }
}

/// Updates Get Difference.
///
/// ID: `19c2f763`.
class UpdatesGetDifference extends TlMethod<UpdatesDifferenceBase> {
  /// Updates Get Difference constructor.
  const UpdatesGetDifference({
    required this.pts,
    this.ptsLimit,
    this.ptsTotalLimit,
    required this.date,
    required this.qts,
    this.qtsLimit,
  }) : super._();

  /// Deserialize.
  factory UpdatesGetDifference.deserialize(BinaryReader reader) {
    // Read [UpdatesGetDifference] fields.
    final flags = reader.readInt32();
    final pts = reader.readInt32();
    final hasPtsLimitField = (flags & 2) != 0;
    final ptsLimit = hasPtsLimitField ? reader.readInt32() : null;
    final hasPtsTotalLimitField = (flags & 1) != 0;
    final ptsTotalLimit = hasPtsTotalLimitField ? reader.readInt32() : null;
    final date = reader.readDateTime();
    final qts = reader.readInt32();
    final hasQtsLimitField = (flags & 4) != 0;
    final qtsLimit = hasQtsLimitField ? reader.readInt32() : null;

    // Construct [UpdatesGetDifference] object.
    final returnValue = UpdatesGetDifference(
      pts: pts,
      ptsLimit: ptsLimit,
      ptsTotalLimit: ptsTotalLimit,
      date: date,
      qts: qts,
      qtsLimit: qtsLimit,
    );

    // Now return the deserialized [UpdatesGetDifference].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: ptsLimit != null,
      b00: ptsTotalLimit != null,
      b02: qtsLimit != null,
    );

    return v;
  }

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Pts Limit.
  final int? ptsLimit;

  /// Pts Total Limit.
  final int? ptsTotalLimit;

  /// Date.
  final DateTime date;

  /// Qts.
  ///
  /// Field type is Int32.
  final int qts;

  /// Qts Limit.
  final int? qtsLimit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x19c2f763.
    buffer.writeInt32(0x19c2f763);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(pts);
    final localPtsLimitCopy = ptsLimit;
    if (localPtsLimitCopy != null) {
      buffer.writeInt32(localPtsLimitCopy);
    }
    final localPtsTotalLimitCopy = ptsTotalLimit;
    if (localPtsTotalLimitCopy != null) {
      buffer.writeInt32(localPtsTotalLimitCopy);
    }
    buffer.writeDateTime(date);
    buffer.writeInt32(qts);
    final localQtsLimitCopy = qtsLimit;
    if (localQtsLimitCopy != null) {
      buffer.writeInt32(localQtsLimitCopy);
    }

    // Finished serialization.
  }
}

/// Photos Update Profile Photo.
///
/// ID: `09e82039`.
class PhotosUpdateProfilePhoto extends TlMethod<PhotosPhotoBase> {
  /// Photos Update Profile Photo constructor.
  const PhotosUpdateProfilePhoto({
    required this.fallback,
    this.bot,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory PhotosUpdateProfilePhoto.deserialize(BinaryReader reader) {
    // Read [PhotosUpdateProfilePhoto] fields.
    final flags = reader.readInt32();
    final fallback = (flags & 1) != 0;
    final hasBotField = (flags & 2) != 0;
    final bot = hasBotField ? reader.readObject() as InputUserBase : null;
    final id = reader.readObject() as InputPhotoBase;

    // Construct [PhotosUpdateProfilePhoto] object.
    final returnValue = PhotosUpdateProfilePhoto(
      fallback: fallback,
      bot: bot,
      id: id,
    );

    // Now return the deserialized [PhotosUpdateProfilePhoto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: fallback,
      b01: bot != null,
    );

    return v;
  }

  /// fallback: bit 0 of flags.0?true
  final bool fallback;

  /// Bot.
  final InputUserBase? bot;

  /// Id.
  final InputPhotoBase id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x09e82039.
    buffer.writeInt32(0x09e82039);

    // Write fields.
    buffer.writeInt32(flags);
    final localBotCopy = bot;
    if (localBotCopy != null) {
      buffer.writeObject(localBotCopy);
    }
    buffer.writeObject(id);

    // Finished serialization.
  }
}

/// Photos Upload Profile Photo.
///
/// ID: `0388a3b5`.
class PhotosUploadProfilePhoto extends TlMethod<PhotosPhotoBase> {
  /// Photos Upload Profile Photo constructor.
  const PhotosUploadProfilePhoto({
    required this.fallback,
    this.bot,
    this.file,
    this.video,
    this.videoStartTs,
    this.videoEmojiMarkup,
  }) : super._();

  /// Deserialize.
  factory PhotosUploadProfilePhoto.deserialize(BinaryReader reader) {
    // Read [PhotosUploadProfilePhoto] fields.
    final flags = reader.readInt32();
    final fallback = (flags & 8) != 0;
    final hasBotField = (flags & 32) != 0;
    final bot = hasBotField ? reader.readObject() as InputUserBase : null;
    final hasFileField = (flags & 1) != 0;
    final file = hasFileField ? reader.readObject() as InputFileBase : null;
    final hasVideoField = (flags & 2) != 0;
    final video = hasVideoField ? reader.readObject() as InputFileBase : null;
    final hasVideoStartTsField = (flags & 4) != 0;
    final videoStartTs = hasVideoStartTsField ? reader.readFloat64() : null;
    final hasVideoEmojiMarkupField = (flags & 16) != 0;
    final videoEmojiMarkup =
        hasVideoEmojiMarkupField ? reader.readObject() as VideoSizeBase : null;

    // Construct [PhotosUploadProfilePhoto] object.
    final returnValue = PhotosUploadProfilePhoto(
      fallback: fallback,
      bot: bot,
      file: file,
      video: video,
      videoStartTs: videoStartTs,
      videoEmojiMarkup: videoEmojiMarkup,
    );

    // Now return the deserialized [PhotosUploadProfilePhoto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: fallback,
      b05: bot != null,
      b00: file != null,
      b01: video != null,
      b02: videoStartTs != null,
      b04: videoEmojiMarkup != null,
    );

    return v;
  }

  /// fallback: bit 3 of flags.3?true
  final bool fallback;

  /// Bot.
  final InputUserBase? bot;

  /// File.
  final InputFileBase? file;

  /// Video.
  final InputFileBase? video;

  /// Video Start Ts.
  final double? videoStartTs;

  /// Video Emoji Markup.
  final VideoSizeBase? videoEmojiMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0388a3b5.
    buffer.writeInt32(0x0388a3b5);

    // Write fields.
    buffer.writeInt32(flags);
    final localBotCopy = bot;
    if (localBotCopy != null) {
      buffer.writeObject(localBotCopy);
    }
    final localFileCopy = file;
    if (localFileCopy != null) {
      buffer.writeObject(localFileCopy);
    }
    final localVideoCopy = video;
    if (localVideoCopy != null) {
      buffer.writeObject(localVideoCopy);
    }
    final localVideoStartTsCopy = videoStartTs;
    if (localVideoStartTsCopy != null) {
      buffer.writeDouble(localVideoStartTsCopy);
    }
    final localVideoEmojiMarkupCopy = videoEmojiMarkup;
    if (localVideoEmojiMarkupCopy != null) {
      buffer.writeObject(localVideoEmojiMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Photos Delete Photos.
///
/// ID: `87cf7f2f`.
class PhotosDeletePhotos extends TlMethod<List<int>> {
  /// Photos Delete Photos constructor.
  const PhotosDeletePhotos({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory PhotosDeletePhotos.deserialize(BinaryReader reader) {
    // Read [PhotosDeletePhotos] fields.
    final id = reader.readVectorObject<InputPhotoBase>();

    // Construct [PhotosDeletePhotos] object.
    final returnValue = PhotosDeletePhotos(
      id: id,
    );

    // Now return the deserialized [PhotosDeletePhotos].
    return returnValue;
  }

  /// Id.
  final List<InputPhotoBase> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x87cf7f2f.
    buffer.writeInt32(0x87cf7f2f);

    // Write fields.
    buffer.writeVectorObject(id);

    // Finished serialization.
  }
}

/// Upload Save File Part.
///
/// ID: `b304a621`.
class UploadSaveFilePart extends TlMethod<bool> {
  /// Upload Save File Part constructor.
  const UploadSaveFilePart({
    required this.fileId,
    required this.filePart,
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory UploadSaveFilePart.deserialize(BinaryReader reader) {
    // Read [UploadSaveFilePart] fields.
    final fileId = reader.readInt64();
    final filePart = reader.readInt32();
    final bytes = reader.readBytes();

    // Construct [UploadSaveFilePart] object.
    final returnValue = UploadSaveFilePart(
      fileId: fileId,
      filePart: filePart,
      bytes: bytes,
    );

    // Now return the deserialized [UploadSaveFilePart].
    return returnValue;
  }

  /// File Id.
  ///
  /// Field type is Int64.
  final int fileId;

  /// File Part.
  ///
  /// Field type is Int32.
  final int filePart;

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb304a621.
    buffer.writeInt32(0xb304a621);

    // Write fields.
    buffer.writeInt64(fileId);
    buffer.writeInt32(filePart);
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Upload Get File.
///
/// ID: `be5335be`.
class UploadGetFile extends TlMethod<UploadFileBase> {
  /// Upload Get File constructor.
  const UploadGetFile({
    required this.precise,
    required this.cdnSupported,
    required this.location,
    required this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory UploadGetFile.deserialize(BinaryReader reader) {
    // Read [UploadGetFile] fields.
    final flags = reader.readInt32();
    final precise = (flags & 1) != 0;
    final cdnSupported = (flags & 2) != 0;
    final location = reader.readObject() as InputFileLocationBase;
    final offset = reader.readInt64();
    final limit = reader.readInt32();

    // Construct [UploadGetFile] object.
    final returnValue = UploadGetFile(
      precise: precise,
      cdnSupported: cdnSupported,
      location: location,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [UploadGetFile].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: precise,
      b01: cdnSupported,
    );

    return v;
  }

  /// precise: bit 0 of flags.0?true
  final bool precise;

  /// cdn_supported: bit 1 of flags.1?true
  final bool cdnSupported;

  /// Location.
  final InputFileLocationBase location;

  /// Offset.
  ///
  /// Field type is Int64.
  final int offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbe5335be.
    buffer.writeInt32(0xbe5335be);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(location);
    buffer.writeInt64(offset);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Help Get Config.
///
/// ID: `c4f9186b`.
class HelpGetConfig extends TlMethod<ConfigBase> {
  /// Help Get Config constructor.
  const HelpGetConfig() : super._();

  /// Deserialize.
  factory HelpGetConfig.deserialize(BinaryReader reader) {
    // Construct [HelpGetConfig] object.
    final returnValue = HelpGetConfig();

    // Now return the deserialized [HelpGetConfig].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc4f9186b.
    buffer.writeInt32(0xc4f9186b);

    // Finished serialization.
  }
}

/// Help Get Nearest Dc.
///
/// ID: `1fb33026`.
class HelpGetNearestDc extends TlMethod<NearestDcBase> {
  /// Help Get Nearest Dc constructor.
  const HelpGetNearestDc() : super._();

  /// Deserialize.
  factory HelpGetNearestDc.deserialize(BinaryReader reader) {
    // Construct [HelpGetNearestDc] object.
    final returnValue = HelpGetNearestDc();

    // Now return the deserialized [HelpGetNearestDc].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1fb33026.
    buffer.writeInt32(0x1fb33026);

    // Finished serialization.
  }
}

/// Help Get App Update.
///
/// ID: `522d5a7d`.
class HelpGetAppUpdate extends TlMethod<HelpAppUpdateBase> {
  /// Help Get App Update constructor.
  const HelpGetAppUpdate({
    required this.source,
  }) : super._();

  /// Deserialize.
  factory HelpGetAppUpdate.deserialize(BinaryReader reader) {
    // Read [HelpGetAppUpdate] fields.
    final source = reader.readString();

    // Construct [HelpGetAppUpdate] object.
    final returnValue = HelpGetAppUpdate(
      source: source,
    );

    // Now return the deserialized [HelpGetAppUpdate].
    return returnValue;
  }

  /// Source.
  final String source;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x522d5a7d.
    buffer.writeInt32(0x522d5a7d);

    // Write fields.
    buffer.writeString(source);

    // Finished serialization.
  }
}

/// Help Get Invite Text.
///
/// ID: `4d392343`.
class HelpGetInviteText extends TlMethod<HelpInviteTextBase> {
  /// Help Get Invite Text constructor.
  const HelpGetInviteText() : super._();

  /// Deserialize.
  factory HelpGetInviteText.deserialize(BinaryReader reader) {
    // Construct [HelpGetInviteText] object.
    final returnValue = HelpGetInviteText();

    // Now return the deserialized [HelpGetInviteText].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4d392343.
    buffer.writeInt32(0x4d392343);

    // Finished serialization.
  }
}

/// Photos Get User Photos.
///
/// ID: `91cd32a8`.
class PhotosGetUserPhotos extends TlMethod<PhotosPhotosBase> {
  /// Photos Get User Photos constructor.
  const PhotosGetUserPhotos({
    required this.userId,
    required this.offset,
    required this.maxId,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory PhotosGetUserPhotos.deserialize(BinaryReader reader) {
    // Read [PhotosGetUserPhotos] fields.
    final userId = reader.readObject() as InputUserBase;
    final offset = reader.readInt32();
    final maxId = reader.readInt64();
    final limit = reader.readInt32();

    // Construct [PhotosGetUserPhotos] object.
    final returnValue = PhotosGetUserPhotos(
      userId: userId,
      offset: offset,
      maxId: maxId,
      limit: limit,
    );

    // Now return the deserialized [PhotosGetUserPhotos].
    return returnValue;
  }

  /// User Id.
  final InputUserBase userId;

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Max Id.
  ///
  /// Field type is Int64.
  final int maxId;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x91cd32a8.
    buffer.writeInt32(0x91cd32a8);

    // Write fields.
    buffer.writeObject(userId);
    buffer.writeInt32(offset);
    buffer.writeInt64(maxId);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Messages Get Dh Config.
///
/// ID: `26cf8950`.
class MessagesGetDhConfig extends TlMethod<MessagesDhConfigBase> {
  /// Messages Get Dh Config constructor.
  const MessagesGetDhConfig({
    required this.version,
    required this.randomLength,
  }) : super._();

  /// Deserialize.
  factory MessagesGetDhConfig.deserialize(BinaryReader reader) {
    // Read [MessagesGetDhConfig] fields.
    final version = reader.readInt32();
    final randomLength = reader.readInt32();

    // Construct [MessagesGetDhConfig] object.
    final returnValue = MessagesGetDhConfig(
      version: version,
      randomLength: randomLength,
    );

    // Now return the deserialized [MessagesGetDhConfig].
    return returnValue;
  }

  /// Version.
  ///
  /// Field type is Int32.
  final int version;

  /// Random Length.
  ///
  /// Field type is Int32.
  final int randomLength;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x26cf8950.
    buffer.writeInt32(0x26cf8950);

    // Write fields.
    buffer.writeInt32(version);
    buffer.writeInt32(randomLength);

    // Finished serialization.
  }
}

/// Messages Request Encryption.
///
/// ID: `f64daf43`.
class MessagesRequestEncryption extends TlMethod<EncryptedChatBase> {
  /// Messages Request Encryption constructor.
  const MessagesRequestEncryption({
    required this.userId,
    required this.randomId,
    required this.gA,
  }) : super._();

  /// Deserialize.
  factory MessagesRequestEncryption.deserialize(BinaryReader reader) {
    // Read [MessagesRequestEncryption] fields.
    final userId = reader.readObject() as InputUserBase;
    final randomId = reader.readInt32();
    final gA = reader.readBytes();

    // Construct [MessagesRequestEncryption] object.
    final returnValue = MessagesRequestEncryption(
      userId: userId,
      randomId: randomId,
      gA: gA,
    );

    // Now return the deserialized [MessagesRequestEncryption].
    return returnValue;
  }

  /// User Id.
  final InputUserBase userId;

  /// Random Id.
  ///
  /// Field type is Int32.
  final int randomId;

  /// G A.
  final Uint8List gA;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf64daf43.
    buffer.writeInt32(0xf64daf43);

    // Write fields.
    buffer.writeObject(userId);
    buffer.writeInt32(randomId);
    buffer.writeBytes(gA);

    // Finished serialization.
  }
}

/// Messages Accept Encryption.
///
/// ID: `3dbc0415`.
class MessagesAcceptEncryption extends TlMethod<EncryptedChatBase> {
  /// Messages Accept Encryption constructor.
  const MessagesAcceptEncryption({
    required this.peer,
    required this.gB,
    required this.keyFingerprint,
  }) : super._();

  /// Deserialize.
  factory MessagesAcceptEncryption.deserialize(BinaryReader reader) {
    // Read [MessagesAcceptEncryption] fields.
    final peer = reader.readObject() as InputEncryptedChatBase;
    final gB = reader.readBytes();
    final keyFingerprint = reader.readInt64();

    // Construct [MessagesAcceptEncryption] object.
    final returnValue = MessagesAcceptEncryption(
      peer: peer,
      gB: gB,
      keyFingerprint: keyFingerprint,
    );

    // Now return the deserialized [MessagesAcceptEncryption].
    return returnValue;
  }

  /// Peer.
  final InputEncryptedChatBase peer;

  /// G B.
  final Uint8List gB;

  /// Key Fingerprint.
  ///
  /// Field type is Int64.
  final int keyFingerprint;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3dbc0415.
    buffer.writeInt32(0x3dbc0415);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeBytes(gB);
    buffer.writeInt64(keyFingerprint);

    // Finished serialization.
  }
}

/// Messages Discard Encryption.
///
/// ID: `f393aea0`.
class MessagesDiscardEncryption extends TlMethod<bool> {
  /// Messages Discard Encryption constructor.
  const MessagesDiscardEncryption({
    required this.deleteHistory,
    required this.chatId,
  }) : super._();

  /// Deserialize.
  factory MessagesDiscardEncryption.deserialize(BinaryReader reader) {
    // Read [MessagesDiscardEncryption] fields.
    final flags = reader.readInt32();
    final deleteHistory = (flags & 1) != 0;
    final chatId = reader.readInt32();

    // Construct [MessagesDiscardEncryption] object.
    final returnValue = MessagesDiscardEncryption(
      deleteHistory: deleteHistory,
      chatId: chatId,
    );

    // Now return the deserialized [MessagesDiscardEncryption].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: deleteHistory,
    );

    return v;
  }

  /// delete_history: bit 0 of flags.0?true
  final bool deleteHistory;

  /// Chat Id.
  ///
  /// Field type is Int32.
  final int chatId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf393aea0.
    buffer.writeInt32(0xf393aea0);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(chatId);

    // Finished serialization.
  }
}

/// Messages Set Encrypted Typing.
///
/// ID: `791451ed`.
class MessagesSetEncryptedTyping extends TlMethod<bool> {
  /// Messages Set Encrypted Typing constructor.
  const MessagesSetEncryptedTyping({
    required this.peer,
    required this.typing,
  }) : super._();

  /// Deserialize.
  factory MessagesSetEncryptedTyping.deserialize(BinaryReader reader) {
    // Read [MessagesSetEncryptedTyping] fields.
    final peer = reader.readObject() as InputEncryptedChatBase;
    final typing = reader.readBool();

    // Construct [MessagesSetEncryptedTyping] object.
    final returnValue = MessagesSetEncryptedTyping(
      peer: peer,
      typing: typing,
    );

    // Now return the deserialized [MessagesSetEncryptedTyping].
    return returnValue;
  }

  /// Peer.
  final InputEncryptedChatBase peer;

  /// Typing.
  final bool typing;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x791451ed.
    buffer.writeInt32(0x791451ed);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeBool(typing);

    // Finished serialization.
  }
}

/// Messages Read Encrypted History.
///
/// ID: `7f4b690a`.
class MessagesReadEncryptedHistory extends TlMethod<bool> {
  /// Messages Read Encrypted History constructor.
  const MessagesReadEncryptedHistory({
    required this.peer,
    required this.maxDate,
  }) : super._();

  /// Deserialize.
  factory MessagesReadEncryptedHistory.deserialize(BinaryReader reader) {
    // Read [MessagesReadEncryptedHistory] fields.
    final peer = reader.readObject() as InputEncryptedChatBase;
    final maxDate = reader.readDateTime();

    // Construct [MessagesReadEncryptedHistory] object.
    final returnValue = MessagesReadEncryptedHistory(
      peer: peer,
      maxDate: maxDate,
    );

    // Now return the deserialized [MessagesReadEncryptedHistory].
    return returnValue;
  }

  /// Peer.
  final InputEncryptedChatBase peer;

  /// Max Date.
  final DateTime maxDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7f4b690a.
    buffer.writeInt32(0x7f4b690a);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeDateTime(maxDate);

    // Finished serialization.
  }
}

/// Messages Send Encrypted.
///
/// ID: `44fa7a15`.
class MessagesSendEncrypted extends TlMethod<MessagesSentEncryptedMessageBase> {
  /// Messages Send Encrypted constructor.
  const MessagesSendEncrypted({
    required this.silent,
    required this.peer,
    required this.randomId,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory MessagesSendEncrypted.deserialize(BinaryReader reader) {
    // Read [MessagesSendEncrypted] fields.
    final flags = reader.readInt32();
    final silent = (flags & 1) != 0;
    final peer = reader.readObject() as InputEncryptedChatBase;
    final randomId = reader.readInt64();
    final data = reader.readBytes();

    // Construct [MessagesSendEncrypted] object.
    final returnValue = MessagesSendEncrypted(
      silent: silent,
      peer: peer,
      randomId: randomId,
      data: data,
    );

    // Now return the deserialized [MessagesSendEncrypted].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: silent,
    );

    return v;
  }

  /// silent: bit 0 of flags.0?true
  final bool silent;

  /// Peer.
  final InputEncryptedChatBase peer;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Data.
  final Uint8List data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x44fa7a15.
    buffer.writeInt32(0x44fa7a15);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt64(randomId);
    buffer.writeBytes(data);

    // Finished serialization.
  }
}

/// Messages Send Encrypted File.
///
/// ID: `5559481d`.
class MessagesSendEncryptedFile
    extends TlMethod<MessagesSentEncryptedMessageBase> {
  /// Messages Send Encrypted File constructor.
  const MessagesSendEncryptedFile({
    required this.silent,
    required this.peer,
    required this.randomId,
    required this.data,
    required this.file,
  }) : super._();

  /// Deserialize.
  factory MessagesSendEncryptedFile.deserialize(BinaryReader reader) {
    // Read [MessagesSendEncryptedFile] fields.
    final flags = reader.readInt32();
    final silent = (flags & 1) != 0;
    final peer = reader.readObject() as InputEncryptedChatBase;
    final randomId = reader.readInt64();
    final data = reader.readBytes();
    final file = reader.readObject() as InputEncryptedFileBase;

    // Construct [MessagesSendEncryptedFile] object.
    final returnValue = MessagesSendEncryptedFile(
      silent: silent,
      peer: peer,
      randomId: randomId,
      data: data,
      file: file,
    );

    // Now return the deserialized [MessagesSendEncryptedFile].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: silent,
    );

    return v;
  }

  /// silent: bit 0 of flags.0?true
  final bool silent;

  /// Peer.
  final InputEncryptedChatBase peer;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Data.
  final Uint8List data;

  /// File.
  final InputEncryptedFileBase file;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5559481d.
    buffer.writeInt32(0x5559481d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt64(randomId);
    buffer.writeBytes(data);
    buffer.writeObject(file);

    // Finished serialization.
  }
}

/// Messages Send Encrypted Service.
///
/// ID: `32d439a4`.
class MessagesSendEncryptedService
    extends TlMethod<MessagesSentEncryptedMessageBase> {
  /// Messages Send Encrypted Service constructor.
  const MessagesSendEncryptedService({
    required this.peer,
    required this.randomId,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory MessagesSendEncryptedService.deserialize(BinaryReader reader) {
    // Read [MessagesSendEncryptedService] fields.
    final peer = reader.readObject() as InputEncryptedChatBase;
    final randomId = reader.readInt64();
    final data = reader.readBytes();

    // Construct [MessagesSendEncryptedService] object.
    final returnValue = MessagesSendEncryptedService(
      peer: peer,
      randomId: randomId,
      data: data,
    );

    // Now return the deserialized [MessagesSendEncryptedService].
    return returnValue;
  }

  /// Peer.
  final InputEncryptedChatBase peer;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Data.
  final Uint8List data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x32d439a4.
    buffer.writeInt32(0x32d439a4);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt64(randomId);
    buffer.writeBytes(data);

    // Finished serialization.
  }
}

/// Messages Received Queue.
///
/// ID: `55a5bb66`.
class MessagesReceivedQueue extends TlMethod<List<int>> {
  /// Messages Received Queue constructor.
  const MessagesReceivedQueue({
    required this.maxQts,
  }) : super._();

  /// Deserialize.
  factory MessagesReceivedQueue.deserialize(BinaryReader reader) {
    // Read [MessagesReceivedQueue] fields.
    final maxQts = reader.readInt32();

    // Construct [MessagesReceivedQueue] object.
    final returnValue = MessagesReceivedQueue(
      maxQts: maxQts,
    );

    // Now return the deserialized [MessagesReceivedQueue].
    return returnValue;
  }

  /// Max Qts.
  ///
  /// Field type is Int32.
  final int maxQts;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x55a5bb66.
    buffer.writeInt32(0x55a5bb66);

    // Write fields.
    buffer.writeInt32(maxQts);

    // Finished serialization.
  }
}

/// Messages Report Encrypted Spam.
///
/// ID: `4b0c8c0f`.
class MessagesReportEncryptedSpam extends TlMethod<bool> {
  /// Messages Report Encrypted Spam constructor.
  const MessagesReportEncryptedSpam({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesReportEncryptedSpam.deserialize(BinaryReader reader) {
    // Read [MessagesReportEncryptedSpam] fields.
    final peer = reader.readObject() as InputEncryptedChatBase;

    // Construct [MessagesReportEncryptedSpam] object.
    final returnValue = MessagesReportEncryptedSpam(
      peer: peer,
    );

    // Now return the deserialized [MessagesReportEncryptedSpam].
    return returnValue;
  }

  /// Peer.
  final InputEncryptedChatBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4b0c8c0f.
    buffer.writeInt32(0x4b0c8c0f);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Upload Save Big File Part.
///
/// ID: `de7b673d`.
class UploadSaveBigFilePart extends TlMethod<bool> {
  /// Upload Save Big File Part constructor.
  const UploadSaveBigFilePart({
    required this.fileId,
    required this.filePart,
    required this.fileTotalParts,
    required this.bytes,
  }) : super._();

  /// Deserialize.
  factory UploadSaveBigFilePart.deserialize(BinaryReader reader) {
    // Read [UploadSaveBigFilePart] fields.
    final fileId = reader.readInt64();
    final filePart = reader.readInt32();
    final fileTotalParts = reader.readInt32();
    final bytes = reader.readBytes();

    // Construct [UploadSaveBigFilePart] object.
    final returnValue = UploadSaveBigFilePart(
      fileId: fileId,
      filePart: filePart,
      fileTotalParts: fileTotalParts,
      bytes: bytes,
    );

    // Now return the deserialized [UploadSaveBigFilePart].
    return returnValue;
  }

  /// File Id.
  ///
  /// Field type is Int64.
  final int fileId;

  /// File Part.
  ///
  /// Field type is Int32.
  final int filePart;

  /// File Total Parts.
  ///
  /// Field type is Int32.
  final int fileTotalParts;

  /// Bytes.
  final Uint8List bytes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xde7b673d.
    buffer.writeInt32(0xde7b673d);

    // Write fields.
    buffer.writeInt64(fileId);
    buffer.writeInt32(filePart);
    buffer.writeInt32(fileTotalParts);
    buffer.writeBytes(bytes);

    // Finished serialization.
  }
}

/// Init Connection.
///
/// ID: `c1cd5ea9`.
class InitConnection<X> extends TlMethod<X> {
  /// Init Connection constructor.
  const InitConnection({
    required this.apiId,
    required this.deviceModel,
    required this.systemVersion,
    required this.appVersion,
    required this.systemLangCode,
    required this.langPack,
    required this.langCode,
    this.proxy,
    this.params,
    required this.query,
  }) : super._();

  /// Deserialize.
  factory InitConnection.deserialize(BinaryReader reader) {
    // Read [InitConnection] fields.
    final flags = reader.readInt32();
    final apiId = reader.readInt32();
    final deviceModel = reader.readString();
    final systemVersion = reader.readString();
    final appVersion = reader.readString();
    final systemLangCode = reader.readString();
    final langPack = reader.readString();
    final langCode = reader.readString();
    final hasProxyField = (flags & 1) != 0;
    final proxy =
        hasProxyField ? reader.readObject() as InputClientProxyBase : null;
    final hasParamsField = (flags & 2) != 0;
    final params = hasParamsField ? reader.readObject() as JSONValueBase : null;
    final query = reader.readObject() as TlMethod<X>;

    // Construct [InitConnection] object.
    final returnValue = InitConnection(
      apiId: apiId,
      deviceModel: deviceModel,
      systemVersion: systemVersion,
      appVersion: appVersion,
      systemLangCode: systemLangCode,
      langPack: langPack,
      langCode: langCode,
      proxy: proxy,
      params: params,
      query: query,
    );

    // Now return the deserialized [InitConnection].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: proxy != null,
      b01: params != null,
    );

    return v;
  }

  /// Api Id.
  ///
  /// Field type is Int32.
  final int apiId;

  /// Device Model.
  final String deviceModel;

  /// System Version.
  final String systemVersion;

  /// App Version.
  final String appVersion;

  /// System Lang Code.
  final String systemLangCode;

  /// Lang Pack.
  final String langPack;

  /// Lang Code.
  final String langCode;

  /// Proxy.
  final InputClientProxyBase? proxy;

  /// Params.
  final JSONValueBase? params;

  /// Query.
  final TlMethod<X> query;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc1cd5ea9.
    buffer.writeInt32(0xc1cd5ea9);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(apiId);
    buffer.writeString(deviceModel);
    buffer.writeString(systemVersion);
    buffer.writeString(appVersion);
    buffer.writeString(systemLangCode);
    buffer.writeString(langPack);
    buffer.writeString(langCode);
    final localProxyCopy = proxy;
    if (localProxyCopy != null) {
      buffer.writeObject(localProxyCopy);
    }
    final localParamsCopy = params;
    if (localParamsCopy != null) {
      buffer.writeObject(localParamsCopy);
    }
    buffer.writeObject(query);

    // Finished serialization.
  }
}

/// Help Get Support.
///
/// ID: `9cdf08cd`.
class HelpGetSupport extends TlMethod<HelpSupportBase> {
  /// Help Get Support constructor.
  const HelpGetSupport() : super._();

  /// Deserialize.
  factory HelpGetSupport.deserialize(BinaryReader reader) {
    // Construct [HelpGetSupport] object.
    final returnValue = HelpGetSupport();

    // Now return the deserialized [HelpGetSupport].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9cdf08cd.
    buffer.writeInt32(0x9cdf08cd);

    // Finished serialization.
  }
}

/// Messages Read Message Contents.
///
/// ID: `36a73f77`.
class MessagesReadMessageContents
    extends TlMethod<MessagesAffectedMessagesBase> {
  /// Messages Read Message Contents constructor.
  const MessagesReadMessageContents({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesReadMessageContents.deserialize(BinaryReader reader) {
    // Read [MessagesReadMessageContents] fields.
    final id = reader.readVectorInt32();

    // Construct [MessagesReadMessageContents] object.
    final returnValue = MessagesReadMessageContents(
      id: id,
    );

    // Now return the deserialized [MessagesReadMessageContents].
    return returnValue;
  }

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x36a73f77.
    buffer.writeInt32(0x36a73f77);

    // Write fields.
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Account Check Username.
///
/// ID: `2714d86c`.
class AccountCheckUsername extends TlMethod<bool> {
  /// Account Check Username constructor.
  const AccountCheckUsername({
    required this.username,
  }) : super._();

  /// Deserialize.
  factory AccountCheckUsername.deserialize(BinaryReader reader) {
    // Read [AccountCheckUsername] fields.
    final username = reader.readString();

    // Construct [AccountCheckUsername] object.
    final returnValue = AccountCheckUsername(
      username: username,
    );

    // Now return the deserialized [AccountCheckUsername].
    return returnValue;
  }

  /// Username.
  final String username;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2714d86c.
    buffer.writeInt32(0x2714d86c);

    // Write fields.
    buffer.writeString(username);

    // Finished serialization.
  }
}

/// Account Update Username.
///
/// ID: `3e0bdd7c`.
class AccountUpdateUsername extends TlMethod<UserBase> {
  /// Account Update Username constructor.
  const AccountUpdateUsername({
    required this.username,
  }) : super._();

  /// Deserialize.
  factory AccountUpdateUsername.deserialize(BinaryReader reader) {
    // Read [AccountUpdateUsername] fields.
    final username = reader.readString();

    // Construct [AccountUpdateUsername] object.
    final returnValue = AccountUpdateUsername(
      username: username,
    );

    // Now return the deserialized [AccountUpdateUsername].
    return returnValue;
  }

  /// Username.
  final String username;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3e0bdd7c.
    buffer.writeInt32(0x3e0bdd7c);

    // Write fields.
    buffer.writeString(username);

    // Finished serialization.
  }
}

/// Contacts Search.
///
/// ID: `11f812d8`.
class ContactsSearch extends TlMethod<ContactsFoundBase> {
  /// Contacts Search constructor.
  const ContactsSearch({
    required this.q,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory ContactsSearch.deserialize(BinaryReader reader) {
    // Read [ContactsSearch] fields.
    final q = reader.readString();
    final limit = reader.readInt32();

    // Construct [ContactsSearch] object.
    final returnValue = ContactsSearch(
      q: q,
      limit: limit,
    );

    // Now return the deserialized [ContactsSearch].
    return returnValue;
  }

  /// Q.
  final String q;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x11f812d8.
    buffer.writeInt32(0x11f812d8);

    // Write fields.
    buffer.writeString(q);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Account Get Privacy.
///
/// ID: `dadbc950`.
class AccountGetPrivacy extends TlMethod<AccountPrivacyRulesBase> {
  /// Account Get Privacy constructor.
  const AccountGetPrivacy({
    required this.key,
  }) : super._();

  /// Deserialize.
  factory AccountGetPrivacy.deserialize(BinaryReader reader) {
    // Read [AccountGetPrivacy] fields.
    final key = reader.readObject() as InputPrivacyKeyBase;

    // Construct [AccountGetPrivacy] object.
    final returnValue = AccountGetPrivacy(
      key: key,
    );

    // Now return the deserialized [AccountGetPrivacy].
    return returnValue;
  }

  /// Key.
  final InputPrivacyKeyBase key;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdadbc950.
    buffer.writeInt32(0xdadbc950);

    // Write fields.
    buffer.writeObject(key);

    // Finished serialization.
  }
}

/// Account Set Privacy.
///
/// ID: `c9f81ce8`.
class AccountSetPrivacy extends TlMethod<AccountPrivacyRulesBase> {
  /// Account Set Privacy constructor.
  const AccountSetPrivacy({
    required this.key,
    required this.rules,
  }) : super._();

  /// Deserialize.
  factory AccountSetPrivacy.deserialize(BinaryReader reader) {
    // Read [AccountSetPrivacy] fields.
    final key = reader.readObject() as InputPrivacyKeyBase;
    final rules = reader.readVectorObject<InputPrivacyRuleBase>();

    // Construct [AccountSetPrivacy] object.
    final returnValue = AccountSetPrivacy(
      key: key,
      rules: rules,
    );

    // Now return the deserialized [AccountSetPrivacy].
    return returnValue;
  }

  /// Key.
  final InputPrivacyKeyBase key;

  /// Rules.
  final List<InputPrivacyRuleBase> rules;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc9f81ce8.
    buffer.writeInt32(0xc9f81ce8);

    // Write fields.
    buffer.writeObject(key);
    buffer.writeVectorObject(rules);

    // Finished serialization.
  }
}

/// Account Delete Account.
///
/// ID: `a2c0cf74`.
class AccountDeleteAccount extends TlMethod<bool> {
  /// Account Delete Account constructor.
  const AccountDeleteAccount({
    required this.reason,
    this.password,
  }) : super._();

  /// Deserialize.
  factory AccountDeleteAccount.deserialize(BinaryReader reader) {
    // Read [AccountDeleteAccount] fields.
    final flags = reader.readInt32();
    final reason = reader.readString();
    final hasPasswordField = (flags & 1) != 0;
    final password = hasPasswordField
        ? reader.readObject() as InputCheckPasswordSRPBase
        : null;

    // Construct [AccountDeleteAccount] object.
    final returnValue = AccountDeleteAccount(
      reason: reason,
      password: password,
    );

    // Now return the deserialized [AccountDeleteAccount].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: password != null,
    );

    return v;
  }

  /// Reason.
  final String reason;

  /// Password.
  final InputCheckPasswordSRPBase? password;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa2c0cf74.
    buffer.writeInt32(0xa2c0cf74);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(reason);
    final localPasswordCopy = password;
    if (localPasswordCopy != null) {
      buffer.writeObject(localPasswordCopy);
    }

    // Finished serialization.
  }
}

/// Account Get Account T T L.
///
/// ID: `08fc711d`.
class AccountGetAccountTTL extends TlMethod<AccountDaysTTLBase> {
  /// Account Get Account T T L constructor.
  const AccountGetAccountTTL() : super._();

  /// Deserialize.
  factory AccountGetAccountTTL.deserialize(BinaryReader reader) {
    // Construct [AccountGetAccountTTL] object.
    final returnValue = AccountGetAccountTTL();

    // Now return the deserialized [AccountGetAccountTTL].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x08fc711d.
    buffer.writeInt32(0x08fc711d);

    // Finished serialization.
  }
}

/// Account Set Account T T L.
///
/// ID: `2442485e`.
class AccountSetAccountTTL extends TlMethod<bool> {
  /// Account Set Account T T L constructor.
  const AccountSetAccountTTL({
    required this.ttl,
  }) : super._();

  /// Deserialize.
  factory AccountSetAccountTTL.deserialize(BinaryReader reader) {
    // Read [AccountSetAccountTTL] fields.
    final ttl = reader.readObject() as AccountDaysTTLBase;

    // Construct [AccountSetAccountTTL] object.
    final returnValue = AccountSetAccountTTL(
      ttl: ttl,
    );

    // Now return the deserialized [AccountSetAccountTTL].
    return returnValue;
  }

  /// Ttl.
  final AccountDaysTTLBase ttl;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2442485e.
    buffer.writeInt32(0x2442485e);

    // Write fields.
    buffer.writeObject(ttl);

    // Finished serialization.
  }
}

/// Invoke With Layer.
///
/// ID: `da9b0d0d`.
class InvokeWithLayer<X> extends TlMethod<X> {
  /// Invoke With Layer constructor.
  const InvokeWithLayer({
    required this.layer,
    required this.query,
  }) : super._();

  /// Deserialize.
  factory InvokeWithLayer.deserialize(BinaryReader reader) {
    // Read [InvokeWithLayer] fields.
    final layer = reader.readInt32();
    final query = reader.readObject() as TlMethod<X>;

    // Construct [InvokeWithLayer] object.
    final returnValue = InvokeWithLayer(
      layer: layer,
      query: query,
    );

    // Now return the deserialized [InvokeWithLayer].
    return returnValue;
  }

  /// Layer.
  ///
  /// Field type is Int32.
  final int layer;

  /// Query.
  final TlMethod<X> query;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xda9b0d0d.
    buffer.writeInt32(0xda9b0d0d);

    // Write fields.
    buffer.writeInt32(layer);
    buffer.writeObject(query);

    // Finished serialization.
  }
}

/// Contacts Resolve Username.
///
/// ID: `f93ccba3`.
class ContactsResolveUsername extends TlMethod<ContactsResolvedPeerBase> {
  /// Contacts Resolve Username constructor.
  const ContactsResolveUsername({
    required this.username,
  }) : super._();

  /// Deserialize.
  factory ContactsResolveUsername.deserialize(BinaryReader reader) {
    // Read [ContactsResolveUsername] fields.
    final username = reader.readString();

    // Construct [ContactsResolveUsername] object.
    final returnValue = ContactsResolveUsername(
      username: username,
    );

    // Now return the deserialized [ContactsResolveUsername].
    return returnValue;
  }

  /// Username.
  final String username;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf93ccba3.
    buffer.writeInt32(0xf93ccba3);

    // Write fields.
    buffer.writeString(username);

    // Finished serialization.
  }
}

/// Account Send Change Phone Code.
///
/// ID: `82574ae5`.
class AccountSendChangePhoneCode extends TlMethod<AuthSentCodeBase> {
  /// Account Send Change Phone Code constructor.
  const AccountSendChangePhoneCode({
    required this.phoneNumber,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountSendChangePhoneCode.deserialize(BinaryReader reader) {
    // Read [AccountSendChangePhoneCode] fields.
    final phoneNumber = reader.readString();
    final settings = reader.readObject() as CodeSettingsBase;

    // Construct [AccountSendChangePhoneCode] object.
    final returnValue = AccountSendChangePhoneCode(
      phoneNumber: phoneNumber,
      settings: settings,
    );

    // Now return the deserialized [AccountSendChangePhoneCode].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Settings.
  final CodeSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x82574ae5.
    buffer.writeInt32(0x82574ae5);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Account Change Phone.
///
/// ID: `70c32edb`.
class AccountChangePhone extends TlMethod<UserBase> {
  /// Account Change Phone constructor.
  const AccountChangePhone({
    required this.phoneNumber,
    required this.phoneCodeHash,
    required this.phoneCode,
  }) : super._();

  /// Deserialize.
  factory AccountChangePhone.deserialize(BinaryReader reader) {
    // Read [AccountChangePhone] fields.
    final phoneNumber = reader.readString();
    final phoneCodeHash = reader.readString();
    final phoneCode = reader.readString();

    // Construct [AccountChangePhone] object.
    final returnValue = AccountChangePhone(
      phoneNumber: phoneNumber,
      phoneCodeHash: phoneCodeHash,
      phoneCode: phoneCode,
    );

    // Now return the deserialized [AccountChangePhone].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// Phone Code.
  final String phoneCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x70c32edb.
    buffer.writeInt32(0x70c32edb);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeString(phoneCodeHash);
    buffer.writeString(phoneCode);

    // Finished serialization.
  }
}

/// Messages Get Stickers.
///
/// ID: `d5a5d3a1`.
class MessagesGetStickers extends TlMethod<MessagesStickersBase> {
  /// Messages Get Stickers constructor.
  const MessagesGetStickers({
    required this.emoticon,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetStickers] fields.
    final emoticon = reader.readString();
    final hash = reader.readInt64();

    // Construct [MessagesGetStickers] object.
    final returnValue = MessagesGetStickers(
      emoticon: emoticon,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetStickers].
    return returnValue;
  }

  /// Emoticon.
  final String emoticon;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd5a5d3a1.
    buffer.writeInt32(0xd5a5d3a1);

    // Write fields.
    buffer.writeString(emoticon);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Get All Stickers.
///
/// ID: `b8a0a1a8`.
class MessagesGetAllStickers extends TlMethod<MessagesAllStickersBase> {
  /// Messages Get All Stickers constructor.
  const MessagesGetAllStickers({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetAllStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetAllStickers] fields.
    final hash = reader.readInt64();

    // Construct [MessagesGetAllStickers] object.
    final returnValue = MessagesGetAllStickers(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetAllStickers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb8a0a1a8.
    buffer.writeInt32(0xb8a0a1a8);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Account Update Device Locked.
///
/// ID: `38df3532`.
class AccountUpdateDeviceLocked extends TlMethod<bool> {
  /// Account Update Device Locked constructor.
  const AccountUpdateDeviceLocked({
    required this.period,
  }) : super._();

  /// Deserialize.
  factory AccountUpdateDeviceLocked.deserialize(BinaryReader reader) {
    // Read [AccountUpdateDeviceLocked] fields.
    final period = reader.readInt32();

    // Construct [AccountUpdateDeviceLocked] object.
    final returnValue = AccountUpdateDeviceLocked(
      period: period,
    );

    // Now return the deserialized [AccountUpdateDeviceLocked].
    return returnValue;
  }

  /// Period.
  ///
  /// Field type is Int32.
  final int period;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x38df3532.
    buffer.writeInt32(0x38df3532);

    // Write fields.
    buffer.writeInt32(period);

    // Finished serialization.
  }
}

/// Auth Import Bot Authorization.
///
/// ID: `67a3ff2c`.
class AuthImportBotAuthorization extends TlMethod<AuthAuthorizationBase> {
  /// Auth Import Bot Authorization constructor.
  const AuthImportBotAuthorization({
    required this.flags,
    required this.apiId,
    required this.apiHash,
    required this.botAuthToken,
  }) : super._();

  /// Deserialize.
  factory AuthImportBotAuthorization.deserialize(BinaryReader reader) {
    // Read [AuthImportBotAuthorization] fields.
    final flags = reader.readInt32();
    final apiId = reader.readInt32();
    final apiHash = reader.readString();
    final botAuthToken = reader.readString();

    // Construct [AuthImportBotAuthorization] object.
    final returnValue = AuthImportBotAuthorization(
      flags: flags,
      apiId: apiId,
      apiHash: apiHash,
      botAuthToken: botAuthToken,
    );

    // Now return the deserialized [AuthImportBotAuthorization].
    return returnValue;
  }

  /// Flags.
  ///
  /// Field type is Int32.
  final int flags;

  /// Api Id.
  ///
  /// Field type is Int32.
  final int apiId;

  /// Api Hash.
  final String apiHash;

  /// Bot Auth Token.
  final String botAuthToken;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x67a3ff2c.
    buffer.writeInt32(0x67a3ff2c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(apiId);
    buffer.writeString(apiHash);
    buffer.writeString(botAuthToken);

    // Finished serialization.
  }
}

/// Messages Get Web Page Preview.
///
/// ID: `8b68b0cc`.
class MessagesGetWebPagePreview extends TlMethod<MessageMediaBase> {
  /// Messages Get Web Page Preview constructor.
  const MessagesGetWebPagePreview({
    required this.message,
    this.entities,
  }) : super._();

  /// Deserialize.
  factory MessagesGetWebPagePreview.deserialize(BinaryReader reader) {
    // Read [MessagesGetWebPagePreview] fields.
    final flags = reader.readInt32();
    final message = reader.readString();
    final hasEntitiesField = (flags & 8) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;

    // Construct [MessagesGetWebPagePreview] object.
    final returnValue = MessagesGetWebPagePreview(
      message: message,
      entities: entities,
    );

    // Now return the deserialized [MessagesGetWebPagePreview].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: entities != null,
    );

    return v;
  }

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8b68b0cc.
    buffer.writeInt32(0x8b68b0cc);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }

    // Finished serialization.
  }
}

/// Account Get Authorizations.
///
/// ID: `e320c158`.
class AccountGetAuthorizations extends TlMethod<AccountAuthorizationsBase> {
  /// Account Get Authorizations constructor.
  const AccountGetAuthorizations() : super._();

  /// Deserialize.
  factory AccountGetAuthorizations.deserialize(BinaryReader reader) {
    // Construct [AccountGetAuthorizations] object.
    final returnValue = AccountGetAuthorizations();

    // Now return the deserialized [AccountGetAuthorizations].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe320c158.
    buffer.writeInt32(0xe320c158);

    // Finished serialization.
  }
}

/// Account Reset Authorization.
///
/// ID: `df77f3bc`.
class AccountResetAuthorization extends TlMethod<bool> {
  /// Account Reset Authorization constructor.
  const AccountResetAuthorization({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountResetAuthorization.deserialize(BinaryReader reader) {
    // Read [AccountResetAuthorization] fields.
    final hash = reader.readInt64();

    // Construct [AccountResetAuthorization] object.
    final returnValue = AccountResetAuthorization(
      hash: hash,
    );

    // Now return the deserialized [AccountResetAuthorization].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdf77f3bc.
    buffer.writeInt32(0xdf77f3bc);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Account Get Password.
///
/// ID: `548a30f5`.
class AccountGetPassword extends TlMethod<AccountPasswordBase> {
  /// Account Get Password constructor.
  const AccountGetPassword() : super._();

  /// Deserialize.
  factory AccountGetPassword.deserialize(BinaryReader reader) {
    // Construct [AccountGetPassword] object.
    final returnValue = AccountGetPassword();

    // Now return the deserialized [AccountGetPassword].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x548a30f5.
    buffer.writeInt32(0x548a30f5);

    // Finished serialization.
  }
}

/// Account Get Password Settings.
///
/// ID: `9cd4eaf9`.
class AccountGetPasswordSettings extends TlMethod<AccountPasswordSettingsBase> {
  /// Account Get Password Settings constructor.
  const AccountGetPasswordSettings({
    required this.password,
  }) : super._();

  /// Deserialize.
  factory AccountGetPasswordSettings.deserialize(BinaryReader reader) {
    // Read [AccountGetPasswordSettings] fields.
    final password = reader.readObject() as InputCheckPasswordSRPBase;

    // Construct [AccountGetPasswordSettings] object.
    final returnValue = AccountGetPasswordSettings(
      password: password,
    );

    // Now return the deserialized [AccountGetPasswordSettings].
    return returnValue;
  }

  /// Password.
  final InputCheckPasswordSRPBase password;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9cd4eaf9.
    buffer.writeInt32(0x9cd4eaf9);

    // Write fields.
    buffer.writeObject(password);

    // Finished serialization.
  }
}

/// Account Update Password Settings.
///
/// ID: `a59b102f`.
class AccountUpdatePasswordSettings extends TlMethod<bool> {
  /// Account Update Password Settings constructor.
  const AccountUpdatePasswordSettings({
    required this.password,
    required this.newSettings,
  }) : super._();

  /// Deserialize.
  factory AccountUpdatePasswordSettings.deserialize(BinaryReader reader) {
    // Read [AccountUpdatePasswordSettings] fields.
    final password = reader.readObject() as InputCheckPasswordSRPBase;
    final newSettings = reader.readObject() as AccountPasswordInputSettingsBase;

    // Construct [AccountUpdatePasswordSettings] object.
    final returnValue = AccountUpdatePasswordSettings(
      password: password,
      newSettings: newSettings,
    );

    // Now return the deserialized [AccountUpdatePasswordSettings].
    return returnValue;
  }

  /// Password.
  final InputCheckPasswordSRPBase password;

  /// New Settings.
  final AccountPasswordInputSettingsBase newSettings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa59b102f.
    buffer.writeInt32(0xa59b102f);

    // Write fields.
    buffer.writeObject(password);
    buffer.writeObject(newSettings);

    // Finished serialization.
  }
}

/// Auth Check Password.
///
/// ID: `d18b4d16`.
class AuthCheckPassword extends TlMethod<AuthAuthorizationBase> {
  /// Auth Check Password constructor.
  const AuthCheckPassword({
    required this.password,
  }) : super._();

  /// Deserialize.
  factory AuthCheckPassword.deserialize(BinaryReader reader) {
    // Read [AuthCheckPassword] fields.
    final password = reader.readObject() as InputCheckPasswordSRPBase;

    // Construct [AuthCheckPassword] object.
    final returnValue = AuthCheckPassword(
      password: password,
    );

    // Now return the deserialized [AuthCheckPassword].
    return returnValue;
  }

  /// Password.
  final InputCheckPasswordSRPBase password;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd18b4d16.
    buffer.writeInt32(0xd18b4d16);

    // Write fields.
    buffer.writeObject(password);

    // Finished serialization.
  }
}

/// Auth Request Password Recovery.
///
/// ID: `d897bc66`.
class AuthRequestPasswordRecovery extends TlMethod<AuthPasswordRecoveryBase> {
  /// Auth Request Password Recovery constructor.
  const AuthRequestPasswordRecovery() : super._();

  /// Deserialize.
  factory AuthRequestPasswordRecovery.deserialize(BinaryReader reader) {
    // Construct [AuthRequestPasswordRecovery] object.
    final returnValue = AuthRequestPasswordRecovery();

    // Now return the deserialized [AuthRequestPasswordRecovery].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd897bc66.
    buffer.writeInt32(0xd897bc66);

    // Finished serialization.
  }
}

/// Auth Recover Password.
///
/// ID: `37096c70`.
class AuthRecoverPassword extends TlMethod<AuthAuthorizationBase> {
  /// Auth Recover Password constructor.
  const AuthRecoverPassword({
    required this.code,
    this.newSettings,
  }) : super._();

  /// Deserialize.
  factory AuthRecoverPassword.deserialize(BinaryReader reader) {
    // Read [AuthRecoverPassword] fields.
    final flags = reader.readInt32();
    final code = reader.readString();
    final hasNewSettingsField = (flags & 1) != 0;
    final newSettings = hasNewSettingsField
        ? reader.readObject() as AccountPasswordInputSettingsBase
        : null;

    // Construct [AuthRecoverPassword] object.
    final returnValue = AuthRecoverPassword(
      code: code,
      newSettings: newSettings,
    );

    // Now return the deserialized [AuthRecoverPassword].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: newSettings != null,
    );

    return v;
  }

  /// Code.
  final String code;

  /// New Settings.
  final AccountPasswordInputSettingsBase? newSettings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x37096c70.
    buffer.writeInt32(0x37096c70);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(code);
    final localNewSettingsCopy = newSettings;
    if (localNewSettingsCopy != null) {
      buffer.writeObject(localNewSettingsCopy);
    }

    // Finished serialization.
  }
}

/// Invoke Without Updates.
///
/// ID: `bf9459b7`.
class InvokeWithoutUpdates<X> extends TlMethod<X> {
  /// Invoke Without Updates constructor.
  const InvokeWithoutUpdates({
    required this.query,
  }) : super._();

  /// Deserialize.
  factory InvokeWithoutUpdates.deserialize(BinaryReader reader) {
    // Read [InvokeWithoutUpdates] fields.
    final query = reader.readObject() as TlMethod<X>;

    // Construct [InvokeWithoutUpdates] object.
    final returnValue = InvokeWithoutUpdates(
      query: query,
    );

    // Now return the deserialized [InvokeWithoutUpdates].
    return returnValue;
  }

  /// Query.
  final TlMethod<X> query;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbf9459b7.
    buffer.writeInt32(0xbf9459b7);

    // Write fields.
    buffer.writeObject(query);

    // Finished serialization.
  }
}

/// Messages Export Chat Invite.
///
/// ID: `a02ce5d5`.
class MessagesExportChatInvite extends TlMethod<ExportedChatInviteBase> {
  /// Messages Export Chat Invite constructor.
  const MessagesExportChatInvite({
    required this.legacyRevokePermanent,
    required this.requestNeeded,
    required this.peer,
    this.expireDate,
    this.usageLimit,
    this.title,
  }) : super._();

  /// Deserialize.
  factory MessagesExportChatInvite.deserialize(BinaryReader reader) {
    // Read [MessagesExportChatInvite] fields.
    final flags = reader.readInt32();
    final legacyRevokePermanent = (flags & 4) != 0;
    final requestNeeded = (flags & 8) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final hasExpireDateField = (flags & 1) != 0;
    final expireDate = hasExpireDateField ? reader.readDateTime() : null;
    final hasUsageLimitField = (flags & 2) != 0;
    final usageLimit = hasUsageLimitField ? reader.readInt32() : null;
    final hasTitleField = (flags & 16) != 0;
    final title = hasTitleField ? reader.readString() : null;

    // Construct [MessagesExportChatInvite] object.
    final returnValue = MessagesExportChatInvite(
      legacyRevokePermanent: legacyRevokePermanent,
      requestNeeded: requestNeeded,
      peer: peer,
      expireDate: expireDate,
      usageLimit: usageLimit,
      title: title,
    );

    // Now return the deserialized [MessagesExportChatInvite].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: legacyRevokePermanent,
      b03: requestNeeded,
      b00: expireDate != null,
      b01: usageLimit != null,
      b04: title != null,
    );

    return v;
  }

  /// legacy_revoke_permanent: bit 2 of flags.2?true
  final bool legacyRevokePermanent;

  /// request_needed: bit 3 of flags.3?true
  final bool requestNeeded;

  /// Peer.
  final InputPeerBase peer;

  /// Expire Date.
  final DateTime? expireDate;

  /// Usage Limit.
  final int? usageLimit;

  /// Title.
  final String? title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa02ce5d5.
    buffer.writeInt32(0xa02ce5d5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localExpireDateCopy = expireDate;
    if (localExpireDateCopy != null) {
      buffer.writeDateTime(localExpireDateCopy);
    }
    final localUsageLimitCopy = usageLimit;
    if (localUsageLimitCopy != null) {
      buffer.writeInt32(localUsageLimitCopy);
    }
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }

    // Finished serialization.
  }
}

/// Messages Check Chat Invite.
///
/// ID: `3eadb1bb`.
class MessagesCheckChatInvite extends TlMethod<ChatInviteBase> {
  /// Messages Check Chat Invite constructor.
  const MessagesCheckChatInvite({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesCheckChatInvite.deserialize(BinaryReader reader) {
    // Read [MessagesCheckChatInvite] fields.
    final hash = reader.readString();

    // Construct [MessagesCheckChatInvite] object.
    final returnValue = MessagesCheckChatInvite(
      hash: hash,
    );

    // Now return the deserialized [MessagesCheckChatInvite].
    return returnValue;
  }

  /// Hash.
  final String hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3eadb1bb.
    buffer.writeInt32(0x3eadb1bb);

    // Write fields.
    buffer.writeString(hash);

    // Finished serialization.
  }
}

/// Messages Import Chat Invite.
///
/// ID: `6c50051c`.
class MessagesImportChatInvite extends TlMethod<UpdatesBase> {
  /// Messages Import Chat Invite constructor.
  const MessagesImportChatInvite({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesImportChatInvite.deserialize(BinaryReader reader) {
    // Read [MessagesImportChatInvite] fields.
    final hash = reader.readString();

    // Construct [MessagesImportChatInvite] object.
    final returnValue = MessagesImportChatInvite(
      hash: hash,
    );

    // Now return the deserialized [MessagesImportChatInvite].
    return returnValue;
  }

  /// Hash.
  final String hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6c50051c.
    buffer.writeInt32(0x6c50051c);

    // Write fields.
    buffer.writeString(hash);

    // Finished serialization.
  }
}

/// Messages Get Sticker Set.
///
/// ID: `c8a0ec74`.
class MessagesGetStickerSet extends TlMethod<MessagesStickerSetBase> {
  /// Messages Get Sticker Set constructor.
  const MessagesGetStickerSet({
    required this.stickerset,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetStickerSet.deserialize(BinaryReader reader) {
    // Read [MessagesGetStickerSet] fields.
    final stickerset = reader.readObject() as InputStickerSetBase;
    final hash = reader.readInt32();

    // Construct [MessagesGetStickerSet] object.
    final returnValue = MessagesGetStickerSet(
      stickerset: stickerset,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetStickerSet].
    return returnValue;
  }

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc8a0ec74.
    buffer.writeInt32(0xc8a0ec74);

    // Write fields.
    buffer.writeObject(stickerset);
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Messages Install Sticker Set.
///
/// ID: `c78fe460`.
class MessagesInstallStickerSet
    extends TlMethod<MessagesStickerSetInstallResultBase> {
  /// Messages Install Sticker Set constructor.
  const MessagesInstallStickerSet({
    required this.stickerset,
    required this.archived,
  }) : super._();

  /// Deserialize.
  factory MessagesInstallStickerSet.deserialize(BinaryReader reader) {
    // Read [MessagesInstallStickerSet] fields.
    final stickerset = reader.readObject() as InputStickerSetBase;
    final archived = reader.readBool();

    // Construct [MessagesInstallStickerSet] object.
    final returnValue = MessagesInstallStickerSet(
      stickerset: stickerset,
      archived: archived,
    );

    // Now return the deserialized [MessagesInstallStickerSet].
    return returnValue;
  }

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Archived.
  final bool archived;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc78fe460.
    buffer.writeInt32(0xc78fe460);

    // Write fields.
    buffer.writeObject(stickerset);
    buffer.writeBool(archived);

    // Finished serialization.
  }
}

/// Messages Uninstall Sticker Set.
///
/// ID: `f96e55de`.
class MessagesUninstallStickerSet extends TlMethod<bool> {
  /// Messages Uninstall Sticker Set constructor.
  const MessagesUninstallStickerSet({
    required this.stickerset,
  }) : super._();

  /// Deserialize.
  factory MessagesUninstallStickerSet.deserialize(BinaryReader reader) {
    // Read [MessagesUninstallStickerSet] fields.
    final stickerset = reader.readObject() as InputStickerSetBase;

    // Construct [MessagesUninstallStickerSet] object.
    final returnValue = MessagesUninstallStickerSet(
      stickerset: stickerset,
    );

    // Now return the deserialized [MessagesUninstallStickerSet].
    return returnValue;
  }

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf96e55de.
    buffer.writeInt32(0xf96e55de);

    // Write fields.
    buffer.writeObject(stickerset);

    // Finished serialization.
  }
}

/// Messages Start Bot.
///
/// ID: `e6df7378`.
class MessagesStartBot extends TlMethod<UpdatesBase> {
  /// Messages Start Bot constructor.
  const MessagesStartBot({
    required this.bot,
    required this.peer,
    required this.randomId,
    required this.startParam,
  }) : super._();

  /// Deserialize.
  factory MessagesStartBot.deserialize(BinaryReader reader) {
    // Read [MessagesStartBot] fields.
    final bot = reader.readObject() as InputUserBase;
    final peer = reader.readObject() as InputPeerBase;
    final randomId = reader.readInt64();
    final startParam = reader.readString();

    // Construct [MessagesStartBot] object.
    final returnValue = MessagesStartBot(
      bot: bot,
      peer: peer,
      randomId: randomId,
      startParam: startParam,
    );

    // Now return the deserialized [MessagesStartBot].
    return returnValue;
  }

  /// Bot.
  final InputUserBase bot;

  /// Peer.
  final InputPeerBase peer;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Start Param.
  final String startParam;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe6df7378.
    buffer.writeInt32(0xe6df7378);

    // Write fields.
    buffer.writeObject(bot);
    buffer.writeObject(peer);
    buffer.writeInt64(randomId);
    buffer.writeString(startParam);

    // Finished serialization.
  }
}

/// Messages Get Messages Views.
///
/// ID: `5784d3e1`.
class MessagesGetMessagesViews extends TlMethod<MessagesMessageViewsBase> {
  /// Messages Get Messages Views constructor.
  const MessagesGetMessagesViews({
    required this.peer,
    required this.id,
    required this.increment,
  }) : super._();

  /// Deserialize.
  factory MessagesGetMessagesViews.deserialize(BinaryReader reader) {
    // Read [MessagesGetMessagesViews] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();
    final increment = reader.readBool();

    // Construct [MessagesGetMessagesViews] object.
    final returnValue = MessagesGetMessagesViews(
      peer: peer,
      id: id,
      increment: increment,
    );

    // Now return the deserialized [MessagesGetMessagesViews].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Increment.
  final bool increment;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5784d3e1.
    buffer.writeInt32(0x5784d3e1);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);
    buffer.writeBool(increment);

    // Finished serialization.
  }
}

/// Channels Read History.
///
/// ID: `cc104937`.
class ChannelsReadHistory extends TlMethod<bool> {
  /// Channels Read History constructor.
  const ChannelsReadHistory({
    required this.channel,
    required this.maxId,
  }) : super._();

  /// Deserialize.
  factory ChannelsReadHistory.deserialize(BinaryReader reader) {
    // Read [ChannelsReadHistory] fields.
    final channel = reader.readObject() as InputChannelBase;
    final maxId = reader.readInt32();

    // Construct [ChannelsReadHistory] object.
    final returnValue = ChannelsReadHistory(
      channel: channel,
      maxId: maxId,
    );

    // Now return the deserialized [ChannelsReadHistory].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcc104937.
    buffer.writeInt32(0xcc104937);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeInt32(maxId);

    // Finished serialization.
  }
}

/// Channels Delete Messages.
///
/// ID: `84c1fd4e`.
class ChannelsDeleteMessages extends TlMethod<MessagesAffectedMessagesBase> {
  /// Channels Delete Messages constructor.
  const ChannelsDeleteMessages({
    required this.channel,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ChannelsDeleteMessages.deserialize(BinaryReader reader) {
    // Read [ChannelsDeleteMessages] fields.
    final channel = reader.readObject() as InputChannelBase;
    final id = reader.readVectorInt32();

    // Construct [ChannelsDeleteMessages] object.
    final returnValue = ChannelsDeleteMessages(
      channel: channel,
      id: id,
    );

    // Now return the deserialized [ChannelsDeleteMessages].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x84c1fd4e.
    buffer.writeInt32(0x84c1fd4e);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Channels Report Spam.
///
/// ID: `f44a8315`.
class ChannelsReportSpam extends TlMethod<bool> {
  /// Channels Report Spam constructor.
  const ChannelsReportSpam({
    required this.channel,
    required this.participant,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ChannelsReportSpam.deserialize(BinaryReader reader) {
    // Read [ChannelsReportSpam] fields.
    final channel = reader.readObject() as InputChannelBase;
    final participant = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();

    // Construct [ChannelsReportSpam] object.
    final returnValue = ChannelsReportSpam(
      channel: channel,
      participant: participant,
      id: id,
    );

    // Now return the deserialized [ChannelsReportSpam].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Participant.
  final InputPeerBase participant;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf44a8315.
    buffer.writeInt32(0xf44a8315);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(participant);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Channels Get Messages.
///
/// ID: `ad8c9a23`.
class ChannelsGetMessages extends TlMethod<MessagesMessagesBase> {
  /// Channels Get Messages constructor.
  const ChannelsGetMessages({
    required this.channel,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetMessages.deserialize(BinaryReader reader) {
    // Read [ChannelsGetMessages] fields.
    final channel = reader.readObject() as InputChannelBase;
    final id = reader.readVectorObject<InputMessageBase>();

    // Construct [ChannelsGetMessages] object.
    final returnValue = ChannelsGetMessages(
      channel: channel,
      id: id,
    );

    // Now return the deserialized [ChannelsGetMessages].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Id.
  final List<InputMessageBase> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xad8c9a23.
    buffer.writeInt32(0xad8c9a23);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeVectorObject(id);

    // Finished serialization.
  }
}

/// Channels Get Participants.
///
/// ID: `77ced9d0`.
class ChannelsGetParticipants
    extends TlMethod<ChannelsChannelParticipantsBase> {
  /// Channels Get Participants constructor.
  const ChannelsGetParticipants({
    required this.channel,
    required this.filter,
    required this.offset,
    required this.limit,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetParticipants.deserialize(BinaryReader reader) {
    // Read [ChannelsGetParticipants] fields.
    final channel = reader.readObject() as InputChannelBase;
    final filter = reader.readObject() as ChannelParticipantsFilterBase;
    final offset = reader.readInt32();
    final limit = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [ChannelsGetParticipants] object.
    final returnValue = ChannelsGetParticipants(
      channel: channel,
      filter: filter,
      offset: offset,
      limit: limit,
      hash: hash,
    );

    // Now return the deserialized [ChannelsGetParticipants].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Filter.
  final ChannelParticipantsFilterBase filter;

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x77ced9d0.
    buffer.writeInt32(0x77ced9d0);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(filter);
    buffer.writeInt32(offset);
    buffer.writeInt32(limit);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Channels Get Participant.
///
/// ID: `a0ab6cc6`.
class ChannelsGetParticipant extends TlMethod<ChannelsChannelParticipantBase> {
  /// Channels Get Participant constructor.
  const ChannelsGetParticipant({
    required this.channel,
    required this.participant,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetParticipant.deserialize(BinaryReader reader) {
    // Read [ChannelsGetParticipant] fields.
    final channel = reader.readObject() as InputChannelBase;
    final participant = reader.readObject() as InputPeerBase;

    // Construct [ChannelsGetParticipant] object.
    final returnValue = ChannelsGetParticipant(
      channel: channel,
      participant: participant,
    );

    // Now return the deserialized [ChannelsGetParticipant].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Participant.
  final InputPeerBase participant;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa0ab6cc6.
    buffer.writeInt32(0xa0ab6cc6);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(participant);

    // Finished serialization.
  }
}

/// Channels Get Channels.
///
/// ID: `0a7f6bbb`.
class ChannelsGetChannels extends TlMethod<MessagesChatsBase> {
  /// Channels Get Channels constructor.
  const ChannelsGetChannels({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetChannels.deserialize(BinaryReader reader) {
    // Read [ChannelsGetChannels] fields.
    final id = reader.readVectorObject<InputChannelBase>();

    // Construct [ChannelsGetChannels] object.
    final returnValue = ChannelsGetChannels(
      id: id,
    );

    // Now return the deserialized [ChannelsGetChannels].
    return returnValue;
  }

  /// Id.
  final List<InputChannelBase> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0a7f6bbb.
    buffer.writeInt32(0x0a7f6bbb);

    // Write fields.
    buffer.writeVectorObject(id);

    // Finished serialization.
  }
}

/// Channels Get Full Channel.
///
/// ID: `08736a09`.
class ChannelsGetFullChannel extends TlMethod<MessagesChatFullBase> {
  /// Channels Get Full Channel constructor.
  const ChannelsGetFullChannel({
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetFullChannel.deserialize(BinaryReader reader) {
    // Read [ChannelsGetFullChannel] fields.
    final channel = reader.readObject() as InputChannelBase;

    // Construct [ChannelsGetFullChannel] object.
    final returnValue = ChannelsGetFullChannel(
      channel: channel,
    );

    // Now return the deserialized [ChannelsGetFullChannel].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x08736a09.
    buffer.writeInt32(0x08736a09);

    // Write fields.
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Channels Create Channel.
///
/// ID: `91006707`.
class ChannelsCreateChannel extends TlMethod<UpdatesBase> {
  /// Channels Create Channel constructor.
  const ChannelsCreateChannel({
    required this.broadcast,
    required this.megagroup,
    required this.forImport,
    required this.forum,
    required this.title,
    required this.about,
    this.geoPoint,
    this.address,
    this.ttlPeriod,
  }) : super._();

  /// Deserialize.
  factory ChannelsCreateChannel.deserialize(BinaryReader reader) {
    // Read [ChannelsCreateChannel] fields.
    final flags = reader.readInt32();
    final broadcast = (flags & 1) != 0;
    final megagroup = (flags & 2) != 0;
    final forImport = (flags & 8) != 0;
    final forum = (flags & 32) != 0;
    final title = reader.readString();
    final about = reader.readString();
    final hasGeoPointField = (flags & 4) != 0;
    final geoPoint =
        hasGeoPointField ? reader.readObject() as InputGeoPointBase : null;
    final hasAddressField = (flags & 4) != 0;
    final address = hasAddressField ? reader.readString() : null;
    final hasTtlPeriodField = (flags & 16) != 0;
    final ttlPeriod = hasTtlPeriodField ? reader.readInt32() : null;

    // Construct [ChannelsCreateChannel] object.
    final returnValue = ChannelsCreateChannel(
      broadcast: broadcast,
      megagroup: megagroup,
      forImport: forImport,
      forum: forum,
      title: title,
      about: about,
      geoPoint: geoPoint,
      address: address,
      ttlPeriod: ttlPeriod,
    );

    // Now return the deserialized [ChannelsCreateChannel].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: broadcast,
      b01: megagroup,
      b03: forImport,
      b05: forum,
      b02: geoPoint != null || address != null,
      b04: ttlPeriod != null,
    );

    return v;
  }

  /// broadcast: bit 0 of flags.0?true
  final bool broadcast;

  /// megagroup: bit 1 of flags.1?true
  final bool megagroup;

  /// for_import: bit 3 of flags.3?true
  final bool forImport;

  /// forum: bit 5 of flags.5?true
  final bool forum;

  /// Title.
  final String title;

  /// About.
  final String about;

  /// Geo Point.
  final InputGeoPointBase? geoPoint;

  /// Address.
  final String? address;

  /// Ttl Period.
  final int? ttlPeriod;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x91006707.
    buffer.writeInt32(0x91006707);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(title);
    buffer.writeString(about);
    final localGeoPointCopy = geoPoint;
    if (localGeoPointCopy != null) {
      buffer.writeObject(localGeoPointCopy);
    }
    final localAddressCopy = address;
    if (localAddressCopy != null) {
      buffer.writeString(localAddressCopy);
    }
    final localTtlPeriodCopy = ttlPeriod;
    if (localTtlPeriodCopy != null) {
      buffer.writeInt32(localTtlPeriodCopy);
    }

    // Finished serialization.
  }
}

/// Channels Edit Admin.
///
/// ID: `d33c8902`.
class ChannelsEditAdmin extends TlMethod<UpdatesBase> {
  /// Channels Edit Admin constructor.
  const ChannelsEditAdmin({
    required this.channel,
    required this.userId,
    required this.adminRights,
    required this.rank,
  }) : super._();

  /// Deserialize.
  factory ChannelsEditAdmin.deserialize(BinaryReader reader) {
    // Read [ChannelsEditAdmin] fields.
    final channel = reader.readObject() as InputChannelBase;
    final userId = reader.readObject() as InputUserBase;
    final adminRights = reader.readObject() as ChatAdminRightsBase;
    final rank = reader.readString();

    // Construct [ChannelsEditAdmin] object.
    final returnValue = ChannelsEditAdmin(
      channel: channel,
      userId: userId,
      adminRights: adminRights,
      rank: rank,
    );

    // Now return the deserialized [ChannelsEditAdmin].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// User Id.
  final InputUserBase userId;

  /// Admin Rights.
  final ChatAdminRightsBase adminRights;

  /// Rank.
  final String rank;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd33c8902.
    buffer.writeInt32(0xd33c8902);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(userId);
    buffer.writeObject(adminRights);
    buffer.writeString(rank);

    // Finished serialization.
  }
}

/// Channels Edit Title.
///
/// ID: `566decd0`.
class ChannelsEditTitle extends TlMethod<UpdatesBase> {
  /// Channels Edit Title constructor.
  const ChannelsEditTitle({
    required this.channel,
    required this.title,
  }) : super._();

  /// Deserialize.
  factory ChannelsEditTitle.deserialize(BinaryReader reader) {
    // Read [ChannelsEditTitle] fields.
    final channel = reader.readObject() as InputChannelBase;
    final title = reader.readString();

    // Construct [ChannelsEditTitle] object.
    final returnValue = ChannelsEditTitle(
      channel: channel,
      title: title,
    );

    // Now return the deserialized [ChannelsEditTitle].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Title.
  final String title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x566decd0.
    buffer.writeInt32(0x566decd0);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeString(title);

    // Finished serialization.
  }
}

/// Channels Edit Photo.
///
/// ID: `f12e57c9`.
class ChannelsEditPhoto extends TlMethod<UpdatesBase> {
  /// Channels Edit Photo constructor.
  const ChannelsEditPhoto({
    required this.channel,
    required this.photo,
  }) : super._();

  /// Deserialize.
  factory ChannelsEditPhoto.deserialize(BinaryReader reader) {
    // Read [ChannelsEditPhoto] fields.
    final channel = reader.readObject() as InputChannelBase;
    final photo = reader.readObject() as InputChatPhotoBase;

    // Construct [ChannelsEditPhoto] object.
    final returnValue = ChannelsEditPhoto(
      channel: channel,
      photo: photo,
    );

    // Now return the deserialized [ChannelsEditPhoto].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Photo.
  final InputChatPhotoBase photo;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf12e57c9.
    buffer.writeInt32(0xf12e57c9);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(photo);

    // Finished serialization.
  }
}

/// Channels Check Username.
///
/// ID: `10e6bd2c`.
class ChannelsCheckUsername extends TlMethod<bool> {
  /// Channels Check Username constructor.
  const ChannelsCheckUsername({
    required this.channel,
    required this.username,
  }) : super._();

  /// Deserialize.
  factory ChannelsCheckUsername.deserialize(BinaryReader reader) {
    // Read [ChannelsCheckUsername] fields.
    final channel = reader.readObject() as InputChannelBase;
    final username = reader.readString();

    // Construct [ChannelsCheckUsername] object.
    final returnValue = ChannelsCheckUsername(
      channel: channel,
      username: username,
    );

    // Now return the deserialized [ChannelsCheckUsername].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Username.
  final String username;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x10e6bd2c.
    buffer.writeInt32(0x10e6bd2c);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeString(username);

    // Finished serialization.
  }
}

/// Channels Update Username.
///
/// ID: `3514b3de`.
class ChannelsUpdateUsername extends TlMethod<bool> {
  /// Channels Update Username constructor.
  const ChannelsUpdateUsername({
    required this.channel,
    required this.username,
  }) : super._();

  /// Deserialize.
  factory ChannelsUpdateUsername.deserialize(BinaryReader reader) {
    // Read [ChannelsUpdateUsername] fields.
    final channel = reader.readObject() as InputChannelBase;
    final username = reader.readString();

    // Construct [ChannelsUpdateUsername] object.
    final returnValue = ChannelsUpdateUsername(
      channel: channel,
      username: username,
    );

    // Now return the deserialized [ChannelsUpdateUsername].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Username.
  final String username;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3514b3de.
    buffer.writeInt32(0x3514b3de);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeString(username);

    // Finished serialization.
  }
}

/// Channels Join Channel.
///
/// ID: `24b524c5`.
class ChannelsJoinChannel extends TlMethod<UpdatesBase> {
  /// Channels Join Channel constructor.
  const ChannelsJoinChannel({
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory ChannelsJoinChannel.deserialize(BinaryReader reader) {
    // Read [ChannelsJoinChannel] fields.
    final channel = reader.readObject() as InputChannelBase;

    // Construct [ChannelsJoinChannel] object.
    final returnValue = ChannelsJoinChannel(
      channel: channel,
    );

    // Now return the deserialized [ChannelsJoinChannel].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x24b524c5.
    buffer.writeInt32(0x24b524c5);

    // Write fields.
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Channels Leave Channel.
///
/// ID: `f836aa95`.
class ChannelsLeaveChannel extends TlMethod<UpdatesBase> {
  /// Channels Leave Channel constructor.
  const ChannelsLeaveChannel({
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory ChannelsLeaveChannel.deserialize(BinaryReader reader) {
    // Read [ChannelsLeaveChannel] fields.
    final channel = reader.readObject() as InputChannelBase;

    // Construct [ChannelsLeaveChannel] object.
    final returnValue = ChannelsLeaveChannel(
      channel: channel,
    );

    // Now return the deserialized [ChannelsLeaveChannel].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf836aa95.
    buffer.writeInt32(0xf836aa95);

    // Write fields.
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Channels Invite To Channel.
///
/// ID: `199f3a6c`.
class ChannelsInviteToChannel extends TlMethod<UpdatesBase> {
  /// Channels Invite To Channel constructor.
  const ChannelsInviteToChannel({
    required this.channel,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory ChannelsInviteToChannel.deserialize(BinaryReader reader) {
    // Read [ChannelsInviteToChannel] fields.
    final channel = reader.readObject() as InputChannelBase;
    final users = reader.readVectorObject<InputUserBase>();

    // Construct [ChannelsInviteToChannel] object.
    final returnValue = ChannelsInviteToChannel(
      channel: channel,
      users: users,
    );

    // Now return the deserialized [ChannelsInviteToChannel].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Users.
  final List<InputUserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x199f3a6c.
    buffer.writeInt32(0x199f3a6c);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Channels Delete Channel.
///
/// ID: `c0111fe3`.
class ChannelsDeleteChannel extends TlMethod<UpdatesBase> {
  /// Channels Delete Channel constructor.
  const ChannelsDeleteChannel({
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory ChannelsDeleteChannel.deserialize(BinaryReader reader) {
    // Read [ChannelsDeleteChannel] fields.
    final channel = reader.readObject() as InputChannelBase;

    // Construct [ChannelsDeleteChannel] object.
    final returnValue = ChannelsDeleteChannel(
      channel: channel,
    );

    // Now return the deserialized [ChannelsDeleteChannel].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc0111fe3.
    buffer.writeInt32(0xc0111fe3);

    // Write fields.
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Updates Get Channel Difference.
///
/// ID: `03173d78`.
class UpdatesGetChannelDifference
    extends TlMethod<UpdatesChannelDifferenceBase> {
  /// Updates Get Channel Difference constructor.
  const UpdatesGetChannelDifference({
    required this.force,
    required this.channel,
    required this.filter,
    required this.pts,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory UpdatesGetChannelDifference.deserialize(BinaryReader reader) {
    // Read [UpdatesGetChannelDifference] fields.
    final flags = reader.readInt32();
    final force = (flags & 1) != 0;
    final channel = reader.readObject() as InputChannelBase;
    final filter = reader.readObject() as ChannelMessagesFilterBase;
    final pts = reader.readInt32();
    final limit = reader.readInt32();

    // Construct [UpdatesGetChannelDifference] object.
    final returnValue = UpdatesGetChannelDifference(
      force: force,
      channel: channel,
      filter: filter,
      pts: pts,
      limit: limit,
    );

    // Now return the deserialized [UpdatesGetChannelDifference].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: force,
    );

    return v;
  }

  /// force: bit 0 of flags.0?true
  final bool force;

  /// Channel.
  final InputChannelBase channel;

  /// Filter.
  final ChannelMessagesFilterBase filter;

  /// Pts.
  ///
  /// Field type is Int32.
  final int pts;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x03173d78.
    buffer.writeInt32(0x03173d78);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);
    buffer.writeObject(filter);
    buffer.writeInt32(pts);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Messages Edit Chat Admin.
///
/// ID: `a85bd1c2`.
class MessagesEditChatAdmin extends TlMethod<bool> {
  /// Messages Edit Chat Admin constructor.
  const MessagesEditChatAdmin({
    required this.chatId,
    required this.userId,
    required this.isAdmin,
  }) : super._();

  /// Deserialize.
  factory MessagesEditChatAdmin.deserialize(BinaryReader reader) {
    // Read [MessagesEditChatAdmin] fields.
    final chatId = reader.readInt64();
    final userId = reader.readObject() as InputUserBase;
    final isAdmin = reader.readBool();

    // Construct [MessagesEditChatAdmin] object.
    final returnValue = MessagesEditChatAdmin(
      chatId: chatId,
      userId: userId,
      isAdmin: isAdmin,
    );

    // Now return the deserialized [MessagesEditChatAdmin].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// User Id.
  final InputUserBase userId;

  /// Is Admin.
  final bool isAdmin;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa85bd1c2.
    buffer.writeInt32(0xa85bd1c2);

    // Write fields.
    buffer.writeInt64(chatId);
    buffer.writeObject(userId);
    buffer.writeBool(isAdmin);

    // Finished serialization.
  }
}

/// Messages Migrate Chat.
///
/// ID: `a2875319`.
class MessagesMigrateChat extends TlMethod<UpdatesBase> {
  /// Messages Migrate Chat constructor.
  const MessagesMigrateChat({
    required this.chatId,
  }) : super._();

  /// Deserialize.
  factory MessagesMigrateChat.deserialize(BinaryReader reader) {
    // Read [MessagesMigrateChat] fields.
    final chatId = reader.readInt64();

    // Construct [MessagesMigrateChat] object.
    final returnValue = MessagesMigrateChat(
      chatId: chatId,
    );

    // Now return the deserialized [MessagesMigrateChat].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa2875319.
    buffer.writeInt32(0xa2875319);

    // Write fields.
    buffer.writeInt64(chatId);

    // Finished serialization.
  }
}

/// Messages Search Global.
///
/// ID: `4bc6589a`.
class MessagesSearchGlobal extends TlMethod<MessagesMessagesBase> {
  /// Messages Search Global constructor.
  const MessagesSearchGlobal({
    this.folderId,
    required this.q,
    required this.filter,
    required this.minDate,
    required this.maxDate,
    required this.offsetRate,
    required this.offsetPeer,
    required this.offsetId,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory MessagesSearchGlobal.deserialize(BinaryReader reader) {
    // Read [MessagesSearchGlobal] fields.
    final flags = reader.readInt32();
    final hasFolderIdField = (flags & 1) != 0;
    final folderId = hasFolderIdField ? reader.readInt32() : null;
    final q = reader.readString();
    final filter = reader.readObject() as MessagesFilterBase;
    final minDate = reader.readDateTime();
    final maxDate = reader.readDateTime();
    final offsetRate = reader.readInt32();
    final offsetPeer = reader.readObject() as InputPeerBase;
    final offsetId = reader.readInt32();
    final limit = reader.readInt32();

    // Construct [MessagesSearchGlobal] object.
    final returnValue = MessagesSearchGlobal(
      folderId: folderId,
      q: q,
      filter: filter,
      minDate: minDate,
      maxDate: maxDate,
      offsetRate: offsetRate,
      offsetPeer: offsetPeer,
      offsetId: offsetId,
      limit: limit,
    );

    // Now return the deserialized [MessagesSearchGlobal].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: folderId != null,
    );

    return v;
  }

  /// Folder Id.
  final int? folderId;

  /// Q.
  final String q;

  /// Filter.
  final MessagesFilterBase filter;

  /// Min Date.
  final DateTime minDate;

  /// Max Date.
  final DateTime maxDate;

  /// Offset Rate.
  ///
  /// Field type is Int32.
  final int offsetRate;

  /// Offset Peer.
  final InputPeerBase offsetPeer;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4bc6589a.
    buffer.writeInt32(0x4bc6589a);

    // Write fields.
    buffer.writeInt32(flags);
    final localFolderIdCopy = folderId;
    if (localFolderIdCopy != null) {
      buffer.writeInt32(localFolderIdCopy);
    }
    buffer.writeString(q);
    buffer.writeObject(filter);
    buffer.writeDateTime(minDate);
    buffer.writeDateTime(maxDate);
    buffer.writeInt32(offsetRate);
    buffer.writeObject(offsetPeer);
    buffer.writeInt32(offsetId);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Messages Reorder Sticker Sets.
///
/// ID: `78337739`.
class MessagesReorderStickerSets extends TlMethod<bool> {
  /// Messages Reorder Sticker Sets constructor.
  const MessagesReorderStickerSets({
    required this.masks,
    required this.emojis,
    required this.order,
  }) : super._();

  /// Deserialize.
  factory MessagesReorderStickerSets.deserialize(BinaryReader reader) {
    // Read [MessagesReorderStickerSets] fields.
    final flags = reader.readInt32();
    final masks = (flags & 1) != 0;
    final emojis = (flags & 2) != 0;
    final order = reader.readVectorInt64();

    // Construct [MessagesReorderStickerSets] object.
    final returnValue = MessagesReorderStickerSets(
      masks: masks,
      emojis: emojis,
      order: order,
    );

    // Now return the deserialized [MessagesReorderStickerSets].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: masks,
      b01: emojis,
    );

    return v;
  }

  /// masks: bit 0 of flags.0?true
  final bool masks;

  /// emojis: bit 1 of flags.1?true
  final bool emojis;

  /// Order.
  final List<int> order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x78337739.
    buffer.writeInt32(0x78337739);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorInt64(order);

    // Finished serialization.
  }
}

/// Messages Get Document By Hash.
///
/// ID: `b1f2061f`.
class MessagesGetDocumentByHash extends TlMethod<DocumentBase> {
  /// Messages Get Document By Hash constructor.
  const MessagesGetDocumentByHash({
    required this.sha256,
    required this.size,
    required this.mimeType,
  }) : super._();

  /// Deserialize.
  factory MessagesGetDocumentByHash.deserialize(BinaryReader reader) {
    // Read [MessagesGetDocumentByHash] fields.
    final sha256 = reader.readBytes();
    final size = reader.readInt64();
    final mimeType = reader.readString();

    // Construct [MessagesGetDocumentByHash] object.
    final returnValue = MessagesGetDocumentByHash(
      sha256: sha256,
      size: size,
      mimeType: mimeType,
    );

    // Now return the deserialized [MessagesGetDocumentByHash].
    return returnValue;
  }

  /// Sha256.
  final Uint8List sha256;

  /// Size.
  ///
  /// Field type is Int64.
  final int size;

  /// Mime Type.
  final String mimeType;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb1f2061f.
    buffer.writeInt32(0xb1f2061f);

    // Write fields.
    buffer.writeBytes(sha256);
    buffer.writeInt64(size);
    buffer.writeString(mimeType);

    // Finished serialization.
  }
}

/// Messages Get Saved Gifs.
///
/// ID: `5cf09635`.
class MessagesGetSavedGifs extends TlMethod<MessagesSavedGifsBase> {
  /// Messages Get Saved Gifs constructor.
  const MessagesGetSavedGifs({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetSavedGifs.deserialize(BinaryReader reader) {
    // Read [MessagesGetSavedGifs] fields.
    final hash = reader.readInt64();

    // Construct [MessagesGetSavedGifs] object.
    final returnValue = MessagesGetSavedGifs(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetSavedGifs].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5cf09635.
    buffer.writeInt32(0x5cf09635);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Save Gif.
///
/// ID: `327a30cb`.
class MessagesSaveGif extends TlMethod<bool> {
  /// Messages Save Gif constructor.
  const MessagesSaveGif({
    required this.id,
    required this.unsave,
  }) : super._();

  /// Deserialize.
  factory MessagesSaveGif.deserialize(BinaryReader reader) {
    // Read [MessagesSaveGif] fields.
    final id = reader.readObject() as InputDocumentBase;
    final unsave = reader.readBool();

    // Construct [MessagesSaveGif] object.
    final returnValue = MessagesSaveGif(
      id: id,
      unsave: unsave,
    );

    // Now return the deserialized [MessagesSaveGif].
    return returnValue;
  }

  /// Id.
  final InputDocumentBase id;

  /// Unsave.
  final bool unsave;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x327a30cb.
    buffer.writeInt32(0x327a30cb);

    // Write fields.
    buffer.writeObject(id);
    buffer.writeBool(unsave);

    // Finished serialization.
  }
}

/// Messages Get Inline Bot Results.
///
/// ID: `514e999d`.
class MessagesGetInlineBotResults extends TlMethod<MessagesBotResultsBase> {
  /// Messages Get Inline Bot Results constructor.
  const MessagesGetInlineBotResults({
    required this.bot,
    required this.peer,
    this.geoPoint,
    required this.query,
    required this.offset,
  }) : super._();

  /// Deserialize.
  factory MessagesGetInlineBotResults.deserialize(BinaryReader reader) {
    // Read [MessagesGetInlineBotResults] fields.
    final flags = reader.readInt32();
    final bot = reader.readObject() as InputUserBase;
    final peer = reader.readObject() as InputPeerBase;
    final hasGeoPointField = (flags & 1) != 0;
    final geoPoint =
        hasGeoPointField ? reader.readObject() as InputGeoPointBase : null;
    final query = reader.readString();
    final offset = reader.readString();

    // Construct [MessagesGetInlineBotResults] object.
    final returnValue = MessagesGetInlineBotResults(
      bot: bot,
      peer: peer,
      geoPoint: geoPoint,
      query: query,
      offset: offset,
    );

    // Now return the deserialized [MessagesGetInlineBotResults].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: geoPoint != null,
    );

    return v;
  }

  /// Bot.
  final InputUserBase bot;

  /// Peer.
  final InputPeerBase peer;

  /// Geo Point.
  final InputGeoPointBase? geoPoint;

  /// Query.
  final String query;

  /// Offset.
  final String offset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x514e999d.
    buffer.writeInt32(0x514e999d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(bot);
    buffer.writeObject(peer);
    final localGeoPointCopy = geoPoint;
    if (localGeoPointCopy != null) {
      buffer.writeObject(localGeoPointCopy);
    }
    buffer.writeString(query);
    buffer.writeString(offset);

    // Finished serialization.
  }
}

/// Messages Set Inline Bot Results.
///
/// ID: `bb12a419`.
class MessagesSetInlineBotResults extends TlMethod<bool> {
  /// Messages Set Inline Bot Results constructor.
  const MessagesSetInlineBotResults({
    required this.gallery,
    required this.private,
    required this.queryId,
    required this.results,
    required this.cacheTime,
    this.nextOffset,
    this.switchPm,
    this.switchWebview,
  }) : super._();

  /// Deserialize.
  factory MessagesSetInlineBotResults.deserialize(BinaryReader reader) {
    // Read [MessagesSetInlineBotResults] fields.
    final flags = reader.readInt32();
    final gallery = (flags & 1) != 0;
    final private = (flags & 2) != 0;
    final queryId = reader.readInt64();
    final results = reader.readVectorObject<InputBotInlineResultBase>();
    final cacheTime = reader.readInt32();
    final hasNextOffsetField = (flags & 4) != 0;
    final nextOffset = hasNextOffsetField ? reader.readString() : null;
    final hasSwitchPmField = (flags & 8) != 0;
    final switchPm =
        hasSwitchPmField ? reader.readObject() as InlineBotSwitchPMBase : null;
    final hasSwitchWebviewField = (flags & 16) != 0;
    final switchWebview = hasSwitchWebviewField
        ? reader.readObject() as InlineBotWebViewBase
        : null;

    // Construct [MessagesSetInlineBotResults] object.
    final returnValue = MessagesSetInlineBotResults(
      gallery: gallery,
      private: private,
      queryId: queryId,
      results: results,
      cacheTime: cacheTime,
      nextOffset: nextOffset,
      switchPm: switchPm,
      switchWebview: switchWebview,
    );

    // Now return the deserialized [MessagesSetInlineBotResults].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: gallery,
      b01: private,
      b02: nextOffset != null,
      b03: switchPm != null,
      b04: switchWebview != null,
    );

    return v;
  }

  /// gallery: bit 0 of flags.0?true
  final bool gallery;

  /// private: bit 1 of flags.1?true
  final bool private;

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Results.
  final List<InputBotInlineResultBase> results;

  /// Cache Time.
  ///
  /// Field type is Int32.
  final int cacheTime;

  /// Next Offset.
  final String? nextOffset;

  /// Switch Pm.
  final InlineBotSwitchPMBase? switchPm;

  /// Switch Webview.
  final InlineBotWebViewBase? switchWebview;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbb12a419.
    buffer.writeInt32(0xbb12a419);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(queryId);
    buffer.writeVectorObject(results);
    buffer.writeInt32(cacheTime);
    final localNextOffsetCopy = nextOffset;
    if (localNextOffsetCopy != null) {
      buffer.writeString(localNextOffsetCopy);
    }
    final localSwitchPmCopy = switchPm;
    if (localSwitchPmCopy != null) {
      buffer.writeObject(localSwitchPmCopy);
    }
    final localSwitchWebviewCopy = switchWebview;
    if (localSwitchWebviewCopy != null) {
      buffer.writeObject(localSwitchWebviewCopy);
    }

    // Finished serialization.
  }
}

/// Messages Send Inline Bot Result.
///
/// ID: `f7bc68ba`.
class MessagesSendInlineBotResult extends TlMethod<UpdatesBase> {
  /// Messages Send Inline Bot Result constructor.
  const MessagesSendInlineBotResult({
    required this.silent,
    required this.background,
    required this.clearDraft,
    required this.hideVia,
    required this.peer,
    this.replyTo,
    required this.randomId,
    required this.queryId,
    required this.id,
    this.scheduleDate,
    this.sendAs,
  }) : super._();

  /// Deserialize.
  factory MessagesSendInlineBotResult.deserialize(BinaryReader reader) {
    // Read [MessagesSendInlineBotResult] fields.
    final flags = reader.readInt32();
    final silent = (flags & 32) != 0;
    final background = (flags & 64) != 0;
    final clearDraft = (flags & 128) != 0;
    final hideVia = (flags & 2048) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final hasReplyToField = (flags & 1) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as InputReplyToBase : null;
    final randomId = reader.readInt64();
    final queryId = reader.readInt64();
    final id = reader.readString();
    final hasScheduleDateField = (flags & 1024) != 0;
    final scheduleDate = hasScheduleDateField ? reader.readDateTime() : null;
    final hasSendAsField = (flags & 8192) != 0;
    final sendAs = hasSendAsField ? reader.readObject() as InputPeerBase : null;

    // Construct [MessagesSendInlineBotResult] object.
    final returnValue = MessagesSendInlineBotResult(
      silent: silent,
      background: background,
      clearDraft: clearDraft,
      hideVia: hideVia,
      peer: peer,
      replyTo: replyTo,
      randomId: randomId,
      queryId: queryId,
      id: id,
      scheduleDate: scheduleDate,
      sendAs: sendAs,
    );

    // Now return the deserialized [MessagesSendInlineBotResult].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b05: silent,
      b06: background,
      b07: clearDraft,
      b11: hideVia,
      b00: replyTo != null,
      b10: scheduleDate != null,
      b13: sendAs != null,
    );

    return v;
  }

  /// silent: bit 5 of flags.5?true
  final bool silent;

  /// background: bit 6 of flags.6?true
  final bool background;

  /// clear_draft: bit 7 of flags.7?true
  final bool clearDraft;

  /// hide_via: bit 11 of flags.11?true
  final bool hideVia;

  /// Peer.
  final InputPeerBase peer;

  /// Reply To.
  final InputReplyToBase? replyTo;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Id.
  final String id;

  /// Schedule Date.
  final DateTime? scheduleDate;

  /// Send As.
  final InputPeerBase? sendAs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf7bc68ba.
    buffer.writeInt32(0xf7bc68ba);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    buffer.writeInt64(randomId);
    buffer.writeInt64(queryId);
    buffer.writeString(id);
    final localScheduleDateCopy = scheduleDate;
    if (localScheduleDateCopy != null) {
      buffer.writeDateTime(localScheduleDateCopy);
    }
    final localSendAsCopy = sendAs;
    if (localSendAsCopy != null) {
      buffer.writeObject(localSendAsCopy);
    }

    // Finished serialization.
  }
}

/// Channels Export Message Link.
///
/// ID: `e63fadeb`.
class ChannelsExportMessageLink extends TlMethod<ExportedMessageLinkBase> {
  /// Channels Export Message Link constructor.
  const ChannelsExportMessageLink({
    required this.grouped,
    required this.thread,
    required this.channel,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ChannelsExportMessageLink.deserialize(BinaryReader reader) {
    // Read [ChannelsExportMessageLink] fields.
    final flags = reader.readInt32();
    final grouped = (flags & 1) != 0;
    final thread = (flags & 2) != 0;
    final channel = reader.readObject() as InputChannelBase;
    final id = reader.readInt32();

    // Construct [ChannelsExportMessageLink] object.
    final returnValue = ChannelsExportMessageLink(
      grouped: grouped,
      thread: thread,
      channel: channel,
      id: id,
    );

    // Now return the deserialized [ChannelsExportMessageLink].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: grouped,
      b01: thread,
    );

    return v;
  }

  /// grouped: bit 0 of flags.0?true
  final bool grouped;

  /// thread: bit 1 of flags.1?true
  final bool thread;

  /// Channel.
  final InputChannelBase channel;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe63fadeb.
    buffer.writeInt32(0xe63fadeb);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Channels Toggle Signatures.
///
/// ID: `1f69b606`.
class ChannelsToggleSignatures extends TlMethod<UpdatesBase> {
  /// Channels Toggle Signatures constructor.
  const ChannelsToggleSignatures({
    required this.channel,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory ChannelsToggleSignatures.deserialize(BinaryReader reader) {
    // Read [ChannelsToggleSignatures] fields.
    final channel = reader.readObject() as InputChannelBase;
    final enabled = reader.readBool();

    // Construct [ChannelsToggleSignatures] object.
    final returnValue = ChannelsToggleSignatures(
      channel: channel,
      enabled: enabled,
    );

    // Now return the deserialized [ChannelsToggleSignatures].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1f69b606.
    buffer.writeInt32(0x1f69b606);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Auth Resend Code.
///
/// ID: `3ef1a9bf`.
class AuthResendCode extends TlMethod<AuthSentCodeBase> {
  /// Auth Resend Code constructor.
  const AuthResendCode({
    required this.phoneNumber,
    required this.phoneCodeHash,
  }) : super._();

  /// Deserialize.
  factory AuthResendCode.deserialize(BinaryReader reader) {
    // Read [AuthResendCode] fields.
    final phoneNumber = reader.readString();
    final phoneCodeHash = reader.readString();

    // Construct [AuthResendCode] object.
    final returnValue = AuthResendCode(
      phoneNumber: phoneNumber,
      phoneCodeHash: phoneCodeHash,
    );

    // Now return the deserialized [AuthResendCode].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3ef1a9bf.
    buffer.writeInt32(0x3ef1a9bf);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeString(phoneCodeHash);

    // Finished serialization.
  }
}

/// Auth Cancel Code.
///
/// ID: `1f040578`.
class AuthCancelCode extends TlMethod<bool> {
  /// Auth Cancel Code constructor.
  const AuthCancelCode({
    required this.phoneNumber,
    required this.phoneCodeHash,
  }) : super._();

  /// Deserialize.
  factory AuthCancelCode.deserialize(BinaryReader reader) {
    // Read [AuthCancelCode] fields.
    final phoneNumber = reader.readString();
    final phoneCodeHash = reader.readString();

    // Construct [AuthCancelCode] object.
    final returnValue = AuthCancelCode(
      phoneNumber: phoneNumber,
      phoneCodeHash: phoneCodeHash,
    );

    // Now return the deserialized [AuthCancelCode].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1f040578.
    buffer.writeInt32(0x1f040578);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeString(phoneCodeHash);

    // Finished serialization.
  }
}

/// Messages Get Message Edit Data.
///
/// ID: `fda68d36`.
class MessagesGetMessageEditData extends TlMethod<MessagesMessageEditDataBase> {
  /// Messages Get Message Edit Data constructor.
  const MessagesGetMessageEditData({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesGetMessageEditData.deserialize(BinaryReader reader) {
    // Read [MessagesGetMessageEditData] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();

    // Construct [MessagesGetMessageEditData] object.
    final returnValue = MessagesGetMessageEditData(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [MessagesGetMessageEditData].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfda68d36.
    buffer.writeInt32(0xfda68d36);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Messages Edit Message.
///
/// ID: `48f71778`.
class MessagesEditMessage extends TlMethod<UpdatesBase> {
  /// Messages Edit Message constructor.
  const MessagesEditMessage({
    required this.noWebpage,
    required this.invertMedia,
    required this.peer,
    required this.id,
    this.message,
    this.media,
    this.replyMarkup,
    this.entities,
    this.scheduleDate,
  }) : super._();

  /// Deserialize.
  factory MessagesEditMessage.deserialize(BinaryReader reader) {
    // Read [MessagesEditMessage] fields.
    final flags = reader.readInt32();
    final noWebpage = (flags & 2) != 0;
    final invertMedia = (flags & 65536) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();
    final hasMessageField = (flags & 2048) != 0;
    final message = hasMessageField ? reader.readString() : null;
    final hasMediaField = (flags & 16384) != 0;
    final media = hasMediaField ? reader.readObject() as InputMediaBase : null;
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;
    final hasEntitiesField = (flags & 8) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasScheduleDateField = (flags & 32768) != 0;
    final scheduleDate = hasScheduleDateField ? reader.readDateTime() : null;

    // Construct [MessagesEditMessage] object.
    final returnValue = MessagesEditMessage(
      noWebpage: noWebpage,
      invertMedia: invertMedia,
      peer: peer,
      id: id,
      message: message,
      media: media,
      replyMarkup: replyMarkup,
      entities: entities,
      scheduleDate: scheduleDate,
    );

    // Now return the deserialized [MessagesEditMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: noWebpage,
      b16: invertMedia,
      b11: message != null,
      b14: media != null,
      b02: replyMarkup != null,
      b03: entities != null,
      b15: scheduleDate != null,
    );

    return v;
  }

  /// no_webpage: bit 1 of flags.1?true
  final bool noWebpage;

  /// invert_media: bit 16 of flags.16?true
  final bool invertMedia;

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Message.
  final String? message;

  /// Media.
  final InputMediaBase? media;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Schedule Date.
  final DateTime? scheduleDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x48f71778.
    buffer.writeInt32(0x48f71778);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    final localMessageCopy = message;
    if (localMessageCopy != null) {
      buffer.writeString(localMessageCopy);
    }
    final localMediaCopy = media;
    if (localMediaCopy != null) {
      buffer.writeObject(localMediaCopy);
    }
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localScheduleDateCopy = scheduleDate;
    if (localScheduleDateCopy != null) {
      buffer.writeDateTime(localScheduleDateCopy);
    }

    // Finished serialization.
  }
}

/// Messages Edit Inline Bot Message.
///
/// ID: `83557dba`.
class MessagesEditInlineBotMessage extends TlMethod<bool> {
  /// Messages Edit Inline Bot Message constructor.
  const MessagesEditInlineBotMessage({
    required this.noWebpage,
    required this.invertMedia,
    required this.id,
    this.message,
    this.media,
    this.replyMarkup,
    this.entities,
  }) : super._();

  /// Deserialize.
  factory MessagesEditInlineBotMessage.deserialize(BinaryReader reader) {
    // Read [MessagesEditInlineBotMessage] fields.
    final flags = reader.readInt32();
    final noWebpage = (flags & 2) != 0;
    final invertMedia = (flags & 65536) != 0;
    final id = reader.readObject() as InputBotInlineMessageIDBase;
    final hasMessageField = (flags & 2048) != 0;
    final message = hasMessageField ? reader.readString() : null;
    final hasMediaField = (flags & 16384) != 0;
    final media = hasMediaField ? reader.readObject() as InputMediaBase : null;
    final hasReplyMarkupField = (flags & 4) != 0;
    final replyMarkup =
        hasReplyMarkupField ? reader.readObject() as ReplyMarkupBase : null;
    final hasEntitiesField = (flags & 8) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;

    // Construct [MessagesEditInlineBotMessage] object.
    final returnValue = MessagesEditInlineBotMessage(
      noWebpage: noWebpage,
      invertMedia: invertMedia,
      id: id,
      message: message,
      media: media,
      replyMarkup: replyMarkup,
      entities: entities,
    );

    // Now return the deserialized [MessagesEditInlineBotMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: noWebpage,
      b16: invertMedia,
      b11: message != null,
      b14: media != null,
      b02: replyMarkup != null,
      b03: entities != null,
    );

    return v;
  }

  /// no_webpage: bit 1 of flags.1?true
  final bool noWebpage;

  /// invert_media: bit 16 of flags.16?true
  final bool invertMedia;

  /// Id.
  final InputBotInlineMessageIDBase id;

  /// Message.
  final String? message;

  /// Media.
  final InputMediaBase? media;

  /// Reply Markup.
  final ReplyMarkupBase? replyMarkup;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x83557dba.
    buffer.writeInt32(0x83557dba);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(id);
    final localMessageCopy = message;
    if (localMessageCopy != null) {
      buffer.writeString(localMessageCopy);
    }
    final localMediaCopy = media;
    if (localMediaCopy != null) {
      buffer.writeObject(localMediaCopy);
    }
    final localReplyMarkupCopy = replyMarkup;
    if (localReplyMarkupCopy != null) {
      buffer.writeObject(localReplyMarkupCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }

    // Finished serialization.
  }
}

/// Messages Get Bot Callback Answer.
///
/// ID: `9342ca07`.
class MessagesGetBotCallbackAnswer
    extends TlMethod<MessagesBotCallbackAnswerBase> {
  /// Messages Get Bot Callback Answer constructor.
  const MessagesGetBotCallbackAnswer({
    required this.game,
    required this.peer,
    required this.msgId,
    this.data,
    this.password,
  }) : super._();

  /// Deserialize.
  factory MessagesGetBotCallbackAnswer.deserialize(BinaryReader reader) {
    // Read [MessagesGetBotCallbackAnswer] fields.
    final flags = reader.readInt32();
    final game = (flags & 2) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final hasDataField = (flags & 1) != 0;
    final data = hasDataField ? reader.readBytes() : null;
    final hasPasswordField = (flags & 4) != 0;
    final password = hasPasswordField
        ? reader.readObject() as InputCheckPasswordSRPBase
        : null;

    // Construct [MessagesGetBotCallbackAnswer] object.
    final returnValue = MessagesGetBotCallbackAnswer(
      game: game,
      peer: peer,
      msgId: msgId,
      data: data,
      password: password,
    );

    // Now return the deserialized [MessagesGetBotCallbackAnswer].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: game,
      b00: data != null,
      b02: password != null,
    );

    return v;
  }

  /// game: bit 1 of flags.1?true
  final bool game;

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Data.
  final Uint8List? data;

  /// Password.
  final InputCheckPasswordSRPBase? password;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9342ca07.
    buffer.writeInt32(0x9342ca07);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    final localDataCopy = data;
    if (localDataCopy != null) {
      buffer.writeBytes(localDataCopy);
    }
    final localPasswordCopy = password;
    if (localPasswordCopy != null) {
      buffer.writeObject(localPasswordCopy);
    }

    // Finished serialization.
  }
}

/// Messages Set Bot Callback Answer.
///
/// ID: `d58f130a`.
class MessagesSetBotCallbackAnswer extends TlMethod<bool> {
  /// Messages Set Bot Callback Answer constructor.
  const MessagesSetBotCallbackAnswer({
    required this.alert,
    required this.queryId,
    this.message,
    this.url,
    required this.cacheTime,
  }) : super._();

  /// Deserialize.
  factory MessagesSetBotCallbackAnswer.deserialize(BinaryReader reader) {
    // Read [MessagesSetBotCallbackAnswer] fields.
    final flags = reader.readInt32();
    final alert = (flags & 2) != 0;
    final queryId = reader.readInt64();
    final hasMessageField = (flags & 1) != 0;
    final message = hasMessageField ? reader.readString() : null;
    final hasUrlField = (flags & 4) != 0;
    final url = hasUrlField ? reader.readString() : null;
    final cacheTime = reader.readInt32();

    // Construct [MessagesSetBotCallbackAnswer] object.
    final returnValue = MessagesSetBotCallbackAnswer(
      alert: alert,
      queryId: queryId,
      message: message,
      url: url,
      cacheTime: cacheTime,
    );

    // Now return the deserialized [MessagesSetBotCallbackAnswer].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: alert,
      b00: message != null,
      b02: url != null,
    );

    return v;
  }

  /// alert: bit 1 of flags.1?true
  final bool alert;

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Message.
  final String? message;

  /// Url.
  final String? url;

  /// Cache Time.
  ///
  /// Field type is Int32.
  final int cacheTime;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd58f130a.
    buffer.writeInt32(0xd58f130a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(queryId);
    final localMessageCopy = message;
    if (localMessageCopy != null) {
      buffer.writeString(localMessageCopy);
    }
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }
    buffer.writeInt32(cacheTime);

    // Finished serialization.
  }
}

/// Contacts Get Top Peers.
///
/// ID: `973478b6`.
class ContactsGetTopPeers extends TlMethod<ContactsTopPeersBase> {
  /// Contacts Get Top Peers constructor.
  const ContactsGetTopPeers({
    required this.correspondents,
    required this.botsPm,
    required this.botsInline,
    required this.phoneCalls,
    required this.forwardUsers,
    required this.forwardChats,
    required this.groups,
    required this.channels,
    required this.offset,
    required this.limit,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory ContactsGetTopPeers.deserialize(BinaryReader reader) {
    // Read [ContactsGetTopPeers] fields.
    final flags = reader.readInt32();
    final correspondents = (flags & 1) != 0;
    final botsPm = (flags & 2) != 0;
    final botsInline = (flags & 4) != 0;
    final phoneCalls = (flags & 8) != 0;
    final forwardUsers = (flags & 16) != 0;
    final forwardChats = (flags & 32) != 0;
    final groups = (flags & 1024) != 0;
    final channels = (flags & 32768) != 0;
    final offset = reader.readInt32();
    final limit = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [ContactsGetTopPeers] object.
    final returnValue = ContactsGetTopPeers(
      correspondents: correspondents,
      botsPm: botsPm,
      botsInline: botsInline,
      phoneCalls: phoneCalls,
      forwardUsers: forwardUsers,
      forwardChats: forwardChats,
      groups: groups,
      channels: channels,
      offset: offset,
      limit: limit,
      hash: hash,
    );

    // Now return the deserialized [ContactsGetTopPeers].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: correspondents,
      b01: botsPm,
      b02: botsInline,
      b03: phoneCalls,
      b04: forwardUsers,
      b05: forwardChats,
      b10: groups,
      b15: channels,
    );

    return v;
  }

  /// correspondents: bit 0 of flags.0?true
  final bool correspondents;

  /// bots_pm: bit 1 of flags.1?true
  final bool botsPm;

  /// bots_inline: bit 2 of flags.2?true
  final bool botsInline;

  /// phone_calls: bit 3 of flags.3?true
  final bool phoneCalls;

  /// forward_users: bit 4 of flags.4?true
  final bool forwardUsers;

  /// forward_chats: bit 5 of flags.5?true
  final bool forwardChats;

  /// groups: bit 10 of flags.10?true
  final bool groups;

  /// channels: bit 15 of flags.15?true
  final bool channels;

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x973478b6.
    buffer.writeInt32(0x973478b6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(offset);
    buffer.writeInt32(limit);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Contacts Reset Top Peer Rating.
///
/// ID: `1ae373ac`.
class ContactsResetTopPeerRating extends TlMethod<bool> {
  /// Contacts Reset Top Peer Rating constructor.
  const ContactsResetTopPeerRating({
    required this.category,
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory ContactsResetTopPeerRating.deserialize(BinaryReader reader) {
    // Read [ContactsResetTopPeerRating] fields.
    final category = reader.readObject() as TopPeerCategoryBase;
    final peer = reader.readObject() as InputPeerBase;

    // Construct [ContactsResetTopPeerRating] object.
    final returnValue = ContactsResetTopPeerRating(
      category: category,
      peer: peer,
    );

    // Now return the deserialized [ContactsResetTopPeerRating].
    return returnValue;
  }

  /// Category.
  final TopPeerCategoryBase category;

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1ae373ac.
    buffer.writeInt32(0x1ae373ac);

    // Write fields.
    buffer.writeObject(category);
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Messages Get Peer Dialogs.
///
/// ID: `e470bcfd`.
class MessagesGetPeerDialogs extends TlMethod<MessagesPeerDialogsBase> {
  /// Messages Get Peer Dialogs constructor.
  const MessagesGetPeerDialogs({
    required this.peers,
  }) : super._();

  /// Deserialize.
  factory MessagesGetPeerDialogs.deserialize(BinaryReader reader) {
    // Read [MessagesGetPeerDialogs] fields.
    final peers = reader.readVectorObject<InputDialogPeerBase>();

    // Construct [MessagesGetPeerDialogs] object.
    final returnValue = MessagesGetPeerDialogs(
      peers: peers,
    );

    // Now return the deserialized [MessagesGetPeerDialogs].
    return returnValue;
  }

  /// Peers.
  final List<InputDialogPeerBase> peers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe470bcfd.
    buffer.writeInt32(0xe470bcfd);

    // Write fields.
    buffer.writeVectorObject(peers);

    // Finished serialization.
  }
}

/// Messages Save Draft.
///
/// ID: `7ff3b806`.
class MessagesSaveDraft extends TlMethod<bool> {
  /// Messages Save Draft constructor.
  const MessagesSaveDraft({
    required this.noWebpage,
    required this.invertMedia,
    this.replyTo,
    required this.peer,
    required this.message,
    this.entities,
    this.media,
  }) : super._();

  /// Deserialize.
  factory MessagesSaveDraft.deserialize(BinaryReader reader) {
    // Read [MessagesSaveDraft] fields.
    final flags = reader.readInt32();
    final noWebpage = (flags & 2) != 0;
    final invertMedia = (flags & 64) != 0;
    final hasReplyToField = (flags & 16) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as InputReplyToBase : null;
    final peer = reader.readObject() as InputPeerBase;
    final message = reader.readString();
    final hasEntitiesField = (flags & 8) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasMediaField = (flags & 32) != 0;
    final media = hasMediaField ? reader.readObject() as InputMediaBase : null;

    // Construct [MessagesSaveDraft] object.
    final returnValue = MessagesSaveDraft(
      noWebpage: noWebpage,
      invertMedia: invertMedia,
      replyTo: replyTo,
      peer: peer,
      message: message,
      entities: entities,
      media: media,
    );

    // Now return the deserialized [MessagesSaveDraft].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: noWebpage,
      b06: invertMedia,
      b04: replyTo != null,
      b03: entities != null,
      b05: media != null,
    );

    return v;
  }

  /// no_webpage: bit 1 of flags.1?true
  final bool noWebpage;

  /// invert_media: bit 6 of flags.6?true
  final bool invertMedia;

  /// Reply To.
  final InputReplyToBase? replyTo;

  /// Peer.
  final InputPeerBase peer;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Media.
  final InputMediaBase? media;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7ff3b806.
    buffer.writeInt32(0x7ff3b806);

    // Write fields.
    buffer.writeInt32(flags);
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    buffer.writeObject(peer);
    buffer.writeString(message);
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localMediaCopy = media;
    if (localMediaCopy != null) {
      buffer.writeObject(localMediaCopy);
    }

    // Finished serialization.
  }
}

/// Messages Get All Drafts.
///
/// ID: `6a3f8d65`.
class MessagesGetAllDrafts extends TlMethod<UpdatesBase> {
  /// Messages Get All Drafts constructor.
  const MessagesGetAllDrafts() : super._();

  /// Deserialize.
  factory MessagesGetAllDrafts.deserialize(BinaryReader reader) {
    // Construct [MessagesGetAllDrafts] object.
    final returnValue = MessagesGetAllDrafts();

    // Now return the deserialized [MessagesGetAllDrafts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6a3f8d65.
    buffer.writeInt32(0x6a3f8d65);

    // Finished serialization.
  }
}

/// Messages Get Featured Stickers.
///
/// ID: `64780b14`.
class MessagesGetFeaturedStickers
    extends TlMethod<MessagesFeaturedStickersBase> {
  /// Messages Get Featured Stickers constructor.
  const MessagesGetFeaturedStickers({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetFeaturedStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetFeaturedStickers] fields.
    final hash = reader.readInt64();

    // Construct [MessagesGetFeaturedStickers] object.
    final returnValue = MessagesGetFeaturedStickers(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetFeaturedStickers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x64780b14.
    buffer.writeInt32(0x64780b14);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Read Featured Stickers.
///
/// ID: `5b118126`.
class MessagesReadFeaturedStickers extends TlMethod<bool> {
  /// Messages Read Featured Stickers constructor.
  const MessagesReadFeaturedStickers({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesReadFeaturedStickers.deserialize(BinaryReader reader) {
    // Read [MessagesReadFeaturedStickers] fields.
    final id = reader.readVectorInt64();

    // Construct [MessagesReadFeaturedStickers] object.
    final returnValue = MessagesReadFeaturedStickers(
      id: id,
    );

    // Now return the deserialized [MessagesReadFeaturedStickers].
    return returnValue;
  }

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5b118126.
    buffer.writeInt32(0x5b118126);

    // Write fields.
    buffer.writeVectorInt64(id);

    // Finished serialization.
  }
}

/// Messages Get Recent Stickers.
///
/// ID: `9da9403b`.
class MessagesGetRecentStickers extends TlMethod<MessagesRecentStickersBase> {
  /// Messages Get Recent Stickers constructor.
  const MessagesGetRecentStickers({
    required this.attached,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetRecentStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetRecentStickers] fields.
    final flags = reader.readInt32();
    final attached = (flags & 1) != 0;
    final hash = reader.readInt64();

    // Construct [MessagesGetRecentStickers] object.
    final returnValue = MessagesGetRecentStickers(
      attached: attached,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetRecentStickers].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: attached,
    );

    return v;
  }

  /// attached: bit 0 of flags.0?true
  final bool attached;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9da9403b.
    buffer.writeInt32(0x9da9403b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Save Recent Sticker.
///
/// ID: `392718f8`.
class MessagesSaveRecentSticker extends TlMethod<bool> {
  /// Messages Save Recent Sticker constructor.
  const MessagesSaveRecentSticker({
    required this.attached,
    required this.id,
    required this.unsave,
  }) : super._();

  /// Deserialize.
  factory MessagesSaveRecentSticker.deserialize(BinaryReader reader) {
    // Read [MessagesSaveRecentSticker] fields.
    final flags = reader.readInt32();
    final attached = (flags & 1) != 0;
    final id = reader.readObject() as InputDocumentBase;
    final unsave = reader.readBool();

    // Construct [MessagesSaveRecentSticker] object.
    final returnValue = MessagesSaveRecentSticker(
      attached: attached,
      id: id,
      unsave: unsave,
    );

    // Now return the deserialized [MessagesSaveRecentSticker].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: attached,
    );

    return v;
  }

  /// attached: bit 0 of flags.0?true
  final bool attached;

  /// Id.
  final InputDocumentBase id;

  /// Unsave.
  final bool unsave;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x392718f8.
    buffer.writeInt32(0x392718f8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(id);
    buffer.writeBool(unsave);

    // Finished serialization.
  }
}

/// Messages Clear Recent Stickers.
///
/// ID: `8999602d`.
class MessagesClearRecentStickers extends TlMethod<bool> {
  /// Messages Clear Recent Stickers constructor.
  const MessagesClearRecentStickers({
    required this.attached,
  }) : super._();

  /// Deserialize.
  factory MessagesClearRecentStickers.deserialize(BinaryReader reader) {
    // Read [MessagesClearRecentStickers] fields.
    final flags = reader.readInt32();
    final attached = (flags & 1) != 0;

    // Construct [MessagesClearRecentStickers] object.
    final returnValue = MessagesClearRecentStickers(
      attached: attached,
    );

    // Now return the deserialized [MessagesClearRecentStickers].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: attached,
    );

    return v;
  }

  /// attached: bit 0 of flags.0?true
  final bool attached;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8999602d.
    buffer.writeInt32(0x8999602d);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Messages Get Archived Stickers.
///
/// ID: `57f17692`.
class MessagesGetArchivedStickers
    extends TlMethod<MessagesArchivedStickersBase> {
  /// Messages Get Archived Stickers constructor.
  const MessagesGetArchivedStickers({
    required this.masks,
    required this.emojis,
    required this.offsetId,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory MessagesGetArchivedStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetArchivedStickers] fields.
    final flags = reader.readInt32();
    final masks = (flags & 1) != 0;
    final emojis = (flags & 2) != 0;
    final offsetId = reader.readInt64();
    final limit = reader.readInt32();

    // Construct [MessagesGetArchivedStickers] object.
    final returnValue = MessagesGetArchivedStickers(
      masks: masks,
      emojis: emojis,
      offsetId: offsetId,
      limit: limit,
    );

    // Now return the deserialized [MessagesGetArchivedStickers].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: masks,
      b01: emojis,
    );

    return v;
  }

  /// masks: bit 0 of flags.0?true
  final bool masks;

  /// emojis: bit 1 of flags.1?true
  final bool emojis;

  /// Offset Id.
  ///
  /// Field type is Int64.
  final int offsetId;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x57f17692.
    buffer.writeInt32(0x57f17692);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(offsetId);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Account Send Confirm Phone Code.
///
/// ID: `1b3faa88`.
class AccountSendConfirmPhoneCode extends TlMethod<AuthSentCodeBase> {
  /// Account Send Confirm Phone Code constructor.
  const AccountSendConfirmPhoneCode({
    required this.hash,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountSendConfirmPhoneCode.deserialize(BinaryReader reader) {
    // Read [AccountSendConfirmPhoneCode] fields.
    final hash = reader.readString();
    final settings = reader.readObject() as CodeSettingsBase;

    // Construct [AccountSendConfirmPhoneCode] object.
    final returnValue = AccountSendConfirmPhoneCode(
      hash: hash,
      settings: settings,
    );

    // Now return the deserialized [AccountSendConfirmPhoneCode].
    return returnValue;
  }

  /// Hash.
  final String hash;

  /// Settings.
  final CodeSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1b3faa88.
    buffer.writeInt32(0x1b3faa88);

    // Write fields.
    buffer.writeString(hash);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Account Confirm Phone.
///
/// ID: `5f2178c3`.
class AccountConfirmPhone extends TlMethod<bool> {
  /// Account Confirm Phone constructor.
  const AccountConfirmPhone({
    required this.phoneCodeHash,
    required this.phoneCode,
  }) : super._();

  /// Deserialize.
  factory AccountConfirmPhone.deserialize(BinaryReader reader) {
    // Read [AccountConfirmPhone] fields.
    final phoneCodeHash = reader.readString();
    final phoneCode = reader.readString();

    // Construct [AccountConfirmPhone] object.
    final returnValue = AccountConfirmPhone(
      phoneCodeHash: phoneCodeHash,
      phoneCode: phoneCode,
    );

    // Now return the deserialized [AccountConfirmPhone].
    return returnValue;
  }

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// Phone Code.
  final String phoneCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5f2178c3.
    buffer.writeInt32(0x5f2178c3);

    // Write fields.
    buffer.writeString(phoneCodeHash);
    buffer.writeString(phoneCode);

    // Finished serialization.
  }
}

/// Channels Get Admined Public Channels.
///
/// ID: `f8b036af`.
class ChannelsGetAdminedPublicChannels extends TlMethod<MessagesChatsBase> {
  /// Channels Get Admined Public Channels constructor.
  const ChannelsGetAdminedPublicChannels({
    required this.byLocation,
    required this.checkLimit,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetAdminedPublicChannels.deserialize(BinaryReader reader) {
    // Read [ChannelsGetAdminedPublicChannels] fields.
    final flags = reader.readInt32();
    final byLocation = (flags & 1) != 0;
    final checkLimit = (flags & 2) != 0;

    // Construct [ChannelsGetAdminedPublicChannels] object.
    final returnValue = ChannelsGetAdminedPublicChannels(
      byLocation: byLocation,
      checkLimit: checkLimit,
    );

    // Now return the deserialized [ChannelsGetAdminedPublicChannels].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: byLocation,
      b01: checkLimit,
    );

    return v;
  }

  /// by_location: bit 0 of flags.0?true
  final bool byLocation;

  /// check_limit: bit 1 of flags.1?true
  final bool checkLimit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf8b036af.
    buffer.writeInt32(0xf8b036af);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Messages Get Mask Stickers.
///
/// ID: `640f82b8`.
class MessagesGetMaskStickers extends TlMethod<MessagesAllStickersBase> {
  /// Messages Get Mask Stickers constructor.
  const MessagesGetMaskStickers({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetMaskStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetMaskStickers] fields.
    final hash = reader.readInt64();

    // Construct [MessagesGetMaskStickers] object.
    final returnValue = MessagesGetMaskStickers(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetMaskStickers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x640f82b8.
    buffer.writeInt32(0x640f82b8);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Get Attached Stickers.
///
/// ID: `cc5b67cc`.
class MessagesGetAttachedStickers
    extends TlMethod<List<StickerSetCoveredBase>> {
  /// Messages Get Attached Stickers constructor.
  const MessagesGetAttachedStickers({
    required this.media,
  }) : super._();

  /// Deserialize.
  factory MessagesGetAttachedStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetAttachedStickers] fields.
    final media = reader.readObject() as InputStickeredMediaBase;

    // Construct [MessagesGetAttachedStickers] object.
    final returnValue = MessagesGetAttachedStickers(
      media: media,
    );

    // Now return the deserialized [MessagesGetAttachedStickers].
    return returnValue;
  }

  /// Media.
  final InputStickeredMediaBase media;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcc5b67cc.
    buffer.writeInt32(0xcc5b67cc);

    // Write fields.
    buffer.writeObject(media);

    // Finished serialization.
  }
}

/// Auth Drop Temp Auth Keys.
///
/// ID: `8e48a188`.
class AuthDropTempAuthKeys extends TlMethod<bool> {
  /// Auth Drop Temp Auth Keys constructor.
  const AuthDropTempAuthKeys({
    required this.exceptAuthKeys,
  }) : super._();

  /// Deserialize.
  factory AuthDropTempAuthKeys.deserialize(BinaryReader reader) {
    // Read [AuthDropTempAuthKeys] fields.
    final exceptAuthKeys = reader.readVectorInt64();

    // Construct [AuthDropTempAuthKeys] object.
    final returnValue = AuthDropTempAuthKeys(
      exceptAuthKeys: exceptAuthKeys,
    );

    // Now return the deserialized [AuthDropTempAuthKeys].
    return returnValue;
  }

  /// Except Auth Keys.
  final List<int> exceptAuthKeys;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8e48a188.
    buffer.writeInt32(0x8e48a188);

    // Write fields.
    buffer.writeVectorInt64(exceptAuthKeys);

    // Finished serialization.
  }
}

/// Messages Set Game Score.
///
/// ID: `8ef8ecc0`.
class MessagesSetGameScore extends TlMethod<UpdatesBase> {
  /// Messages Set Game Score constructor.
  const MessagesSetGameScore({
    required this.editMessage,
    required this.force,
    required this.peer,
    required this.id,
    required this.userId,
    required this.score,
  }) : super._();

  /// Deserialize.
  factory MessagesSetGameScore.deserialize(BinaryReader reader) {
    // Read [MessagesSetGameScore] fields.
    final flags = reader.readInt32();
    final editMessage = (flags & 1) != 0;
    final force = (flags & 2) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();
    final userId = reader.readObject() as InputUserBase;
    final score = reader.readInt32();

    // Construct [MessagesSetGameScore] object.
    final returnValue = MessagesSetGameScore(
      editMessage: editMessage,
      force: force,
      peer: peer,
      id: id,
      userId: userId,
      score: score,
    );

    // Now return the deserialized [MessagesSetGameScore].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: editMessage,
      b01: force,
    );

    return v;
  }

  /// edit_message: bit 0 of flags.0?true
  final bool editMessage;

  /// force: bit 1 of flags.1?true
  final bool force;

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// User Id.
  final InputUserBase userId;

  /// Score.
  ///
  /// Field type is Int32.
  final int score;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8ef8ecc0.
    buffer.writeInt32(0x8ef8ecc0);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    buffer.writeObject(userId);
    buffer.writeInt32(score);

    // Finished serialization.
  }
}

/// Messages Set Inline Game Score.
///
/// ID: `15ad9f64`.
class MessagesSetInlineGameScore extends TlMethod<bool> {
  /// Messages Set Inline Game Score constructor.
  const MessagesSetInlineGameScore({
    required this.editMessage,
    required this.force,
    required this.id,
    required this.userId,
    required this.score,
  }) : super._();

  /// Deserialize.
  factory MessagesSetInlineGameScore.deserialize(BinaryReader reader) {
    // Read [MessagesSetInlineGameScore] fields.
    final flags = reader.readInt32();
    final editMessage = (flags & 1) != 0;
    final force = (flags & 2) != 0;
    final id = reader.readObject() as InputBotInlineMessageIDBase;
    final userId = reader.readObject() as InputUserBase;
    final score = reader.readInt32();

    // Construct [MessagesSetInlineGameScore] object.
    final returnValue = MessagesSetInlineGameScore(
      editMessage: editMessage,
      force: force,
      id: id,
      userId: userId,
      score: score,
    );

    // Now return the deserialized [MessagesSetInlineGameScore].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: editMessage,
      b01: force,
    );

    return v;
  }

  /// edit_message: bit 0 of flags.0?true
  final bool editMessage;

  /// force: bit 1 of flags.1?true
  final bool force;

  /// Id.
  final InputBotInlineMessageIDBase id;

  /// User Id.
  final InputUserBase userId;

  /// Score.
  ///
  /// Field type is Int32.
  final int score;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x15ad9f64.
    buffer.writeInt32(0x15ad9f64);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(id);
    buffer.writeObject(userId);
    buffer.writeInt32(score);

    // Finished serialization.
  }
}

/// Messages Get Game High Scores.
///
/// ID: `e822649d`.
class MessagesGetGameHighScores extends TlMethod<MessagesHighScoresBase> {
  /// Messages Get Game High Scores constructor.
  const MessagesGetGameHighScores({
    required this.peer,
    required this.id,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory MessagesGetGameHighScores.deserialize(BinaryReader reader) {
    // Read [MessagesGetGameHighScores] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();
    final userId = reader.readObject() as InputUserBase;

    // Construct [MessagesGetGameHighScores] object.
    final returnValue = MessagesGetGameHighScores(
      peer: peer,
      id: id,
      userId: userId,
    );

    // Now return the deserialized [MessagesGetGameHighScores].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// User Id.
  final InputUserBase userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe822649d.
    buffer.writeInt32(0xe822649d);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    buffer.writeObject(userId);

    // Finished serialization.
  }
}

/// Messages Get Inline Game High Scores.
///
/// ID: `0f635e1b`.
class MessagesGetInlineGameHighScores extends TlMethod<MessagesHighScoresBase> {
  /// Messages Get Inline Game High Scores constructor.
  const MessagesGetInlineGameHighScores({
    required this.id,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory MessagesGetInlineGameHighScores.deserialize(BinaryReader reader) {
    // Read [MessagesGetInlineGameHighScores] fields.
    final id = reader.readObject() as InputBotInlineMessageIDBase;
    final userId = reader.readObject() as InputUserBase;

    // Construct [MessagesGetInlineGameHighScores] object.
    final returnValue = MessagesGetInlineGameHighScores(
      id: id,
      userId: userId,
    );

    // Now return the deserialized [MessagesGetInlineGameHighScores].
    return returnValue;
  }

  /// Id.
  final InputBotInlineMessageIDBase id;

  /// User Id.
  final InputUserBase userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0f635e1b.
    buffer.writeInt32(0x0f635e1b);

    // Write fields.
    buffer.writeObject(id);
    buffer.writeObject(userId);

    // Finished serialization.
  }
}

/// Messages Get Common Chats.
///
/// ID: `e40ca104`.
class MessagesGetCommonChats extends TlMethod<MessagesChatsBase> {
  /// Messages Get Common Chats constructor.
  const MessagesGetCommonChats({
    required this.userId,
    required this.maxId,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory MessagesGetCommonChats.deserialize(BinaryReader reader) {
    // Read [MessagesGetCommonChats] fields.
    final userId = reader.readObject() as InputUserBase;
    final maxId = reader.readInt64();
    final limit = reader.readInt32();

    // Construct [MessagesGetCommonChats] object.
    final returnValue = MessagesGetCommonChats(
      userId: userId,
      maxId: maxId,
      limit: limit,
    );

    // Now return the deserialized [MessagesGetCommonChats].
    return returnValue;
  }

  /// User Id.
  final InputUserBase userId;

  /// Max Id.
  ///
  /// Field type is Int64.
  final int maxId;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe40ca104.
    buffer.writeInt32(0xe40ca104);

    // Write fields.
    buffer.writeObject(userId);
    buffer.writeInt64(maxId);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Help Set Bot Updates Status.
///
/// ID: `ec22cfcd`.
class HelpSetBotUpdatesStatus extends TlMethod<bool> {
  /// Help Set Bot Updates Status constructor.
  const HelpSetBotUpdatesStatus({
    required this.pendingUpdatesCount,
    required this.message,
  }) : super._();

  /// Deserialize.
  factory HelpSetBotUpdatesStatus.deserialize(BinaryReader reader) {
    // Read [HelpSetBotUpdatesStatus] fields.
    final pendingUpdatesCount = reader.readInt32();
    final message = reader.readString();

    // Construct [HelpSetBotUpdatesStatus] object.
    final returnValue = HelpSetBotUpdatesStatus(
      pendingUpdatesCount: pendingUpdatesCount,
      message: message,
    );

    // Now return the deserialized [HelpSetBotUpdatesStatus].
    return returnValue;
  }

  /// Pending Updates Count.
  ///
  /// Field type is Int32.
  final int pendingUpdatesCount;

  /// Message.
  final String message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xec22cfcd.
    buffer.writeInt32(0xec22cfcd);

    // Write fields.
    buffer.writeInt32(pendingUpdatesCount);
    buffer.writeString(message);

    // Finished serialization.
  }
}

/// Messages Get Web Page.
///
/// ID: `8d9692a3`.
class MessagesGetWebPage extends TlMethod<MessagesWebPageBase> {
  /// Messages Get Web Page constructor.
  const MessagesGetWebPage({
    required this.url,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetWebPage.deserialize(BinaryReader reader) {
    // Read [MessagesGetWebPage] fields.
    final url = reader.readString();
    final hash = reader.readInt32();

    // Construct [MessagesGetWebPage] object.
    final returnValue = MessagesGetWebPage(
      url: url,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetWebPage].
    return returnValue;
  }

  /// Url.
  final String url;

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8d9692a3.
    buffer.writeInt32(0x8d9692a3);

    // Write fields.
    buffer.writeString(url);
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Messages Toggle Dialog Pin.
///
/// ID: `a731e257`.
class MessagesToggleDialogPin extends TlMethod<bool> {
  /// Messages Toggle Dialog Pin constructor.
  const MessagesToggleDialogPin({
    required this.pinned,
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesToggleDialogPin.deserialize(BinaryReader reader) {
    // Read [MessagesToggleDialogPin] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 1) != 0;
    final peer = reader.readObject() as InputDialogPeerBase;

    // Construct [MessagesToggleDialogPin] object.
    final returnValue = MessagesToggleDialogPin(
      pinned: pinned,
      peer: peer,
    );

    // Now return the deserialized [MessagesToggleDialogPin].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pinned,
    );

    return v;
  }

  /// pinned: bit 0 of flags.0?true
  final bool pinned;

  /// Peer.
  final InputDialogPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa731e257.
    buffer.writeInt32(0xa731e257);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Messages Reorder Pinned Dialogs.
///
/// ID: `3b1adf37`.
class MessagesReorderPinnedDialogs extends TlMethod<bool> {
  /// Messages Reorder Pinned Dialogs constructor.
  const MessagesReorderPinnedDialogs({
    required this.force,
    required this.folderId,
    required this.order,
  }) : super._();

  /// Deserialize.
  factory MessagesReorderPinnedDialogs.deserialize(BinaryReader reader) {
    // Read [MessagesReorderPinnedDialogs] fields.
    final flags = reader.readInt32();
    final force = (flags & 1) != 0;
    final folderId = reader.readInt32();
    final order = reader.readVectorObject<InputDialogPeerBase>();

    // Construct [MessagesReorderPinnedDialogs] object.
    final returnValue = MessagesReorderPinnedDialogs(
      force: force,
      folderId: folderId,
      order: order,
    );

    // Now return the deserialized [MessagesReorderPinnedDialogs].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: force,
    );

    return v;
  }

  /// force: bit 0 of flags.0?true
  final bool force;

  /// Folder Id.
  ///
  /// Field type is Int32.
  final int folderId;

  /// Order.
  final List<InputDialogPeerBase> order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3b1adf37.
    buffer.writeInt32(0x3b1adf37);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(folderId);
    buffer.writeVectorObject(order);

    // Finished serialization.
  }
}

/// Messages Get Pinned Dialogs.
///
/// ID: `d6b94df2`.
class MessagesGetPinnedDialogs extends TlMethod<MessagesPeerDialogsBase> {
  /// Messages Get Pinned Dialogs constructor.
  const MessagesGetPinnedDialogs({
    required this.folderId,
  }) : super._();

  /// Deserialize.
  factory MessagesGetPinnedDialogs.deserialize(BinaryReader reader) {
    // Read [MessagesGetPinnedDialogs] fields.
    final folderId = reader.readInt32();

    // Construct [MessagesGetPinnedDialogs] object.
    final returnValue = MessagesGetPinnedDialogs(
      folderId: folderId,
    );

    // Now return the deserialized [MessagesGetPinnedDialogs].
    return returnValue;
  }

  /// Folder Id.
  ///
  /// Field type is Int32.
  final int folderId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd6b94df2.
    buffer.writeInt32(0xd6b94df2);

    // Write fields.
    buffer.writeInt32(folderId);

    // Finished serialization.
  }
}

/// Bots Send Custom Request.
///
/// ID: `aa2769ed`.
class BotsSendCustomRequest extends TlMethod<DataJSONBase> {
  /// Bots Send Custom Request constructor.
  const BotsSendCustomRequest({
    required this.customMethod,
    required this.params,
  }) : super._();

  /// Deserialize.
  factory BotsSendCustomRequest.deserialize(BinaryReader reader) {
    // Read [BotsSendCustomRequest] fields.
    final customMethod = reader.readString();
    final params = reader.readObject() as DataJSONBase;

    // Construct [BotsSendCustomRequest] object.
    final returnValue = BotsSendCustomRequest(
      customMethod: customMethod,
      params: params,
    );

    // Now return the deserialized [BotsSendCustomRequest].
    return returnValue;
  }

  /// Custom Method.
  final String customMethod;

  /// Params.
  final DataJSONBase params;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaa2769ed.
    buffer.writeInt32(0xaa2769ed);

    // Write fields.
    buffer.writeString(customMethod);
    buffer.writeObject(params);

    // Finished serialization.
  }
}

/// Bots Answer Webhook J S O N Query.
///
/// ID: `e6213f4d`.
class BotsAnswerWebhookJSONQuery extends TlMethod<bool> {
  /// Bots Answer Webhook J S O N Query constructor.
  const BotsAnswerWebhookJSONQuery({
    required this.queryId,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory BotsAnswerWebhookJSONQuery.deserialize(BinaryReader reader) {
    // Read [BotsAnswerWebhookJSONQuery] fields.
    final queryId = reader.readInt64();
    final data = reader.readObject() as DataJSONBase;

    // Construct [BotsAnswerWebhookJSONQuery] object.
    final returnValue = BotsAnswerWebhookJSONQuery(
      queryId: queryId,
      data: data,
    );

    // Now return the deserialized [BotsAnswerWebhookJSONQuery].
    return returnValue;
  }

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Data.
  final DataJSONBase data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe6213f4d.
    buffer.writeInt32(0xe6213f4d);

    // Write fields.
    buffer.writeInt64(queryId);
    buffer.writeObject(data);

    // Finished serialization.
  }
}

/// Upload Get Web File.
///
/// ID: `24e6818d`.
class UploadGetWebFile extends TlMethod<UploadWebFileBase> {
  /// Upload Get Web File constructor.
  const UploadGetWebFile({
    required this.location,
    required this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory UploadGetWebFile.deserialize(BinaryReader reader) {
    // Read [UploadGetWebFile] fields.
    final location = reader.readObject() as InputWebFileLocationBase;
    final offset = reader.readInt32();
    final limit = reader.readInt32();

    // Construct [UploadGetWebFile] object.
    final returnValue = UploadGetWebFile(
      location: location,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [UploadGetWebFile].
    return returnValue;
  }

  /// Location.
  final InputWebFileLocationBase location;

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x24e6818d.
    buffer.writeInt32(0x24e6818d);

    // Write fields.
    buffer.writeObject(location);
    buffer.writeInt32(offset);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Payments Get Payment Form.
///
/// ID: `37148dbb`.
class PaymentsGetPaymentForm extends TlMethod<PaymentsPaymentFormBase> {
  /// Payments Get Payment Form constructor.
  const PaymentsGetPaymentForm({
    required this.invoice,
    this.themeParams,
  }) : super._();

  /// Deserialize.
  factory PaymentsGetPaymentForm.deserialize(BinaryReader reader) {
    // Read [PaymentsGetPaymentForm] fields.
    final flags = reader.readInt32();
    final invoice = reader.readObject() as InputInvoiceBase;
    final hasThemeParamsField = (flags & 1) != 0;
    final themeParams =
        hasThemeParamsField ? reader.readObject() as DataJSONBase : null;

    // Construct [PaymentsGetPaymentForm] object.
    final returnValue = PaymentsGetPaymentForm(
      invoice: invoice,
      themeParams: themeParams,
    );

    // Now return the deserialized [PaymentsGetPaymentForm].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: themeParams != null,
    );

    return v;
  }

  /// Invoice.
  final InputInvoiceBase invoice;

  /// Theme Params.
  final DataJSONBase? themeParams;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x37148dbb.
    buffer.writeInt32(0x37148dbb);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(invoice);
    final localThemeParamsCopy = themeParams;
    if (localThemeParamsCopy != null) {
      buffer.writeObject(localThemeParamsCopy);
    }

    // Finished serialization.
  }
}

/// Payments Get Payment Receipt.
///
/// ID: `2478d1cc`.
class PaymentsGetPaymentReceipt extends TlMethod<PaymentsPaymentReceiptBase> {
  /// Payments Get Payment Receipt constructor.
  const PaymentsGetPaymentReceipt({
    required this.peer,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory PaymentsGetPaymentReceipt.deserialize(BinaryReader reader) {
    // Read [PaymentsGetPaymentReceipt] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();

    // Construct [PaymentsGetPaymentReceipt] object.
    final returnValue = PaymentsGetPaymentReceipt(
      peer: peer,
      msgId: msgId,
    );

    // Now return the deserialized [PaymentsGetPaymentReceipt].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2478d1cc.
    buffer.writeInt32(0x2478d1cc);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Payments Validate Requested Info.
///
/// ID: `b6c8f12b`.
class PaymentsValidateRequestedInfo
    extends TlMethod<PaymentsValidatedRequestedInfoBase> {
  /// Payments Validate Requested Info constructor.
  const PaymentsValidateRequestedInfo({
    required this.save,
    required this.invoice,
    required this.info,
  }) : super._();

  /// Deserialize.
  factory PaymentsValidateRequestedInfo.deserialize(BinaryReader reader) {
    // Read [PaymentsValidateRequestedInfo] fields.
    final flags = reader.readInt32();
    final save = (flags & 1) != 0;
    final invoice = reader.readObject() as InputInvoiceBase;
    final info = reader.readObject() as PaymentRequestedInfoBase;

    // Construct [PaymentsValidateRequestedInfo] object.
    final returnValue = PaymentsValidateRequestedInfo(
      save: save,
      invoice: invoice,
      info: info,
    );

    // Now return the deserialized [PaymentsValidateRequestedInfo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: save,
    );

    return v;
  }

  /// save: bit 0 of flags.0?true
  final bool save;

  /// Invoice.
  final InputInvoiceBase invoice;

  /// Info.
  final PaymentRequestedInfoBase info;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb6c8f12b.
    buffer.writeInt32(0xb6c8f12b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(invoice);
    buffer.writeObject(info);

    // Finished serialization.
  }
}

/// Payments Send Payment Form.
///
/// ID: `2d03522f`.
class PaymentsSendPaymentForm extends TlMethod<PaymentsPaymentResultBase> {
  /// Payments Send Payment Form constructor.
  const PaymentsSendPaymentForm({
    required this.formId,
    required this.invoice,
    this.requestedInfoId,
    this.shippingOptionId,
    required this.credentials,
    this.tipAmount,
  }) : super._();

  /// Deserialize.
  factory PaymentsSendPaymentForm.deserialize(BinaryReader reader) {
    // Read [PaymentsSendPaymentForm] fields.
    final flags = reader.readInt32();
    final formId = reader.readInt64();
    final invoice = reader.readObject() as InputInvoiceBase;
    final hasRequestedInfoIdField = (flags & 1) != 0;
    final requestedInfoId =
        hasRequestedInfoIdField ? reader.readString() : null;
    final hasShippingOptionIdField = (flags & 2) != 0;
    final shippingOptionId =
        hasShippingOptionIdField ? reader.readString() : null;
    final credentials = reader.readObject() as InputPaymentCredentialsBase;
    final hasTipAmountField = (flags & 4) != 0;
    final tipAmount = hasTipAmountField ? reader.readInt64() : null;

    // Construct [PaymentsSendPaymentForm] object.
    final returnValue = PaymentsSendPaymentForm(
      formId: formId,
      invoice: invoice,
      requestedInfoId: requestedInfoId,
      shippingOptionId: shippingOptionId,
      credentials: credentials,
      tipAmount: tipAmount,
    );

    // Now return the deserialized [PaymentsSendPaymentForm].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: requestedInfoId != null,
      b01: shippingOptionId != null,
      b02: tipAmount != null,
    );

    return v;
  }

  /// Form Id.
  ///
  /// Field type is Int64.
  final int formId;

  /// Invoice.
  final InputInvoiceBase invoice;

  /// Requested Info Id.
  final String? requestedInfoId;

  /// Shipping Option Id.
  final String? shippingOptionId;

  /// Credentials.
  final InputPaymentCredentialsBase credentials;

  /// Tip Amount.
  final int? tipAmount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2d03522f.
    buffer.writeInt32(0x2d03522f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(formId);
    buffer.writeObject(invoice);
    final localRequestedInfoIdCopy = requestedInfoId;
    if (localRequestedInfoIdCopy != null) {
      buffer.writeString(localRequestedInfoIdCopy);
    }
    final localShippingOptionIdCopy = shippingOptionId;
    if (localShippingOptionIdCopy != null) {
      buffer.writeString(localShippingOptionIdCopy);
    }
    buffer.writeObject(credentials);
    final localTipAmountCopy = tipAmount;
    if (localTipAmountCopy != null) {
      buffer.writeInt64(localTipAmountCopy);
    }

    // Finished serialization.
  }
}

/// Account Get Tmp Password.
///
/// ID: `449e0b51`.
class AccountGetTmpPassword extends TlMethod<AccountTmpPasswordBase> {
  /// Account Get Tmp Password constructor.
  const AccountGetTmpPassword({
    required this.password,
    required this.period,
  }) : super._();

  /// Deserialize.
  factory AccountGetTmpPassword.deserialize(BinaryReader reader) {
    // Read [AccountGetTmpPassword] fields.
    final password = reader.readObject() as InputCheckPasswordSRPBase;
    final period = reader.readInt32();

    // Construct [AccountGetTmpPassword] object.
    final returnValue = AccountGetTmpPassword(
      password: password,
      period: period,
    );

    // Now return the deserialized [AccountGetTmpPassword].
    return returnValue;
  }

  /// Password.
  final InputCheckPasswordSRPBase password;

  /// Period.
  ///
  /// Field type is Int32.
  final int period;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x449e0b51.
    buffer.writeInt32(0x449e0b51);

    // Write fields.
    buffer.writeObject(password);
    buffer.writeInt32(period);

    // Finished serialization.
  }
}

/// Payments Get Saved Info.
///
/// ID: `227d824b`.
class PaymentsGetSavedInfo extends TlMethod<PaymentsSavedInfoBase> {
  /// Payments Get Saved Info constructor.
  const PaymentsGetSavedInfo() : super._();

  /// Deserialize.
  factory PaymentsGetSavedInfo.deserialize(BinaryReader reader) {
    // Construct [PaymentsGetSavedInfo] object.
    final returnValue = PaymentsGetSavedInfo();

    // Now return the deserialized [PaymentsGetSavedInfo].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x227d824b.
    buffer.writeInt32(0x227d824b);

    // Finished serialization.
  }
}

/// Payments Clear Saved Info.
///
/// ID: `d83d70c1`.
class PaymentsClearSavedInfo extends TlMethod<bool> {
  /// Payments Clear Saved Info constructor.
  const PaymentsClearSavedInfo({
    required this.credentials,
    required this.info,
  }) : super._();

  /// Deserialize.
  factory PaymentsClearSavedInfo.deserialize(BinaryReader reader) {
    // Read [PaymentsClearSavedInfo] fields.
    final flags = reader.readInt32();
    final credentials = (flags & 1) != 0;
    final info = (flags & 2) != 0;

    // Construct [PaymentsClearSavedInfo] object.
    final returnValue = PaymentsClearSavedInfo(
      credentials: credentials,
      info: info,
    );

    // Now return the deserialized [PaymentsClearSavedInfo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: credentials,
      b01: info,
    );

    return v;
  }

  /// credentials: bit 0 of flags.0?true
  final bool credentials;

  /// info: bit 1 of flags.1?true
  final bool info;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd83d70c1.
    buffer.writeInt32(0xd83d70c1);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Messages Set Bot Shipping Results.
///
/// ID: `e5f672fa`.
class MessagesSetBotShippingResults extends TlMethod<bool> {
  /// Messages Set Bot Shipping Results constructor.
  const MessagesSetBotShippingResults({
    required this.queryId,
    this.error,
    this.shippingOptions,
  }) : super._();

  /// Deserialize.
  factory MessagesSetBotShippingResults.deserialize(BinaryReader reader) {
    // Read [MessagesSetBotShippingResults] fields.
    final flags = reader.readInt32();
    final queryId = reader.readInt64();
    final hasErrorField = (flags & 1) != 0;
    final error = hasErrorField ? reader.readString() : null;
    final hasShippingOptionsField = (flags & 2) != 0;
    final shippingOptions = hasShippingOptionsField
        ? reader.readVectorObject<ShippingOptionBase>()
        : null;

    // Construct [MessagesSetBotShippingResults] object.
    final returnValue = MessagesSetBotShippingResults(
      queryId: queryId,
      error: error,
      shippingOptions: shippingOptions,
    );

    // Now return the deserialized [MessagesSetBotShippingResults].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: error != null,
      b01: shippingOptions != null,
    );

    return v;
  }

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Error.
  final String? error;

  /// Shipping Options.
  final List<ShippingOptionBase>? shippingOptions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe5f672fa.
    buffer.writeInt32(0xe5f672fa);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(queryId);
    final localErrorCopy = error;
    if (localErrorCopy != null) {
      buffer.writeString(localErrorCopy);
    }
    final localShippingOptionsCopy = shippingOptions;
    if (localShippingOptionsCopy != null) {
      buffer.writeVectorObject(localShippingOptionsCopy);
    }

    // Finished serialization.
  }
}

/// Messages Set Bot Precheckout Results.
///
/// ID: `09c2dd95`.
class MessagesSetBotPrecheckoutResults extends TlMethod<bool> {
  /// Messages Set Bot Precheckout Results constructor.
  const MessagesSetBotPrecheckoutResults({
    required this.success,
    required this.queryId,
    this.error,
  }) : super._();

  /// Deserialize.
  factory MessagesSetBotPrecheckoutResults.deserialize(BinaryReader reader) {
    // Read [MessagesSetBotPrecheckoutResults] fields.
    final flags = reader.readInt32();
    final success = (flags & 2) != 0;
    final queryId = reader.readInt64();
    final hasErrorField = (flags & 1) != 0;
    final error = hasErrorField ? reader.readString() : null;

    // Construct [MessagesSetBotPrecheckoutResults] object.
    final returnValue = MessagesSetBotPrecheckoutResults(
      success: success,
      queryId: queryId,
      error: error,
    );

    // Now return the deserialized [MessagesSetBotPrecheckoutResults].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: success,
      b00: error != null,
    );

    return v;
  }

  /// success: bit 1 of flags.1?true
  final bool success;

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Error.
  final String? error;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x09c2dd95.
    buffer.writeInt32(0x09c2dd95);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(queryId);
    final localErrorCopy = error;
    if (localErrorCopy != null) {
      buffer.writeString(localErrorCopy);
    }

    // Finished serialization.
  }
}

/// Stickers Create Sticker Set.
///
/// ID: `9021ab67`.
class StickersCreateStickerSet extends TlMethod<MessagesStickerSetBase> {
  /// Stickers Create Sticker Set constructor.
  const StickersCreateStickerSet({
    required this.masks,
    required this.emojis,
    required this.textColor,
    required this.userId,
    required this.title,
    required this.shortName,
    this.thumb,
    required this.stickers,
    this.software,
  }) : super._();

  /// Deserialize.
  factory StickersCreateStickerSet.deserialize(BinaryReader reader) {
    // Read [StickersCreateStickerSet] fields.
    final flags = reader.readInt32();
    final masks = (flags & 1) != 0;
    final emojis = (flags & 32) != 0;
    final textColor = (flags & 64) != 0;
    final userId = reader.readObject() as InputUserBase;
    final title = reader.readString();
    final shortName = reader.readString();
    final hasThumbField = (flags & 4) != 0;
    final thumb =
        hasThumbField ? reader.readObject() as InputDocumentBase : null;
    final stickers = reader.readVectorObject<InputStickerSetItemBase>();
    final hasSoftwareField = (flags & 8) != 0;
    final software = hasSoftwareField ? reader.readString() : null;

    // Construct [StickersCreateStickerSet] object.
    final returnValue = StickersCreateStickerSet(
      masks: masks,
      emojis: emojis,
      textColor: textColor,
      userId: userId,
      title: title,
      shortName: shortName,
      thumb: thumb,
      stickers: stickers,
      software: software,
    );

    // Now return the deserialized [StickersCreateStickerSet].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: masks,
      b05: emojis,
      b06: textColor,
      b02: thumb != null,
      b03: software != null,
    );

    return v;
  }

  /// masks: bit 0 of flags.0?true
  final bool masks;

  /// emojis: bit 5 of flags.5?true
  final bool emojis;

  /// text_color: bit 6 of flags.6?true
  final bool textColor;

  /// User Id.
  final InputUserBase userId;

  /// Title.
  final String title;

  /// Short Name.
  final String shortName;

  /// Thumb.
  final InputDocumentBase? thumb;

  /// Stickers.
  final List<InputStickerSetItemBase> stickers;

  /// Software.
  final String? software;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9021ab67.
    buffer.writeInt32(0x9021ab67);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(userId);
    buffer.writeString(title);
    buffer.writeString(shortName);
    final localThumbCopy = thumb;
    if (localThumbCopy != null) {
      buffer.writeObject(localThumbCopy);
    }
    buffer.writeVectorObject(stickers);
    final localSoftwareCopy = software;
    if (localSoftwareCopy != null) {
      buffer.writeString(localSoftwareCopy);
    }

    // Finished serialization.
  }
}

/// Stickers Remove Sticker From Set.
///
/// ID: `f7760f51`.
class StickersRemoveStickerFromSet extends TlMethod<MessagesStickerSetBase> {
  /// Stickers Remove Sticker From Set constructor.
  const StickersRemoveStickerFromSet({
    required this.sticker,
  }) : super._();

  /// Deserialize.
  factory StickersRemoveStickerFromSet.deserialize(BinaryReader reader) {
    // Read [StickersRemoveStickerFromSet] fields.
    final sticker = reader.readObject() as InputDocumentBase;

    // Construct [StickersRemoveStickerFromSet] object.
    final returnValue = StickersRemoveStickerFromSet(
      sticker: sticker,
    );

    // Now return the deserialized [StickersRemoveStickerFromSet].
    return returnValue;
  }

  /// Sticker.
  final InputDocumentBase sticker;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf7760f51.
    buffer.writeInt32(0xf7760f51);

    // Write fields.
    buffer.writeObject(sticker);

    // Finished serialization.
  }
}

/// Stickers Change Sticker Position.
///
/// ID: `ffb6d4ca`.
class StickersChangeStickerPosition extends TlMethod<MessagesStickerSetBase> {
  /// Stickers Change Sticker Position constructor.
  const StickersChangeStickerPosition({
    required this.sticker,
    required this.position,
  }) : super._();

  /// Deserialize.
  factory StickersChangeStickerPosition.deserialize(BinaryReader reader) {
    // Read [StickersChangeStickerPosition] fields.
    final sticker = reader.readObject() as InputDocumentBase;
    final position = reader.readInt32();

    // Construct [StickersChangeStickerPosition] object.
    final returnValue = StickersChangeStickerPosition(
      sticker: sticker,
      position: position,
    );

    // Now return the deserialized [StickersChangeStickerPosition].
    return returnValue;
  }

  /// Sticker.
  final InputDocumentBase sticker;

  /// Position.
  ///
  /// Field type is Int32.
  final int position;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xffb6d4ca.
    buffer.writeInt32(0xffb6d4ca);

    // Write fields.
    buffer.writeObject(sticker);
    buffer.writeInt32(position);

    // Finished serialization.
  }
}

/// Stickers Add Sticker To Set.
///
/// ID: `8653febe`.
class StickersAddStickerToSet extends TlMethod<MessagesStickerSetBase> {
  /// Stickers Add Sticker To Set constructor.
  const StickersAddStickerToSet({
    required this.stickerset,
    required this.sticker,
  }) : super._();

  /// Deserialize.
  factory StickersAddStickerToSet.deserialize(BinaryReader reader) {
    // Read [StickersAddStickerToSet] fields.
    final stickerset = reader.readObject() as InputStickerSetBase;
    final sticker = reader.readObject() as InputStickerSetItemBase;

    // Construct [StickersAddStickerToSet] object.
    final returnValue = StickersAddStickerToSet(
      stickerset: stickerset,
      sticker: sticker,
    );

    // Now return the deserialized [StickersAddStickerToSet].
    return returnValue;
  }

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Sticker.
  final InputStickerSetItemBase sticker;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8653febe.
    buffer.writeInt32(0x8653febe);

    // Write fields.
    buffer.writeObject(stickerset);
    buffer.writeObject(sticker);

    // Finished serialization.
  }
}

/// Messages Upload Media.
///
/// ID: `519bc2b1`.
class MessagesUploadMedia extends TlMethod<MessageMediaBase> {
  /// Messages Upload Media constructor.
  const MessagesUploadMedia({
    required this.peer,
    required this.media,
  }) : super._();

  /// Deserialize.
  factory MessagesUploadMedia.deserialize(BinaryReader reader) {
    // Read [MessagesUploadMedia] fields.
    final peer = reader.readObject() as InputPeerBase;
    final media = reader.readObject() as InputMediaBase;

    // Construct [MessagesUploadMedia] object.
    final returnValue = MessagesUploadMedia(
      peer: peer,
      media: media,
    );

    // Now return the deserialized [MessagesUploadMedia].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Media.
  final InputMediaBase media;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x519bc2b1.
    buffer.writeInt32(0x519bc2b1);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(media);

    // Finished serialization.
  }
}

/// Phone Get Call Config.
///
/// ID: `55451fa9`.
class PhoneGetCallConfig extends TlMethod<DataJSONBase> {
  /// Phone Get Call Config constructor.
  const PhoneGetCallConfig() : super._();

  /// Deserialize.
  factory PhoneGetCallConfig.deserialize(BinaryReader reader) {
    // Construct [PhoneGetCallConfig] object.
    final returnValue = PhoneGetCallConfig();

    // Now return the deserialized [PhoneGetCallConfig].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x55451fa9.
    buffer.writeInt32(0x55451fa9);

    // Finished serialization.
  }
}

/// Phone Request Call.
///
/// ID: `42ff96ed`.
class PhoneRequestCall extends TlMethod<PhonePhoneCallBase> {
  /// Phone Request Call constructor.
  const PhoneRequestCall({
    required this.video,
    required this.userId,
    required this.randomId,
    required this.gAHash,
    required this.protocol,
  }) : super._();

  /// Deserialize.
  factory PhoneRequestCall.deserialize(BinaryReader reader) {
    // Read [PhoneRequestCall] fields.
    final flags = reader.readInt32();
    final video = (flags & 1) != 0;
    final userId = reader.readObject() as InputUserBase;
    final randomId = reader.readInt32();
    final gAHash = reader.readBytes();
    final protocol = reader.readObject() as PhoneCallProtocolBase;

    // Construct [PhoneRequestCall] object.
    final returnValue = PhoneRequestCall(
      video: video,
      userId: userId,
      randomId: randomId,
      gAHash: gAHash,
      protocol: protocol,
    );

    // Now return the deserialized [PhoneRequestCall].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: video,
    );

    return v;
  }

  /// video: bit 0 of flags.0?true
  final bool video;

  /// User Id.
  final InputUserBase userId;

  /// Random Id.
  ///
  /// Field type is Int32.
  final int randomId;

  /// G A Hash.
  final Uint8List gAHash;

  /// Protocol.
  final PhoneCallProtocolBase protocol;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x42ff96ed.
    buffer.writeInt32(0x42ff96ed);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(userId);
    buffer.writeInt32(randomId);
    buffer.writeBytes(gAHash);
    buffer.writeObject(protocol);

    // Finished serialization.
  }
}

/// Phone Accept Call.
///
/// ID: `3bd2b4a0`.
class PhoneAcceptCall extends TlMethod<PhonePhoneCallBase> {
  /// Phone Accept Call constructor.
  const PhoneAcceptCall({
    required this.peer,
    required this.gB,
    required this.protocol,
  }) : super._();

  /// Deserialize.
  factory PhoneAcceptCall.deserialize(BinaryReader reader) {
    // Read [PhoneAcceptCall] fields.
    final peer = reader.readObject() as InputPhoneCallBase;
    final gB = reader.readBytes();
    final protocol = reader.readObject() as PhoneCallProtocolBase;

    // Construct [PhoneAcceptCall] object.
    final returnValue = PhoneAcceptCall(
      peer: peer,
      gB: gB,
      protocol: protocol,
    );

    // Now return the deserialized [PhoneAcceptCall].
    return returnValue;
  }

  /// Peer.
  final InputPhoneCallBase peer;

  /// G B.
  final Uint8List gB;

  /// Protocol.
  final PhoneCallProtocolBase protocol;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3bd2b4a0.
    buffer.writeInt32(0x3bd2b4a0);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeBytes(gB);
    buffer.writeObject(protocol);

    // Finished serialization.
  }
}

/// Phone Confirm Call.
///
/// ID: `2efe1722`.
class PhoneConfirmCall extends TlMethod<PhonePhoneCallBase> {
  /// Phone Confirm Call constructor.
  const PhoneConfirmCall({
    required this.peer,
    required this.gA,
    required this.keyFingerprint,
    required this.protocol,
  }) : super._();

  /// Deserialize.
  factory PhoneConfirmCall.deserialize(BinaryReader reader) {
    // Read [PhoneConfirmCall] fields.
    final peer = reader.readObject() as InputPhoneCallBase;
    final gA = reader.readBytes();
    final keyFingerprint = reader.readInt64();
    final protocol = reader.readObject() as PhoneCallProtocolBase;

    // Construct [PhoneConfirmCall] object.
    final returnValue = PhoneConfirmCall(
      peer: peer,
      gA: gA,
      keyFingerprint: keyFingerprint,
      protocol: protocol,
    );

    // Now return the deserialized [PhoneConfirmCall].
    return returnValue;
  }

  /// Peer.
  final InputPhoneCallBase peer;

  /// G A.
  final Uint8List gA;

  /// Key Fingerprint.
  ///
  /// Field type is Int64.
  final int keyFingerprint;

  /// Protocol.
  final PhoneCallProtocolBase protocol;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2efe1722.
    buffer.writeInt32(0x2efe1722);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeBytes(gA);
    buffer.writeInt64(keyFingerprint);
    buffer.writeObject(protocol);

    // Finished serialization.
  }
}

/// Phone Received Call.
///
/// ID: `17d54f61`.
class PhoneReceivedCall extends TlMethod<bool> {
  /// Phone Received Call constructor.
  const PhoneReceivedCall({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory PhoneReceivedCall.deserialize(BinaryReader reader) {
    // Read [PhoneReceivedCall] fields.
    final peer = reader.readObject() as InputPhoneCallBase;

    // Construct [PhoneReceivedCall] object.
    final returnValue = PhoneReceivedCall(
      peer: peer,
    );

    // Now return the deserialized [PhoneReceivedCall].
    return returnValue;
  }

  /// Peer.
  final InputPhoneCallBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x17d54f61.
    buffer.writeInt32(0x17d54f61);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Phone Discard Call.
///
/// ID: `b2cbc1c0`.
class PhoneDiscardCall extends TlMethod<UpdatesBase> {
  /// Phone Discard Call constructor.
  const PhoneDiscardCall({
    required this.video,
    required this.peer,
    required this.duration,
    required this.reason,
    required this.connectionId,
  }) : super._();

  /// Deserialize.
  factory PhoneDiscardCall.deserialize(BinaryReader reader) {
    // Read [PhoneDiscardCall] fields.
    final flags = reader.readInt32();
    final video = (flags & 1) != 0;
    final peer = reader.readObject() as InputPhoneCallBase;
    final duration = reader.readInt32();
    final reason = reader.readObject() as PhoneCallDiscardReasonBase;
    final connectionId = reader.readInt64();

    // Construct [PhoneDiscardCall] object.
    final returnValue = PhoneDiscardCall(
      video: video,
      peer: peer,
      duration: duration,
      reason: reason,
      connectionId: connectionId,
    );

    // Now return the deserialized [PhoneDiscardCall].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: video,
    );

    return v;
  }

  /// video: bit 0 of flags.0?true
  final bool video;

  /// Peer.
  final InputPhoneCallBase peer;

  /// Duration.
  ///
  /// Field type is Int32.
  final int duration;

  /// Reason.
  final PhoneCallDiscardReasonBase reason;

  /// Connection Id.
  ///
  /// Field type is Int64.
  final int connectionId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb2cbc1c0.
    buffer.writeInt32(0xb2cbc1c0);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(duration);
    buffer.writeObject(reason);
    buffer.writeInt64(connectionId);

    // Finished serialization.
  }
}

/// Phone Set Call Rating.
///
/// ID: `59ead627`.
class PhoneSetCallRating extends TlMethod<UpdatesBase> {
  /// Phone Set Call Rating constructor.
  const PhoneSetCallRating({
    required this.userInitiative,
    required this.peer,
    required this.rating,
    required this.comment,
  }) : super._();

  /// Deserialize.
  factory PhoneSetCallRating.deserialize(BinaryReader reader) {
    // Read [PhoneSetCallRating] fields.
    final flags = reader.readInt32();
    final userInitiative = (flags & 1) != 0;
    final peer = reader.readObject() as InputPhoneCallBase;
    final rating = reader.readInt32();
    final comment = reader.readString();

    // Construct [PhoneSetCallRating] object.
    final returnValue = PhoneSetCallRating(
      userInitiative: userInitiative,
      peer: peer,
      rating: rating,
      comment: comment,
    );

    // Now return the deserialized [PhoneSetCallRating].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: userInitiative,
    );

    return v;
  }

  /// user_initiative: bit 0 of flags.0?true
  final bool userInitiative;

  /// Peer.
  final InputPhoneCallBase peer;

  /// Rating.
  ///
  /// Field type is Int32.
  final int rating;

  /// Comment.
  final String comment;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x59ead627.
    buffer.writeInt32(0x59ead627);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(rating);
    buffer.writeString(comment);

    // Finished serialization.
  }
}

/// Phone Save Call Debug.
///
/// ID: `277add7e`.
class PhoneSaveCallDebug extends TlMethod<bool> {
  /// Phone Save Call Debug constructor.
  const PhoneSaveCallDebug({
    required this.peer,
    required this.debug,
  }) : super._();

  /// Deserialize.
  factory PhoneSaveCallDebug.deserialize(BinaryReader reader) {
    // Read [PhoneSaveCallDebug] fields.
    final peer = reader.readObject() as InputPhoneCallBase;
    final debug = reader.readObject() as DataJSONBase;

    // Construct [PhoneSaveCallDebug] object.
    final returnValue = PhoneSaveCallDebug(
      peer: peer,
      debug: debug,
    );

    // Now return the deserialized [PhoneSaveCallDebug].
    return returnValue;
  }

  /// Peer.
  final InputPhoneCallBase peer;

  /// Debug.
  final DataJSONBase debug;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x277add7e.
    buffer.writeInt32(0x277add7e);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(debug);

    // Finished serialization.
  }
}

/// Upload Get Cdn File.
///
/// ID: `395f69da`.
class UploadGetCdnFile extends TlMethod<UploadCdnFileBase> {
  /// Upload Get Cdn File constructor.
  const UploadGetCdnFile({
    required this.fileToken,
    required this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory UploadGetCdnFile.deserialize(BinaryReader reader) {
    // Read [UploadGetCdnFile] fields.
    final fileToken = reader.readBytes();
    final offset = reader.readInt64();
    final limit = reader.readInt32();

    // Construct [UploadGetCdnFile] object.
    final returnValue = UploadGetCdnFile(
      fileToken: fileToken,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [UploadGetCdnFile].
    return returnValue;
  }

  /// File Token.
  final Uint8List fileToken;

  /// Offset.
  ///
  /// Field type is Int64.
  final int offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x395f69da.
    buffer.writeInt32(0x395f69da);

    // Write fields.
    buffer.writeBytes(fileToken);
    buffer.writeInt64(offset);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Upload Reupload Cdn File.
///
/// ID: `9b2754a8`.
class UploadReuploadCdnFile extends TlMethod<List<FileHashBase>> {
  /// Upload Reupload Cdn File constructor.
  const UploadReuploadCdnFile({
    required this.fileToken,
    required this.requestToken,
  }) : super._();

  /// Deserialize.
  factory UploadReuploadCdnFile.deserialize(BinaryReader reader) {
    // Read [UploadReuploadCdnFile] fields.
    final fileToken = reader.readBytes();
    final requestToken = reader.readBytes();

    // Construct [UploadReuploadCdnFile] object.
    final returnValue = UploadReuploadCdnFile(
      fileToken: fileToken,
      requestToken: requestToken,
    );

    // Now return the deserialized [UploadReuploadCdnFile].
    return returnValue;
  }

  /// File Token.
  final Uint8List fileToken;

  /// Request Token.
  final Uint8List requestToken;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9b2754a8.
    buffer.writeInt32(0x9b2754a8);

    // Write fields.
    buffer.writeBytes(fileToken);
    buffer.writeBytes(requestToken);

    // Finished serialization.
  }
}

/// Help Get Cdn Config.
///
/// ID: `52029342`.
class HelpGetCdnConfig extends TlMethod<CdnConfigBase> {
  /// Help Get Cdn Config constructor.
  const HelpGetCdnConfig() : super._();

  /// Deserialize.
  factory HelpGetCdnConfig.deserialize(BinaryReader reader) {
    // Construct [HelpGetCdnConfig] object.
    final returnValue = HelpGetCdnConfig();

    // Now return the deserialized [HelpGetCdnConfig].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x52029342.
    buffer.writeInt32(0x52029342);

    // Finished serialization.
  }
}

/// Langpack Get Lang Pack.
///
/// ID: `f2f2330a`.
class LangpackGetLangPack extends TlMethod<LangPackDifferenceBase> {
  /// Langpack Get Lang Pack constructor.
  const LangpackGetLangPack({
    required this.langPack,
    required this.langCode,
  }) : super._();

  /// Deserialize.
  factory LangpackGetLangPack.deserialize(BinaryReader reader) {
    // Read [LangpackGetLangPack] fields.
    final langPack = reader.readString();
    final langCode = reader.readString();

    // Construct [LangpackGetLangPack] object.
    final returnValue = LangpackGetLangPack(
      langPack: langPack,
      langCode: langCode,
    );

    // Now return the deserialized [LangpackGetLangPack].
    return returnValue;
  }

  /// Lang Pack.
  final String langPack;

  /// Lang Code.
  final String langCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf2f2330a.
    buffer.writeInt32(0xf2f2330a);

    // Write fields.
    buffer.writeString(langPack);
    buffer.writeString(langCode);

    // Finished serialization.
  }
}

/// Langpack Get Strings.
///
/// ID: `efea3803`.
class LangpackGetStrings extends TlMethod<List<LangPackStringBase>> {
  /// Langpack Get Strings constructor.
  const LangpackGetStrings({
    required this.langPack,
    required this.langCode,
    required this.keys,
  }) : super._();

  /// Deserialize.
  factory LangpackGetStrings.deserialize(BinaryReader reader) {
    // Read [LangpackGetStrings] fields.
    final langPack = reader.readString();
    final langCode = reader.readString();
    final keys = reader.readVectorString();

    // Construct [LangpackGetStrings] object.
    final returnValue = LangpackGetStrings(
      langPack: langPack,
      langCode: langCode,
      keys: keys,
    );

    // Now return the deserialized [LangpackGetStrings].
    return returnValue;
  }

  /// Lang Pack.
  final String langPack;

  /// Lang Code.
  final String langCode;

  /// Keys.
  final List<String> keys;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xefea3803.
    buffer.writeInt32(0xefea3803);

    // Write fields.
    buffer.writeString(langPack);
    buffer.writeString(langCode);
    buffer.writeVectorString(keys);

    // Finished serialization.
  }
}

/// Langpack Get Difference.
///
/// ID: `cd984aa5`.
class LangpackGetDifference extends TlMethod<LangPackDifferenceBase> {
  /// Langpack Get Difference constructor.
  const LangpackGetDifference({
    required this.langPack,
    required this.langCode,
    required this.fromVersion,
  }) : super._();

  /// Deserialize.
  factory LangpackGetDifference.deserialize(BinaryReader reader) {
    // Read [LangpackGetDifference] fields.
    final langPack = reader.readString();
    final langCode = reader.readString();
    final fromVersion = reader.readInt32();

    // Construct [LangpackGetDifference] object.
    final returnValue = LangpackGetDifference(
      langPack: langPack,
      langCode: langCode,
      fromVersion: fromVersion,
    );

    // Now return the deserialized [LangpackGetDifference].
    return returnValue;
  }

  /// Lang Pack.
  final String langPack;

  /// Lang Code.
  final String langCode;

  /// From Version.
  ///
  /// Field type is Int32.
  final int fromVersion;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcd984aa5.
    buffer.writeInt32(0xcd984aa5);

    // Write fields.
    buffer.writeString(langPack);
    buffer.writeString(langCode);
    buffer.writeInt32(fromVersion);

    // Finished serialization.
  }
}

/// Langpack Get Languages.
///
/// ID: `42c6978f`.
class LangpackGetLanguages extends TlMethod<List<LangPackLanguageBase>> {
  /// Langpack Get Languages constructor.
  const LangpackGetLanguages({
    required this.langPack,
  }) : super._();

  /// Deserialize.
  factory LangpackGetLanguages.deserialize(BinaryReader reader) {
    // Read [LangpackGetLanguages] fields.
    final langPack = reader.readString();

    // Construct [LangpackGetLanguages] object.
    final returnValue = LangpackGetLanguages(
      langPack: langPack,
    );

    // Now return the deserialized [LangpackGetLanguages].
    return returnValue;
  }

  /// Lang Pack.
  final String langPack;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x42c6978f.
    buffer.writeInt32(0x42c6978f);

    // Write fields.
    buffer.writeString(langPack);

    // Finished serialization.
  }
}

/// Channels Edit Banned.
///
/// ID: `96e6cd81`.
class ChannelsEditBanned extends TlMethod<UpdatesBase> {
  /// Channels Edit Banned constructor.
  const ChannelsEditBanned({
    required this.channel,
    required this.participant,
    required this.bannedRights,
  }) : super._();

  /// Deserialize.
  factory ChannelsEditBanned.deserialize(BinaryReader reader) {
    // Read [ChannelsEditBanned] fields.
    final channel = reader.readObject() as InputChannelBase;
    final participant = reader.readObject() as InputPeerBase;
    final bannedRights = reader.readObject() as ChatBannedRightsBase;

    // Construct [ChannelsEditBanned] object.
    final returnValue = ChannelsEditBanned(
      channel: channel,
      participant: participant,
      bannedRights: bannedRights,
    );

    // Now return the deserialized [ChannelsEditBanned].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Participant.
  final InputPeerBase participant;

  /// Banned Rights.
  final ChatBannedRightsBase bannedRights;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x96e6cd81.
    buffer.writeInt32(0x96e6cd81);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(participant);
    buffer.writeObject(bannedRights);

    // Finished serialization.
  }
}

/// Channels Get Admin Log.
///
/// ID: `33ddf480`.
class ChannelsGetAdminLog extends TlMethod<ChannelsAdminLogResultsBase> {
  /// Channels Get Admin Log constructor.
  const ChannelsGetAdminLog({
    required this.channel,
    required this.q,
    this.eventsFilter,
    this.admins,
    required this.maxId,
    required this.minId,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetAdminLog.deserialize(BinaryReader reader) {
    // Read [ChannelsGetAdminLog] fields.
    final flags = reader.readInt32();
    final channel = reader.readObject() as InputChannelBase;
    final q = reader.readString();
    final hasEventsFilterField = (flags & 1) != 0;
    final eventsFilter = hasEventsFilterField
        ? reader.readObject() as ChannelAdminLogEventsFilterBase
        : null;
    final hasAdminsField = (flags & 2) != 0;
    final admins =
        hasAdminsField ? reader.readVectorObject<InputUserBase>() : null;
    final maxId = reader.readInt64();
    final minId = reader.readInt64();
    final limit = reader.readInt32();

    // Construct [ChannelsGetAdminLog] object.
    final returnValue = ChannelsGetAdminLog(
      channel: channel,
      q: q,
      eventsFilter: eventsFilter,
      admins: admins,
      maxId: maxId,
      minId: minId,
      limit: limit,
    );

    // Now return the deserialized [ChannelsGetAdminLog].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: eventsFilter != null,
      b01: admins != null,
    );

    return v;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Q.
  final String q;

  /// Events Filter.
  final ChannelAdminLogEventsFilterBase? eventsFilter;

  /// Admins.
  final List<InputUserBase>? admins;

  /// Max Id.
  ///
  /// Field type is Int64.
  final int maxId;

  /// Min Id.
  ///
  /// Field type is Int64.
  final int minId;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x33ddf480.
    buffer.writeInt32(0x33ddf480);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);
    buffer.writeString(q);
    final localEventsFilterCopy = eventsFilter;
    if (localEventsFilterCopy != null) {
      buffer.writeObject(localEventsFilterCopy);
    }
    final localAdminsCopy = admins;
    if (localAdminsCopy != null) {
      buffer.writeVectorObject(localAdminsCopy);
    }
    buffer.writeInt64(maxId);
    buffer.writeInt64(minId);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Upload Get Cdn File Hashes.
///
/// ID: `91dc3f31`.
class UploadGetCdnFileHashes extends TlMethod<List<FileHashBase>> {
  /// Upload Get Cdn File Hashes constructor.
  const UploadGetCdnFileHashes({
    required this.fileToken,
    required this.offset,
  }) : super._();

  /// Deserialize.
  factory UploadGetCdnFileHashes.deserialize(BinaryReader reader) {
    // Read [UploadGetCdnFileHashes] fields.
    final fileToken = reader.readBytes();
    final offset = reader.readInt64();

    // Construct [UploadGetCdnFileHashes] object.
    final returnValue = UploadGetCdnFileHashes(
      fileToken: fileToken,
      offset: offset,
    );

    // Now return the deserialized [UploadGetCdnFileHashes].
    return returnValue;
  }

  /// File Token.
  final Uint8List fileToken;

  /// Offset.
  ///
  /// Field type is Int64.
  final int offset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x91dc3f31.
    buffer.writeInt32(0x91dc3f31);

    // Write fields.
    buffer.writeBytes(fileToken);
    buffer.writeInt64(offset);

    // Finished serialization.
  }
}

/// Messages Send Screenshot Notification.
///
/// ID: `a1405817`.
class MessagesSendScreenshotNotification extends TlMethod<UpdatesBase> {
  /// Messages Send Screenshot Notification constructor.
  const MessagesSendScreenshotNotification({
    required this.peer,
    required this.replyTo,
    required this.randomId,
  }) : super._();

  /// Deserialize.
  factory MessagesSendScreenshotNotification.deserialize(BinaryReader reader) {
    // Read [MessagesSendScreenshotNotification] fields.
    final peer = reader.readObject() as InputPeerBase;
    final replyTo = reader.readObject() as InputReplyToBase;
    final randomId = reader.readInt64();

    // Construct [MessagesSendScreenshotNotification] object.
    final returnValue = MessagesSendScreenshotNotification(
      peer: peer,
      replyTo: replyTo,
      randomId: randomId,
    );

    // Now return the deserialized [MessagesSendScreenshotNotification].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Reply To.
  final InputReplyToBase replyTo;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa1405817.
    buffer.writeInt32(0xa1405817);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(replyTo);
    buffer.writeInt64(randomId);

    // Finished serialization.
  }
}

/// Channels Set Stickers.
///
/// ID: `ea8ca4f9`.
class ChannelsSetStickers extends TlMethod<bool> {
  /// Channels Set Stickers constructor.
  const ChannelsSetStickers({
    required this.channel,
    required this.stickerset,
  }) : super._();

  /// Deserialize.
  factory ChannelsSetStickers.deserialize(BinaryReader reader) {
    // Read [ChannelsSetStickers] fields.
    final channel = reader.readObject() as InputChannelBase;
    final stickerset = reader.readObject() as InputStickerSetBase;

    // Construct [ChannelsSetStickers] object.
    final returnValue = ChannelsSetStickers(
      channel: channel,
      stickerset: stickerset,
    );

    // Now return the deserialized [ChannelsSetStickers].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xea8ca4f9.
    buffer.writeInt32(0xea8ca4f9);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(stickerset);

    // Finished serialization.
  }
}

/// Messages Get Faved Stickers.
///
/// ID: `04f1aaa9`.
class MessagesGetFavedStickers extends TlMethod<MessagesFavedStickersBase> {
  /// Messages Get Faved Stickers constructor.
  const MessagesGetFavedStickers({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetFavedStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetFavedStickers] fields.
    final hash = reader.readInt64();

    // Construct [MessagesGetFavedStickers] object.
    final returnValue = MessagesGetFavedStickers(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetFavedStickers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x04f1aaa9.
    buffer.writeInt32(0x04f1aaa9);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Fave Sticker.
///
/// ID: `b9ffc55b`.
class MessagesFaveSticker extends TlMethod<bool> {
  /// Messages Fave Sticker constructor.
  const MessagesFaveSticker({
    required this.id,
    required this.unfave,
  }) : super._();

  /// Deserialize.
  factory MessagesFaveSticker.deserialize(BinaryReader reader) {
    // Read [MessagesFaveSticker] fields.
    final id = reader.readObject() as InputDocumentBase;
    final unfave = reader.readBool();

    // Construct [MessagesFaveSticker] object.
    final returnValue = MessagesFaveSticker(
      id: id,
      unfave: unfave,
    );

    // Now return the deserialized [MessagesFaveSticker].
    return returnValue;
  }

  /// Id.
  final InputDocumentBase id;

  /// Unfave.
  final bool unfave;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb9ffc55b.
    buffer.writeInt32(0xb9ffc55b);

    // Write fields.
    buffer.writeObject(id);
    buffer.writeBool(unfave);

    // Finished serialization.
  }
}

/// Channels Read Message Contents.
///
/// ID: `eab5dc38`.
class ChannelsReadMessageContents extends TlMethod<bool> {
  /// Channels Read Message Contents constructor.
  const ChannelsReadMessageContents({
    required this.channel,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ChannelsReadMessageContents.deserialize(BinaryReader reader) {
    // Read [ChannelsReadMessageContents] fields.
    final channel = reader.readObject() as InputChannelBase;
    final id = reader.readVectorInt32();

    // Construct [ChannelsReadMessageContents] object.
    final returnValue = ChannelsReadMessageContents(
      channel: channel,
      id: id,
    );

    // Now return the deserialized [ChannelsReadMessageContents].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeab5dc38.
    buffer.writeInt32(0xeab5dc38);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Contacts Reset Saved.
///
/// ID: `879537f1`.
class ContactsResetSaved extends TlMethod<bool> {
  /// Contacts Reset Saved constructor.
  const ContactsResetSaved() : super._();

  /// Deserialize.
  factory ContactsResetSaved.deserialize(BinaryReader reader) {
    // Construct [ContactsResetSaved] object.
    final returnValue = ContactsResetSaved();

    // Now return the deserialized [ContactsResetSaved].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x879537f1.
    buffer.writeInt32(0x879537f1);

    // Finished serialization.
  }
}

/// Messages Get Unread Mentions.
///
/// ID: `f107e790`.
class MessagesGetUnreadMentions extends TlMethod<MessagesMessagesBase> {
  /// Messages Get Unread Mentions constructor.
  const MessagesGetUnreadMentions({
    required this.peer,
    this.topMsgId,
    required this.offsetId,
    required this.addOffset,
    required this.limit,
    required this.maxId,
    required this.minId,
  }) : super._();

  /// Deserialize.
  factory MessagesGetUnreadMentions.deserialize(BinaryReader reader) {
    // Read [MessagesGetUnreadMentions] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final offsetId = reader.readInt32();
    final addOffset = reader.readInt32();
    final limit = reader.readInt32();
    final maxId = reader.readInt32();
    final minId = reader.readInt32();

    // Construct [MessagesGetUnreadMentions] object.
    final returnValue = MessagesGetUnreadMentions(
      peer: peer,
      topMsgId: topMsgId,
      offsetId: offsetId,
      addOffset: addOffset,
      limit: limit,
      maxId: maxId,
      minId: minId,
    );

    // Now return the deserialized [MessagesGetUnreadMentions].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Top Msg Id.
  final int? topMsgId;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Add Offset.
  ///
  /// Field type is Int32.
  final int addOffset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Min Id.
  ///
  /// Field type is Int32.
  final int minId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf107e790.
    buffer.writeInt32(0xf107e790);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    buffer.writeInt32(offsetId);
    buffer.writeInt32(addOffset);
    buffer.writeInt32(limit);
    buffer.writeInt32(maxId);
    buffer.writeInt32(minId);

    // Finished serialization.
  }
}

/// Channels Delete History.
///
/// ID: `9baa9647`.
class ChannelsDeleteHistory extends TlMethod<UpdatesBase> {
  /// Channels Delete History constructor.
  const ChannelsDeleteHistory({
    required this.forEveryone,
    required this.channel,
    required this.maxId,
  }) : super._();

  /// Deserialize.
  factory ChannelsDeleteHistory.deserialize(BinaryReader reader) {
    // Read [ChannelsDeleteHistory] fields.
    final flags = reader.readInt32();
    final forEveryone = (flags & 1) != 0;
    final channel = reader.readObject() as InputChannelBase;
    final maxId = reader.readInt32();

    // Construct [ChannelsDeleteHistory] object.
    final returnValue = ChannelsDeleteHistory(
      forEveryone: forEveryone,
      channel: channel,
      maxId: maxId,
    );

    // Now return the deserialized [ChannelsDeleteHistory].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: forEveryone,
    );

    return v;
  }

  /// for_everyone: bit 0 of flags.0?true
  final bool forEveryone;

  /// Channel.
  final InputChannelBase channel;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9baa9647.
    buffer.writeInt32(0x9baa9647);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);
    buffer.writeInt32(maxId);

    // Finished serialization.
  }
}

/// Help Get Recent Me Urls.
///
/// ID: `3dc0f114`.
class HelpGetRecentMeUrls extends TlMethod<HelpRecentMeUrlsBase> {
  /// Help Get Recent Me Urls constructor.
  const HelpGetRecentMeUrls({
    required this.referer,
  }) : super._();

  /// Deserialize.
  factory HelpGetRecentMeUrls.deserialize(BinaryReader reader) {
    // Read [HelpGetRecentMeUrls] fields.
    final referer = reader.readString();

    // Construct [HelpGetRecentMeUrls] object.
    final returnValue = HelpGetRecentMeUrls(
      referer: referer,
    );

    // Now return the deserialized [HelpGetRecentMeUrls].
    return returnValue;
  }

  /// Referer.
  final String referer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3dc0f114.
    buffer.writeInt32(0x3dc0f114);

    // Write fields.
    buffer.writeString(referer);

    // Finished serialization.
  }
}

/// Channels Toggle Pre History Hidden.
///
/// ID: `eabbb94c`.
class ChannelsTogglePreHistoryHidden extends TlMethod<UpdatesBase> {
  /// Channels Toggle Pre History Hidden constructor.
  const ChannelsTogglePreHistoryHidden({
    required this.channel,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory ChannelsTogglePreHistoryHidden.deserialize(BinaryReader reader) {
    // Read [ChannelsTogglePreHistoryHidden] fields.
    final channel = reader.readObject() as InputChannelBase;
    final enabled = reader.readBool();

    // Construct [ChannelsTogglePreHistoryHidden] object.
    final returnValue = ChannelsTogglePreHistoryHidden(
      channel: channel,
      enabled: enabled,
    );

    // Now return the deserialized [ChannelsTogglePreHistoryHidden].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeabbb94c.
    buffer.writeInt32(0xeabbb94c);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Messages Read Mentions.
///
/// ID: `36e5bf4d`.
class MessagesReadMentions extends TlMethod<MessagesAffectedHistoryBase> {
  /// Messages Read Mentions constructor.
  const MessagesReadMentions({
    required this.peer,
    this.topMsgId,
  }) : super._();

  /// Deserialize.
  factory MessagesReadMentions.deserialize(BinaryReader reader) {
    // Read [MessagesReadMentions] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;

    // Construct [MessagesReadMentions] object.
    final returnValue = MessagesReadMentions(
      peer: peer,
      topMsgId: topMsgId,
    );

    // Now return the deserialized [MessagesReadMentions].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Top Msg Id.
  final int? topMsgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x36e5bf4d.
    buffer.writeInt32(0x36e5bf4d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }

    // Finished serialization.
  }
}

/// Messages Get Recent Locations.
///
/// ID: `702a40e0`.
class MessagesGetRecentLocations extends TlMethod<MessagesMessagesBase> {
  /// Messages Get Recent Locations constructor.
  const MessagesGetRecentLocations({
    required this.peer,
    required this.limit,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetRecentLocations.deserialize(BinaryReader reader) {
    // Read [MessagesGetRecentLocations] fields.
    final peer = reader.readObject() as InputPeerBase;
    final limit = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [MessagesGetRecentLocations] object.
    final returnValue = MessagesGetRecentLocations(
      peer: peer,
      limit: limit,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetRecentLocations].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x702a40e0.
    buffer.writeInt32(0x702a40e0);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(limit);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Send Multi Media.
///
/// ID: `456e8987`.
class MessagesSendMultiMedia extends TlMethod<UpdatesBase> {
  /// Messages Send Multi Media constructor.
  const MessagesSendMultiMedia({
    required this.silent,
    required this.background,
    required this.clearDraft,
    required this.noforwards,
    required this.updateStickersetsOrder,
    required this.invertMedia,
    required this.peer,
    this.replyTo,
    required this.multiMedia,
    this.scheduleDate,
    this.sendAs,
  }) : super._();

  /// Deserialize.
  factory MessagesSendMultiMedia.deserialize(BinaryReader reader) {
    // Read [MessagesSendMultiMedia] fields.
    final flags = reader.readInt32();
    final silent = (flags & 32) != 0;
    final background = (flags & 64) != 0;
    final clearDraft = (flags & 128) != 0;
    final noforwards = (flags & 16384) != 0;
    final updateStickersetsOrder = (flags & 32768) != 0;
    final invertMedia = (flags & 65536) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final hasReplyToField = (flags & 1) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as InputReplyToBase : null;
    final multiMedia = reader.readVectorObject<InputSingleMediaBase>();
    final hasScheduleDateField = (flags & 1024) != 0;
    final scheduleDate = hasScheduleDateField ? reader.readDateTime() : null;
    final hasSendAsField = (flags & 8192) != 0;
    final sendAs = hasSendAsField ? reader.readObject() as InputPeerBase : null;

    // Construct [MessagesSendMultiMedia] object.
    final returnValue = MessagesSendMultiMedia(
      silent: silent,
      background: background,
      clearDraft: clearDraft,
      noforwards: noforwards,
      updateStickersetsOrder: updateStickersetsOrder,
      invertMedia: invertMedia,
      peer: peer,
      replyTo: replyTo,
      multiMedia: multiMedia,
      scheduleDate: scheduleDate,
      sendAs: sendAs,
    );

    // Now return the deserialized [MessagesSendMultiMedia].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b05: silent,
      b06: background,
      b07: clearDraft,
      b14: noforwards,
      b15: updateStickersetsOrder,
      b16: invertMedia,
      b00: replyTo != null,
      b10: scheduleDate != null,
      b13: sendAs != null,
    );

    return v;
  }

  /// silent: bit 5 of flags.5?true
  final bool silent;

  /// background: bit 6 of flags.6?true
  final bool background;

  /// clear_draft: bit 7 of flags.7?true
  final bool clearDraft;

  /// noforwards: bit 14 of flags.14?true
  final bool noforwards;

  /// update_stickersets_order: bit 15 of flags.15?true
  final bool updateStickersetsOrder;

  /// invert_media: bit 16 of flags.16?true
  final bool invertMedia;

  /// Peer.
  final InputPeerBase peer;

  /// Reply To.
  final InputReplyToBase? replyTo;

  /// Multi Media.
  final List<InputSingleMediaBase> multiMedia;

  /// Schedule Date.
  final DateTime? scheduleDate;

  /// Send As.
  final InputPeerBase? sendAs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x456e8987.
    buffer.writeInt32(0x456e8987);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    buffer.writeVectorObject(multiMedia);
    final localScheduleDateCopy = scheduleDate;
    if (localScheduleDateCopy != null) {
      buffer.writeDateTime(localScheduleDateCopy);
    }
    final localSendAsCopy = sendAs;
    if (localSendAsCopy != null) {
      buffer.writeObject(localSendAsCopy);
    }

    // Finished serialization.
  }
}

/// Messages Upload Encrypted File.
///
/// ID: `5057c497`.
class MessagesUploadEncryptedFile extends TlMethod<EncryptedFileBase> {
  /// Messages Upload Encrypted File constructor.
  const MessagesUploadEncryptedFile({
    required this.peer,
    required this.file,
  }) : super._();

  /// Deserialize.
  factory MessagesUploadEncryptedFile.deserialize(BinaryReader reader) {
    // Read [MessagesUploadEncryptedFile] fields.
    final peer = reader.readObject() as InputEncryptedChatBase;
    final file = reader.readObject() as InputEncryptedFileBase;

    // Construct [MessagesUploadEncryptedFile] object.
    final returnValue = MessagesUploadEncryptedFile(
      peer: peer,
      file: file,
    );

    // Now return the deserialized [MessagesUploadEncryptedFile].
    return returnValue;
  }

  /// Peer.
  final InputEncryptedChatBase peer;

  /// File.
  final InputEncryptedFileBase file;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5057c497.
    buffer.writeInt32(0x5057c497);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(file);

    // Finished serialization.
  }
}

/// Account Get Web Authorizations.
///
/// ID: `182e6d6f`.
class AccountGetWebAuthorizations
    extends TlMethod<AccountWebAuthorizationsBase> {
  /// Account Get Web Authorizations constructor.
  const AccountGetWebAuthorizations() : super._();

  /// Deserialize.
  factory AccountGetWebAuthorizations.deserialize(BinaryReader reader) {
    // Construct [AccountGetWebAuthorizations] object.
    final returnValue = AccountGetWebAuthorizations();

    // Now return the deserialized [AccountGetWebAuthorizations].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x182e6d6f.
    buffer.writeInt32(0x182e6d6f);

    // Finished serialization.
  }
}

/// Account Reset Web Authorization.
///
/// ID: `2d01b9ef`.
class AccountResetWebAuthorization extends TlMethod<bool> {
  /// Account Reset Web Authorization constructor.
  const AccountResetWebAuthorization({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountResetWebAuthorization.deserialize(BinaryReader reader) {
    // Read [AccountResetWebAuthorization] fields.
    final hash = reader.readInt64();

    // Construct [AccountResetWebAuthorization] object.
    final returnValue = AccountResetWebAuthorization(
      hash: hash,
    );

    // Now return the deserialized [AccountResetWebAuthorization].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2d01b9ef.
    buffer.writeInt32(0x2d01b9ef);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Account Reset Web Authorizations.
///
/// ID: `682d2594`.
class AccountResetWebAuthorizations extends TlMethod<bool> {
  /// Account Reset Web Authorizations constructor.
  const AccountResetWebAuthorizations() : super._();

  /// Deserialize.
  factory AccountResetWebAuthorizations.deserialize(BinaryReader reader) {
    // Construct [AccountResetWebAuthorizations] object.
    final returnValue = AccountResetWebAuthorizations();

    // Now return the deserialized [AccountResetWebAuthorizations].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x682d2594.
    buffer.writeInt32(0x682d2594);

    // Finished serialization.
  }
}

/// Messages Search Sticker Sets.
///
/// ID: `35705b8a`.
class MessagesSearchStickerSets extends TlMethod<MessagesFoundStickerSetsBase> {
  /// Messages Search Sticker Sets constructor.
  const MessagesSearchStickerSets({
    required this.excludeFeatured,
    required this.q,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesSearchStickerSets.deserialize(BinaryReader reader) {
    // Read [MessagesSearchStickerSets] fields.
    final flags = reader.readInt32();
    final excludeFeatured = (flags & 1) != 0;
    final q = reader.readString();
    final hash = reader.readInt64();

    // Construct [MessagesSearchStickerSets] object.
    final returnValue = MessagesSearchStickerSets(
      excludeFeatured: excludeFeatured,
      q: q,
      hash: hash,
    );

    // Now return the deserialized [MessagesSearchStickerSets].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: excludeFeatured,
    );

    return v;
  }

  /// exclude_featured: bit 0 of flags.0?true
  final bool excludeFeatured;

  /// Q.
  final String q;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x35705b8a.
    buffer.writeInt32(0x35705b8a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(q);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Upload Get File Hashes.
///
/// ID: `9156982a`.
class UploadGetFileHashes extends TlMethod<List<FileHashBase>> {
  /// Upload Get File Hashes constructor.
  const UploadGetFileHashes({
    required this.location,
    required this.offset,
  }) : super._();

  /// Deserialize.
  factory UploadGetFileHashes.deserialize(BinaryReader reader) {
    // Read [UploadGetFileHashes] fields.
    final location = reader.readObject() as InputFileLocationBase;
    final offset = reader.readInt64();

    // Construct [UploadGetFileHashes] object.
    final returnValue = UploadGetFileHashes(
      location: location,
      offset: offset,
    );

    // Now return the deserialized [UploadGetFileHashes].
    return returnValue;
  }

  /// Location.
  final InputFileLocationBase location;

  /// Offset.
  ///
  /// Field type is Int64.
  final int offset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9156982a.
    buffer.writeInt32(0x9156982a);

    // Write fields.
    buffer.writeObject(location);
    buffer.writeInt64(offset);

    // Finished serialization.
  }
}

/// Help Get Terms Of Service Update.
///
/// ID: `2ca51fd1`.
class HelpGetTermsOfServiceUpdate
    extends TlMethod<HelpTermsOfServiceUpdateBase> {
  /// Help Get Terms Of Service Update constructor.
  const HelpGetTermsOfServiceUpdate() : super._();

  /// Deserialize.
  factory HelpGetTermsOfServiceUpdate.deserialize(BinaryReader reader) {
    // Construct [HelpGetTermsOfServiceUpdate] object.
    final returnValue = HelpGetTermsOfServiceUpdate();

    // Now return the deserialized [HelpGetTermsOfServiceUpdate].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2ca51fd1.
    buffer.writeInt32(0x2ca51fd1);

    // Finished serialization.
  }
}

/// Help Accept Terms Of Service.
///
/// ID: `ee72f79a`.
class HelpAcceptTermsOfService extends TlMethod<bool> {
  /// Help Accept Terms Of Service constructor.
  const HelpAcceptTermsOfService({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory HelpAcceptTermsOfService.deserialize(BinaryReader reader) {
    // Read [HelpAcceptTermsOfService] fields.
    final id = reader.readObject() as DataJSONBase;

    // Construct [HelpAcceptTermsOfService] object.
    final returnValue = HelpAcceptTermsOfService(
      id: id,
    );

    // Now return the deserialized [HelpAcceptTermsOfService].
    return returnValue;
  }

  /// Id.
  final DataJSONBase id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xee72f79a.
    buffer.writeInt32(0xee72f79a);

    // Write fields.
    buffer.writeObject(id);

    // Finished serialization.
  }
}

/// Account Get All Secure Values.
///
/// ID: `b288bc7d`.
class AccountGetAllSecureValues extends TlMethod<List<SecureValueBase>> {
  /// Account Get All Secure Values constructor.
  const AccountGetAllSecureValues() : super._();

  /// Deserialize.
  factory AccountGetAllSecureValues.deserialize(BinaryReader reader) {
    // Construct [AccountGetAllSecureValues] object.
    final returnValue = AccountGetAllSecureValues();

    // Now return the deserialized [AccountGetAllSecureValues].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb288bc7d.
    buffer.writeInt32(0xb288bc7d);

    // Finished serialization.
  }
}

/// Account Get Secure Value.
///
/// ID: `73665bc2`.
class AccountGetSecureValue extends TlMethod<List<SecureValueBase>> {
  /// Account Get Secure Value constructor.
  const AccountGetSecureValue({
    required this.types,
  }) : super._();

  /// Deserialize.
  factory AccountGetSecureValue.deserialize(BinaryReader reader) {
    // Read [AccountGetSecureValue] fields.
    final types = reader.readVectorObject<SecureValueTypeBase>();

    // Construct [AccountGetSecureValue] object.
    final returnValue = AccountGetSecureValue(
      types: types,
    );

    // Now return the deserialized [AccountGetSecureValue].
    return returnValue;
  }

  /// Types.
  final List<SecureValueTypeBase> types;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x73665bc2.
    buffer.writeInt32(0x73665bc2);

    // Write fields.
    buffer.writeVectorObject(types);

    // Finished serialization.
  }
}

/// Account Save Secure Value.
///
/// ID: `899fe31d`.
class AccountSaveSecureValue extends TlMethod<SecureValueBase> {
  /// Account Save Secure Value constructor.
  const AccountSaveSecureValue({
    required this.value,
    required this.secureSecretId,
  }) : super._();

  /// Deserialize.
  factory AccountSaveSecureValue.deserialize(BinaryReader reader) {
    // Read [AccountSaveSecureValue] fields.
    final value = reader.readObject() as InputSecureValueBase;
    final secureSecretId = reader.readInt64();

    // Construct [AccountSaveSecureValue] object.
    final returnValue = AccountSaveSecureValue(
      value: value,
      secureSecretId: secureSecretId,
    );

    // Now return the deserialized [AccountSaveSecureValue].
    return returnValue;
  }

  /// Value.
  final InputSecureValueBase value;

  /// Secure Secret Id.
  ///
  /// Field type is Int64.
  final int secureSecretId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x899fe31d.
    buffer.writeInt32(0x899fe31d);

    // Write fields.
    buffer.writeObject(value);
    buffer.writeInt64(secureSecretId);

    // Finished serialization.
  }
}

/// Account Delete Secure Value.
///
/// ID: `b880bc4b`.
class AccountDeleteSecureValue extends TlMethod<bool> {
  /// Account Delete Secure Value constructor.
  const AccountDeleteSecureValue({
    required this.types,
  }) : super._();

  /// Deserialize.
  factory AccountDeleteSecureValue.deserialize(BinaryReader reader) {
    // Read [AccountDeleteSecureValue] fields.
    final types = reader.readVectorObject<SecureValueTypeBase>();

    // Construct [AccountDeleteSecureValue] object.
    final returnValue = AccountDeleteSecureValue(
      types: types,
    );

    // Now return the deserialized [AccountDeleteSecureValue].
    return returnValue;
  }

  /// Types.
  final List<SecureValueTypeBase> types;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb880bc4b.
    buffer.writeInt32(0xb880bc4b);

    // Write fields.
    buffer.writeVectorObject(types);

    // Finished serialization.
  }
}

/// Users Set Secure Value Errors.
///
/// ID: `90c894b5`.
class UsersSetSecureValueErrors extends TlMethod<bool> {
  /// Users Set Secure Value Errors constructor.
  const UsersSetSecureValueErrors({
    required this.id,
    required this.errors,
  }) : super._();

  /// Deserialize.
  factory UsersSetSecureValueErrors.deserialize(BinaryReader reader) {
    // Read [UsersSetSecureValueErrors] fields.
    final id = reader.readObject() as InputUserBase;
    final errors = reader.readVectorObject<SecureValueErrorBase>();

    // Construct [UsersSetSecureValueErrors] object.
    final returnValue = UsersSetSecureValueErrors(
      id: id,
      errors: errors,
    );

    // Now return the deserialized [UsersSetSecureValueErrors].
    return returnValue;
  }

  /// Id.
  final InputUserBase id;

  /// Errors.
  final List<SecureValueErrorBase> errors;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x90c894b5.
    buffer.writeInt32(0x90c894b5);

    // Write fields.
    buffer.writeObject(id);
    buffer.writeVectorObject(errors);

    // Finished serialization.
  }
}

/// Account Get Authorization Form.
///
/// ID: `a929597a`.
class AccountGetAuthorizationForm
    extends TlMethod<AccountAuthorizationFormBase> {
  /// Account Get Authorization Form constructor.
  const AccountGetAuthorizationForm({
    required this.botId,
    required this.scope,
    required this.publicKey,
  }) : super._();

  /// Deserialize.
  factory AccountGetAuthorizationForm.deserialize(BinaryReader reader) {
    // Read [AccountGetAuthorizationForm] fields.
    final botId = reader.readInt64();
    final scope = reader.readString();
    final publicKey = reader.readString();

    // Construct [AccountGetAuthorizationForm] object.
    final returnValue = AccountGetAuthorizationForm(
      botId: botId,
      scope: scope,
      publicKey: publicKey,
    );

    // Now return the deserialized [AccountGetAuthorizationForm].
    return returnValue;
  }

  /// Bot Id.
  ///
  /// Field type is Int64.
  final int botId;

  /// Scope.
  final String scope;

  /// Public Key.
  final String publicKey;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa929597a.
    buffer.writeInt32(0xa929597a);

    // Write fields.
    buffer.writeInt64(botId);
    buffer.writeString(scope);
    buffer.writeString(publicKey);

    // Finished serialization.
  }
}

/// Account Accept Authorization.
///
/// ID: `f3ed4c73`.
class AccountAcceptAuthorization extends TlMethod<bool> {
  /// Account Accept Authorization constructor.
  const AccountAcceptAuthorization({
    required this.botId,
    required this.scope,
    required this.publicKey,
    required this.valueHashes,
    required this.credentials,
  }) : super._();

  /// Deserialize.
  factory AccountAcceptAuthorization.deserialize(BinaryReader reader) {
    // Read [AccountAcceptAuthorization] fields.
    final botId = reader.readInt64();
    final scope = reader.readString();
    final publicKey = reader.readString();
    final valueHashes = reader.readVectorObject<SecureValueHashBase>();
    final credentials = reader.readObject() as SecureCredentialsEncryptedBase;

    // Construct [AccountAcceptAuthorization] object.
    final returnValue = AccountAcceptAuthorization(
      botId: botId,
      scope: scope,
      publicKey: publicKey,
      valueHashes: valueHashes,
      credentials: credentials,
    );

    // Now return the deserialized [AccountAcceptAuthorization].
    return returnValue;
  }

  /// Bot Id.
  ///
  /// Field type is Int64.
  final int botId;

  /// Scope.
  final String scope;

  /// Public Key.
  final String publicKey;

  /// Value Hashes.
  final List<SecureValueHashBase> valueHashes;

  /// Credentials.
  final SecureCredentialsEncryptedBase credentials;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf3ed4c73.
    buffer.writeInt32(0xf3ed4c73);

    // Write fields.
    buffer.writeInt64(botId);
    buffer.writeString(scope);
    buffer.writeString(publicKey);
    buffer.writeVectorObject(valueHashes);
    buffer.writeObject(credentials);

    // Finished serialization.
  }
}

/// Account Send Verify Phone Code.
///
/// ID: `a5a356f9`.
class AccountSendVerifyPhoneCode extends TlMethod<AuthSentCodeBase> {
  /// Account Send Verify Phone Code constructor.
  const AccountSendVerifyPhoneCode({
    required this.phoneNumber,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountSendVerifyPhoneCode.deserialize(BinaryReader reader) {
    // Read [AccountSendVerifyPhoneCode] fields.
    final phoneNumber = reader.readString();
    final settings = reader.readObject() as CodeSettingsBase;

    // Construct [AccountSendVerifyPhoneCode] object.
    final returnValue = AccountSendVerifyPhoneCode(
      phoneNumber: phoneNumber,
      settings: settings,
    );

    // Now return the deserialized [AccountSendVerifyPhoneCode].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Settings.
  final CodeSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa5a356f9.
    buffer.writeInt32(0xa5a356f9);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Account Verify Phone.
///
/// ID: `4dd3a7f6`.
class AccountVerifyPhone extends TlMethod<bool> {
  /// Account Verify Phone constructor.
  const AccountVerifyPhone({
    required this.phoneNumber,
    required this.phoneCodeHash,
    required this.phoneCode,
  }) : super._();

  /// Deserialize.
  factory AccountVerifyPhone.deserialize(BinaryReader reader) {
    // Read [AccountVerifyPhone] fields.
    final phoneNumber = reader.readString();
    final phoneCodeHash = reader.readString();
    final phoneCode = reader.readString();

    // Construct [AccountVerifyPhone] object.
    final returnValue = AccountVerifyPhone(
      phoneNumber: phoneNumber,
      phoneCodeHash: phoneCodeHash,
      phoneCode: phoneCode,
    );

    // Now return the deserialized [AccountVerifyPhone].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// Phone Code.
  final String phoneCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4dd3a7f6.
    buffer.writeInt32(0x4dd3a7f6);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeString(phoneCodeHash);
    buffer.writeString(phoneCode);

    // Finished serialization.
  }
}

/// Account Send Verify Email Code.
///
/// ID: `98e037bb`.
class AccountSendVerifyEmailCode extends TlMethod<AccountSentEmailCodeBase> {
  /// Account Send Verify Email Code constructor.
  const AccountSendVerifyEmailCode({
    required this.purpose,
    required this.email,
  }) : super._();

  /// Deserialize.
  factory AccountSendVerifyEmailCode.deserialize(BinaryReader reader) {
    // Read [AccountSendVerifyEmailCode] fields.
    final purpose = reader.readObject() as EmailVerifyPurposeBase;
    final email = reader.readString();

    // Construct [AccountSendVerifyEmailCode] object.
    final returnValue = AccountSendVerifyEmailCode(
      purpose: purpose,
      email: email,
    );

    // Now return the deserialized [AccountSendVerifyEmailCode].
    return returnValue;
  }

  /// Purpose.
  final EmailVerifyPurposeBase purpose;

  /// Email.
  final String email;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x98e037bb.
    buffer.writeInt32(0x98e037bb);

    // Write fields.
    buffer.writeObject(purpose);
    buffer.writeString(email);

    // Finished serialization.
  }
}

/// Account Verify Email.
///
/// ID: `032da4cf`.
class AccountVerifyEmail extends TlMethod<AccountEmailVerifiedBase> {
  /// Account Verify Email constructor.
  const AccountVerifyEmail({
    required this.purpose,
    required this.verification,
  }) : super._();

  /// Deserialize.
  factory AccountVerifyEmail.deserialize(BinaryReader reader) {
    // Read [AccountVerifyEmail] fields.
    final purpose = reader.readObject() as EmailVerifyPurposeBase;
    final verification = reader.readObject() as EmailVerificationBase;

    // Construct [AccountVerifyEmail] object.
    final returnValue = AccountVerifyEmail(
      purpose: purpose,
      verification: verification,
    );

    // Now return the deserialized [AccountVerifyEmail].
    return returnValue;
  }

  /// Purpose.
  final EmailVerifyPurposeBase purpose;

  /// Verification.
  final EmailVerificationBase verification;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x032da4cf.
    buffer.writeInt32(0x032da4cf);

    // Write fields.
    buffer.writeObject(purpose);
    buffer.writeObject(verification);

    // Finished serialization.
  }
}

/// Help Get Deep Link Info.
///
/// ID: `3fedc75f`.
class HelpGetDeepLinkInfo extends TlMethod<HelpDeepLinkInfoBase> {
  /// Help Get Deep Link Info constructor.
  const HelpGetDeepLinkInfo({
    required this.path,
  }) : super._();

  /// Deserialize.
  factory HelpGetDeepLinkInfo.deserialize(BinaryReader reader) {
    // Read [HelpGetDeepLinkInfo] fields.
    final path = reader.readString();

    // Construct [HelpGetDeepLinkInfo] object.
    final returnValue = HelpGetDeepLinkInfo(
      path: path,
    );

    // Now return the deserialized [HelpGetDeepLinkInfo].
    return returnValue;
  }

  /// Path.
  final String path;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3fedc75f.
    buffer.writeInt32(0x3fedc75f);

    // Write fields.
    buffer.writeString(path);

    // Finished serialization.
  }
}

/// Contacts Get Saved.
///
/// ID: `82f1e39f`.
class ContactsGetSaved extends TlMethod<List<SavedContactBase>> {
  /// Contacts Get Saved constructor.
  const ContactsGetSaved() : super._();

  /// Deserialize.
  factory ContactsGetSaved.deserialize(BinaryReader reader) {
    // Construct [ContactsGetSaved] object.
    final returnValue = ContactsGetSaved();

    // Now return the deserialized [ContactsGetSaved].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x82f1e39f.
    buffer.writeInt32(0x82f1e39f);

    // Finished serialization.
  }
}

/// Channels Get Left Channels.
///
/// ID: `8341ecc0`.
class ChannelsGetLeftChannels extends TlMethod<MessagesChatsBase> {
  /// Channels Get Left Channels constructor.
  const ChannelsGetLeftChannels({
    required this.offset,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetLeftChannels.deserialize(BinaryReader reader) {
    // Read [ChannelsGetLeftChannels] fields.
    final offset = reader.readInt32();

    // Construct [ChannelsGetLeftChannels] object.
    final returnValue = ChannelsGetLeftChannels(
      offset: offset,
    );

    // Now return the deserialized [ChannelsGetLeftChannels].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8341ecc0.
    buffer.writeInt32(0x8341ecc0);

    // Write fields.
    buffer.writeInt32(offset);

    // Finished serialization.
  }
}

/// Account Init Takeout Session.
///
/// ID: `8ef3eab0`.
class AccountInitTakeoutSession extends TlMethod<AccountTakeoutBase> {
  /// Account Init Takeout Session constructor.
  const AccountInitTakeoutSession({
    required this.contacts,
    required this.messageUsers,
    required this.messageChats,
    required this.messageMegagroups,
    required this.messageChannels,
    required this.files,
    this.fileMaxSize,
  }) : super._();

  /// Deserialize.
  factory AccountInitTakeoutSession.deserialize(BinaryReader reader) {
    // Read [AccountInitTakeoutSession] fields.
    final flags = reader.readInt32();
    final contacts = (flags & 1) != 0;
    final messageUsers = (flags & 2) != 0;
    final messageChats = (flags & 4) != 0;
    final messageMegagroups = (flags & 8) != 0;
    final messageChannels = (flags & 16) != 0;
    final files = (flags & 32) != 0;
    final hasFileMaxSizeField = (flags & 32) != 0;
    final fileMaxSize = hasFileMaxSizeField ? reader.readInt64() : null;

    // Construct [AccountInitTakeoutSession] object.
    final returnValue = AccountInitTakeoutSession(
      contacts: contacts,
      messageUsers: messageUsers,
      messageChats: messageChats,
      messageMegagroups: messageMegagroups,
      messageChannels: messageChannels,
      files: files,
      fileMaxSize: fileMaxSize,
    );

    // Now return the deserialized [AccountInitTakeoutSession].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: contacts,
      b01: messageUsers,
      b02: messageChats,
      b03: messageMegagroups,
      b04: messageChannels,
      b05: files || fileMaxSize != null,
    );

    return v;
  }

  /// contacts: bit 0 of flags.0?true
  final bool contacts;

  /// message_users: bit 1 of flags.1?true
  final bool messageUsers;

  /// message_chats: bit 2 of flags.2?true
  final bool messageChats;

  /// message_megagroups: bit 3 of flags.3?true
  final bool messageMegagroups;

  /// message_channels: bit 4 of flags.4?true
  final bool messageChannels;

  /// files: bit 5 of flags.5?true
  final bool files;

  /// File Max Size.
  final int? fileMaxSize;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8ef3eab0.
    buffer.writeInt32(0x8ef3eab0);

    // Write fields.
    buffer.writeInt32(flags);
    final localFileMaxSizeCopy = fileMaxSize;
    if (localFileMaxSizeCopy != null) {
      buffer.writeInt64(localFileMaxSizeCopy);
    }

    // Finished serialization.
  }
}

/// Account Finish Takeout Session.
///
/// ID: `1d2652ee`.
class AccountFinishTakeoutSession extends TlMethod<bool> {
  /// Account Finish Takeout Session constructor.
  const AccountFinishTakeoutSession({
    required this.success,
  }) : super._();

  /// Deserialize.
  factory AccountFinishTakeoutSession.deserialize(BinaryReader reader) {
    // Read [AccountFinishTakeoutSession] fields.
    final flags = reader.readInt32();
    final success = (flags & 1) != 0;

    // Construct [AccountFinishTakeoutSession] object.
    final returnValue = AccountFinishTakeoutSession(
      success: success,
    );

    // Now return the deserialized [AccountFinishTakeoutSession].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: success,
    );

    return v;
  }

  /// success: bit 0 of flags.0?true
  final bool success;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1d2652ee.
    buffer.writeInt32(0x1d2652ee);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Messages Get Split Ranges.
///
/// ID: `1cff7e08`.
class MessagesGetSplitRanges extends TlMethod<List<MessageRangeBase>> {
  /// Messages Get Split Ranges constructor.
  const MessagesGetSplitRanges() : super._();

  /// Deserialize.
  factory MessagesGetSplitRanges.deserialize(BinaryReader reader) {
    // Construct [MessagesGetSplitRanges] object.
    final returnValue = MessagesGetSplitRanges();

    // Now return the deserialized [MessagesGetSplitRanges].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1cff7e08.
    buffer.writeInt32(0x1cff7e08);

    // Finished serialization.
  }
}

/// Invoke With Messages Range.
///
/// ID: `365275f2`.
class InvokeWithMessagesRange<X> extends TlMethod<X> {
  /// Invoke With Messages Range constructor.
  const InvokeWithMessagesRange({
    required this.range,
    required this.query,
  }) : super._();

  /// Deserialize.
  factory InvokeWithMessagesRange.deserialize(BinaryReader reader) {
    // Read [InvokeWithMessagesRange] fields.
    final range = reader.readObject() as MessageRangeBase;
    final query = reader.readObject() as TlMethod<X>;

    // Construct [InvokeWithMessagesRange] object.
    final returnValue = InvokeWithMessagesRange(
      range: range,
      query: query,
    );

    // Now return the deserialized [InvokeWithMessagesRange].
    return returnValue;
  }

  /// Range.
  final MessageRangeBase range;

  /// Query.
  final TlMethod<X> query;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x365275f2.
    buffer.writeInt32(0x365275f2);

    // Write fields.
    buffer.writeObject(range);
    buffer.writeObject(query);

    // Finished serialization.
  }
}

/// Invoke With Takeout.
///
/// ID: `aca9fd2e`.
class InvokeWithTakeout<X> extends TlMethod<X> {
  /// Invoke With Takeout constructor.
  const InvokeWithTakeout({
    required this.takeoutId,
    required this.query,
  }) : super._();

  /// Deserialize.
  factory InvokeWithTakeout.deserialize(BinaryReader reader) {
    // Read [InvokeWithTakeout] fields.
    final takeoutId = reader.readInt64();
    final query = reader.readObject() as TlMethod<X>;

    // Construct [InvokeWithTakeout] object.
    final returnValue = InvokeWithTakeout(
      takeoutId: takeoutId,
      query: query,
    );

    // Now return the deserialized [InvokeWithTakeout].
    return returnValue;
  }

  /// Takeout Id.
  ///
  /// Field type is Int64.
  final int takeoutId;

  /// Query.
  final TlMethod<X> query;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xaca9fd2e.
    buffer.writeInt32(0xaca9fd2e);

    // Write fields.
    buffer.writeInt64(takeoutId);
    buffer.writeObject(query);

    // Finished serialization.
  }
}

/// Messages Mark Dialog Unread.
///
/// ID: `c286d98f`.
class MessagesMarkDialogUnread extends TlMethod<bool> {
  /// Messages Mark Dialog Unread constructor.
  const MessagesMarkDialogUnread({
    required this.unread,
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesMarkDialogUnread.deserialize(BinaryReader reader) {
    // Read [MessagesMarkDialogUnread] fields.
    final flags = reader.readInt32();
    final unread = (flags & 1) != 0;
    final peer = reader.readObject() as InputDialogPeerBase;

    // Construct [MessagesMarkDialogUnread] object.
    final returnValue = MessagesMarkDialogUnread(
      unread: unread,
      peer: peer,
    );

    // Now return the deserialized [MessagesMarkDialogUnread].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: unread,
    );

    return v;
  }

  /// unread: bit 0 of flags.0?true
  final bool unread;

  /// Peer.
  final InputDialogPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc286d98f.
    buffer.writeInt32(0xc286d98f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Messages Get Dialog Unread Marks.
///
/// ID: `22e24e22`.
class MessagesGetDialogUnreadMarks extends TlMethod<List<DialogPeerBase>> {
  /// Messages Get Dialog Unread Marks constructor.
  const MessagesGetDialogUnreadMarks() : super._();

  /// Deserialize.
  factory MessagesGetDialogUnreadMarks.deserialize(BinaryReader reader) {
    // Construct [MessagesGetDialogUnreadMarks] object.
    final returnValue = MessagesGetDialogUnreadMarks();

    // Now return the deserialized [MessagesGetDialogUnreadMarks].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x22e24e22.
    buffer.writeInt32(0x22e24e22);

    // Finished serialization.
  }
}

/// Contacts Toggle Top Peers.
///
/// ID: `8514bdda`.
class ContactsToggleTopPeers extends TlMethod<bool> {
  /// Contacts Toggle Top Peers constructor.
  const ContactsToggleTopPeers({
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory ContactsToggleTopPeers.deserialize(BinaryReader reader) {
    // Read [ContactsToggleTopPeers] fields.
    final enabled = reader.readBool();

    // Construct [ContactsToggleTopPeers] object.
    final returnValue = ContactsToggleTopPeers(
      enabled: enabled,
    );

    // Now return the deserialized [ContactsToggleTopPeers].
    return returnValue;
  }

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8514bdda.
    buffer.writeInt32(0x8514bdda);

    // Write fields.
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Messages Clear All Drafts.
///
/// ID: `7e58ee9c`.
class MessagesClearAllDrafts extends TlMethod<bool> {
  /// Messages Clear All Drafts constructor.
  const MessagesClearAllDrafts() : super._();

  /// Deserialize.
  factory MessagesClearAllDrafts.deserialize(BinaryReader reader) {
    // Construct [MessagesClearAllDrafts] object.
    final returnValue = MessagesClearAllDrafts();

    // Now return the deserialized [MessagesClearAllDrafts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7e58ee9c.
    buffer.writeInt32(0x7e58ee9c);

    // Finished serialization.
  }
}

/// Help Get App Config.
///
/// ID: `61e3f854`.
class HelpGetAppConfig extends TlMethod<HelpAppConfigBase> {
  /// Help Get App Config constructor.
  const HelpGetAppConfig({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory HelpGetAppConfig.deserialize(BinaryReader reader) {
    // Read [HelpGetAppConfig] fields.
    final hash = reader.readInt32();

    // Construct [HelpGetAppConfig] object.
    final returnValue = HelpGetAppConfig(
      hash: hash,
    );

    // Now return the deserialized [HelpGetAppConfig].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x61e3f854.
    buffer.writeInt32(0x61e3f854);

    // Write fields.
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Help Save App Log.
///
/// ID: `6f02f748`.
class HelpSaveAppLog extends TlMethod<bool> {
  /// Help Save App Log constructor.
  const HelpSaveAppLog({
    required this.events,
  }) : super._();

  /// Deserialize.
  factory HelpSaveAppLog.deserialize(BinaryReader reader) {
    // Read [HelpSaveAppLog] fields.
    final events = reader.readVectorObject<InputAppEventBase>();

    // Construct [HelpSaveAppLog] object.
    final returnValue = HelpSaveAppLog(
      events: events,
    );

    // Now return the deserialized [HelpSaveAppLog].
    return returnValue;
  }

  /// Events.
  final List<InputAppEventBase> events;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6f02f748.
    buffer.writeInt32(0x6f02f748);

    // Write fields.
    buffer.writeVectorObject(events);

    // Finished serialization.
  }
}

/// Help Get Passport Config.
///
/// ID: `c661ad08`.
class HelpGetPassportConfig extends TlMethod<HelpPassportConfigBase> {
  /// Help Get Passport Config constructor.
  const HelpGetPassportConfig({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory HelpGetPassportConfig.deserialize(BinaryReader reader) {
    // Read [HelpGetPassportConfig] fields.
    final hash = reader.readInt32();

    // Construct [HelpGetPassportConfig] object.
    final returnValue = HelpGetPassportConfig(
      hash: hash,
    );

    // Now return the deserialized [HelpGetPassportConfig].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc661ad08.
    buffer.writeInt32(0xc661ad08);

    // Write fields.
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Langpack Get Language.
///
/// ID: `6a596502`.
class LangpackGetLanguage extends TlMethod<LangPackLanguageBase> {
  /// Langpack Get Language constructor.
  const LangpackGetLanguage({
    required this.langPack,
    required this.langCode,
  }) : super._();

  /// Deserialize.
  factory LangpackGetLanguage.deserialize(BinaryReader reader) {
    // Read [LangpackGetLanguage] fields.
    final langPack = reader.readString();
    final langCode = reader.readString();

    // Construct [LangpackGetLanguage] object.
    final returnValue = LangpackGetLanguage(
      langPack: langPack,
      langCode: langCode,
    );

    // Now return the deserialized [LangpackGetLanguage].
    return returnValue;
  }

  /// Lang Pack.
  final String langPack;

  /// Lang Code.
  final String langCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6a596502.
    buffer.writeInt32(0x6a596502);

    // Write fields.
    buffer.writeString(langPack);
    buffer.writeString(langCode);

    // Finished serialization.
  }
}

/// Messages Update Pinned Message.
///
/// ID: `d2aaf7ec`.
class MessagesUpdatePinnedMessage extends TlMethod<UpdatesBase> {
  /// Messages Update Pinned Message constructor.
  const MessagesUpdatePinnedMessage({
    required this.silent,
    required this.unpin,
    required this.pmOneside,
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesUpdatePinnedMessage.deserialize(BinaryReader reader) {
    // Read [MessagesUpdatePinnedMessage] fields.
    final flags = reader.readInt32();
    final silent = (flags & 1) != 0;
    final unpin = (flags & 2) != 0;
    final pmOneside = (flags & 4) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();

    // Construct [MessagesUpdatePinnedMessage] object.
    final returnValue = MessagesUpdatePinnedMessage(
      silent: silent,
      unpin: unpin,
      pmOneside: pmOneside,
      peer: peer,
      id: id,
    );

    // Now return the deserialized [MessagesUpdatePinnedMessage].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: silent,
      b01: unpin,
      b02: pmOneside,
    );

    return v;
  }

  /// silent: bit 0 of flags.0?true
  final bool silent;

  /// unpin: bit 1 of flags.1?true
  final bool unpin;

  /// pm_oneside: bit 2 of flags.2?true
  final bool pmOneside;

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd2aaf7ec.
    buffer.writeInt32(0xd2aaf7ec);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Account Confirm Password Email.
///
/// ID: `8fdf1920`.
class AccountConfirmPasswordEmail extends TlMethod<bool> {
  /// Account Confirm Password Email constructor.
  const AccountConfirmPasswordEmail({
    required this.code,
  }) : super._();

  /// Deserialize.
  factory AccountConfirmPasswordEmail.deserialize(BinaryReader reader) {
    // Read [AccountConfirmPasswordEmail] fields.
    final code = reader.readString();

    // Construct [AccountConfirmPasswordEmail] object.
    final returnValue = AccountConfirmPasswordEmail(
      code: code,
    );

    // Now return the deserialized [AccountConfirmPasswordEmail].
    return returnValue;
  }

  /// Code.
  final String code;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8fdf1920.
    buffer.writeInt32(0x8fdf1920);

    // Write fields.
    buffer.writeString(code);

    // Finished serialization.
  }
}

/// Account Resend Password Email.
///
/// ID: `7a7f2a15`.
class AccountResendPasswordEmail extends TlMethod<bool> {
  /// Account Resend Password Email constructor.
  const AccountResendPasswordEmail() : super._();

  /// Deserialize.
  factory AccountResendPasswordEmail.deserialize(BinaryReader reader) {
    // Construct [AccountResendPasswordEmail] object.
    final returnValue = AccountResendPasswordEmail();

    // Now return the deserialized [AccountResendPasswordEmail].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7a7f2a15.
    buffer.writeInt32(0x7a7f2a15);

    // Finished serialization.
  }
}

/// Account Cancel Password Email.
///
/// ID: `c1cbd5b6`.
class AccountCancelPasswordEmail extends TlMethod<bool> {
  /// Account Cancel Password Email constructor.
  const AccountCancelPasswordEmail() : super._();

  /// Deserialize.
  factory AccountCancelPasswordEmail.deserialize(BinaryReader reader) {
    // Construct [AccountCancelPasswordEmail] object.
    final returnValue = AccountCancelPasswordEmail();

    // Now return the deserialized [AccountCancelPasswordEmail].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc1cbd5b6.
    buffer.writeInt32(0xc1cbd5b6);

    // Finished serialization.
  }
}

/// Help Get Support Name.
///
/// ID: `d360e72c`.
class HelpGetSupportName extends TlMethod<HelpSupportNameBase> {
  /// Help Get Support Name constructor.
  const HelpGetSupportName() : super._();

  /// Deserialize.
  factory HelpGetSupportName.deserialize(BinaryReader reader) {
    // Construct [HelpGetSupportName] object.
    final returnValue = HelpGetSupportName();

    // Now return the deserialized [HelpGetSupportName].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd360e72c.
    buffer.writeInt32(0xd360e72c);

    // Finished serialization.
  }
}

/// Help Get User Info.
///
/// ID: `038a08d3`.
class HelpGetUserInfo extends TlMethod<HelpUserInfoBase> {
  /// Help Get User Info constructor.
  const HelpGetUserInfo({
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory HelpGetUserInfo.deserialize(BinaryReader reader) {
    // Read [HelpGetUserInfo] fields.
    final userId = reader.readObject() as InputUserBase;

    // Construct [HelpGetUserInfo] object.
    final returnValue = HelpGetUserInfo(
      userId: userId,
    );

    // Now return the deserialized [HelpGetUserInfo].
    return returnValue;
  }

  /// User Id.
  final InputUserBase userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x038a08d3.
    buffer.writeInt32(0x038a08d3);

    // Write fields.
    buffer.writeObject(userId);

    // Finished serialization.
  }
}

/// Help Edit User Info.
///
/// ID: `66b91b70`.
class HelpEditUserInfo extends TlMethod<HelpUserInfoBase> {
  /// Help Edit User Info constructor.
  const HelpEditUserInfo({
    required this.userId,
    required this.message,
    required this.entities,
  }) : super._();

  /// Deserialize.
  factory HelpEditUserInfo.deserialize(BinaryReader reader) {
    // Read [HelpEditUserInfo] fields.
    final userId = reader.readObject() as InputUserBase;
    final message = reader.readString();
    final entities = reader.readVectorObject<MessageEntityBase>();

    // Construct [HelpEditUserInfo] object.
    final returnValue = HelpEditUserInfo(
      userId: userId,
      message: message,
      entities: entities,
    );

    // Now return the deserialized [HelpEditUserInfo].
    return returnValue;
  }

  /// User Id.
  final InputUserBase userId;

  /// Message.
  final String message;

  /// Entities.
  final List<MessageEntityBase> entities;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x66b91b70.
    buffer.writeInt32(0x66b91b70);

    // Write fields.
    buffer.writeObject(userId);
    buffer.writeString(message);
    buffer.writeVectorObject(entities);

    // Finished serialization.
  }
}

/// Account Get Contact Sign Up Notification.
///
/// ID: `9f07c728`.
class AccountGetContactSignUpNotification extends TlMethod<bool> {
  /// Account Get Contact Sign Up Notification constructor.
  const AccountGetContactSignUpNotification() : super._();

  /// Deserialize.
  factory AccountGetContactSignUpNotification.deserialize(BinaryReader reader) {
    // Construct [AccountGetContactSignUpNotification] object.
    final returnValue = AccountGetContactSignUpNotification();

    // Now return the deserialized [AccountGetContactSignUpNotification].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9f07c728.
    buffer.writeInt32(0x9f07c728);

    // Finished serialization.
  }
}

/// Account Set Contact Sign Up Notification.
///
/// ID: `cff43f61`.
class AccountSetContactSignUpNotification extends TlMethod<bool> {
  /// Account Set Contact Sign Up Notification constructor.
  const AccountSetContactSignUpNotification({
    required this.silent,
  }) : super._();

  /// Deserialize.
  factory AccountSetContactSignUpNotification.deserialize(BinaryReader reader) {
    // Read [AccountSetContactSignUpNotification] fields.
    final silent = reader.readBool();

    // Construct [AccountSetContactSignUpNotification] object.
    final returnValue = AccountSetContactSignUpNotification(
      silent: silent,
    );

    // Now return the deserialized [AccountSetContactSignUpNotification].
    return returnValue;
  }

  /// Silent.
  final bool silent;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcff43f61.
    buffer.writeInt32(0xcff43f61);

    // Write fields.
    buffer.writeBool(silent);

    // Finished serialization.
  }
}

/// Account Get Notify Exceptions.
///
/// ID: `53577479`.
class AccountGetNotifyExceptions extends TlMethod<UpdatesBase> {
  /// Account Get Notify Exceptions constructor.
  const AccountGetNotifyExceptions({
    required this.compareSound,
    required this.compareStories,
    this.peer,
  }) : super._();

  /// Deserialize.
  factory AccountGetNotifyExceptions.deserialize(BinaryReader reader) {
    // Read [AccountGetNotifyExceptions] fields.
    final flags = reader.readInt32();
    final compareSound = (flags & 2) != 0;
    final compareStories = (flags & 4) != 0;
    final hasPeerField = (flags & 1) != 0;
    final peer =
        hasPeerField ? reader.readObject() as InputNotifyPeerBase : null;

    // Construct [AccountGetNotifyExceptions] object.
    final returnValue = AccountGetNotifyExceptions(
      compareSound: compareSound,
      compareStories: compareStories,
      peer: peer,
    );

    // Now return the deserialized [AccountGetNotifyExceptions].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: compareSound,
      b02: compareStories,
      b00: peer != null,
    );

    return v;
  }

  /// compare_sound: bit 1 of flags.1?true
  final bool compareSound;

  /// compare_stories: bit 2 of flags.2?true
  final bool compareStories;

  /// Peer.
  final InputNotifyPeerBase? peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x53577479.
    buffer.writeInt32(0x53577479);

    // Write fields.
    buffer.writeInt32(flags);
    final localPeerCopy = peer;
    if (localPeerCopy != null) {
      buffer.writeObject(localPeerCopy);
    }

    // Finished serialization.
  }
}

/// Messages Send Vote.
///
/// ID: `10ea6184`.
class MessagesSendVote extends TlMethod<UpdatesBase> {
  /// Messages Send Vote constructor.
  const MessagesSendVote({
    required this.peer,
    required this.msgId,
    required this.options,
  }) : super._();

  /// Deserialize.
  factory MessagesSendVote.deserialize(BinaryReader reader) {
    // Read [MessagesSendVote] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final options = reader.readVectorBytes();

    // Construct [MessagesSendVote] object.
    final returnValue = MessagesSendVote(
      peer: peer,
      msgId: msgId,
      options: options,
    );

    // Now return the deserialized [MessagesSendVote].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Options.
  final List<Uint8List> options;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x10ea6184.
    buffer.writeInt32(0x10ea6184);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeVectorBytes(options);

    // Finished serialization.
  }
}

/// Messages Get Poll Results.
///
/// ID: `73bb643b`.
class MessagesGetPollResults extends TlMethod<UpdatesBase> {
  /// Messages Get Poll Results constructor.
  const MessagesGetPollResults({
    required this.peer,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory MessagesGetPollResults.deserialize(BinaryReader reader) {
    // Read [MessagesGetPollResults] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();

    // Construct [MessagesGetPollResults] object.
    final returnValue = MessagesGetPollResults(
      peer: peer,
      msgId: msgId,
    );

    // Now return the deserialized [MessagesGetPollResults].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x73bb643b.
    buffer.writeInt32(0x73bb643b);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Messages Get Onlines.
///
/// ID: `6e2be050`.
class MessagesGetOnlines extends TlMethod<ChatOnlinesBase> {
  /// Messages Get Onlines constructor.
  const MessagesGetOnlines({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesGetOnlines.deserialize(BinaryReader reader) {
    // Read [MessagesGetOnlines] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [MessagesGetOnlines] object.
    final returnValue = MessagesGetOnlines(
      peer: peer,
    );

    // Now return the deserialized [MessagesGetOnlines].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6e2be050.
    buffer.writeInt32(0x6e2be050);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Messages Edit Chat About.
///
/// ID: `def60797`.
class MessagesEditChatAbout extends TlMethod<bool> {
  /// Messages Edit Chat About constructor.
  const MessagesEditChatAbout({
    required this.peer,
    required this.about,
  }) : super._();

  /// Deserialize.
  factory MessagesEditChatAbout.deserialize(BinaryReader reader) {
    // Read [MessagesEditChatAbout] fields.
    final peer = reader.readObject() as InputPeerBase;
    final about = reader.readString();

    // Construct [MessagesEditChatAbout] object.
    final returnValue = MessagesEditChatAbout(
      peer: peer,
      about: about,
    );

    // Now return the deserialized [MessagesEditChatAbout].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// About.
  final String about;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdef60797.
    buffer.writeInt32(0xdef60797);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeString(about);

    // Finished serialization.
  }
}

/// Messages Edit Chat Default Banned Rights.
///
/// ID: `a5866b41`.
class MessagesEditChatDefaultBannedRights extends TlMethod<UpdatesBase> {
  /// Messages Edit Chat Default Banned Rights constructor.
  const MessagesEditChatDefaultBannedRights({
    required this.peer,
    required this.bannedRights,
  }) : super._();

  /// Deserialize.
  factory MessagesEditChatDefaultBannedRights.deserialize(BinaryReader reader) {
    // Read [MessagesEditChatDefaultBannedRights] fields.
    final peer = reader.readObject() as InputPeerBase;
    final bannedRights = reader.readObject() as ChatBannedRightsBase;

    // Construct [MessagesEditChatDefaultBannedRights] object.
    final returnValue = MessagesEditChatDefaultBannedRights(
      peer: peer,
      bannedRights: bannedRights,
    );

    // Now return the deserialized [MessagesEditChatDefaultBannedRights].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Banned Rights.
  final ChatBannedRightsBase bannedRights;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa5866b41.
    buffer.writeInt32(0xa5866b41);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(bannedRights);

    // Finished serialization.
  }
}

/// Account Get Wall Paper.
///
/// ID: `fc8ddbea`.
class AccountGetWallPaper extends TlMethod<WallPaperBase> {
  /// Account Get Wall Paper constructor.
  const AccountGetWallPaper({
    required this.wallpaper,
  }) : super._();

  /// Deserialize.
  factory AccountGetWallPaper.deserialize(BinaryReader reader) {
    // Read [AccountGetWallPaper] fields.
    final wallpaper = reader.readObject() as InputWallPaperBase;

    // Construct [AccountGetWallPaper] object.
    final returnValue = AccountGetWallPaper(
      wallpaper: wallpaper,
    );

    // Now return the deserialized [AccountGetWallPaper].
    return returnValue;
  }

  /// Wallpaper.
  final InputWallPaperBase wallpaper;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfc8ddbea.
    buffer.writeInt32(0xfc8ddbea);

    // Write fields.
    buffer.writeObject(wallpaper);

    // Finished serialization.
  }
}

/// Account Upload Wall Paper.
///
/// ID: `e39a8f03`.
class AccountUploadWallPaper extends TlMethod<WallPaperBase> {
  /// Account Upload Wall Paper constructor.
  const AccountUploadWallPaper({
    required this.forChat,
    required this.file,
    required this.mimeType,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountUploadWallPaper.deserialize(BinaryReader reader) {
    // Read [AccountUploadWallPaper] fields.
    final flags = reader.readInt32();
    final forChat = (flags & 1) != 0;
    final file = reader.readObject() as InputFileBase;
    final mimeType = reader.readString();
    final settings = reader.readObject() as WallPaperSettingsBase;

    // Construct [AccountUploadWallPaper] object.
    final returnValue = AccountUploadWallPaper(
      forChat: forChat,
      file: file,
      mimeType: mimeType,
      settings: settings,
    );

    // Now return the deserialized [AccountUploadWallPaper].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: forChat,
    );

    return v;
  }

  /// for_chat: bit 0 of flags.0?true
  final bool forChat;

  /// File.
  final InputFileBase file;

  /// Mime Type.
  final String mimeType;

  /// Settings.
  final WallPaperSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe39a8f03.
    buffer.writeInt32(0xe39a8f03);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(file);
    buffer.writeString(mimeType);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Account Save Wall Paper.
///
/// ID: `6c5a5b37`.
class AccountSaveWallPaper extends TlMethod<bool> {
  /// Account Save Wall Paper constructor.
  const AccountSaveWallPaper({
    required this.wallpaper,
    required this.unsave,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountSaveWallPaper.deserialize(BinaryReader reader) {
    // Read [AccountSaveWallPaper] fields.
    final wallpaper = reader.readObject() as InputWallPaperBase;
    final unsave = reader.readBool();
    final settings = reader.readObject() as WallPaperSettingsBase;

    // Construct [AccountSaveWallPaper] object.
    final returnValue = AccountSaveWallPaper(
      wallpaper: wallpaper,
      unsave: unsave,
      settings: settings,
    );

    // Now return the deserialized [AccountSaveWallPaper].
    return returnValue;
  }

  /// Wallpaper.
  final InputWallPaperBase wallpaper;

  /// Unsave.
  final bool unsave;

  /// Settings.
  final WallPaperSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6c5a5b37.
    buffer.writeInt32(0x6c5a5b37);

    // Write fields.
    buffer.writeObject(wallpaper);
    buffer.writeBool(unsave);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Account Install Wall Paper.
///
/// ID: `feed5769`.
class AccountInstallWallPaper extends TlMethod<bool> {
  /// Account Install Wall Paper constructor.
  const AccountInstallWallPaper({
    required this.wallpaper,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountInstallWallPaper.deserialize(BinaryReader reader) {
    // Read [AccountInstallWallPaper] fields.
    final wallpaper = reader.readObject() as InputWallPaperBase;
    final settings = reader.readObject() as WallPaperSettingsBase;

    // Construct [AccountInstallWallPaper] object.
    final returnValue = AccountInstallWallPaper(
      wallpaper: wallpaper,
      settings: settings,
    );

    // Now return the deserialized [AccountInstallWallPaper].
    return returnValue;
  }

  /// Wallpaper.
  final InputWallPaperBase wallpaper;

  /// Settings.
  final WallPaperSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfeed5769.
    buffer.writeInt32(0xfeed5769);

    // Write fields.
    buffer.writeObject(wallpaper);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Account Reset Wall Papers.
///
/// ID: `bb3b9804`.
class AccountResetWallPapers extends TlMethod<bool> {
  /// Account Reset Wall Papers constructor.
  const AccountResetWallPapers() : super._();

  /// Deserialize.
  factory AccountResetWallPapers.deserialize(BinaryReader reader) {
    // Construct [AccountResetWallPapers] object.
    final returnValue = AccountResetWallPapers();

    // Now return the deserialized [AccountResetWallPapers].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbb3b9804.
    buffer.writeInt32(0xbb3b9804);

    // Finished serialization.
  }
}

/// Account Get Auto Download Settings.
///
/// ID: `56da0b3f`.
class AccountGetAutoDownloadSettings
    extends TlMethod<AccountAutoDownloadSettingsBase> {
  /// Account Get Auto Download Settings constructor.
  const AccountGetAutoDownloadSettings() : super._();

  /// Deserialize.
  factory AccountGetAutoDownloadSettings.deserialize(BinaryReader reader) {
    // Construct [AccountGetAutoDownloadSettings] object.
    final returnValue = AccountGetAutoDownloadSettings();

    // Now return the deserialized [AccountGetAutoDownloadSettings].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x56da0b3f.
    buffer.writeInt32(0x56da0b3f);

    // Finished serialization.
  }
}

/// Account Save Auto Download Settings.
///
/// ID: `76f36233`.
class AccountSaveAutoDownloadSettings extends TlMethod<bool> {
  /// Account Save Auto Download Settings constructor.
  const AccountSaveAutoDownloadSettings({
    required this.low,
    required this.high,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountSaveAutoDownloadSettings.deserialize(BinaryReader reader) {
    // Read [AccountSaveAutoDownloadSettings] fields.
    final flags = reader.readInt32();
    final low = (flags & 1) != 0;
    final high = (flags & 2) != 0;
    final settings = reader.readObject() as AutoDownloadSettingsBase;

    // Construct [AccountSaveAutoDownloadSettings] object.
    final returnValue = AccountSaveAutoDownloadSettings(
      low: low,
      high: high,
      settings: settings,
    );

    // Now return the deserialized [AccountSaveAutoDownloadSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: low,
      b01: high,
    );

    return v;
  }

  /// low: bit 0 of flags.0?true
  final bool low;

  /// high: bit 1 of flags.1?true
  final bool high;

  /// Settings.
  final AutoDownloadSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x76f36233.
    buffer.writeInt32(0x76f36233);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Messages Get Emoji Keywords.
///
/// ID: `35a0e062`.
class MessagesGetEmojiKeywords extends TlMethod<EmojiKeywordsDifferenceBase> {
  /// Messages Get Emoji Keywords constructor.
  const MessagesGetEmojiKeywords({
    required this.langCode,
  }) : super._();

  /// Deserialize.
  factory MessagesGetEmojiKeywords.deserialize(BinaryReader reader) {
    // Read [MessagesGetEmojiKeywords] fields.
    final langCode = reader.readString();

    // Construct [MessagesGetEmojiKeywords] object.
    final returnValue = MessagesGetEmojiKeywords(
      langCode: langCode,
    );

    // Now return the deserialized [MessagesGetEmojiKeywords].
    return returnValue;
  }

  /// Lang Code.
  final String langCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x35a0e062.
    buffer.writeInt32(0x35a0e062);

    // Write fields.
    buffer.writeString(langCode);

    // Finished serialization.
  }
}

/// Messages Get Emoji Keywords Difference.
///
/// ID: `1508b6af`.
class MessagesGetEmojiKeywordsDifference
    extends TlMethod<EmojiKeywordsDifferenceBase> {
  /// Messages Get Emoji Keywords Difference constructor.
  const MessagesGetEmojiKeywordsDifference({
    required this.langCode,
    required this.fromVersion,
  }) : super._();

  /// Deserialize.
  factory MessagesGetEmojiKeywordsDifference.deserialize(BinaryReader reader) {
    // Read [MessagesGetEmojiKeywordsDifference] fields.
    final langCode = reader.readString();
    final fromVersion = reader.readInt32();

    // Construct [MessagesGetEmojiKeywordsDifference] object.
    final returnValue = MessagesGetEmojiKeywordsDifference(
      langCode: langCode,
      fromVersion: fromVersion,
    );

    // Now return the deserialized [MessagesGetEmojiKeywordsDifference].
    return returnValue;
  }

  /// Lang Code.
  final String langCode;

  /// From Version.
  ///
  /// Field type is Int32.
  final int fromVersion;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1508b6af.
    buffer.writeInt32(0x1508b6af);

    // Write fields.
    buffer.writeString(langCode);
    buffer.writeInt32(fromVersion);

    // Finished serialization.
  }
}

/// Messages Get Emoji Keywords Languages.
///
/// ID: `4e9963b2`.
class MessagesGetEmojiKeywordsLanguages
    extends TlMethod<List<EmojiLanguageBase>> {
  /// Messages Get Emoji Keywords Languages constructor.
  const MessagesGetEmojiKeywordsLanguages({
    required this.langCodes,
  }) : super._();

  /// Deserialize.
  factory MessagesGetEmojiKeywordsLanguages.deserialize(BinaryReader reader) {
    // Read [MessagesGetEmojiKeywordsLanguages] fields.
    final langCodes = reader.readVectorString();

    // Construct [MessagesGetEmojiKeywordsLanguages] object.
    final returnValue = MessagesGetEmojiKeywordsLanguages(
      langCodes: langCodes,
    );

    // Now return the deserialized [MessagesGetEmojiKeywordsLanguages].
    return returnValue;
  }

  /// Lang Codes.
  final List<String> langCodes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4e9963b2.
    buffer.writeInt32(0x4e9963b2);

    // Write fields.
    buffer.writeVectorString(langCodes);

    // Finished serialization.
  }
}

/// Messages Get Emoji U R L.
///
/// ID: `d5b10c26`.
class MessagesGetEmojiURL extends TlMethod<EmojiURLBase> {
  /// Messages Get Emoji U R L constructor.
  const MessagesGetEmojiURL({
    required this.langCode,
  }) : super._();

  /// Deserialize.
  factory MessagesGetEmojiURL.deserialize(BinaryReader reader) {
    // Read [MessagesGetEmojiURL] fields.
    final langCode = reader.readString();

    // Construct [MessagesGetEmojiURL] object.
    final returnValue = MessagesGetEmojiURL(
      langCode: langCode,
    );

    // Now return the deserialized [MessagesGetEmojiURL].
    return returnValue;
  }

  /// Lang Code.
  final String langCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd5b10c26.
    buffer.writeInt32(0xd5b10c26);

    // Write fields.
    buffer.writeString(langCode);

    // Finished serialization.
  }
}

/// Folders Edit Peer Folders.
///
/// ID: `6847d0ab`.
class FoldersEditPeerFolders extends TlMethod<UpdatesBase> {
  /// Folders Edit Peer Folders constructor.
  const FoldersEditPeerFolders({
    required this.folderPeers,
  }) : super._();

  /// Deserialize.
  factory FoldersEditPeerFolders.deserialize(BinaryReader reader) {
    // Read [FoldersEditPeerFolders] fields.
    final folderPeers = reader.readVectorObject<InputFolderPeerBase>();

    // Construct [FoldersEditPeerFolders] object.
    final returnValue = FoldersEditPeerFolders(
      folderPeers: folderPeers,
    );

    // Now return the deserialized [FoldersEditPeerFolders].
    return returnValue;
  }

  /// Folder Peers.
  final List<InputFolderPeerBase> folderPeers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6847d0ab.
    buffer.writeInt32(0x6847d0ab);

    // Write fields.
    buffer.writeVectorObject(folderPeers);

    // Finished serialization.
  }
}

/// Messages Get Search Counters.
///
/// ID: `1bbcf300`.
class MessagesGetSearchCounters
    extends TlMethod<List<MessagesSearchCounterBase>> {
  /// Messages Get Search Counters constructor.
  const MessagesGetSearchCounters({
    required this.peer,
    this.savedPeerId,
    this.topMsgId,
    required this.filters,
  }) : super._();

  /// Deserialize.
  factory MessagesGetSearchCounters.deserialize(BinaryReader reader) {
    // Read [MessagesGetSearchCounters] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final hasSavedPeerIdField = (flags & 4) != 0;
    final savedPeerId =
        hasSavedPeerIdField ? reader.readObject() as InputPeerBase : null;
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final filters = reader.readVectorObject<MessagesFilterBase>();

    // Construct [MessagesGetSearchCounters] object.
    final returnValue = MessagesGetSearchCounters(
      peer: peer,
      savedPeerId: savedPeerId,
      topMsgId: topMsgId,
      filters: filters,
    );

    // Now return the deserialized [MessagesGetSearchCounters].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: savedPeerId != null,
      b00: topMsgId != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Saved Peer Id.
  final InputPeerBase? savedPeerId;

  /// Top Msg Id.
  final int? topMsgId;

  /// Filters.
  final List<MessagesFilterBase> filters;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1bbcf300.
    buffer.writeInt32(0x1bbcf300);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localSavedPeerIdCopy = savedPeerId;
    if (localSavedPeerIdCopy != null) {
      buffer.writeObject(localSavedPeerIdCopy);
    }
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    buffer.writeVectorObject(filters);

    // Finished serialization.
  }
}

/// Channels Get Groups For Discussion.
///
/// ID: `f5dad378`.
class ChannelsGetGroupsForDiscussion extends TlMethod<MessagesChatsBase> {
  /// Channels Get Groups For Discussion constructor.
  const ChannelsGetGroupsForDiscussion() : super._();

  /// Deserialize.
  factory ChannelsGetGroupsForDiscussion.deserialize(BinaryReader reader) {
    // Construct [ChannelsGetGroupsForDiscussion] object.
    final returnValue = ChannelsGetGroupsForDiscussion();

    // Now return the deserialized [ChannelsGetGroupsForDiscussion].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf5dad378.
    buffer.writeInt32(0xf5dad378);

    // Finished serialization.
  }
}

/// Channels Set Discussion Group.
///
/// ID: `40582bb2`.
class ChannelsSetDiscussionGroup extends TlMethod<bool> {
  /// Channels Set Discussion Group constructor.
  const ChannelsSetDiscussionGroup({
    required this.broadcast,
    required this.group,
  }) : super._();

  /// Deserialize.
  factory ChannelsSetDiscussionGroup.deserialize(BinaryReader reader) {
    // Read [ChannelsSetDiscussionGroup] fields.
    final broadcast = reader.readObject() as InputChannelBase;
    final group = reader.readObject() as InputChannelBase;

    // Construct [ChannelsSetDiscussionGroup] object.
    final returnValue = ChannelsSetDiscussionGroup(
      broadcast: broadcast,
      group: group,
    );

    // Now return the deserialized [ChannelsSetDiscussionGroup].
    return returnValue;
  }

  /// Broadcast.
  final InputChannelBase broadcast;

  /// Group.
  final InputChannelBase group;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x40582bb2.
    buffer.writeInt32(0x40582bb2);

    // Write fields.
    buffer.writeObject(broadcast);
    buffer.writeObject(group);

    // Finished serialization.
  }
}

/// Messages Request Url Auth.
///
/// ID: `198fb446`.
class MessagesRequestUrlAuth extends TlMethod<UrlAuthResultBase> {
  /// Messages Request Url Auth constructor.
  const MessagesRequestUrlAuth({
    this.peer,
    this.msgId,
    this.buttonId,
    this.url,
  }) : super._();

  /// Deserialize.
  factory MessagesRequestUrlAuth.deserialize(BinaryReader reader) {
    // Read [MessagesRequestUrlAuth] fields.
    final flags = reader.readInt32();
    final hasPeerField = (flags & 2) != 0;
    final peer = hasPeerField ? reader.readObject() as InputPeerBase : null;
    final hasMsgIdField = (flags & 2) != 0;
    final msgId = hasMsgIdField ? reader.readInt32() : null;
    final hasButtonIdField = (flags & 2) != 0;
    final buttonId = hasButtonIdField ? reader.readInt32() : null;
    final hasUrlField = (flags & 4) != 0;
    final url = hasUrlField ? reader.readString() : null;

    // Construct [MessagesRequestUrlAuth] object.
    final returnValue = MessagesRequestUrlAuth(
      peer: peer,
      msgId: msgId,
      buttonId: buttonId,
      url: url,
    );

    // Now return the deserialized [MessagesRequestUrlAuth].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: peer != null || msgId != null || buttonId != null,
      b02: url != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase? peer;

  /// Msg Id.
  final int? msgId;

  /// Button Id.
  final int? buttonId;

  /// Url.
  final String? url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x198fb446.
    buffer.writeInt32(0x198fb446);

    // Write fields.
    buffer.writeInt32(flags);
    final localPeerCopy = peer;
    if (localPeerCopy != null) {
      buffer.writeObject(localPeerCopy);
    }
    final localMsgIdCopy = msgId;
    if (localMsgIdCopy != null) {
      buffer.writeInt32(localMsgIdCopy);
    }
    final localButtonIdCopy = buttonId;
    if (localButtonIdCopy != null) {
      buffer.writeInt32(localButtonIdCopy);
    }
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }

    // Finished serialization.
  }
}

/// Messages Accept Url Auth.
///
/// ID: `b12c7125`.
class MessagesAcceptUrlAuth extends TlMethod<UrlAuthResultBase> {
  /// Messages Accept Url Auth constructor.
  const MessagesAcceptUrlAuth({
    required this.writeAllowed,
    this.peer,
    this.msgId,
    this.buttonId,
    this.url,
  }) : super._();

  /// Deserialize.
  factory MessagesAcceptUrlAuth.deserialize(BinaryReader reader) {
    // Read [MessagesAcceptUrlAuth] fields.
    final flags = reader.readInt32();
    final writeAllowed = (flags & 1) != 0;
    final hasPeerField = (flags & 2) != 0;
    final peer = hasPeerField ? reader.readObject() as InputPeerBase : null;
    final hasMsgIdField = (flags & 2) != 0;
    final msgId = hasMsgIdField ? reader.readInt32() : null;
    final hasButtonIdField = (flags & 2) != 0;
    final buttonId = hasButtonIdField ? reader.readInt32() : null;
    final hasUrlField = (flags & 4) != 0;
    final url = hasUrlField ? reader.readString() : null;

    // Construct [MessagesAcceptUrlAuth] object.
    final returnValue = MessagesAcceptUrlAuth(
      writeAllowed: writeAllowed,
      peer: peer,
      msgId: msgId,
      buttonId: buttonId,
      url: url,
    );

    // Now return the deserialized [MessagesAcceptUrlAuth].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: writeAllowed,
      b01: peer != null || msgId != null || buttonId != null,
      b02: url != null,
    );

    return v;
  }

  /// write_allowed: bit 0 of flags.0?true
  final bool writeAllowed;

  /// Peer.
  final InputPeerBase? peer;

  /// Msg Id.
  final int? msgId;

  /// Button Id.
  final int? buttonId;

  /// Url.
  final String? url;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb12c7125.
    buffer.writeInt32(0xb12c7125);

    // Write fields.
    buffer.writeInt32(flags);
    final localPeerCopy = peer;
    if (localPeerCopy != null) {
      buffer.writeObject(localPeerCopy);
    }
    final localMsgIdCopy = msgId;
    if (localMsgIdCopy != null) {
      buffer.writeInt32(localMsgIdCopy);
    }
    final localButtonIdCopy = buttonId;
    if (localButtonIdCopy != null) {
      buffer.writeInt32(localButtonIdCopy);
    }
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }

    // Finished serialization.
  }
}

/// Messages Hide Peer Settings Bar.
///
/// ID: `4facb138`.
class MessagesHidePeerSettingsBar extends TlMethod<bool> {
  /// Messages Hide Peer Settings Bar constructor.
  const MessagesHidePeerSettingsBar({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesHidePeerSettingsBar.deserialize(BinaryReader reader) {
    // Read [MessagesHidePeerSettingsBar] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [MessagesHidePeerSettingsBar] object.
    final returnValue = MessagesHidePeerSettingsBar(
      peer: peer,
    );

    // Now return the deserialized [MessagesHidePeerSettingsBar].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4facb138.
    buffer.writeInt32(0x4facb138);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Contacts Add Contact.
///
/// ID: `e8f463d0`.
class ContactsAddContact extends TlMethod<UpdatesBase> {
  /// Contacts Add Contact constructor.
  const ContactsAddContact({
    required this.addPhonePrivacyException,
    required this.id,
    required this.firstName,
    required this.lastName,
    required this.phone,
  }) : super._();

  /// Deserialize.
  factory ContactsAddContact.deserialize(BinaryReader reader) {
    // Read [ContactsAddContact] fields.
    final flags = reader.readInt32();
    final addPhonePrivacyException = (flags & 1) != 0;
    final id = reader.readObject() as InputUserBase;
    final firstName = reader.readString();
    final lastName = reader.readString();
    final phone = reader.readString();

    // Construct [ContactsAddContact] object.
    final returnValue = ContactsAddContact(
      addPhonePrivacyException: addPhonePrivacyException,
      id: id,
      firstName: firstName,
      lastName: lastName,
      phone: phone,
    );

    // Now return the deserialized [ContactsAddContact].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: addPhonePrivacyException,
    );

    return v;
  }

  /// add_phone_privacy_exception: bit 0 of flags.0?true
  final bool addPhonePrivacyException;

  /// Id.
  final InputUserBase id;

  /// First Name.
  final String firstName;

  /// Last Name.
  final String lastName;

  /// Phone.
  final String phone;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe8f463d0.
    buffer.writeInt32(0xe8f463d0);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(id);
    buffer.writeString(firstName);
    buffer.writeString(lastName);
    buffer.writeString(phone);

    // Finished serialization.
  }
}

/// Contacts Accept Contact.
///
/// ID: `f831a20f`.
class ContactsAcceptContact extends TlMethod<UpdatesBase> {
  /// Contacts Accept Contact constructor.
  const ContactsAcceptContact({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ContactsAcceptContact.deserialize(BinaryReader reader) {
    // Read [ContactsAcceptContact] fields.
    final id = reader.readObject() as InputUserBase;

    // Construct [ContactsAcceptContact] object.
    final returnValue = ContactsAcceptContact(
      id: id,
    );

    // Now return the deserialized [ContactsAcceptContact].
    return returnValue;
  }

  /// Id.
  final InputUserBase id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf831a20f.
    buffer.writeInt32(0xf831a20f);

    // Write fields.
    buffer.writeObject(id);

    // Finished serialization.
  }
}

/// Channels Edit Creator.
///
/// ID: `8f38cd1f`.
class ChannelsEditCreator extends TlMethod<UpdatesBase> {
  /// Channels Edit Creator constructor.
  const ChannelsEditCreator({
    required this.channel,
    required this.userId,
    required this.password,
  }) : super._();

  /// Deserialize.
  factory ChannelsEditCreator.deserialize(BinaryReader reader) {
    // Read [ChannelsEditCreator] fields.
    final channel = reader.readObject() as InputChannelBase;
    final userId = reader.readObject() as InputUserBase;
    final password = reader.readObject() as InputCheckPasswordSRPBase;

    // Construct [ChannelsEditCreator] object.
    final returnValue = ChannelsEditCreator(
      channel: channel,
      userId: userId,
      password: password,
    );

    // Now return the deserialized [ChannelsEditCreator].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// User Id.
  final InputUserBase userId;

  /// Password.
  final InputCheckPasswordSRPBase password;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8f38cd1f.
    buffer.writeInt32(0x8f38cd1f);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(userId);
    buffer.writeObject(password);

    // Finished serialization.
  }
}

/// Contacts Get Located.
///
/// ID: `d348bc44`.
class ContactsGetLocated extends TlMethod<UpdatesBase> {
  /// Contacts Get Located constructor.
  const ContactsGetLocated({
    required this.background,
    required this.geoPoint,
    this.selfExpires,
  }) : super._();

  /// Deserialize.
  factory ContactsGetLocated.deserialize(BinaryReader reader) {
    // Read [ContactsGetLocated] fields.
    final flags = reader.readInt32();
    final background = (flags & 2) != 0;
    final geoPoint = reader.readObject() as InputGeoPointBase;
    final hasSelfExpiresField = (flags & 1) != 0;
    final selfExpires = hasSelfExpiresField ? reader.readInt32() : null;

    // Construct [ContactsGetLocated] object.
    final returnValue = ContactsGetLocated(
      background: background,
      geoPoint: geoPoint,
      selfExpires: selfExpires,
    );

    // Now return the deserialized [ContactsGetLocated].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: background,
      b00: selfExpires != null,
    );

    return v;
  }

  /// background: bit 1 of flags.1?true
  final bool background;

  /// Geo Point.
  final InputGeoPointBase geoPoint;

  /// Self Expires.
  final int? selfExpires;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd348bc44.
    buffer.writeInt32(0xd348bc44);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(geoPoint);
    final localSelfExpiresCopy = selfExpires;
    if (localSelfExpiresCopy != null) {
      buffer.writeInt32(localSelfExpiresCopy);
    }

    // Finished serialization.
  }
}

/// Channels Edit Location.
///
/// ID: `58e63f6d`.
class ChannelsEditLocation extends TlMethod<bool> {
  /// Channels Edit Location constructor.
  const ChannelsEditLocation({
    required this.channel,
    required this.geoPoint,
    required this.address,
  }) : super._();

  /// Deserialize.
  factory ChannelsEditLocation.deserialize(BinaryReader reader) {
    // Read [ChannelsEditLocation] fields.
    final channel = reader.readObject() as InputChannelBase;
    final geoPoint = reader.readObject() as InputGeoPointBase;
    final address = reader.readString();

    // Construct [ChannelsEditLocation] object.
    final returnValue = ChannelsEditLocation(
      channel: channel,
      geoPoint: geoPoint,
      address: address,
    );

    // Now return the deserialized [ChannelsEditLocation].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Geo Point.
  final InputGeoPointBase geoPoint;

  /// Address.
  final String address;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x58e63f6d.
    buffer.writeInt32(0x58e63f6d);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(geoPoint);
    buffer.writeString(address);

    // Finished serialization.
  }
}

/// Channels Toggle Slow Mode.
///
/// ID: `edd49ef0`.
class ChannelsToggleSlowMode extends TlMethod<UpdatesBase> {
  /// Channels Toggle Slow Mode constructor.
  const ChannelsToggleSlowMode({
    required this.channel,
    required this.seconds,
  }) : super._();

  /// Deserialize.
  factory ChannelsToggleSlowMode.deserialize(BinaryReader reader) {
    // Read [ChannelsToggleSlowMode] fields.
    final channel = reader.readObject() as InputChannelBase;
    final seconds = reader.readInt32();

    // Construct [ChannelsToggleSlowMode] object.
    final returnValue = ChannelsToggleSlowMode(
      channel: channel,
      seconds: seconds,
    );

    // Now return the deserialized [ChannelsToggleSlowMode].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Seconds.
  ///
  /// Field type is Int32.
  final int seconds;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xedd49ef0.
    buffer.writeInt32(0xedd49ef0);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeInt32(seconds);

    // Finished serialization.
  }
}

/// Messages Get Scheduled History.
///
/// ID: `f516760b`.
class MessagesGetScheduledHistory extends TlMethod<MessagesMessagesBase> {
  /// Messages Get Scheduled History constructor.
  const MessagesGetScheduledHistory({
    required this.peer,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetScheduledHistory.deserialize(BinaryReader reader) {
    // Read [MessagesGetScheduledHistory] fields.
    final peer = reader.readObject() as InputPeerBase;
    final hash = reader.readInt64();

    // Construct [MessagesGetScheduledHistory] object.
    final returnValue = MessagesGetScheduledHistory(
      peer: peer,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetScheduledHistory].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf516760b.
    buffer.writeInt32(0xf516760b);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Get Scheduled Messages.
///
/// ID: `bdbb0464`.
class MessagesGetScheduledMessages extends TlMethod<MessagesMessagesBase> {
  /// Messages Get Scheduled Messages constructor.
  const MessagesGetScheduledMessages({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesGetScheduledMessages.deserialize(BinaryReader reader) {
    // Read [MessagesGetScheduledMessages] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();

    // Construct [MessagesGetScheduledMessages] object.
    final returnValue = MessagesGetScheduledMessages(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [MessagesGetScheduledMessages].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbdbb0464.
    buffer.writeInt32(0xbdbb0464);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Messages Send Scheduled Messages.
///
/// ID: `bd38850a`.
class MessagesSendScheduledMessages extends TlMethod<UpdatesBase> {
  /// Messages Send Scheduled Messages constructor.
  const MessagesSendScheduledMessages({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesSendScheduledMessages.deserialize(BinaryReader reader) {
    // Read [MessagesSendScheduledMessages] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();

    // Construct [MessagesSendScheduledMessages] object.
    final returnValue = MessagesSendScheduledMessages(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [MessagesSendScheduledMessages].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbd38850a.
    buffer.writeInt32(0xbd38850a);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Messages Delete Scheduled Messages.
///
/// ID: `59ae2b16`.
class MessagesDeleteScheduledMessages extends TlMethod<UpdatesBase> {
  /// Messages Delete Scheduled Messages constructor.
  const MessagesDeleteScheduledMessages({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesDeleteScheduledMessages.deserialize(BinaryReader reader) {
    // Read [MessagesDeleteScheduledMessages] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();

    // Construct [MessagesDeleteScheduledMessages] object.
    final returnValue = MessagesDeleteScheduledMessages(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [MessagesDeleteScheduledMessages].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x59ae2b16.
    buffer.writeInt32(0x59ae2b16);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Account Upload Theme.
///
/// ID: `1c3db333`.
class AccountUploadTheme extends TlMethod<DocumentBase> {
  /// Account Upload Theme constructor.
  const AccountUploadTheme({
    required this.file,
    this.thumb,
    required this.fileName,
    required this.mimeType,
  }) : super._();

  /// Deserialize.
  factory AccountUploadTheme.deserialize(BinaryReader reader) {
    // Read [AccountUploadTheme] fields.
    final flags = reader.readInt32();
    final file = reader.readObject() as InputFileBase;
    final hasThumbField = (flags & 1) != 0;
    final thumb = hasThumbField ? reader.readObject() as InputFileBase : null;
    final fileName = reader.readString();
    final mimeType = reader.readString();

    // Construct [AccountUploadTheme] object.
    final returnValue = AccountUploadTheme(
      file: file,
      thumb: thumb,
      fileName: fileName,
      mimeType: mimeType,
    );

    // Now return the deserialized [AccountUploadTheme].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: thumb != null,
    );

    return v;
  }

  /// File.
  final InputFileBase file;

  /// Thumb.
  final InputFileBase? thumb;

  /// File Name.
  final String fileName;

  /// Mime Type.
  final String mimeType;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1c3db333.
    buffer.writeInt32(0x1c3db333);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(file);
    final localThumbCopy = thumb;
    if (localThumbCopy != null) {
      buffer.writeObject(localThumbCopy);
    }
    buffer.writeString(fileName);
    buffer.writeString(mimeType);

    // Finished serialization.
  }
}

/// Account Create Theme.
///
/// ID: `652e4400`.
class AccountCreateTheme extends TlMethod<ThemeBase> {
  /// Account Create Theme constructor.
  const AccountCreateTheme({
    required this.slug,
    required this.title,
    this.document,
    this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountCreateTheme.deserialize(BinaryReader reader) {
    // Read [AccountCreateTheme] fields.
    final flags = reader.readInt32();
    final slug = reader.readString();
    final title = reader.readString();
    final hasDocumentField = (flags & 4) != 0;
    final document =
        hasDocumentField ? reader.readObject() as InputDocumentBase : null;
    final hasSettingsField = (flags & 8) != 0;
    final settings = hasSettingsField
        ? reader.readVectorObject<InputThemeSettingsBase>()
        : null;

    // Construct [AccountCreateTheme] object.
    final returnValue = AccountCreateTheme(
      slug: slug,
      title: title,
      document: document,
      settings: settings,
    );

    // Now return the deserialized [AccountCreateTheme].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: document != null,
      b03: settings != null,
    );

    return v;
  }

  /// Slug.
  final String slug;

  /// Title.
  final String title;

  /// Document.
  final InputDocumentBase? document;

  /// Settings.
  final List<InputThemeSettingsBase>? settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x652e4400.
    buffer.writeInt32(0x652e4400);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(slug);
    buffer.writeString(title);
    final localDocumentCopy = document;
    if (localDocumentCopy != null) {
      buffer.writeObject(localDocumentCopy);
    }
    final localSettingsCopy = settings;
    if (localSettingsCopy != null) {
      buffer.writeVectorObject(localSettingsCopy);
    }

    // Finished serialization.
  }
}

/// Account Update Theme.
///
/// ID: `2bf40ccc`.
class AccountUpdateTheme extends TlMethod<ThemeBase> {
  /// Account Update Theme constructor.
  const AccountUpdateTheme({
    required this.format,
    required this.theme,
    this.slug,
    this.title,
    this.document,
    this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountUpdateTheme.deserialize(BinaryReader reader) {
    // Read [AccountUpdateTheme] fields.
    final flags = reader.readInt32();
    final format = reader.readString();
    final theme = reader.readObject() as InputThemeBase;
    final hasSlugField = (flags & 1) != 0;
    final slug = hasSlugField ? reader.readString() : null;
    final hasTitleField = (flags & 2) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasDocumentField = (flags & 4) != 0;
    final document =
        hasDocumentField ? reader.readObject() as InputDocumentBase : null;
    final hasSettingsField = (flags & 8) != 0;
    final settings = hasSettingsField
        ? reader.readVectorObject<InputThemeSettingsBase>()
        : null;

    // Construct [AccountUpdateTheme] object.
    final returnValue = AccountUpdateTheme(
      format: format,
      theme: theme,
      slug: slug,
      title: title,
      document: document,
      settings: settings,
    );

    // Now return the deserialized [AccountUpdateTheme].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: slug != null,
      b01: title != null,
      b02: document != null,
      b03: settings != null,
    );

    return v;
  }

  /// Format.
  final String format;

  /// Theme.
  final InputThemeBase theme;

  /// Slug.
  final String? slug;

  /// Title.
  final String? title;

  /// Document.
  final InputDocumentBase? document;

  /// Settings.
  final List<InputThemeSettingsBase>? settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2bf40ccc.
    buffer.writeInt32(0x2bf40ccc);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(format);
    buffer.writeObject(theme);
    final localSlugCopy = slug;
    if (localSlugCopy != null) {
      buffer.writeString(localSlugCopy);
    }
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localDocumentCopy = document;
    if (localDocumentCopy != null) {
      buffer.writeObject(localDocumentCopy);
    }
    final localSettingsCopy = settings;
    if (localSettingsCopy != null) {
      buffer.writeVectorObject(localSettingsCopy);
    }

    // Finished serialization.
  }
}

/// Account Save Theme.
///
/// ID: `f257106c`.
class AccountSaveTheme extends TlMethod<bool> {
  /// Account Save Theme constructor.
  const AccountSaveTheme({
    required this.theme,
    required this.unsave,
  }) : super._();

  /// Deserialize.
  factory AccountSaveTheme.deserialize(BinaryReader reader) {
    // Read [AccountSaveTheme] fields.
    final theme = reader.readObject() as InputThemeBase;
    final unsave = reader.readBool();

    // Construct [AccountSaveTheme] object.
    final returnValue = AccountSaveTheme(
      theme: theme,
      unsave: unsave,
    );

    // Now return the deserialized [AccountSaveTheme].
    return returnValue;
  }

  /// Theme.
  final InputThemeBase theme;

  /// Unsave.
  final bool unsave;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf257106c.
    buffer.writeInt32(0xf257106c);

    // Write fields.
    buffer.writeObject(theme);
    buffer.writeBool(unsave);

    // Finished serialization.
  }
}

/// Account Install Theme.
///
/// ID: `c727bb3b`.
class AccountInstallTheme extends TlMethod<bool> {
  /// Account Install Theme constructor.
  const AccountInstallTheme({
    required this.dark,
    this.theme,
    this.format,
    this.baseTheme,
  }) : super._();

  /// Deserialize.
  factory AccountInstallTheme.deserialize(BinaryReader reader) {
    // Read [AccountInstallTheme] fields.
    final flags = reader.readInt32();
    final dark = (flags & 1) != 0;
    final hasThemeField = (flags & 2) != 0;
    final theme = hasThemeField ? reader.readObject() as InputThemeBase : null;
    final hasFormatField = (flags & 4) != 0;
    final format = hasFormatField ? reader.readString() : null;
    final hasBaseThemeField = (flags & 8) != 0;
    final baseTheme =
        hasBaseThemeField ? reader.readObject() as BaseThemeBase : null;

    // Construct [AccountInstallTheme] object.
    final returnValue = AccountInstallTheme(
      dark: dark,
      theme: theme,
      format: format,
      baseTheme: baseTheme,
    );

    // Now return the deserialized [AccountInstallTheme].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: dark,
      b01: theme != null,
      b02: format != null,
      b03: baseTheme != null,
    );

    return v;
  }

  /// dark: bit 0 of flags.0?true
  final bool dark;

  /// Theme.
  final InputThemeBase? theme;

  /// Format.
  final String? format;

  /// Base Theme.
  final BaseThemeBase? baseTheme;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc727bb3b.
    buffer.writeInt32(0xc727bb3b);

    // Write fields.
    buffer.writeInt32(flags);
    final localThemeCopy = theme;
    if (localThemeCopy != null) {
      buffer.writeObject(localThemeCopy);
    }
    final localFormatCopy = format;
    if (localFormatCopy != null) {
      buffer.writeString(localFormatCopy);
    }
    final localBaseThemeCopy = baseTheme;
    if (localBaseThemeCopy != null) {
      buffer.writeObject(localBaseThemeCopy);
    }

    // Finished serialization.
  }
}

/// Account Get Theme.
///
/// ID: `3a5869ec`.
class AccountGetTheme extends TlMethod<ThemeBase> {
  /// Account Get Theme constructor.
  const AccountGetTheme({
    required this.format,
    required this.theme,
  }) : super._();

  /// Deserialize.
  factory AccountGetTheme.deserialize(BinaryReader reader) {
    // Read [AccountGetTheme] fields.
    final format = reader.readString();
    final theme = reader.readObject() as InputThemeBase;

    // Construct [AccountGetTheme] object.
    final returnValue = AccountGetTheme(
      format: format,
      theme: theme,
    );

    // Now return the deserialized [AccountGetTheme].
    return returnValue;
  }

  /// Format.
  final String format;

  /// Theme.
  final InputThemeBase theme;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3a5869ec.
    buffer.writeInt32(0x3a5869ec);

    // Write fields.
    buffer.writeString(format);
    buffer.writeObject(theme);

    // Finished serialization.
  }
}

/// Account Get Themes.
///
/// ID: `7206e458`.
class AccountGetThemes extends TlMethod<AccountThemesBase> {
  /// Account Get Themes constructor.
  const AccountGetThemes({
    required this.format,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetThemes.deserialize(BinaryReader reader) {
    // Read [AccountGetThemes] fields.
    final format = reader.readString();
    final hash = reader.readInt64();

    // Construct [AccountGetThemes] object.
    final returnValue = AccountGetThemes(
      format: format,
      hash: hash,
    );

    // Now return the deserialized [AccountGetThemes].
    return returnValue;
  }

  /// Format.
  final String format;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7206e458.
    buffer.writeInt32(0x7206e458);

    // Write fields.
    buffer.writeString(format);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Auth Export Login Token.
///
/// ID: `b7e085fe`.
class AuthExportLoginToken extends TlMethod<AuthLoginTokenBase> {
  /// Auth Export Login Token constructor.
  const AuthExportLoginToken({
    required this.apiId,
    required this.apiHash,
    required this.exceptIds,
  }) : super._();

  /// Deserialize.
  factory AuthExportLoginToken.deserialize(BinaryReader reader) {
    // Read [AuthExportLoginToken] fields.
    final apiId = reader.readInt32();
    final apiHash = reader.readString();
    final exceptIds = reader.readVectorInt64();

    // Construct [AuthExportLoginToken] object.
    final returnValue = AuthExportLoginToken(
      apiId: apiId,
      apiHash: apiHash,
      exceptIds: exceptIds,
    );

    // Now return the deserialized [AuthExportLoginToken].
    return returnValue;
  }

  /// Api Id.
  ///
  /// Field type is Int32.
  final int apiId;

  /// Api Hash.
  final String apiHash;

  /// Except Ids.
  final List<int> exceptIds;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb7e085fe.
    buffer.writeInt32(0xb7e085fe);

    // Write fields.
    buffer.writeInt32(apiId);
    buffer.writeString(apiHash);
    buffer.writeVectorInt64(exceptIds);

    // Finished serialization.
  }
}

/// Auth Import Login Token.
///
/// ID: `95ac5ce4`.
class AuthImportLoginToken extends TlMethod<AuthLoginTokenBase> {
  /// Auth Import Login Token constructor.
  const AuthImportLoginToken({
    required this.token,
  }) : super._();

  /// Deserialize.
  factory AuthImportLoginToken.deserialize(BinaryReader reader) {
    // Read [AuthImportLoginToken] fields.
    final token = reader.readBytes();

    // Construct [AuthImportLoginToken] object.
    final returnValue = AuthImportLoginToken(
      token: token,
    );

    // Now return the deserialized [AuthImportLoginToken].
    return returnValue;
  }

  /// Token.
  final Uint8List token;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x95ac5ce4.
    buffer.writeInt32(0x95ac5ce4);

    // Write fields.
    buffer.writeBytes(token);

    // Finished serialization.
  }
}

/// Auth Accept Login Token.
///
/// ID: `e894ad4d`.
class AuthAcceptLoginToken extends TlMethod<AuthorizationBase> {
  /// Auth Accept Login Token constructor.
  const AuthAcceptLoginToken({
    required this.token,
  }) : super._();

  /// Deserialize.
  factory AuthAcceptLoginToken.deserialize(BinaryReader reader) {
    // Read [AuthAcceptLoginToken] fields.
    final token = reader.readBytes();

    // Construct [AuthAcceptLoginToken] object.
    final returnValue = AuthAcceptLoginToken(
      token: token,
    );

    // Now return the deserialized [AuthAcceptLoginToken].
    return returnValue;
  }

  /// Token.
  final Uint8List token;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe894ad4d.
    buffer.writeInt32(0xe894ad4d);

    // Write fields.
    buffer.writeBytes(token);

    // Finished serialization.
  }
}

/// Account Set Content Settings.
///
/// ID: `b574b16b`.
class AccountSetContentSettings extends TlMethod<bool> {
  /// Account Set Content Settings constructor.
  const AccountSetContentSettings({
    required this.sensitiveEnabled,
  }) : super._();

  /// Deserialize.
  factory AccountSetContentSettings.deserialize(BinaryReader reader) {
    // Read [AccountSetContentSettings] fields.
    final flags = reader.readInt32();
    final sensitiveEnabled = (flags & 1) != 0;

    // Construct [AccountSetContentSettings] object.
    final returnValue = AccountSetContentSettings(
      sensitiveEnabled: sensitiveEnabled,
    );

    // Now return the deserialized [AccountSetContentSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: sensitiveEnabled,
    );

    return v;
  }

  /// sensitive_enabled: bit 0 of flags.0?true
  final bool sensitiveEnabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb574b16b.
    buffer.writeInt32(0xb574b16b);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Account Get Content Settings.
///
/// ID: `8b9b4dae`.
class AccountGetContentSettings extends TlMethod<AccountContentSettingsBase> {
  /// Account Get Content Settings constructor.
  const AccountGetContentSettings() : super._();

  /// Deserialize.
  factory AccountGetContentSettings.deserialize(BinaryReader reader) {
    // Construct [AccountGetContentSettings] object.
    final returnValue = AccountGetContentSettings();

    // Now return the deserialized [AccountGetContentSettings].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8b9b4dae.
    buffer.writeInt32(0x8b9b4dae);

    // Finished serialization.
  }
}

/// Channels Get Inactive Channels.
///
/// ID: `11e831ee`.
class ChannelsGetInactiveChannels extends TlMethod<MessagesInactiveChatsBase> {
  /// Channels Get Inactive Channels constructor.
  const ChannelsGetInactiveChannels() : super._();

  /// Deserialize.
  factory ChannelsGetInactiveChannels.deserialize(BinaryReader reader) {
    // Construct [ChannelsGetInactiveChannels] object.
    final returnValue = ChannelsGetInactiveChannels();

    // Now return the deserialized [ChannelsGetInactiveChannels].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x11e831ee.
    buffer.writeInt32(0x11e831ee);

    // Finished serialization.
  }
}

/// Account Get Multi Wall Papers.
///
/// ID: `65ad71dc`.
class AccountGetMultiWallPapers extends TlMethod<List<WallPaperBase>> {
  /// Account Get Multi Wall Papers constructor.
  const AccountGetMultiWallPapers({
    required this.wallpapers,
  }) : super._();

  /// Deserialize.
  factory AccountGetMultiWallPapers.deserialize(BinaryReader reader) {
    // Read [AccountGetMultiWallPapers] fields.
    final wallpapers = reader.readVectorObject<InputWallPaperBase>();

    // Construct [AccountGetMultiWallPapers] object.
    final returnValue = AccountGetMultiWallPapers(
      wallpapers: wallpapers,
    );

    // Now return the deserialized [AccountGetMultiWallPapers].
    return returnValue;
  }

  /// Wallpapers.
  final List<InputWallPaperBase> wallpapers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x65ad71dc.
    buffer.writeInt32(0x65ad71dc);

    // Write fields.
    buffer.writeVectorObject(wallpapers);

    // Finished serialization.
  }
}

/// Messages Get Poll Votes.
///
/// ID: `b86e380e`.
class MessagesGetPollVotes extends TlMethod<MessagesVotesListBase> {
  /// Messages Get Poll Votes constructor.
  const MessagesGetPollVotes({
    required this.peer,
    required this.id,
    this.option,
    this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory MessagesGetPollVotes.deserialize(BinaryReader reader) {
    // Read [MessagesGetPollVotes] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();
    final hasOptionField = (flags & 1) != 0;
    final option = hasOptionField ? reader.readBytes() : null;
    final hasOffsetField = (flags & 2) != 0;
    final offset = hasOffsetField ? reader.readString() : null;
    final limit = reader.readInt32();

    // Construct [MessagesGetPollVotes] object.
    final returnValue = MessagesGetPollVotes(
      peer: peer,
      id: id,
      option: option,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [MessagesGetPollVotes].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: option != null,
      b01: offset != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Option.
  final Uint8List? option;

  /// Offset.
  final String? offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb86e380e.
    buffer.writeInt32(0xb86e380e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    final localOptionCopy = option;
    if (localOptionCopy != null) {
      buffer.writeBytes(localOptionCopy);
    }
    final localOffsetCopy = offset;
    if (localOffsetCopy != null) {
      buffer.writeString(localOffsetCopy);
    }
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Messages Toggle Sticker Sets.
///
/// ID: `b5052fea`.
class MessagesToggleStickerSets extends TlMethod<bool> {
  /// Messages Toggle Sticker Sets constructor.
  const MessagesToggleStickerSets({
    required this.uninstall,
    required this.archive,
    required this.unarchive,
    required this.stickersets,
  }) : super._();

  /// Deserialize.
  factory MessagesToggleStickerSets.deserialize(BinaryReader reader) {
    // Read [MessagesToggleStickerSets] fields.
    final flags = reader.readInt32();
    final uninstall = (flags & 1) != 0;
    final archive = (flags & 2) != 0;
    final unarchive = (flags & 4) != 0;
    final stickersets = reader.readVectorObject<InputStickerSetBase>();

    // Construct [MessagesToggleStickerSets] object.
    final returnValue = MessagesToggleStickerSets(
      uninstall: uninstall,
      archive: archive,
      unarchive: unarchive,
      stickersets: stickersets,
    );

    // Now return the deserialized [MessagesToggleStickerSets].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: uninstall,
      b01: archive,
      b02: unarchive,
    );

    return v;
  }

  /// uninstall: bit 0 of flags.0?true
  final bool uninstall;

  /// archive: bit 1 of flags.1?true
  final bool archive;

  /// unarchive: bit 2 of flags.2?true
  final bool unarchive;

  /// Stickersets.
  final List<InputStickerSetBase> stickersets;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb5052fea.
    buffer.writeInt32(0xb5052fea);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(stickersets);

    // Finished serialization.
  }
}

/// Payments Get Bank Card Data.
///
/// ID: `2e79d779`.
class PaymentsGetBankCardData extends TlMethod<PaymentsBankCardDataBase> {
  /// Payments Get Bank Card Data constructor.
  const PaymentsGetBankCardData({
    required this.number,
  }) : super._();

  /// Deserialize.
  factory PaymentsGetBankCardData.deserialize(BinaryReader reader) {
    // Read [PaymentsGetBankCardData] fields.
    final number = reader.readString();

    // Construct [PaymentsGetBankCardData] object.
    final returnValue = PaymentsGetBankCardData(
      number: number,
    );

    // Now return the deserialized [PaymentsGetBankCardData].
    return returnValue;
  }

  /// Number.
  final String number;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2e79d779.
    buffer.writeInt32(0x2e79d779);

    // Write fields.
    buffer.writeString(number);

    // Finished serialization.
  }
}

/// Messages Get Dialog Filters.
///
/// ID: `f19ed96d`.
class MessagesGetDialogFilters extends TlMethod<List<DialogFilterBase>> {
  /// Messages Get Dialog Filters constructor.
  const MessagesGetDialogFilters() : super._();

  /// Deserialize.
  factory MessagesGetDialogFilters.deserialize(BinaryReader reader) {
    // Construct [MessagesGetDialogFilters] object.
    final returnValue = MessagesGetDialogFilters();

    // Now return the deserialized [MessagesGetDialogFilters].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf19ed96d.
    buffer.writeInt32(0xf19ed96d);

    // Finished serialization.
  }
}

/// Messages Get Suggested Dialog Filters.
///
/// ID: `a29cd42c`.
class MessagesGetSuggestedDialogFilters
    extends TlMethod<List<DialogFilterSuggestedBase>> {
  /// Messages Get Suggested Dialog Filters constructor.
  const MessagesGetSuggestedDialogFilters() : super._();

  /// Deserialize.
  factory MessagesGetSuggestedDialogFilters.deserialize(BinaryReader reader) {
    // Construct [MessagesGetSuggestedDialogFilters] object.
    final returnValue = MessagesGetSuggestedDialogFilters();

    // Now return the deserialized [MessagesGetSuggestedDialogFilters].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa29cd42c.
    buffer.writeInt32(0xa29cd42c);

    // Finished serialization.
  }
}

/// Messages Update Dialog Filter.
///
/// ID: `1ad4a04a`.
class MessagesUpdateDialogFilter extends TlMethod<bool> {
  /// Messages Update Dialog Filter constructor.
  const MessagesUpdateDialogFilter({
    required this.id,
    this.filter,
  }) : super._();

  /// Deserialize.
  factory MessagesUpdateDialogFilter.deserialize(BinaryReader reader) {
    // Read [MessagesUpdateDialogFilter] fields.
    final flags = reader.readInt32();
    final id = reader.readInt32();
    final hasFilterField = (flags & 1) != 0;
    final filter =
        hasFilterField ? reader.readObject() as DialogFilterBase : null;

    // Construct [MessagesUpdateDialogFilter] object.
    final returnValue = MessagesUpdateDialogFilter(
      id: id,
      filter: filter,
    );

    // Now return the deserialized [MessagesUpdateDialogFilter].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: filter != null,
    );

    return v;
  }

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Filter.
  final DialogFilterBase? filter;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1ad4a04a.
    buffer.writeInt32(0x1ad4a04a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(id);
    final localFilterCopy = filter;
    if (localFilterCopy != null) {
      buffer.writeObject(localFilterCopy);
    }

    // Finished serialization.
  }
}

/// Messages Update Dialog Filters Order.
///
/// ID: `c563c1e4`.
class MessagesUpdateDialogFiltersOrder extends TlMethod<bool> {
  /// Messages Update Dialog Filters Order constructor.
  const MessagesUpdateDialogFiltersOrder({
    required this.order,
  }) : super._();

  /// Deserialize.
  factory MessagesUpdateDialogFiltersOrder.deserialize(BinaryReader reader) {
    // Read [MessagesUpdateDialogFiltersOrder] fields.
    final order = reader.readVectorInt32();

    // Construct [MessagesUpdateDialogFiltersOrder] object.
    final returnValue = MessagesUpdateDialogFiltersOrder(
      order: order,
    );

    // Now return the deserialized [MessagesUpdateDialogFiltersOrder].
    return returnValue;
  }

  /// Order.
  final List<int> order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc563c1e4.
    buffer.writeInt32(0xc563c1e4);

    // Write fields.
    buffer.writeVectorInt32(order);

    // Finished serialization.
  }
}

/// Stats Get Broadcast Stats.
///
/// ID: `ab42441a`.
class StatsGetBroadcastStats extends TlMethod<StatsBroadcastStatsBase> {
  /// Stats Get Broadcast Stats constructor.
  const StatsGetBroadcastStats({
    required this.dark,
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory StatsGetBroadcastStats.deserialize(BinaryReader reader) {
    // Read [StatsGetBroadcastStats] fields.
    final flags = reader.readInt32();
    final dark = (flags & 1) != 0;
    final channel = reader.readObject() as InputChannelBase;

    // Construct [StatsGetBroadcastStats] object.
    final returnValue = StatsGetBroadcastStats(
      dark: dark,
      channel: channel,
    );

    // Now return the deserialized [StatsGetBroadcastStats].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: dark,
    );

    return v;
  }

  /// dark: bit 0 of flags.0?true
  final bool dark;

  /// Channel.
  final InputChannelBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xab42441a.
    buffer.writeInt32(0xab42441a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Stats Load Async Graph.
///
/// ID: `621d5fa0`.
class StatsLoadAsyncGraph extends TlMethod<StatsGraphBase> {
  /// Stats Load Async Graph constructor.
  const StatsLoadAsyncGraph({
    required this.token,
    this.x,
  }) : super._();

  /// Deserialize.
  factory StatsLoadAsyncGraph.deserialize(BinaryReader reader) {
    // Read [StatsLoadAsyncGraph] fields.
    final flags = reader.readInt32();
    final token = reader.readString();
    final hasXField = (flags & 1) != 0;
    final x = hasXField ? reader.readInt64() : null;

    // Construct [StatsLoadAsyncGraph] object.
    final returnValue = StatsLoadAsyncGraph(
      token: token,
      x: x,
    );

    // Now return the deserialized [StatsLoadAsyncGraph].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: x != null,
    );

    return v;
  }

  /// Token.
  final String token;

  /// X.
  final int? x;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x621d5fa0.
    buffer.writeInt32(0x621d5fa0);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(token);
    final localXCopy = x;
    if (localXCopy != null) {
      buffer.writeInt64(localXCopy);
    }

    // Finished serialization.
  }
}

/// Stickers Set Sticker Set Thumb.
///
/// ID: `a76a5392`.
class StickersSetStickerSetThumb extends TlMethod<MessagesStickerSetBase> {
  /// Stickers Set Sticker Set Thumb constructor.
  const StickersSetStickerSetThumb({
    required this.stickerset,
    this.thumb,
    this.thumbDocumentId,
  }) : super._();

  /// Deserialize.
  factory StickersSetStickerSetThumb.deserialize(BinaryReader reader) {
    // Read [StickersSetStickerSetThumb] fields.
    final flags = reader.readInt32();
    final stickerset = reader.readObject() as InputStickerSetBase;
    final hasThumbField = (flags & 1) != 0;
    final thumb =
        hasThumbField ? reader.readObject() as InputDocumentBase : null;
    final hasThumbDocumentIdField = (flags & 2) != 0;
    final thumbDocumentId = hasThumbDocumentIdField ? reader.readInt64() : null;

    // Construct [StickersSetStickerSetThumb] object.
    final returnValue = StickersSetStickerSetThumb(
      stickerset: stickerset,
      thumb: thumb,
      thumbDocumentId: thumbDocumentId,
    );

    // Now return the deserialized [StickersSetStickerSetThumb].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: thumb != null,
      b01: thumbDocumentId != null,
    );

    return v;
  }

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Thumb.
  final InputDocumentBase? thumb;

  /// Thumb Document Id.
  final int? thumbDocumentId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa76a5392.
    buffer.writeInt32(0xa76a5392);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(stickerset);
    final localThumbCopy = thumb;
    if (localThumbCopy != null) {
      buffer.writeObject(localThumbCopy);
    }
    final localThumbDocumentIdCopy = thumbDocumentId;
    if (localThumbDocumentIdCopy != null) {
      buffer.writeInt64(localThumbDocumentIdCopy);
    }

    // Finished serialization.
  }
}

/// Bots Set Bot Commands.
///
/// ID: `0517165a`.
class BotsSetBotCommands extends TlMethod<bool> {
  /// Bots Set Bot Commands constructor.
  const BotsSetBotCommands({
    required this.scope,
    required this.langCode,
    required this.commands,
  }) : super._();

  /// Deserialize.
  factory BotsSetBotCommands.deserialize(BinaryReader reader) {
    // Read [BotsSetBotCommands] fields.
    final scope = reader.readObject() as BotCommandScopeBase;
    final langCode = reader.readString();
    final commands = reader.readVectorObject<BotCommandBase>();

    // Construct [BotsSetBotCommands] object.
    final returnValue = BotsSetBotCommands(
      scope: scope,
      langCode: langCode,
      commands: commands,
    );

    // Now return the deserialized [BotsSetBotCommands].
    return returnValue;
  }

  /// Scope.
  final BotCommandScopeBase scope;

  /// Lang Code.
  final String langCode;

  /// Commands.
  final List<BotCommandBase> commands;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0517165a.
    buffer.writeInt32(0x0517165a);

    // Write fields.
    buffer.writeObject(scope);
    buffer.writeString(langCode);
    buffer.writeVectorObject(commands);

    // Finished serialization.
  }
}

/// Messages Get Old Featured Stickers.
///
/// ID: `7ed094a1`.
class MessagesGetOldFeaturedStickers
    extends TlMethod<MessagesFeaturedStickersBase> {
  /// Messages Get Old Featured Stickers constructor.
  const MessagesGetOldFeaturedStickers({
    required this.offset,
    required this.limit,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetOldFeaturedStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetOldFeaturedStickers] fields.
    final offset = reader.readInt32();
    final limit = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [MessagesGetOldFeaturedStickers] object.
    final returnValue = MessagesGetOldFeaturedStickers(
      offset: offset,
      limit: limit,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetOldFeaturedStickers].
    return returnValue;
  }

  /// Offset.
  ///
  /// Field type is Int32.
  final int offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7ed094a1.
    buffer.writeInt32(0x7ed094a1);

    // Write fields.
    buffer.writeInt32(offset);
    buffer.writeInt32(limit);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Help Get Promo Data.
///
/// ID: `c0977421`.
class HelpGetPromoData extends TlMethod<HelpPromoDataBase> {
  /// Help Get Promo Data constructor.
  const HelpGetPromoData() : super._();

  /// Deserialize.
  factory HelpGetPromoData.deserialize(BinaryReader reader) {
    // Construct [HelpGetPromoData] object.
    final returnValue = HelpGetPromoData();

    // Now return the deserialized [HelpGetPromoData].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc0977421.
    buffer.writeInt32(0xc0977421);

    // Finished serialization.
  }
}

/// Help Hide Promo Data.
///
/// ID: `1e251c95`.
class HelpHidePromoData extends TlMethod<bool> {
  /// Help Hide Promo Data constructor.
  const HelpHidePromoData({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory HelpHidePromoData.deserialize(BinaryReader reader) {
    // Read [HelpHidePromoData] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [HelpHidePromoData] object.
    final returnValue = HelpHidePromoData(
      peer: peer,
    );

    // Now return the deserialized [HelpHidePromoData].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1e251c95.
    buffer.writeInt32(0x1e251c95);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Phone Send Signaling Data.
///
/// ID: `ff7a9383`.
class PhoneSendSignalingData extends TlMethod<bool> {
  /// Phone Send Signaling Data constructor.
  const PhoneSendSignalingData({
    required this.peer,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory PhoneSendSignalingData.deserialize(BinaryReader reader) {
    // Read [PhoneSendSignalingData] fields.
    final peer = reader.readObject() as InputPhoneCallBase;
    final data = reader.readBytes();

    // Construct [PhoneSendSignalingData] object.
    final returnValue = PhoneSendSignalingData(
      peer: peer,
      data: data,
    );

    // Now return the deserialized [PhoneSendSignalingData].
    return returnValue;
  }

  /// Peer.
  final InputPhoneCallBase peer;

  /// Data.
  final Uint8List data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xff7a9383.
    buffer.writeInt32(0xff7a9383);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeBytes(data);

    // Finished serialization.
  }
}

/// Stats Get Megagroup Stats.
///
/// ID: `dcdf8607`.
class StatsGetMegagroupStats extends TlMethod<StatsMegagroupStatsBase> {
  /// Stats Get Megagroup Stats constructor.
  const StatsGetMegagroupStats({
    required this.dark,
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory StatsGetMegagroupStats.deserialize(BinaryReader reader) {
    // Read [StatsGetMegagroupStats] fields.
    final flags = reader.readInt32();
    final dark = (flags & 1) != 0;
    final channel = reader.readObject() as InputChannelBase;

    // Construct [StatsGetMegagroupStats] object.
    final returnValue = StatsGetMegagroupStats(
      dark: dark,
      channel: channel,
    );

    // Now return the deserialized [StatsGetMegagroupStats].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: dark,
    );

    return v;
  }

  /// dark: bit 0 of flags.0?true
  final bool dark;

  /// Channel.
  final InputChannelBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdcdf8607.
    buffer.writeInt32(0xdcdf8607);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Account Get Global Privacy Settings.
///
/// ID: `eb2b4cf6`.
class AccountGetGlobalPrivacySettings
    extends TlMethod<GlobalPrivacySettingsBase> {
  /// Account Get Global Privacy Settings constructor.
  const AccountGetGlobalPrivacySettings() : super._();

  /// Deserialize.
  factory AccountGetGlobalPrivacySettings.deserialize(BinaryReader reader) {
    // Construct [AccountGetGlobalPrivacySettings] object.
    final returnValue = AccountGetGlobalPrivacySettings();

    // Now return the deserialized [AccountGetGlobalPrivacySettings].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeb2b4cf6.
    buffer.writeInt32(0xeb2b4cf6);

    // Finished serialization.
  }
}

/// Account Set Global Privacy Settings.
///
/// ID: `1edaaac2`.
class AccountSetGlobalPrivacySettings
    extends TlMethod<GlobalPrivacySettingsBase> {
  /// Account Set Global Privacy Settings constructor.
  const AccountSetGlobalPrivacySettings({
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountSetGlobalPrivacySettings.deserialize(BinaryReader reader) {
    // Read [AccountSetGlobalPrivacySettings] fields.
    final settings = reader.readObject() as GlobalPrivacySettingsBase;

    // Construct [AccountSetGlobalPrivacySettings] object.
    final returnValue = AccountSetGlobalPrivacySettings(
      settings: settings,
    );

    // Now return the deserialized [AccountSetGlobalPrivacySettings].
    return returnValue;
  }

  /// Settings.
  final GlobalPrivacySettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1edaaac2.
    buffer.writeInt32(0x1edaaac2);

    // Write fields.
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Help Dismiss Suggestion.
///
/// ID: `f50dbaa1`.
class HelpDismissSuggestion extends TlMethod<bool> {
  /// Help Dismiss Suggestion constructor.
  const HelpDismissSuggestion({
    required this.peer,
    required this.suggestion,
  }) : super._();

  /// Deserialize.
  factory HelpDismissSuggestion.deserialize(BinaryReader reader) {
    // Read [HelpDismissSuggestion] fields.
    final peer = reader.readObject() as InputPeerBase;
    final suggestion = reader.readString();

    // Construct [HelpDismissSuggestion] object.
    final returnValue = HelpDismissSuggestion(
      peer: peer,
      suggestion: suggestion,
    );

    // Now return the deserialized [HelpDismissSuggestion].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Suggestion.
  final String suggestion;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf50dbaa1.
    buffer.writeInt32(0xf50dbaa1);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeString(suggestion);

    // Finished serialization.
  }
}

/// Help Get Countries List.
///
/// ID: `735787a8`.
class HelpGetCountriesList extends TlMethod<HelpCountriesListBase> {
  /// Help Get Countries List constructor.
  const HelpGetCountriesList({
    required this.langCode,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory HelpGetCountriesList.deserialize(BinaryReader reader) {
    // Read [HelpGetCountriesList] fields.
    final langCode = reader.readString();
    final hash = reader.readInt32();

    // Construct [HelpGetCountriesList] object.
    final returnValue = HelpGetCountriesList(
      langCode: langCode,
      hash: hash,
    );

    // Now return the deserialized [HelpGetCountriesList].
    return returnValue;
  }

  /// Lang Code.
  final String langCode;

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x735787a8.
    buffer.writeInt32(0x735787a8);

    // Write fields.
    buffer.writeString(langCode);
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Messages Get Replies.
///
/// ID: `22ddd30c`.
class MessagesGetReplies extends TlMethod<MessagesMessagesBase> {
  /// Messages Get Replies constructor.
  const MessagesGetReplies({
    required this.peer,
    required this.msgId,
    required this.offsetId,
    required this.offsetDate,
    required this.addOffset,
    required this.limit,
    required this.maxId,
    required this.minId,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetReplies.deserialize(BinaryReader reader) {
    // Read [MessagesGetReplies] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final offsetId = reader.readInt32();
    final offsetDate = reader.readDateTime();
    final addOffset = reader.readInt32();
    final limit = reader.readInt32();
    final maxId = reader.readInt32();
    final minId = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [MessagesGetReplies] object.
    final returnValue = MessagesGetReplies(
      peer: peer,
      msgId: msgId,
      offsetId: offsetId,
      offsetDate: offsetDate,
      addOffset: addOffset,
      limit: limit,
      maxId: maxId,
      minId: minId,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetReplies].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Offset Date.
  final DateTime offsetDate;

  /// Add Offset.
  ///
  /// Field type is Int32.
  final int addOffset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Min Id.
  ///
  /// Field type is Int32.
  final int minId;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x22ddd30c.
    buffer.writeInt32(0x22ddd30c);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeInt32(offsetId);
    buffer.writeDateTime(offsetDate);
    buffer.writeInt32(addOffset);
    buffer.writeInt32(limit);
    buffer.writeInt32(maxId);
    buffer.writeInt32(minId);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Get Discussion Message.
///
/// ID: `446972fd`.
class MessagesGetDiscussionMessage
    extends TlMethod<MessagesDiscussionMessageBase> {
  /// Messages Get Discussion Message constructor.
  const MessagesGetDiscussionMessage({
    required this.peer,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory MessagesGetDiscussionMessage.deserialize(BinaryReader reader) {
    // Read [MessagesGetDiscussionMessage] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();

    // Construct [MessagesGetDiscussionMessage] object.
    final returnValue = MessagesGetDiscussionMessage(
      peer: peer,
      msgId: msgId,
    );

    // Now return the deserialized [MessagesGetDiscussionMessage].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x446972fd.
    buffer.writeInt32(0x446972fd);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Messages Read Discussion.
///
/// ID: `f731a9f4`.
class MessagesReadDiscussion extends TlMethod<bool> {
  /// Messages Read Discussion constructor.
  const MessagesReadDiscussion({
    required this.peer,
    required this.msgId,
    required this.readMaxId,
  }) : super._();

  /// Deserialize.
  factory MessagesReadDiscussion.deserialize(BinaryReader reader) {
    // Read [MessagesReadDiscussion] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final readMaxId = reader.readInt32();

    // Construct [MessagesReadDiscussion] object.
    final returnValue = MessagesReadDiscussion(
      peer: peer,
      msgId: msgId,
      readMaxId: readMaxId,
    );

    // Now return the deserialized [MessagesReadDiscussion].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Read Max Id.
  ///
  /// Field type is Int32.
  final int readMaxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf731a9f4.
    buffer.writeInt32(0xf731a9f4);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeInt32(readMaxId);

    // Finished serialization.
  }
}

/// Contacts Block From Replies.
///
/// ID: `29a8962c`.
class ContactsBlockFromReplies extends TlMethod<UpdatesBase> {
  /// Contacts Block From Replies constructor.
  const ContactsBlockFromReplies({
    required this.deleteMessage,
    required this.deleteHistory,
    required this.reportSpam,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory ContactsBlockFromReplies.deserialize(BinaryReader reader) {
    // Read [ContactsBlockFromReplies] fields.
    final flags = reader.readInt32();
    final deleteMessage = (flags & 1) != 0;
    final deleteHistory = (flags & 2) != 0;
    final reportSpam = (flags & 4) != 0;
    final msgId = reader.readInt32();

    // Construct [ContactsBlockFromReplies] object.
    final returnValue = ContactsBlockFromReplies(
      deleteMessage: deleteMessage,
      deleteHistory: deleteHistory,
      reportSpam: reportSpam,
      msgId: msgId,
    );

    // Now return the deserialized [ContactsBlockFromReplies].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: deleteMessage,
      b01: deleteHistory,
      b02: reportSpam,
    );

    return v;
  }

  /// delete_message: bit 0 of flags.0?true
  final bool deleteMessage;

  /// delete_history: bit 1 of flags.1?true
  final bool deleteHistory;

  /// report_spam: bit 2 of flags.2?true
  final bool reportSpam;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x29a8962c.
    buffer.writeInt32(0x29a8962c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Stats Get Message Public Forwards.
///
/// ID: `5f150144`.
class StatsGetMessagePublicForwards extends TlMethod<StatsPublicForwardsBase> {
  /// Stats Get Message Public Forwards constructor.
  const StatsGetMessagePublicForwards({
    required this.channel,
    required this.msgId,
    required this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory StatsGetMessagePublicForwards.deserialize(BinaryReader reader) {
    // Read [StatsGetMessagePublicForwards] fields.
    final channel = reader.readObject() as InputChannelBase;
    final msgId = reader.readInt32();
    final offset = reader.readString();
    final limit = reader.readInt32();

    // Construct [StatsGetMessagePublicForwards] object.
    final returnValue = StatsGetMessagePublicForwards(
      channel: channel,
      msgId: msgId,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [StatsGetMessagePublicForwards].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Offset.
  final String offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5f150144.
    buffer.writeInt32(0x5f150144);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeInt32(msgId);
    buffer.writeString(offset);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Stats Get Message Stats.
///
/// ID: `b6e0a3f5`.
class StatsGetMessageStats extends TlMethod<StatsMessageStatsBase> {
  /// Stats Get Message Stats constructor.
  const StatsGetMessageStats({
    required this.dark,
    required this.channel,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory StatsGetMessageStats.deserialize(BinaryReader reader) {
    // Read [StatsGetMessageStats] fields.
    final flags = reader.readInt32();
    final dark = (flags & 1) != 0;
    final channel = reader.readObject() as InputChannelBase;
    final msgId = reader.readInt32();

    // Construct [StatsGetMessageStats] object.
    final returnValue = StatsGetMessageStats(
      dark: dark,
      channel: channel,
      msgId: msgId,
    );

    // Now return the deserialized [StatsGetMessageStats].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: dark,
    );

    return v;
  }

  /// dark: bit 0 of flags.0?true
  final bool dark;

  /// Channel.
  final InputChannelBase channel;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb6e0a3f5.
    buffer.writeInt32(0xb6e0a3f5);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Messages Unpin All Messages.
///
/// ID: `ee22b9a8`.
class MessagesUnpinAllMessages extends TlMethod<MessagesAffectedHistoryBase> {
  /// Messages Unpin All Messages constructor.
  const MessagesUnpinAllMessages({
    required this.peer,
    this.topMsgId,
  }) : super._();

  /// Deserialize.
  factory MessagesUnpinAllMessages.deserialize(BinaryReader reader) {
    // Read [MessagesUnpinAllMessages] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;

    // Construct [MessagesUnpinAllMessages] object.
    final returnValue = MessagesUnpinAllMessages(
      peer: peer,
      topMsgId: topMsgId,
    );

    // Now return the deserialized [MessagesUnpinAllMessages].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Top Msg Id.
  final int? topMsgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xee22b9a8.
    buffer.writeInt32(0xee22b9a8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }

    // Finished serialization.
  }
}

/// Phone Create Group Call.
///
/// ID: `48cdc6d8`.
class PhoneCreateGroupCall extends TlMethod<UpdatesBase> {
  /// Phone Create Group Call constructor.
  const PhoneCreateGroupCall({
    required this.rtmpStream,
    required this.peer,
    required this.randomId,
    this.title,
    this.scheduleDate,
  }) : super._();

  /// Deserialize.
  factory PhoneCreateGroupCall.deserialize(BinaryReader reader) {
    // Read [PhoneCreateGroupCall] fields.
    final flags = reader.readInt32();
    final rtmpStream = (flags & 4) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final randomId = reader.readInt32();
    final hasTitleField = (flags & 1) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasScheduleDateField = (flags & 2) != 0;
    final scheduleDate = hasScheduleDateField ? reader.readDateTime() : null;

    // Construct [PhoneCreateGroupCall] object.
    final returnValue = PhoneCreateGroupCall(
      rtmpStream: rtmpStream,
      peer: peer,
      randomId: randomId,
      title: title,
      scheduleDate: scheduleDate,
    );

    // Now return the deserialized [PhoneCreateGroupCall].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: rtmpStream,
      b00: title != null,
      b01: scheduleDate != null,
    );

    return v;
  }

  /// rtmp_stream: bit 2 of flags.2?true
  final bool rtmpStream;

  /// Peer.
  final InputPeerBase peer;

  /// Random Id.
  ///
  /// Field type is Int32.
  final int randomId;

  /// Title.
  final String? title;

  /// Schedule Date.
  final DateTime? scheduleDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x48cdc6d8.
    buffer.writeInt32(0x48cdc6d8);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(randomId);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localScheduleDateCopy = scheduleDate;
    if (localScheduleDateCopy != null) {
      buffer.writeDateTime(localScheduleDateCopy);
    }

    // Finished serialization.
  }
}

/// Phone Join Group Call.
///
/// ID: `b132ff7b`.
class PhoneJoinGroupCall extends TlMethod<UpdatesBase> {
  /// Phone Join Group Call constructor.
  const PhoneJoinGroupCall({
    required this.muted,
    required this.videoStopped,
    required this.call,
    required this.joinAs,
    this.inviteHash,
    required this.params,
  }) : super._();

  /// Deserialize.
  factory PhoneJoinGroupCall.deserialize(BinaryReader reader) {
    // Read [PhoneJoinGroupCall] fields.
    final flags = reader.readInt32();
    final muted = (flags & 1) != 0;
    final videoStopped = (flags & 4) != 0;
    final call = reader.readObject() as InputGroupCallBase;
    final joinAs = reader.readObject() as InputPeerBase;
    final hasInviteHashField = (flags & 2) != 0;
    final inviteHash = hasInviteHashField ? reader.readString() : null;
    final params = reader.readObject() as DataJSONBase;

    // Construct [PhoneJoinGroupCall] object.
    final returnValue = PhoneJoinGroupCall(
      muted: muted,
      videoStopped: videoStopped,
      call: call,
      joinAs: joinAs,
      inviteHash: inviteHash,
      params: params,
    );

    // Now return the deserialized [PhoneJoinGroupCall].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: muted,
      b02: videoStopped,
      b01: inviteHash != null,
    );

    return v;
  }

  /// muted: bit 0 of flags.0?true
  final bool muted;

  /// video_stopped: bit 2 of flags.2?true
  final bool videoStopped;

  /// Call.
  final InputGroupCallBase call;

  /// Join As.
  final InputPeerBase joinAs;

  /// Invite Hash.
  final String? inviteHash;

  /// Params.
  final DataJSONBase params;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb132ff7b.
    buffer.writeInt32(0xb132ff7b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(call);
    buffer.writeObject(joinAs);
    final localInviteHashCopy = inviteHash;
    if (localInviteHashCopy != null) {
      buffer.writeString(localInviteHashCopy);
    }
    buffer.writeObject(params);

    // Finished serialization.
  }
}

/// Phone Leave Group Call.
///
/// ID: `500377f9`.
class PhoneLeaveGroupCall extends TlMethod<UpdatesBase> {
  /// Phone Leave Group Call constructor.
  const PhoneLeaveGroupCall({
    required this.call,
    required this.source,
  }) : super._();

  /// Deserialize.
  factory PhoneLeaveGroupCall.deserialize(BinaryReader reader) {
    // Read [PhoneLeaveGroupCall] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final source = reader.readInt32();

    // Construct [PhoneLeaveGroupCall] object.
    final returnValue = PhoneLeaveGroupCall(
      call: call,
      source: source,
    );

    // Now return the deserialized [PhoneLeaveGroupCall].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Source.
  ///
  /// Field type is Int32.
  final int source;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x500377f9.
    buffer.writeInt32(0x500377f9);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeInt32(source);

    // Finished serialization.
  }
}

/// Phone Invite To Group Call.
///
/// ID: `7b393160`.
class PhoneInviteToGroupCall extends TlMethod<UpdatesBase> {
  /// Phone Invite To Group Call constructor.
  const PhoneInviteToGroupCall({
    required this.call,
    required this.users,
  }) : super._();

  /// Deserialize.
  factory PhoneInviteToGroupCall.deserialize(BinaryReader reader) {
    // Read [PhoneInviteToGroupCall] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final users = reader.readVectorObject<InputUserBase>();

    // Construct [PhoneInviteToGroupCall] object.
    final returnValue = PhoneInviteToGroupCall(
      call: call,
      users: users,
    );

    // Now return the deserialized [PhoneInviteToGroupCall].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Users.
  final List<InputUserBase> users;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7b393160.
    buffer.writeInt32(0x7b393160);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeVectorObject(users);

    // Finished serialization.
  }
}

/// Phone Discard Group Call.
///
/// ID: `7a777135`.
class PhoneDiscardGroupCall extends TlMethod<UpdatesBase> {
  /// Phone Discard Group Call constructor.
  const PhoneDiscardGroupCall({
    required this.call,
  }) : super._();

  /// Deserialize.
  factory PhoneDiscardGroupCall.deserialize(BinaryReader reader) {
    // Read [PhoneDiscardGroupCall] fields.
    final call = reader.readObject() as InputGroupCallBase;

    // Construct [PhoneDiscardGroupCall] object.
    final returnValue = PhoneDiscardGroupCall(
      call: call,
    );

    // Now return the deserialized [PhoneDiscardGroupCall].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7a777135.
    buffer.writeInt32(0x7a777135);

    // Write fields.
    buffer.writeObject(call);

    // Finished serialization.
  }
}

/// Phone Toggle Group Call Settings.
///
/// ID: `74bbb43d`.
class PhoneToggleGroupCallSettings extends TlMethod<UpdatesBase> {
  /// Phone Toggle Group Call Settings constructor.
  const PhoneToggleGroupCallSettings({
    required this.resetInviteHash,
    required this.call,
    required this.joinMuted,
  }) : super._();

  /// Deserialize.
  factory PhoneToggleGroupCallSettings.deserialize(BinaryReader reader) {
    // Read [PhoneToggleGroupCallSettings] fields.
    final flags = reader.readInt32();
    final resetInviteHash = (flags & 2) != 0;
    final call = reader.readObject() as InputGroupCallBase;
    final joinMuted = (flags & 1) != 0;

    // Construct [PhoneToggleGroupCallSettings] object.
    final returnValue = PhoneToggleGroupCallSettings(
      resetInviteHash: resetInviteHash,
      call: call,
      joinMuted: joinMuted,
    );

    // Now return the deserialized [PhoneToggleGroupCallSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: resetInviteHash,
      b00: joinMuted,
    );

    return v;
  }

  /// reset_invite_hash: bit 1 of flags.1?true
  final bool resetInviteHash;

  /// Call.
  final InputGroupCallBase call;

  /// join_muted: bit 0 of flags.0?Bool
  final bool joinMuted;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x74bbb43d.
    buffer.writeInt32(0x74bbb43d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(call);

    // Finished serialization.
  }
}

/// Phone Get Group Call.
///
/// ID: `041845db`.
class PhoneGetGroupCall extends TlMethod<PhoneGroupCallBase> {
  /// Phone Get Group Call constructor.
  const PhoneGetGroupCall({
    required this.call,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory PhoneGetGroupCall.deserialize(BinaryReader reader) {
    // Read [PhoneGetGroupCall] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final limit = reader.readInt32();

    // Construct [PhoneGetGroupCall] object.
    final returnValue = PhoneGetGroupCall(
      call: call,
      limit: limit,
    );

    // Now return the deserialized [PhoneGetGroupCall].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x041845db.
    buffer.writeInt32(0x041845db);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Phone Get Group Participants.
///
/// ID: `c558d8ab`.
class PhoneGetGroupParticipants extends TlMethod<PhoneGroupParticipantsBase> {
  /// Phone Get Group Participants constructor.
  const PhoneGetGroupParticipants({
    required this.call,
    required this.ids,
    required this.sources,
    required this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory PhoneGetGroupParticipants.deserialize(BinaryReader reader) {
    // Read [PhoneGetGroupParticipants] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final ids = reader.readVectorObject<InputPeerBase>();
    final sources = reader.readVectorInt32();
    final offset = reader.readString();
    final limit = reader.readInt32();

    // Construct [PhoneGetGroupParticipants] object.
    final returnValue = PhoneGetGroupParticipants(
      call: call,
      ids: ids,
      sources: sources,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [PhoneGetGroupParticipants].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Ids.
  final List<InputPeerBase> ids;

  /// Sources.
  final List<int> sources;

  /// Offset.
  final String offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc558d8ab.
    buffer.writeInt32(0xc558d8ab);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeVectorObject(ids);
    buffer.writeVectorInt32(sources);
    buffer.writeString(offset);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Phone Check Group Call.
///
/// ID: `b59cf977`.
class PhoneCheckGroupCall extends TlMethod<List<int>> {
  /// Phone Check Group Call constructor.
  const PhoneCheckGroupCall({
    required this.call,
    required this.sources,
  }) : super._();

  /// Deserialize.
  factory PhoneCheckGroupCall.deserialize(BinaryReader reader) {
    // Read [PhoneCheckGroupCall] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final sources = reader.readVectorInt32();

    // Construct [PhoneCheckGroupCall] object.
    final returnValue = PhoneCheckGroupCall(
      call: call,
      sources: sources,
    );

    // Now return the deserialized [PhoneCheckGroupCall].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Sources.
  final List<int> sources;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb59cf977.
    buffer.writeInt32(0xb59cf977);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeVectorInt32(sources);

    // Finished serialization.
  }
}

/// Messages Delete Chat.
///
/// ID: `5bd0ee50`.
class MessagesDeleteChat extends TlMethod<bool> {
  /// Messages Delete Chat constructor.
  const MessagesDeleteChat({
    required this.chatId,
  }) : super._();

  /// Deserialize.
  factory MessagesDeleteChat.deserialize(BinaryReader reader) {
    // Read [MessagesDeleteChat] fields.
    final chatId = reader.readInt64();

    // Construct [MessagesDeleteChat] object.
    final returnValue = MessagesDeleteChat(
      chatId: chatId,
    );

    // Now return the deserialized [MessagesDeleteChat].
    return returnValue;
  }

  /// Chat Id.
  ///
  /// Field type is Int64.
  final int chatId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5bd0ee50.
    buffer.writeInt32(0x5bd0ee50);

    // Write fields.
    buffer.writeInt64(chatId);

    // Finished serialization.
  }
}

/// Messages Delete Phone Call History.
///
/// ID: `f9cbe409`.
class MessagesDeletePhoneCallHistory
    extends TlMethod<MessagesAffectedFoundMessagesBase> {
  /// Messages Delete Phone Call History constructor.
  const MessagesDeletePhoneCallHistory({
    required this.revoke,
  }) : super._();

  /// Deserialize.
  factory MessagesDeletePhoneCallHistory.deserialize(BinaryReader reader) {
    // Read [MessagesDeletePhoneCallHistory] fields.
    final flags = reader.readInt32();
    final revoke = (flags & 1) != 0;

    // Construct [MessagesDeletePhoneCallHistory] object.
    final returnValue = MessagesDeletePhoneCallHistory(
      revoke: revoke,
    );

    // Now return the deserialized [MessagesDeletePhoneCallHistory].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: revoke,
    );

    return v;
  }

  /// revoke: bit 0 of flags.0?true
  final bool revoke;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf9cbe409.
    buffer.writeInt32(0xf9cbe409);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Messages Check History Import.
///
/// ID: `43fe19f3`.
class MessagesCheckHistoryImport
    extends TlMethod<MessagesHistoryImportParsedBase> {
  /// Messages Check History Import constructor.
  const MessagesCheckHistoryImport({
    required this.importHead,
  }) : super._();

  /// Deserialize.
  factory MessagesCheckHistoryImport.deserialize(BinaryReader reader) {
    // Read [MessagesCheckHistoryImport] fields.
    final importHead = reader.readString();

    // Construct [MessagesCheckHistoryImport] object.
    final returnValue = MessagesCheckHistoryImport(
      importHead: importHead,
    );

    // Now return the deserialized [MessagesCheckHistoryImport].
    return returnValue;
  }

  /// Import Head.
  final String importHead;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x43fe19f3.
    buffer.writeInt32(0x43fe19f3);

    // Write fields.
    buffer.writeString(importHead);

    // Finished serialization.
  }
}

/// Messages Init History Import.
///
/// ID: `34090c3b`.
class MessagesInitHistoryImport extends TlMethod<MessagesHistoryImportBase> {
  /// Messages Init History Import constructor.
  const MessagesInitHistoryImport({
    required this.peer,
    required this.file,
    required this.mediaCount,
  }) : super._();

  /// Deserialize.
  factory MessagesInitHistoryImport.deserialize(BinaryReader reader) {
    // Read [MessagesInitHistoryImport] fields.
    final peer = reader.readObject() as InputPeerBase;
    final file = reader.readObject() as InputFileBase;
    final mediaCount = reader.readInt32();

    // Construct [MessagesInitHistoryImport] object.
    final returnValue = MessagesInitHistoryImport(
      peer: peer,
      file: file,
      mediaCount: mediaCount,
    );

    // Now return the deserialized [MessagesInitHistoryImport].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// File.
  final InputFileBase file;

  /// Media Count.
  ///
  /// Field type is Int32.
  final int mediaCount;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x34090c3b.
    buffer.writeInt32(0x34090c3b);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(file);
    buffer.writeInt32(mediaCount);

    // Finished serialization.
  }
}

/// Messages Upload Imported Media.
///
/// ID: `2a862092`.
class MessagesUploadImportedMedia extends TlMethod<MessageMediaBase> {
  /// Messages Upload Imported Media constructor.
  const MessagesUploadImportedMedia({
    required this.peer,
    required this.importId,
    required this.fileName,
    required this.media,
  }) : super._();

  /// Deserialize.
  factory MessagesUploadImportedMedia.deserialize(BinaryReader reader) {
    // Read [MessagesUploadImportedMedia] fields.
    final peer = reader.readObject() as InputPeerBase;
    final importId = reader.readInt64();
    final fileName = reader.readString();
    final media = reader.readObject() as InputMediaBase;

    // Construct [MessagesUploadImportedMedia] object.
    final returnValue = MessagesUploadImportedMedia(
      peer: peer,
      importId: importId,
      fileName: fileName,
      media: media,
    );

    // Now return the deserialized [MessagesUploadImportedMedia].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Import Id.
  ///
  /// Field type is Int64.
  final int importId;

  /// File Name.
  final String fileName;

  /// Media.
  final InputMediaBase media;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2a862092.
    buffer.writeInt32(0x2a862092);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt64(importId);
    buffer.writeString(fileName);
    buffer.writeObject(media);

    // Finished serialization.
  }
}

/// Messages Start History Import.
///
/// ID: `b43df344`.
class MessagesStartHistoryImport extends TlMethod<bool> {
  /// Messages Start History Import constructor.
  const MessagesStartHistoryImport({
    required this.peer,
    required this.importId,
  }) : super._();

  /// Deserialize.
  factory MessagesStartHistoryImport.deserialize(BinaryReader reader) {
    // Read [MessagesStartHistoryImport] fields.
    final peer = reader.readObject() as InputPeerBase;
    final importId = reader.readInt64();

    // Construct [MessagesStartHistoryImport] object.
    final returnValue = MessagesStartHistoryImport(
      peer: peer,
      importId: importId,
    );

    // Now return the deserialized [MessagesStartHistoryImport].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Import Id.
  ///
  /// Field type is Int64.
  final int importId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb43df344.
    buffer.writeInt32(0xb43df344);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt64(importId);

    // Finished serialization.
  }
}

/// Messages Get Exported Chat Invites.
///
/// ID: `a2b5a3f6`.
class MessagesGetExportedChatInvites
    extends TlMethod<MessagesExportedChatInvitesBase> {
  /// Messages Get Exported Chat Invites constructor.
  const MessagesGetExportedChatInvites({
    required this.revoked,
    required this.peer,
    required this.adminId,
    this.offsetDate,
    this.offsetLink,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory MessagesGetExportedChatInvites.deserialize(BinaryReader reader) {
    // Read [MessagesGetExportedChatInvites] fields.
    final flags = reader.readInt32();
    final revoked = (flags & 8) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final adminId = reader.readObject() as InputUserBase;
    final hasOffsetDateField = (flags & 4) != 0;
    final offsetDate = hasOffsetDateField ? reader.readDateTime() : null;
    final hasOffsetLinkField = (flags & 4) != 0;
    final offsetLink = hasOffsetLinkField ? reader.readString() : null;
    final limit = reader.readInt32();

    // Construct [MessagesGetExportedChatInvites] object.
    final returnValue = MessagesGetExportedChatInvites(
      revoked: revoked,
      peer: peer,
      adminId: adminId,
      offsetDate: offsetDate,
      offsetLink: offsetLink,
      limit: limit,
    );

    // Now return the deserialized [MessagesGetExportedChatInvites].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: revoked,
      b02: offsetDate != null || offsetLink != null,
    );

    return v;
  }

  /// revoked: bit 3 of flags.3?true
  final bool revoked;

  /// Peer.
  final InputPeerBase peer;

  /// Admin Id.
  final InputUserBase adminId;

  /// Offset Date.
  final DateTime? offsetDate;

  /// Offset Link.
  final String? offsetLink;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa2b5a3f6.
    buffer.writeInt32(0xa2b5a3f6);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeObject(adminId);
    final localOffsetDateCopy = offsetDate;
    if (localOffsetDateCopy != null) {
      buffer.writeDateTime(localOffsetDateCopy);
    }
    final localOffsetLinkCopy = offsetLink;
    if (localOffsetLinkCopy != null) {
      buffer.writeString(localOffsetLinkCopy);
    }
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Messages Get Exported Chat Invite.
///
/// ID: `73746f5c`.
class MessagesGetExportedChatInvite
    extends TlMethod<MessagesExportedChatInviteBase> {
  /// Messages Get Exported Chat Invite constructor.
  const MessagesGetExportedChatInvite({
    required this.peer,
    required this.link,
  }) : super._();

  /// Deserialize.
  factory MessagesGetExportedChatInvite.deserialize(BinaryReader reader) {
    // Read [MessagesGetExportedChatInvite] fields.
    final peer = reader.readObject() as InputPeerBase;
    final link = reader.readString();

    // Construct [MessagesGetExportedChatInvite] object.
    final returnValue = MessagesGetExportedChatInvite(
      peer: peer,
      link: link,
    );

    // Now return the deserialized [MessagesGetExportedChatInvite].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Link.
  final String link;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x73746f5c.
    buffer.writeInt32(0x73746f5c);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeString(link);

    // Finished serialization.
  }
}

/// Messages Edit Exported Chat Invite.
///
/// ID: `bdca2f75`.
class MessagesEditExportedChatInvite
    extends TlMethod<MessagesExportedChatInviteBase> {
  /// Messages Edit Exported Chat Invite constructor.
  const MessagesEditExportedChatInvite({
    required this.revoked,
    required this.peer,
    required this.link,
    this.expireDate,
    this.usageLimit,
    required this.requestNeeded,
    this.title,
  }) : super._();

  /// Deserialize.
  factory MessagesEditExportedChatInvite.deserialize(BinaryReader reader) {
    // Read [MessagesEditExportedChatInvite] fields.
    final flags = reader.readInt32();
    final revoked = (flags & 4) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final link = reader.readString();
    final hasExpireDateField = (flags & 1) != 0;
    final expireDate = hasExpireDateField ? reader.readDateTime() : null;
    final hasUsageLimitField = (flags & 2) != 0;
    final usageLimit = hasUsageLimitField ? reader.readInt32() : null;
    final requestNeeded = (flags & 8) != 0;
    final hasTitleField = (flags & 16) != 0;
    final title = hasTitleField ? reader.readString() : null;

    // Construct [MessagesEditExportedChatInvite] object.
    final returnValue = MessagesEditExportedChatInvite(
      revoked: revoked,
      peer: peer,
      link: link,
      expireDate: expireDate,
      usageLimit: usageLimit,
      requestNeeded: requestNeeded,
      title: title,
    );

    // Now return the deserialized [MessagesEditExportedChatInvite].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: revoked,
      b00: expireDate != null,
      b01: usageLimit != null,
      b03: requestNeeded,
      b04: title != null,
    );

    return v;
  }

  /// revoked: bit 2 of flags.2?true
  final bool revoked;

  /// Peer.
  final InputPeerBase peer;

  /// Link.
  final String link;

  /// Expire Date.
  final DateTime? expireDate;

  /// Usage Limit.
  final int? usageLimit;

  /// request_needed: bit 3 of flags.3?Bool
  final bool requestNeeded;

  /// Title.
  final String? title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbdca2f75.
    buffer.writeInt32(0xbdca2f75);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeString(link);
    final localExpireDateCopy = expireDate;
    if (localExpireDateCopy != null) {
      buffer.writeDateTime(localExpireDateCopy);
    }
    final localUsageLimitCopy = usageLimit;
    if (localUsageLimitCopy != null) {
      buffer.writeInt32(localUsageLimitCopy);
    }
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }

    // Finished serialization.
  }
}

/// Messages Delete Revoked Exported Chat Invites.
///
/// ID: `56987bd5`.
class MessagesDeleteRevokedExportedChatInvites extends TlMethod<bool> {
  /// Messages Delete Revoked Exported Chat Invites constructor.
  const MessagesDeleteRevokedExportedChatInvites({
    required this.peer,
    required this.adminId,
  }) : super._();

  /// Deserialize.
  factory MessagesDeleteRevokedExportedChatInvites.deserialize(
      BinaryReader reader) {
    // Read [MessagesDeleteRevokedExportedChatInvites] fields.
    final peer = reader.readObject() as InputPeerBase;
    final adminId = reader.readObject() as InputUserBase;

    // Construct [MessagesDeleteRevokedExportedChatInvites] object.
    final returnValue = MessagesDeleteRevokedExportedChatInvites(
      peer: peer,
      adminId: adminId,
    );

    // Now return the deserialized [MessagesDeleteRevokedExportedChatInvites].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Admin Id.
  final InputUserBase adminId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x56987bd5.
    buffer.writeInt32(0x56987bd5);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(adminId);

    // Finished serialization.
  }
}

/// Messages Delete Exported Chat Invite.
///
/// ID: `d464a42b`.
class MessagesDeleteExportedChatInvite extends TlMethod<bool> {
  /// Messages Delete Exported Chat Invite constructor.
  const MessagesDeleteExportedChatInvite({
    required this.peer,
    required this.link,
  }) : super._();

  /// Deserialize.
  factory MessagesDeleteExportedChatInvite.deserialize(BinaryReader reader) {
    // Read [MessagesDeleteExportedChatInvite] fields.
    final peer = reader.readObject() as InputPeerBase;
    final link = reader.readString();

    // Construct [MessagesDeleteExportedChatInvite] object.
    final returnValue = MessagesDeleteExportedChatInvite(
      peer: peer,
      link: link,
    );

    // Now return the deserialized [MessagesDeleteExportedChatInvite].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Link.
  final String link;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd464a42b.
    buffer.writeInt32(0xd464a42b);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeString(link);

    // Finished serialization.
  }
}

/// Messages Get Admins With Invites.
///
/// ID: `3920e6ef`.
class MessagesGetAdminsWithInvites
    extends TlMethod<MessagesChatAdminsWithInvitesBase> {
  /// Messages Get Admins With Invites constructor.
  const MessagesGetAdminsWithInvites({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesGetAdminsWithInvites.deserialize(BinaryReader reader) {
    // Read [MessagesGetAdminsWithInvites] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [MessagesGetAdminsWithInvites] object.
    final returnValue = MessagesGetAdminsWithInvites(
      peer: peer,
    );

    // Now return the deserialized [MessagesGetAdminsWithInvites].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3920e6ef.
    buffer.writeInt32(0x3920e6ef);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Messages Get Chat Invite Importers.
///
/// ID: `df04dd4e`.
class MessagesGetChatInviteImporters
    extends TlMethod<MessagesChatInviteImportersBase> {
  /// Messages Get Chat Invite Importers constructor.
  const MessagesGetChatInviteImporters({
    required this.requested,
    required this.peer,
    this.link,
    this.q,
    required this.offsetDate,
    required this.offsetUser,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory MessagesGetChatInviteImporters.deserialize(BinaryReader reader) {
    // Read [MessagesGetChatInviteImporters] fields.
    final flags = reader.readInt32();
    final requested = (flags & 1) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final hasLinkField = (flags & 2) != 0;
    final link = hasLinkField ? reader.readString() : null;
    final hasQField = (flags & 4) != 0;
    final q = hasQField ? reader.readString() : null;
    final offsetDate = reader.readDateTime();
    final offsetUser = reader.readObject() as InputUserBase;
    final limit = reader.readInt32();

    // Construct [MessagesGetChatInviteImporters] object.
    final returnValue = MessagesGetChatInviteImporters(
      requested: requested,
      peer: peer,
      link: link,
      q: q,
      offsetDate: offsetDate,
      offsetUser: offsetUser,
      limit: limit,
    );

    // Now return the deserialized [MessagesGetChatInviteImporters].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: requested,
      b01: link != null,
      b02: q != null,
    );

    return v;
  }

  /// requested: bit 0 of flags.0?true
  final bool requested;

  /// Peer.
  final InputPeerBase peer;

  /// Link.
  final String? link;

  /// Q.
  final String? q;

  /// Offset Date.
  final DateTime offsetDate;

  /// Offset User.
  final InputUserBase offsetUser;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdf04dd4e.
    buffer.writeInt32(0xdf04dd4e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localLinkCopy = link;
    if (localLinkCopy != null) {
      buffer.writeString(localLinkCopy);
    }
    final localQCopy = q;
    if (localQCopy != null) {
      buffer.writeString(localQCopy);
    }
    buffer.writeDateTime(offsetDate);
    buffer.writeObject(offsetUser);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Messages Set History T T L.
///
/// ID: `b80e5fe4`.
class MessagesSetHistoryTTL extends TlMethod<UpdatesBase> {
  /// Messages Set History T T L constructor.
  const MessagesSetHistoryTTL({
    required this.peer,
    required this.period,
  }) : super._();

  /// Deserialize.
  factory MessagesSetHistoryTTL.deserialize(BinaryReader reader) {
    // Read [MessagesSetHistoryTTL] fields.
    final peer = reader.readObject() as InputPeerBase;
    final period = reader.readInt32();

    // Construct [MessagesSetHistoryTTL] object.
    final returnValue = MessagesSetHistoryTTL(
      peer: peer,
      period: period,
    );

    // Now return the deserialized [MessagesSetHistoryTTL].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Period.
  ///
  /// Field type is Int32.
  final int period;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb80e5fe4.
    buffer.writeInt32(0xb80e5fe4);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(period);

    // Finished serialization.
  }
}

/// Account Report Profile Photo.
///
/// ID: `fa8cc6f5`.
class AccountReportProfilePhoto extends TlMethod<bool> {
  /// Account Report Profile Photo constructor.
  const AccountReportProfilePhoto({
    required this.peer,
    required this.photoId,
    required this.reason,
    required this.message,
  }) : super._();

  /// Deserialize.
  factory AccountReportProfilePhoto.deserialize(BinaryReader reader) {
    // Read [AccountReportProfilePhoto] fields.
    final peer = reader.readObject() as InputPeerBase;
    final photoId = reader.readObject() as InputPhotoBase;
    final reason = reader.readObject() as ReportReasonBase;
    final message = reader.readString();

    // Construct [AccountReportProfilePhoto] object.
    final returnValue = AccountReportProfilePhoto(
      peer: peer,
      photoId: photoId,
      reason: reason,
      message: message,
    );

    // Now return the deserialized [AccountReportProfilePhoto].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Photo Id.
  final InputPhotoBase photoId;

  /// Reason.
  final ReportReasonBase reason;

  /// Message.
  final String message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfa8cc6f5.
    buffer.writeInt32(0xfa8cc6f5);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(photoId);
    buffer.writeObject(reason);
    buffer.writeString(message);

    // Finished serialization.
  }
}

/// Channels Convert To Gigagroup.
///
/// ID: `0b290c69`.
class ChannelsConvertToGigagroup extends TlMethod<UpdatesBase> {
  /// Channels Convert To Gigagroup constructor.
  const ChannelsConvertToGigagroup({
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory ChannelsConvertToGigagroup.deserialize(BinaryReader reader) {
    // Read [ChannelsConvertToGigagroup] fields.
    final channel = reader.readObject() as InputChannelBase;

    // Construct [ChannelsConvertToGigagroup] object.
    final returnValue = ChannelsConvertToGigagroup(
      channel: channel,
    );

    // Now return the deserialized [ChannelsConvertToGigagroup].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0b290c69.
    buffer.writeInt32(0x0b290c69);

    // Write fields.
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Messages Check History Import Peer.
///
/// ID: `5dc60f03`.
class MessagesCheckHistoryImportPeer
    extends TlMethod<MessagesCheckedHistoryImportPeerBase> {
  /// Messages Check History Import Peer constructor.
  const MessagesCheckHistoryImportPeer({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesCheckHistoryImportPeer.deserialize(BinaryReader reader) {
    // Read [MessagesCheckHistoryImportPeer] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [MessagesCheckHistoryImportPeer] object.
    final returnValue = MessagesCheckHistoryImportPeer(
      peer: peer,
    );

    // Now return the deserialized [MessagesCheckHistoryImportPeer].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5dc60f03.
    buffer.writeInt32(0x5dc60f03);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Phone Toggle Group Call Record.
///
/// ID: `f128c708`.
class PhoneToggleGroupCallRecord extends TlMethod<UpdatesBase> {
  /// Phone Toggle Group Call Record constructor.
  const PhoneToggleGroupCallRecord({
    required this.start,
    required this.video,
    required this.call,
    this.title,
    required this.videoPortrait,
  }) : super._();

  /// Deserialize.
  factory PhoneToggleGroupCallRecord.deserialize(BinaryReader reader) {
    // Read [PhoneToggleGroupCallRecord] fields.
    final flags = reader.readInt32();
    final start = (flags & 1) != 0;
    final video = (flags & 4) != 0;
    final call = reader.readObject() as InputGroupCallBase;
    final hasTitleField = (flags & 2) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final videoPortrait = (flags & 4) != 0;

    // Construct [PhoneToggleGroupCallRecord] object.
    final returnValue = PhoneToggleGroupCallRecord(
      start: start,
      video: video,
      call: call,
      title: title,
      videoPortrait: videoPortrait,
    );

    // Now return the deserialized [PhoneToggleGroupCallRecord].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: start,
      b02: video || videoPortrait,
      b01: title != null,
    );

    return v;
  }

  /// start: bit 0 of flags.0?true
  final bool start;

  /// video: bit 2 of flags.2?true
  final bool video;

  /// Call.
  final InputGroupCallBase call;

  /// Title.
  final String? title;

  /// video_portrait: bit 2 of flags.2?Bool
  final bool videoPortrait;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf128c708.
    buffer.writeInt32(0xf128c708);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(call);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }

    // Finished serialization.
  }
}

/// Phone Edit Group Call Participant.
///
/// ID: `a5273abf`.
class PhoneEditGroupCallParticipant extends TlMethod<UpdatesBase> {
  /// Phone Edit Group Call Participant constructor.
  const PhoneEditGroupCallParticipant({
    required this.call,
    required this.participant,
    required this.muted,
    this.volume,
    required this.raiseHand,
    required this.videoStopped,
    required this.videoPaused,
    required this.presentationPaused,
  }) : super._();

  /// Deserialize.
  factory PhoneEditGroupCallParticipant.deserialize(BinaryReader reader) {
    // Read [PhoneEditGroupCallParticipant] fields.
    final flags = reader.readInt32();
    final call = reader.readObject() as InputGroupCallBase;
    final participant = reader.readObject() as InputPeerBase;
    final muted = (flags & 1) != 0;
    final hasVolumeField = (flags & 2) != 0;
    final volume = hasVolumeField ? reader.readInt32() : null;
    final raiseHand = (flags & 4) != 0;
    final videoStopped = (flags & 8) != 0;
    final videoPaused = (flags & 16) != 0;
    final presentationPaused = (flags & 32) != 0;

    // Construct [PhoneEditGroupCallParticipant] object.
    final returnValue = PhoneEditGroupCallParticipant(
      call: call,
      participant: participant,
      muted: muted,
      volume: volume,
      raiseHand: raiseHand,
      videoStopped: videoStopped,
      videoPaused: videoPaused,
      presentationPaused: presentationPaused,
    );

    // Now return the deserialized [PhoneEditGroupCallParticipant].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: muted,
      b01: volume != null,
      b02: raiseHand,
      b03: videoStopped,
      b04: videoPaused,
      b05: presentationPaused,
    );

    return v;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Participant.
  final InputPeerBase participant;

  /// muted: bit 0 of flags.0?Bool
  final bool muted;

  /// Volume.
  final int? volume;

  /// raise_hand: bit 2 of flags.2?Bool
  final bool raiseHand;

  /// video_stopped: bit 3 of flags.3?Bool
  final bool videoStopped;

  /// video_paused: bit 4 of flags.4?Bool
  final bool videoPaused;

  /// presentation_paused: bit 5 of flags.5?Bool
  final bool presentationPaused;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa5273abf.
    buffer.writeInt32(0xa5273abf);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(call);
    buffer.writeObject(participant);
    final localVolumeCopy = volume;
    if (localVolumeCopy != null) {
      buffer.writeInt32(localVolumeCopy);
    }

    // Finished serialization.
  }
}

/// Phone Edit Group Call Title.
///
/// ID: `1ca6ac0a`.
class PhoneEditGroupCallTitle extends TlMethod<UpdatesBase> {
  /// Phone Edit Group Call Title constructor.
  const PhoneEditGroupCallTitle({
    required this.call,
    required this.title,
  }) : super._();

  /// Deserialize.
  factory PhoneEditGroupCallTitle.deserialize(BinaryReader reader) {
    // Read [PhoneEditGroupCallTitle] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final title = reader.readString();

    // Construct [PhoneEditGroupCallTitle] object.
    final returnValue = PhoneEditGroupCallTitle(
      call: call,
      title: title,
    );

    // Now return the deserialized [PhoneEditGroupCallTitle].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Title.
  final String title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1ca6ac0a.
    buffer.writeInt32(0x1ca6ac0a);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeString(title);

    // Finished serialization.
  }
}

/// Phone Get Group Call Join As.
///
/// ID: `ef7c213a`.
class PhoneGetGroupCallJoinAs extends TlMethod<PhoneJoinAsPeersBase> {
  /// Phone Get Group Call Join As constructor.
  const PhoneGetGroupCallJoinAs({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory PhoneGetGroupCallJoinAs.deserialize(BinaryReader reader) {
    // Read [PhoneGetGroupCallJoinAs] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [PhoneGetGroupCallJoinAs] object.
    final returnValue = PhoneGetGroupCallJoinAs(
      peer: peer,
    );

    // Now return the deserialized [PhoneGetGroupCallJoinAs].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xef7c213a.
    buffer.writeInt32(0xef7c213a);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Phone Export Group Call Invite.
///
/// ID: `e6aa647f`.
class PhoneExportGroupCallInvite
    extends TlMethod<PhoneExportedGroupCallInviteBase> {
  /// Phone Export Group Call Invite constructor.
  const PhoneExportGroupCallInvite({
    required this.canSelfUnmute,
    required this.call,
  }) : super._();

  /// Deserialize.
  factory PhoneExportGroupCallInvite.deserialize(BinaryReader reader) {
    // Read [PhoneExportGroupCallInvite] fields.
    final flags = reader.readInt32();
    final canSelfUnmute = (flags & 1) != 0;
    final call = reader.readObject() as InputGroupCallBase;

    // Construct [PhoneExportGroupCallInvite] object.
    final returnValue = PhoneExportGroupCallInvite(
      canSelfUnmute: canSelfUnmute,
      call: call,
    );

    // Now return the deserialized [PhoneExportGroupCallInvite].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: canSelfUnmute,
    );

    return v;
  }

  /// can_self_unmute: bit 0 of flags.0?true
  final bool canSelfUnmute;

  /// Call.
  final InputGroupCallBase call;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe6aa647f.
    buffer.writeInt32(0xe6aa647f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(call);

    // Finished serialization.
  }
}

/// Phone Toggle Group Call Start Subscription.
///
/// ID: `219c34e6`.
class PhoneToggleGroupCallStartSubscription extends TlMethod<UpdatesBase> {
  /// Phone Toggle Group Call Start Subscription constructor.
  const PhoneToggleGroupCallStartSubscription({
    required this.call,
    required this.subscribed,
  }) : super._();

  /// Deserialize.
  factory PhoneToggleGroupCallStartSubscription.deserialize(
      BinaryReader reader) {
    // Read [PhoneToggleGroupCallStartSubscription] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final subscribed = reader.readBool();

    // Construct [PhoneToggleGroupCallStartSubscription] object.
    final returnValue = PhoneToggleGroupCallStartSubscription(
      call: call,
      subscribed: subscribed,
    );

    // Now return the deserialized [PhoneToggleGroupCallStartSubscription].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Subscribed.
  final bool subscribed;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x219c34e6.
    buffer.writeInt32(0x219c34e6);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeBool(subscribed);

    // Finished serialization.
  }
}

/// Phone Start Scheduled Group Call.
///
/// ID: `5680e342`.
class PhoneStartScheduledGroupCall extends TlMethod<UpdatesBase> {
  /// Phone Start Scheduled Group Call constructor.
  const PhoneStartScheduledGroupCall({
    required this.call,
  }) : super._();

  /// Deserialize.
  factory PhoneStartScheduledGroupCall.deserialize(BinaryReader reader) {
    // Read [PhoneStartScheduledGroupCall] fields.
    final call = reader.readObject() as InputGroupCallBase;

    // Construct [PhoneStartScheduledGroupCall] object.
    final returnValue = PhoneStartScheduledGroupCall(
      call: call,
    );

    // Now return the deserialized [PhoneStartScheduledGroupCall].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5680e342.
    buffer.writeInt32(0x5680e342);

    // Write fields.
    buffer.writeObject(call);

    // Finished serialization.
  }
}

/// Phone Save Default Group Call Join As.
///
/// ID: `575e1f8c`.
class PhoneSaveDefaultGroupCallJoinAs extends TlMethod<bool> {
  /// Phone Save Default Group Call Join As constructor.
  const PhoneSaveDefaultGroupCallJoinAs({
    required this.peer,
    required this.joinAs,
  }) : super._();

  /// Deserialize.
  factory PhoneSaveDefaultGroupCallJoinAs.deserialize(BinaryReader reader) {
    // Read [PhoneSaveDefaultGroupCallJoinAs] fields.
    final peer = reader.readObject() as InputPeerBase;
    final joinAs = reader.readObject() as InputPeerBase;

    // Construct [PhoneSaveDefaultGroupCallJoinAs] object.
    final returnValue = PhoneSaveDefaultGroupCallJoinAs(
      peer: peer,
      joinAs: joinAs,
    );

    // Now return the deserialized [PhoneSaveDefaultGroupCallJoinAs].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Join As.
  final InputPeerBase joinAs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x575e1f8c.
    buffer.writeInt32(0x575e1f8c);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(joinAs);

    // Finished serialization.
  }
}

/// Phone Join Group Call Presentation.
///
/// ID: `cbea6bc4`.
class PhoneJoinGroupCallPresentation extends TlMethod<UpdatesBase> {
  /// Phone Join Group Call Presentation constructor.
  const PhoneJoinGroupCallPresentation({
    required this.call,
    required this.params,
  }) : super._();

  /// Deserialize.
  factory PhoneJoinGroupCallPresentation.deserialize(BinaryReader reader) {
    // Read [PhoneJoinGroupCallPresentation] fields.
    final call = reader.readObject() as InputGroupCallBase;
    final params = reader.readObject() as DataJSONBase;

    // Construct [PhoneJoinGroupCallPresentation] object.
    final returnValue = PhoneJoinGroupCallPresentation(
      call: call,
      params: params,
    );

    // Now return the deserialized [PhoneJoinGroupCallPresentation].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Params.
  final DataJSONBase params;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xcbea6bc4.
    buffer.writeInt32(0xcbea6bc4);

    // Write fields.
    buffer.writeObject(call);
    buffer.writeObject(params);

    // Finished serialization.
  }
}

/// Phone Leave Group Call Presentation.
///
/// ID: `1c50d144`.
class PhoneLeaveGroupCallPresentation extends TlMethod<UpdatesBase> {
  /// Phone Leave Group Call Presentation constructor.
  const PhoneLeaveGroupCallPresentation({
    required this.call,
  }) : super._();

  /// Deserialize.
  factory PhoneLeaveGroupCallPresentation.deserialize(BinaryReader reader) {
    // Read [PhoneLeaveGroupCallPresentation] fields.
    final call = reader.readObject() as InputGroupCallBase;

    // Construct [PhoneLeaveGroupCallPresentation] object.
    final returnValue = PhoneLeaveGroupCallPresentation(
      call: call,
    );

    // Now return the deserialized [PhoneLeaveGroupCallPresentation].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1c50d144.
    buffer.writeInt32(0x1c50d144);

    // Write fields.
    buffer.writeObject(call);

    // Finished serialization.
  }
}

/// Stickers Check Short Name.
///
/// ID: `284b3639`.
class StickersCheckShortName extends TlMethod<bool> {
  /// Stickers Check Short Name constructor.
  const StickersCheckShortName({
    required this.shortName,
  }) : super._();

  /// Deserialize.
  factory StickersCheckShortName.deserialize(BinaryReader reader) {
    // Read [StickersCheckShortName] fields.
    final shortName = reader.readString();

    // Construct [StickersCheckShortName] object.
    final returnValue = StickersCheckShortName(
      shortName: shortName,
    );

    // Now return the deserialized [StickersCheckShortName].
    return returnValue;
  }

  /// Short Name.
  final String shortName;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x284b3639.
    buffer.writeInt32(0x284b3639);

    // Write fields.
    buffer.writeString(shortName);

    // Finished serialization.
  }
}

/// Stickers Suggest Short Name.
///
/// ID: `4dafc503`.
class StickersSuggestShortName
    extends TlMethod<StickersSuggestedShortNameBase> {
  /// Stickers Suggest Short Name constructor.
  const StickersSuggestShortName({
    required this.title,
  }) : super._();

  /// Deserialize.
  factory StickersSuggestShortName.deserialize(BinaryReader reader) {
    // Read [StickersSuggestShortName] fields.
    final title = reader.readString();

    // Construct [StickersSuggestShortName] object.
    final returnValue = StickersSuggestShortName(
      title: title,
    );

    // Now return the deserialized [StickersSuggestShortName].
    return returnValue;
  }

  /// Title.
  final String title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4dafc503.
    buffer.writeInt32(0x4dafc503);

    // Write fields.
    buffer.writeString(title);

    // Finished serialization.
  }
}

/// Bots Reset Bot Commands.
///
/// ID: `3d8de0f9`.
class BotsResetBotCommands extends TlMethod<bool> {
  /// Bots Reset Bot Commands constructor.
  const BotsResetBotCommands({
    required this.scope,
    required this.langCode,
  }) : super._();

  /// Deserialize.
  factory BotsResetBotCommands.deserialize(BinaryReader reader) {
    // Read [BotsResetBotCommands] fields.
    final scope = reader.readObject() as BotCommandScopeBase;
    final langCode = reader.readString();

    // Construct [BotsResetBotCommands] object.
    final returnValue = BotsResetBotCommands(
      scope: scope,
      langCode: langCode,
    );

    // Now return the deserialized [BotsResetBotCommands].
    return returnValue;
  }

  /// Scope.
  final BotCommandScopeBase scope;

  /// Lang Code.
  final String langCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3d8de0f9.
    buffer.writeInt32(0x3d8de0f9);

    // Write fields.
    buffer.writeObject(scope);
    buffer.writeString(langCode);

    // Finished serialization.
  }
}

/// Bots Get Bot Commands.
///
/// ID: `e34c0dd6`.
class BotsGetBotCommands extends TlMethod<List<BotCommandBase>> {
  /// Bots Get Bot Commands constructor.
  const BotsGetBotCommands({
    required this.scope,
    required this.langCode,
  }) : super._();

  /// Deserialize.
  factory BotsGetBotCommands.deserialize(BinaryReader reader) {
    // Read [BotsGetBotCommands] fields.
    final scope = reader.readObject() as BotCommandScopeBase;
    final langCode = reader.readString();

    // Construct [BotsGetBotCommands] object.
    final returnValue = BotsGetBotCommands(
      scope: scope,
      langCode: langCode,
    );

    // Now return the deserialized [BotsGetBotCommands].
    return returnValue;
  }

  /// Scope.
  final BotCommandScopeBase scope;

  /// Lang Code.
  final String langCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe34c0dd6.
    buffer.writeInt32(0xe34c0dd6);

    // Write fields.
    buffer.writeObject(scope);
    buffer.writeString(langCode);

    // Finished serialization.
  }
}

/// Account Reset Password.
///
/// ID: `9308ce1b`.
class AccountResetPassword extends TlMethod<AccountResetPasswordResultBase> {
  /// Account Reset Password constructor.
  const AccountResetPassword() : super._();

  /// Deserialize.
  factory AccountResetPassword.deserialize(BinaryReader reader) {
    // Construct [AccountResetPassword] object.
    final returnValue = AccountResetPassword();

    // Now return the deserialized [AccountResetPassword].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9308ce1b.
    buffer.writeInt32(0x9308ce1b);

    // Finished serialization.
  }
}

/// Account Decline Password Reset.
///
/// ID: `4c9409f6`.
class AccountDeclinePasswordReset extends TlMethod<bool> {
  /// Account Decline Password Reset constructor.
  const AccountDeclinePasswordReset() : super._();

  /// Deserialize.
  factory AccountDeclinePasswordReset.deserialize(BinaryReader reader) {
    // Construct [AccountDeclinePasswordReset] object.
    final returnValue = AccountDeclinePasswordReset();

    // Now return the deserialized [AccountDeclinePasswordReset].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4c9409f6.
    buffer.writeInt32(0x4c9409f6);

    // Finished serialization.
  }
}

/// Auth Check Recovery Password.
///
/// ID: `0d36bf79`.
class AuthCheckRecoveryPassword extends TlMethod<bool> {
  /// Auth Check Recovery Password constructor.
  const AuthCheckRecoveryPassword({
    required this.code,
  }) : super._();

  /// Deserialize.
  factory AuthCheckRecoveryPassword.deserialize(BinaryReader reader) {
    // Read [AuthCheckRecoveryPassword] fields.
    final code = reader.readString();

    // Construct [AuthCheckRecoveryPassword] object.
    final returnValue = AuthCheckRecoveryPassword(
      code: code,
    );

    // Now return the deserialized [AuthCheckRecoveryPassword].
    return returnValue;
  }

  /// Code.
  final String code;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0d36bf79.
    buffer.writeInt32(0x0d36bf79);

    // Write fields.
    buffer.writeString(code);

    // Finished serialization.
  }
}

/// Account Get Chat Themes.
///
/// ID: `d638de89`.
class AccountGetChatThemes extends TlMethod<AccountThemesBase> {
  /// Account Get Chat Themes constructor.
  const AccountGetChatThemes({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetChatThemes.deserialize(BinaryReader reader) {
    // Read [AccountGetChatThemes] fields.
    final hash = reader.readInt64();

    // Construct [AccountGetChatThemes] object.
    final returnValue = AccountGetChatThemes(
      hash: hash,
    );

    // Now return the deserialized [AccountGetChatThemes].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd638de89.
    buffer.writeInt32(0xd638de89);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Set Chat Theme.
///
/// ID: `e63be13f`.
class MessagesSetChatTheme extends TlMethod<UpdatesBase> {
  /// Messages Set Chat Theme constructor.
  const MessagesSetChatTheme({
    required this.peer,
    required this.emoticon,
  }) : super._();

  /// Deserialize.
  factory MessagesSetChatTheme.deserialize(BinaryReader reader) {
    // Read [MessagesSetChatTheme] fields.
    final peer = reader.readObject() as InputPeerBase;
    final emoticon = reader.readString();

    // Construct [MessagesSetChatTheme] object.
    final returnValue = MessagesSetChatTheme(
      peer: peer,
      emoticon: emoticon,
    );

    // Now return the deserialized [MessagesSetChatTheme].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Emoticon.
  final String emoticon;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe63be13f.
    buffer.writeInt32(0xe63be13f);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeString(emoticon);

    // Finished serialization.
  }
}

/// Channels View Sponsored Message.
///
/// ID: `beaedb94`.
class ChannelsViewSponsoredMessage extends TlMethod<bool> {
  /// Channels View Sponsored Message constructor.
  const ChannelsViewSponsoredMessage({
    required this.channel,
    required this.randomId,
  }) : super._();

  /// Deserialize.
  factory ChannelsViewSponsoredMessage.deserialize(BinaryReader reader) {
    // Read [ChannelsViewSponsoredMessage] fields.
    final channel = reader.readObject() as InputChannelBase;
    final randomId = reader.readBytes();

    // Construct [ChannelsViewSponsoredMessage] object.
    final returnValue = ChannelsViewSponsoredMessage(
      channel: channel,
      randomId: randomId,
    );

    // Now return the deserialized [ChannelsViewSponsoredMessage].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Random Id.
  final Uint8List randomId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbeaedb94.
    buffer.writeInt32(0xbeaedb94);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeBytes(randomId);

    // Finished serialization.
  }
}

/// Channels Get Sponsored Messages.
///
/// ID: `ec210fbf`.
class ChannelsGetSponsoredMessages
    extends TlMethod<MessagesSponsoredMessagesBase> {
  /// Channels Get Sponsored Messages constructor.
  const ChannelsGetSponsoredMessages({
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetSponsoredMessages.deserialize(BinaryReader reader) {
    // Read [ChannelsGetSponsoredMessages] fields.
    final channel = reader.readObject() as InputChannelBase;

    // Construct [ChannelsGetSponsoredMessages] object.
    final returnValue = ChannelsGetSponsoredMessages(
      channel: channel,
    );

    // Now return the deserialized [ChannelsGetSponsoredMessages].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xec210fbf.
    buffer.writeInt32(0xec210fbf);

    // Write fields.
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Messages Get Message Read Participants.
///
/// ID: `31c1c44f`.
class MessagesGetMessageReadParticipants
    extends TlMethod<List<ReadParticipantDateBase>> {
  /// Messages Get Message Read Participants constructor.
  const MessagesGetMessageReadParticipants({
    required this.peer,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory MessagesGetMessageReadParticipants.deserialize(BinaryReader reader) {
    // Read [MessagesGetMessageReadParticipants] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();

    // Construct [MessagesGetMessageReadParticipants] object.
    final returnValue = MessagesGetMessageReadParticipants(
      peer: peer,
      msgId: msgId,
    );

    // Now return the deserialized [MessagesGetMessageReadParticipants].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x31c1c44f.
    buffer.writeInt32(0x31c1c44f);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Messages Get Search Results Calendar.
///
/// ID: `6aa3f6bd`.
class MessagesGetSearchResultsCalendar
    extends TlMethod<MessagesSearchResultsCalendarBase> {
  /// Messages Get Search Results Calendar constructor.
  const MessagesGetSearchResultsCalendar({
    required this.peer,
    this.savedPeerId,
    required this.filter,
    required this.offsetId,
    required this.offsetDate,
  }) : super._();

  /// Deserialize.
  factory MessagesGetSearchResultsCalendar.deserialize(BinaryReader reader) {
    // Read [MessagesGetSearchResultsCalendar] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final hasSavedPeerIdField = (flags & 4) != 0;
    final savedPeerId =
        hasSavedPeerIdField ? reader.readObject() as InputPeerBase : null;
    final filter = reader.readObject() as MessagesFilterBase;
    final offsetId = reader.readInt32();
    final offsetDate = reader.readDateTime();

    // Construct [MessagesGetSearchResultsCalendar] object.
    final returnValue = MessagesGetSearchResultsCalendar(
      peer: peer,
      savedPeerId: savedPeerId,
      filter: filter,
      offsetId: offsetId,
      offsetDate: offsetDate,
    );

    // Now return the deserialized [MessagesGetSearchResultsCalendar].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: savedPeerId != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Saved Peer Id.
  final InputPeerBase? savedPeerId;

  /// Filter.
  final MessagesFilterBase filter;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Offset Date.
  final DateTime offsetDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6aa3f6bd.
    buffer.writeInt32(0x6aa3f6bd);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localSavedPeerIdCopy = savedPeerId;
    if (localSavedPeerIdCopy != null) {
      buffer.writeObject(localSavedPeerIdCopy);
    }
    buffer.writeObject(filter);
    buffer.writeInt32(offsetId);
    buffer.writeDateTime(offsetDate);

    // Finished serialization.
  }
}

/// Messages Get Search Results Positions.
///
/// ID: `9c7f2f10`.
class MessagesGetSearchResultsPositions
    extends TlMethod<MessagesSearchResultsPositionsBase> {
  /// Messages Get Search Results Positions constructor.
  const MessagesGetSearchResultsPositions({
    required this.peer,
    this.savedPeerId,
    required this.filter,
    required this.offsetId,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory MessagesGetSearchResultsPositions.deserialize(BinaryReader reader) {
    // Read [MessagesGetSearchResultsPositions] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final hasSavedPeerIdField = (flags & 4) != 0;
    final savedPeerId =
        hasSavedPeerIdField ? reader.readObject() as InputPeerBase : null;
    final filter = reader.readObject() as MessagesFilterBase;
    final offsetId = reader.readInt32();
    final limit = reader.readInt32();

    // Construct [MessagesGetSearchResultsPositions] object.
    final returnValue = MessagesGetSearchResultsPositions(
      peer: peer,
      savedPeerId: savedPeerId,
      filter: filter,
      offsetId: offsetId,
      limit: limit,
    );

    // Now return the deserialized [MessagesGetSearchResultsPositions].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: savedPeerId != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Saved Peer Id.
  final InputPeerBase? savedPeerId;

  /// Filter.
  final MessagesFilterBase filter;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9c7f2f10.
    buffer.writeInt32(0x9c7f2f10);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localSavedPeerIdCopy = savedPeerId;
    if (localSavedPeerIdCopy != null) {
      buffer.writeObject(localSavedPeerIdCopy);
    }
    buffer.writeObject(filter);
    buffer.writeInt32(offsetId);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Messages Hide Chat Join Request.
///
/// ID: `7fe7e815`.
class MessagesHideChatJoinRequest extends TlMethod<UpdatesBase> {
  /// Messages Hide Chat Join Request constructor.
  const MessagesHideChatJoinRequest({
    required this.approved,
    required this.peer,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory MessagesHideChatJoinRequest.deserialize(BinaryReader reader) {
    // Read [MessagesHideChatJoinRequest] fields.
    final flags = reader.readInt32();
    final approved = (flags & 1) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final userId = reader.readObject() as InputUserBase;

    // Construct [MessagesHideChatJoinRequest] object.
    final returnValue = MessagesHideChatJoinRequest(
      approved: approved,
      peer: peer,
      userId: userId,
    );

    // Now return the deserialized [MessagesHideChatJoinRequest].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: approved,
    );

    return v;
  }

  /// approved: bit 0 of flags.0?true
  final bool approved;

  /// Peer.
  final InputPeerBase peer;

  /// User Id.
  final InputUserBase userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7fe7e815.
    buffer.writeInt32(0x7fe7e815);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeObject(userId);

    // Finished serialization.
  }
}

/// Messages Hide All Chat Join Requests.
///
/// ID: `e085f4ea`.
class MessagesHideAllChatJoinRequests extends TlMethod<UpdatesBase> {
  /// Messages Hide All Chat Join Requests constructor.
  const MessagesHideAllChatJoinRequests({
    required this.approved,
    required this.peer,
    this.link,
  }) : super._();

  /// Deserialize.
  factory MessagesHideAllChatJoinRequests.deserialize(BinaryReader reader) {
    // Read [MessagesHideAllChatJoinRequests] fields.
    final flags = reader.readInt32();
    final approved = (flags & 1) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final hasLinkField = (flags & 2) != 0;
    final link = hasLinkField ? reader.readString() : null;

    // Construct [MessagesHideAllChatJoinRequests] object.
    final returnValue = MessagesHideAllChatJoinRequests(
      approved: approved,
      peer: peer,
      link: link,
    );

    // Now return the deserialized [MessagesHideAllChatJoinRequests].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: approved,
      b01: link != null,
    );

    return v;
  }

  /// approved: bit 0 of flags.0?true
  final bool approved;

  /// Peer.
  final InputPeerBase peer;

  /// Link.
  final String? link;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe085f4ea.
    buffer.writeInt32(0xe085f4ea);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localLinkCopy = link;
    if (localLinkCopy != null) {
      buffer.writeString(localLinkCopy);
    }

    // Finished serialization.
  }
}

/// Messages Toggle No Forwards.
///
/// ID: `b11eafa2`.
class MessagesToggleNoForwards extends TlMethod<UpdatesBase> {
  /// Messages Toggle No Forwards constructor.
  const MessagesToggleNoForwards({
    required this.peer,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory MessagesToggleNoForwards.deserialize(BinaryReader reader) {
    // Read [MessagesToggleNoForwards] fields.
    final peer = reader.readObject() as InputPeerBase;
    final enabled = reader.readBool();

    // Construct [MessagesToggleNoForwards] object.
    final returnValue = MessagesToggleNoForwards(
      peer: peer,
      enabled: enabled,
    );

    // Now return the deserialized [MessagesToggleNoForwards].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb11eafa2.
    buffer.writeInt32(0xb11eafa2);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Messages Save Default Send As.
///
/// ID: `ccfddf96`.
class MessagesSaveDefaultSendAs extends TlMethod<bool> {
  /// Messages Save Default Send As constructor.
  const MessagesSaveDefaultSendAs({
    required this.peer,
    required this.sendAs,
  }) : super._();

  /// Deserialize.
  factory MessagesSaveDefaultSendAs.deserialize(BinaryReader reader) {
    // Read [MessagesSaveDefaultSendAs] fields.
    final peer = reader.readObject() as InputPeerBase;
    final sendAs = reader.readObject() as InputPeerBase;

    // Construct [MessagesSaveDefaultSendAs] object.
    final returnValue = MessagesSaveDefaultSendAs(
      peer: peer,
      sendAs: sendAs,
    );

    // Now return the deserialized [MessagesSaveDefaultSendAs].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Send As.
  final InputPeerBase sendAs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xccfddf96.
    buffer.writeInt32(0xccfddf96);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(sendAs);

    // Finished serialization.
  }
}

/// Channels Get Send As.
///
/// ID: `0dc770ee`.
class ChannelsGetSendAs extends TlMethod<ChannelsSendAsPeersBase> {
  /// Channels Get Send As constructor.
  const ChannelsGetSendAs({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetSendAs.deserialize(BinaryReader reader) {
    // Read [ChannelsGetSendAs] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [ChannelsGetSendAs] object.
    final returnValue = ChannelsGetSendAs(
      peer: peer,
    );

    // Now return the deserialized [ChannelsGetSendAs].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0dc770ee.
    buffer.writeInt32(0x0dc770ee);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Account Set Authorization T T L.
///
/// ID: `bf899aa0`.
class AccountSetAuthorizationTTL extends TlMethod<bool> {
  /// Account Set Authorization T T L constructor.
  const AccountSetAuthorizationTTL({
    required this.authorizationTtlDays,
  }) : super._();

  /// Deserialize.
  factory AccountSetAuthorizationTTL.deserialize(BinaryReader reader) {
    // Read [AccountSetAuthorizationTTL] fields.
    final authorizationTtlDays = reader.readInt32();

    // Construct [AccountSetAuthorizationTTL] object.
    final returnValue = AccountSetAuthorizationTTL(
      authorizationTtlDays: authorizationTtlDays,
    );

    // Now return the deserialized [AccountSetAuthorizationTTL].
    return returnValue;
  }

  /// Authorization Ttl Days.
  ///
  /// Field type is Int32.
  final int authorizationTtlDays;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbf899aa0.
    buffer.writeInt32(0xbf899aa0);

    // Write fields.
    buffer.writeInt32(authorizationTtlDays);

    // Finished serialization.
  }
}

/// Account Change Authorization Settings.
///
/// ID: `40f48462`.
class AccountChangeAuthorizationSettings extends TlMethod<bool> {
  /// Account Change Authorization Settings constructor.
  const AccountChangeAuthorizationSettings({
    required this.confirmed,
    required this.hash,
    required this.encryptedRequestsDisabled,
    required this.callRequestsDisabled,
  }) : super._();

  /// Deserialize.
  factory AccountChangeAuthorizationSettings.deserialize(BinaryReader reader) {
    // Read [AccountChangeAuthorizationSettings] fields.
    final flags = reader.readInt32();
    final confirmed = (flags & 8) != 0;
    final hash = reader.readInt64();
    final encryptedRequestsDisabled = (flags & 1) != 0;
    final callRequestsDisabled = (flags & 2) != 0;

    // Construct [AccountChangeAuthorizationSettings] object.
    final returnValue = AccountChangeAuthorizationSettings(
      confirmed: confirmed,
      hash: hash,
      encryptedRequestsDisabled: encryptedRequestsDisabled,
      callRequestsDisabled: callRequestsDisabled,
    );

    // Now return the deserialized [AccountChangeAuthorizationSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: confirmed,
      b00: encryptedRequestsDisabled,
      b01: callRequestsDisabled,
    );

    return v;
  }

  /// confirmed: bit 3 of flags.3?true
  final bool confirmed;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// encrypted_requests_disabled: bit 0 of flags.0?Bool
  final bool encryptedRequestsDisabled;

  /// call_requests_disabled: bit 1 of flags.1?Bool
  final bool callRequestsDisabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x40f48462.
    buffer.writeInt32(0x40f48462);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Channels Delete Participant History.
///
/// ID: `367544db`.
class ChannelsDeleteParticipantHistory
    extends TlMethod<MessagesAffectedHistoryBase> {
  /// Channels Delete Participant History constructor.
  const ChannelsDeleteParticipantHistory({
    required this.channel,
    required this.participant,
  }) : super._();

  /// Deserialize.
  factory ChannelsDeleteParticipantHistory.deserialize(BinaryReader reader) {
    // Read [ChannelsDeleteParticipantHistory] fields.
    final channel = reader.readObject() as InputChannelBase;
    final participant = reader.readObject() as InputPeerBase;

    // Construct [ChannelsDeleteParticipantHistory] object.
    final returnValue = ChannelsDeleteParticipantHistory(
      channel: channel,
      participant: participant,
    );

    // Now return the deserialized [ChannelsDeleteParticipantHistory].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Participant.
  final InputPeerBase participant;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x367544db.
    buffer.writeInt32(0x367544db);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(participant);

    // Finished serialization.
  }
}

/// Messages Send Reaction.
///
/// ID: `d30d78d4`.
class MessagesSendReaction extends TlMethod<UpdatesBase> {
  /// Messages Send Reaction constructor.
  const MessagesSendReaction({
    required this.big,
    required this.addToRecent,
    required this.peer,
    required this.msgId,
    this.reaction,
  }) : super._();

  /// Deserialize.
  factory MessagesSendReaction.deserialize(BinaryReader reader) {
    // Read [MessagesSendReaction] fields.
    final flags = reader.readInt32();
    final big = (flags & 2) != 0;
    final addToRecent = (flags & 4) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final hasReactionField = (flags & 1) != 0;
    final reaction =
        hasReactionField ? reader.readVectorObject<ReactionBase>() : null;

    // Construct [MessagesSendReaction] object.
    final returnValue = MessagesSendReaction(
      big: big,
      addToRecent: addToRecent,
      peer: peer,
      msgId: msgId,
      reaction: reaction,
    );

    // Now return the deserialized [MessagesSendReaction].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: big,
      b02: addToRecent,
      b00: reaction != null,
    );

    return v;
  }

  /// big: bit 1 of flags.1?true
  final bool big;

  /// add_to_recent: bit 2 of flags.2?true
  final bool addToRecent;

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Reaction.
  final List<ReactionBase>? reaction;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd30d78d4.
    buffer.writeInt32(0xd30d78d4);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    final localReactionCopy = reaction;
    if (localReactionCopy != null) {
      buffer.writeVectorObject(localReactionCopy);
    }

    // Finished serialization.
  }
}

/// Messages Get Messages Reactions.
///
/// ID: `8bba90e6`.
class MessagesGetMessagesReactions extends TlMethod<UpdatesBase> {
  /// Messages Get Messages Reactions constructor.
  const MessagesGetMessagesReactions({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesGetMessagesReactions.deserialize(BinaryReader reader) {
    // Read [MessagesGetMessagesReactions] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();

    // Construct [MessagesGetMessagesReactions] object.
    final returnValue = MessagesGetMessagesReactions(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [MessagesGetMessagesReactions].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8bba90e6.
    buffer.writeInt32(0x8bba90e6);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Messages Get Message Reactions List.
///
/// ID: `461b3f48`.
class MessagesGetMessageReactionsList
    extends TlMethod<MessagesMessageReactionsListBase> {
  /// Messages Get Message Reactions List constructor.
  const MessagesGetMessageReactionsList({
    required this.peer,
    required this.id,
    this.reaction,
    this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory MessagesGetMessageReactionsList.deserialize(BinaryReader reader) {
    // Read [MessagesGetMessageReactionsList] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();
    final hasReactionField = (flags & 1) != 0;
    final reaction =
        hasReactionField ? reader.readObject() as ReactionBase : null;
    final hasOffsetField = (flags & 2) != 0;
    final offset = hasOffsetField ? reader.readString() : null;
    final limit = reader.readInt32();

    // Construct [MessagesGetMessageReactionsList] object.
    final returnValue = MessagesGetMessageReactionsList(
      peer: peer,
      id: id,
      reaction: reaction,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [MessagesGetMessageReactionsList].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: reaction != null,
      b01: offset != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Reaction.
  final ReactionBase? reaction;

  /// Offset.
  final String? offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x461b3f48.
    buffer.writeInt32(0x461b3f48);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    final localReactionCopy = reaction;
    if (localReactionCopy != null) {
      buffer.writeObject(localReactionCopy);
    }
    final localOffsetCopy = offset;
    if (localOffsetCopy != null) {
      buffer.writeString(localOffsetCopy);
    }
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Messages Set Chat Available Reactions.
///
/// ID: `feb16771`.
class MessagesSetChatAvailableReactions extends TlMethod<UpdatesBase> {
  /// Messages Set Chat Available Reactions constructor.
  const MessagesSetChatAvailableReactions({
    required this.peer,
    required this.availableReactions,
  }) : super._();

  /// Deserialize.
  factory MessagesSetChatAvailableReactions.deserialize(BinaryReader reader) {
    // Read [MessagesSetChatAvailableReactions] fields.
    final peer = reader.readObject() as InputPeerBase;
    final availableReactions = reader.readObject() as ChatReactionsBase;

    // Construct [MessagesSetChatAvailableReactions] object.
    final returnValue = MessagesSetChatAvailableReactions(
      peer: peer,
      availableReactions: availableReactions,
    );

    // Now return the deserialized [MessagesSetChatAvailableReactions].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Available Reactions.
  final ChatReactionsBase availableReactions;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfeb16771.
    buffer.writeInt32(0xfeb16771);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(availableReactions);

    // Finished serialization.
  }
}

/// Messages Get Available Reactions.
///
/// ID: `18dea0ac`.
class MessagesGetAvailableReactions
    extends TlMethod<MessagesAvailableReactionsBase> {
  /// Messages Get Available Reactions constructor.
  const MessagesGetAvailableReactions({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetAvailableReactions.deserialize(BinaryReader reader) {
    // Read [MessagesGetAvailableReactions] fields.
    final hash = reader.readInt32();

    // Construct [MessagesGetAvailableReactions] object.
    final returnValue = MessagesGetAvailableReactions(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetAvailableReactions].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x18dea0ac.
    buffer.writeInt32(0x18dea0ac);

    // Write fields.
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Messages Set Default Reaction.
///
/// ID: `4f47a016`.
class MessagesSetDefaultReaction extends TlMethod<bool> {
  /// Messages Set Default Reaction constructor.
  const MessagesSetDefaultReaction({
    required this.reaction,
  }) : super._();

  /// Deserialize.
  factory MessagesSetDefaultReaction.deserialize(BinaryReader reader) {
    // Read [MessagesSetDefaultReaction] fields.
    final reaction = reader.readObject() as ReactionBase;

    // Construct [MessagesSetDefaultReaction] object.
    final returnValue = MessagesSetDefaultReaction(
      reaction: reaction,
    );

    // Now return the deserialized [MessagesSetDefaultReaction].
    return returnValue;
  }

  /// Reaction.
  final ReactionBase reaction;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4f47a016.
    buffer.writeInt32(0x4f47a016);

    // Write fields.
    buffer.writeObject(reaction);

    // Finished serialization.
  }
}

/// Messages Translate Text.
///
/// ID: `63183030`.
class MessagesTranslateText extends TlMethod<MessagesTranslatedTextBase> {
  /// Messages Translate Text constructor.
  const MessagesTranslateText({
    this.peer,
    this.id,
    this.text,
    required this.toLang,
  }) : super._();

  /// Deserialize.
  factory MessagesTranslateText.deserialize(BinaryReader reader) {
    // Read [MessagesTranslateText] fields.
    final flags = reader.readInt32();
    final hasPeerField = (flags & 1) != 0;
    final peer = hasPeerField ? reader.readObject() as InputPeerBase : null;
    final hasIdField = (flags & 1) != 0;
    final id = hasIdField ? reader.readVectorInt32() : null;
    final hasTextField = (flags & 2) != 0;
    final text =
        hasTextField ? reader.readVectorObject<TextWithEntitiesBase>() : null;
    final toLang = reader.readString();

    // Construct [MessagesTranslateText] object.
    final returnValue = MessagesTranslateText(
      peer: peer,
      id: id,
      text: text,
      toLang: toLang,
    );

    // Now return the deserialized [MessagesTranslateText].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: peer != null || id != null,
      b01: text != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase? peer;

  /// Id.
  final List<int>? id;

  /// Text.
  final List<TextWithEntitiesBase>? text;

  /// To Lang.
  final String toLang;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x63183030.
    buffer.writeInt32(0x63183030);

    // Write fields.
    buffer.writeInt32(flags);
    final localPeerCopy = peer;
    if (localPeerCopy != null) {
      buffer.writeObject(localPeerCopy);
    }
    final localIdCopy = id;
    if (localIdCopy != null) {
      buffer.writeVectorInt32(localIdCopy);
    }
    final localTextCopy = text;
    if (localTextCopy != null) {
      buffer.writeVectorObject(localTextCopy);
    }
    buffer.writeString(toLang);

    // Finished serialization.
  }
}

/// Messages Get Unread Reactions.
///
/// ID: `3223495b`.
class MessagesGetUnreadReactions extends TlMethod<MessagesMessagesBase> {
  /// Messages Get Unread Reactions constructor.
  const MessagesGetUnreadReactions({
    required this.peer,
    this.topMsgId,
    required this.offsetId,
    required this.addOffset,
    required this.limit,
    required this.maxId,
    required this.minId,
  }) : super._();

  /// Deserialize.
  factory MessagesGetUnreadReactions.deserialize(BinaryReader reader) {
    // Read [MessagesGetUnreadReactions] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;
    final offsetId = reader.readInt32();
    final addOffset = reader.readInt32();
    final limit = reader.readInt32();
    final maxId = reader.readInt32();
    final minId = reader.readInt32();

    // Construct [MessagesGetUnreadReactions] object.
    final returnValue = MessagesGetUnreadReactions(
      peer: peer,
      topMsgId: topMsgId,
      offsetId: offsetId,
      addOffset: addOffset,
      limit: limit,
      maxId: maxId,
      minId: minId,
    );

    // Now return the deserialized [MessagesGetUnreadReactions].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Top Msg Id.
  final int? topMsgId;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Add Offset.
  ///
  /// Field type is Int32.
  final int addOffset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Min Id.
  ///
  /// Field type is Int32.
  final int minId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3223495b.
    buffer.writeInt32(0x3223495b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }
    buffer.writeInt32(offsetId);
    buffer.writeInt32(addOffset);
    buffer.writeInt32(limit);
    buffer.writeInt32(maxId);
    buffer.writeInt32(minId);

    // Finished serialization.
  }
}

/// Messages Read Reactions.
///
/// ID: `54aa7f8e`.
class MessagesReadReactions extends TlMethod<MessagesAffectedHistoryBase> {
  /// Messages Read Reactions constructor.
  const MessagesReadReactions({
    required this.peer,
    this.topMsgId,
  }) : super._();

  /// Deserialize.
  factory MessagesReadReactions.deserialize(BinaryReader reader) {
    // Read [MessagesReadReactions] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final hasTopMsgIdField = (flags & 1) != 0;
    final topMsgId = hasTopMsgIdField ? reader.readInt32() : null;

    // Construct [MessagesReadReactions] object.
    final returnValue = MessagesReadReactions(
      peer: peer,
      topMsgId: topMsgId,
    );

    // Now return the deserialized [MessagesReadReactions].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: topMsgId != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Top Msg Id.
  final int? topMsgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x54aa7f8e.
    buffer.writeInt32(0x54aa7f8e);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localTopMsgIdCopy = topMsgId;
    if (localTopMsgIdCopy != null) {
      buffer.writeInt32(localTopMsgIdCopy);
    }

    // Finished serialization.
  }
}

/// Contacts Resolve Phone.
///
/// ID: `8af94344`.
class ContactsResolvePhone extends TlMethod<ContactsResolvedPeerBase> {
  /// Contacts Resolve Phone constructor.
  const ContactsResolvePhone({
    required this.phone,
  }) : super._();

  /// Deserialize.
  factory ContactsResolvePhone.deserialize(BinaryReader reader) {
    // Read [ContactsResolvePhone] fields.
    final phone = reader.readString();

    // Construct [ContactsResolvePhone] object.
    final returnValue = ContactsResolvePhone(
      phone: phone,
    );

    // Now return the deserialized [ContactsResolvePhone].
    return returnValue;
  }

  /// Phone.
  final String phone;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8af94344.
    buffer.writeInt32(0x8af94344);

    // Write fields.
    buffer.writeString(phone);

    // Finished serialization.
  }
}

/// Phone Get Group Call Stream Channels.
///
/// ID: `1ab21940`.
class PhoneGetGroupCallStreamChannels
    extends TlMethod<PhoneGroupCallStreamChannelsBase> {
  /// Phone Get Group Call Stream Channels constructor.
  const PhoneGetGroupCallStreamChannels({
    required this.call,
  }) : super._();

  /// Deserialize.
  factory PhoneGetGroupCallStreamChannels.deserialize(BinaryReader reader) {
    // Read [PhoneGetGroupCallStreamChannels] fields.
    final call = reader.readObject() as InputGroupCallBase;

    // Construct [PhoneGetGroupCallStreamChannels] object.
    final returnValue = PhoneGetGroupCallStreamChannels(
      call: call,
    );

    // Now return the deserialized [PhoneGetGroupCallStreamChannels].
    return returnValue;
  }

  /// Call.
  final InputGroupCallBase call;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1ab21940.
    buffer.writeInt32(0x1ab21940);

    // Write fields.
    buffer.writeObject(call);

    // Finished serialization.
  }
}

/// Phone Get Group Call Stream Rtmp Url.
///
/// ID: `deb3abbf`.
class PhoneGetGroupCallStreamRtmpUrl
    extends TlMethod<PhoneGroupCallStreamRtmpUrlBase> {
  /// Phone Get Group Call Stream Rtmp Url constructor.
  const PhoneGetGroupCallStreamRtmpUrl({
    required this.peer,
    required this.revoke,
  }) : super._();

  /// Deserialize.
  factory PhoneGetGroupCallStreamRtmpUrl.deserialize(BinaryReader reader) {
    // Read [PhoneGetGroupCallStreamRtmpUrl] fields.
    final peer = reader.readObject() as InputPeerBase;
    final revoke = reader.readBool();

    // Construct [PhoneGetGroupCallStreamRtmpUrl] object.
    final returnValue = PhoneGetGroupCallStreamRtmpUrl(
      peer: peer,
      revoke: revoke,
    );

    // Now return the deserialized [PhoneGetGroupCallStreamRtmpUrl].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Revoke.
  final bool revoke;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdeb3abbf.
    buffer.writeInt32(0xdeb3abbf);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeBool(revoke);

    // Finished serialization.
  }
}

/// Messages Search Sent Media.
///
/// ID: `107e31a0`.
class MessagesSearchSentMedia extends TlMethod<MessagesMessagesBase> {
  /// Messages Search Sent Media constructor.
  const MessagesSearchSentMedia({
    required this.q,
    required this.filter,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory MessagesSearchSentMedia.deserialize(BinaryReader reader) {
    // Read [MessagesSearchSentMedia] fields.
    final q = reader.readString();
    final filter = reader.readObject() as MessagesFilterBase;
    final limit = reader.readInt32();

    // Construct [MessagesSearchSentMedia] object.
    final returnValue = MessagesSearchSentMedia(
      q: q,
      filter: filter,
      limit: limit,
    );

    // Now return the deserialized [MessagesSearchSentMedia].
    return returnValue;
  }

  /// Q.
  final String q;

  /// Filter.
  final MessagesFilterBase filter;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x107e31a0.
    buffer.writeInt32(0x107e31a0);

    // Write fields.
    buffer.writeString(q);
    buffer.writeObject(filter);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Messages Get Attach Menu Bots.
///
/// ID: `16fcc2cb`.
class MessagesGetAttachMenuBots extends TlMethod<AttachMenuBotsBase> {
  /// Messages Get Attach Menu Bots constructor.
  const MessagesGetAttachMenuBots({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetAttachMenuBots.deserialize(BinaryReader reader) {
    // Read [MessagesGetAttachMenuBots] fields.
    final hash = reader.readInt64();

    // Construct [MessagesGetAttachMenuBots] object.
    final returnValue = MessagesGetAttachMenuBots(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetAttachMenuBots].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x16fcc2cb.
    buffer.writeInt32(0x16fcc2cb);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Get Attach Menu Bot.
///
/// ID: `77216192`.
class MessagesGetAttachMenuBot extends TlMethod<AttachMenuBotsBotBase> {
  /// Messages Get Attach Menu Bot constructor.
  const MessagesGetAttachMenuBot({
    required this.bot,
  }) : super._();

  /// Deserialize.
  factory MessagesGetAttachMenuBot.deserialize(BinaryReader reader) {
    // Read [MessagesGetAttachMenuBot] fields.
    final bot = reader.readObject() as InputUserBase;

    // Construct [MessagesGetAttachMenuBot] object.
    final returnValue = MessagesGetAttachMenuBot(
      bot: bot,
    );

    // Now return the deserialized [MessagesGetAttachMenuBot].
    return returnValue;
  }

  /// Bot.
  final InputUserBase bot;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x77216192.
    buffer.writeInt32(0x77216192);

    // Write fields.
    buffer.writeObject(bot);

    // Finished serialization.
  }
}

/// Messages Toggle Bot In Attach Menu.
///
/// ID: `69f59d69`.
class MessagesToggleBotInAttachMenu extends TlMethod<bool> {
  /// Messages Toggle Bot In Attach Menu constructor.
  const MessagesToggleBotInAttachMenu({
    required this.writeAllowed,
    required this.bot,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory MessagesToggleBotInAttachMenu.deserialize(BinaryReader reader) {
    // Read [MessagesToggleBotInAttachMenu] fields.
    final flags = reader.readInt32();
    final writeAllowed = (flags & 1) != 0;
    final bot = reader.readObject() as InputUserBase;
    final enabled = reader.readBool();

    // Construct [MessagesToggleBotInAttachMenu] object.
    final returnValue = MessagesToggleBotInAttachMenu(
      writeAllowed: writeAllowed,
      bot: bot,
      enabled: enabled,
    );

    // Now return the deserialized [MessagesToggleBotInAttachMenu].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: writeAllowed,
    );

    return v;
  }

  /// write_allowed: bit 0 of flags.0?true
  final bool writeAllowed;

  /// Bot.
  final InputUserBase bot;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x69f59d69.
    buffer.writeInt32(0x69f59d69);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(bot);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Messages Request Web View.
///
/// ID: `269dc2c1`.
class MessagesRequestWebView extends TlMethod<WebViewResultBase> {
  /// Messages Request Web View constructor.
  const MessagesRequestWebView({
    required this.fromBotMenu,
    required this.silent,
    required this.peer,
    required this.bot,
    this.url,
    this.startParam,
    this.themeParams,
    required this.platform,
    this.replyTo,
    this.sendAs,
  }) : super._();

  /// Deserialize.
  factory MessagesRequestWebView.deserialize(BinaryReader reader) {
    // Read [MessagesRequestWebView] fields.
    final flags = reader.readInt32();
    final fromBotMenu = (flags & 16) != 0;
    final silent = (flags & 32) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final bot = reader.readObject() as InputUserBase;
    final hasUrlField = (flags & 2) != 0;
    final url = hasUrlField ? reader.readString() : null;
    final hasStartParamField = (flags & 8) != 0;
    final startParam = hasStartParamField ? reader.readString() : null;
    final hasThemeParamsField = (flags & 4) != 0;
    final themeParams =
        hasThemeParamsField ? reader.readObject() as DataJSONBase : null;
    final platform = reader.readString();
    final hasReplyToField = (flags & 1) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as InputReplyToBase : null;
    final hasSendAsField = (flags & 8192) != 0;
    final sendAs = hasSendAsField ? reader.readObject() as InputPeerBase : null;

    // Construct [MessagesRequestWebView] object.
    final returnValue = MessagesRequestWebView(
      fromBotMenu: fromBotMenu,
      silent: silent,
      peer: peer,
      bot: bot,
      url: url,
      startParam: startParam,
      themeParams: themeParams,
      platform: platform,
      replyTo: replyTo,
      sendAs: sendAs,
    );

    // Now return the deserialized [MessagesRequestWebView].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b04: fromBotMenu,
      b05: silent,
      b01: url != null,
      b03: startParam != null,
      b02: themeParams != null,
      b00: replyTo != null,
      b13: sendAs != null,
    );

    return v;
  }

  /// from_bot_menu: bit 4 of flags.4?true
  final bool fromBotMenu;

  /// silent: bit 5 of flags.5?true
  final bool silent;

  /// Peer.
  final InputPeerBase peer;

  /// Bot.
  final InputUserBase bot;

  /// Url.
  final String? url;

  /// Start Param.
  final String? startParam;

  /// Theme Params.
  final DataJSONBase? themeParams;

  /// Platform.
  final String platform;

  /// Reply To.
  final InputReplyToBase? replyTo;

  /// Send As.
  final InputPeerBase? sendAs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x269dc2c1.
    buffer.writeInt32(0x269dc2c1);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeObject(bot);
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }
    final localStartParamCopy = startParam;
    if (localStartParamCopy != null) {
      buffer.writeString(localStartParamCopy);
    }
    final localThemeParamsCopy = themeParams;
    if (localThemeParamsCopy != null) {
      buffer.writeObject(localThemeParamsCopy);
    }
    buffer.writeString(platform);
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    final localSendAsCopy = sendAs;
    if (localSendAsCopy != null) {
      buffer.writeObject(localSendAsCopy);
    }

    // Finished serialization.
  }
}

/// Messages Prolong Web View.
///
/// ID: `b0d81a83`.
class MessagesProlongWebView extends TlMethod<bool> {
  /// Messages Prolong Web View constructor.
  const MessagesProlongWebView({
    required this.silent,
    required this.peer,
    required this.bot,
    required this.queryId,
    this.replyTo,
    this.sendAs,
  }) : super._();

  /// Deserialize.
  factory MessagesProlongWebView.deserialize(BinaryReader reader) {
    // Read [MessagesProlongWebView] fields.
    final flags = reader.readInt32();
    final silent = (flags & 32) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final bot = reader.readObject() as InputUserBase;
    final queryId = reader.readInt64();
    final hasReplyToField = (flags & 1) != 0;
    final replyTo =
        hasReplyToField ? reader.readObject() as InputReplyToBase : null;
    final hasSendAsField = (flags & 8192) != 0;
    final sendAs = hasSendAsField ? reader.readObject() as InputPeerBase : null;

    // Construct [MessagesProlongWebView] object.
    final returnValue = MessagesProlongWebView(
      silent: silent,
      peer: peer,
      bot: bot,
      queryId: queryId,
      replyTo: replyTo,
      sendAs: sendAs,
    );

    // Now return the deserialized [MessagesProlongWebView].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b05: silent,
      b00: replyTo != null,
      b13: sendAs != null,
    );

    return v;
  }

  /// silent: bit 5 of flags.5?true
  final bool silent;

  /// Peer.
  final InputPeerBase peer;

  /// Bot.
  final InputUserBase bot;

  /// Query Id.
  ///
  /// Field type is Int64.
  final int queryId;

  /// Reply To.
  final InputReplyToBase? replyTo;

  /// Send As.
  final InputPeerBase? sendAs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb0d81a83.
    buffer.writeInt32(0xb0d81a83);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeObject(bot);
    buffer.writeInt64(queryId);
    final localReplyToCopy = replyTo;
    if (localReplyToCopy != null) {
      buffer.writeObject(localReplyToCopy);
    }
    final localSendAsCopy = sendAs;
    if (localSendAsCopy != null) {
      buffer.writeObject(localSendAsCopy);
    }

    // Finished serialization.
  }
}

/// Messages Request Simple Web View.
///
/// ID: `1a46500a`.
class MessagesRequestSimpleWebView extends TlMethod<SimpleWebViewResultBase> {
  /// Messages Request Simple Web View constructor.
  const MessagesRequestSimpleWebView({
    required this.fromSwitchWebview,
    required this.fromSideMenu,
    required this.bot,
    this.url,
    this.startParam,
    this.themeParams,
    required this.platform,
  }) : super._();

  /// Deserialize.
  factory MessagesRequestSimpleWebView.deserialize(BinaryReader reader) {
    // Read [MessagesRequestSimpleWebView] fields.
    final flags = reader.readInt32();
    final fromSwitchWebview = (flags & 2) != 0;
    final fromSideMenu = (flags & 4) != 0;
    final bot = reader.readObject() as InputUserBase;
    final hasUrlField = (flags & 8) != 0;
    final url = hasUrlField ? reader.readString() : null;
    final hasStartParamField = (flags & 16) != 0;
    final startParam = hasStartParamField ? reader.readString() : null;
    final hasThemeParamsField = (flags & 1) != 0;
    final themeParams =
        hasThemeParamsField ? reader.readObject() as DataJSONBase : null;
    final platform = reader.readString();

    // Construct [MessagesRequestSimpleWebView] object.
    final returnValue = MessagesRequestSimpleWebView(
      fromSwitchWebview: fromSwitchWebview,
      fromSideMenu: fromSideMenu,
      bot: bot,
      url: url,
      startParam: startParam,
      themeParams: themeParams,
      platform: platform,
    );

    // Now return the deserialized [MessagesRequestSimpleWebView].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: fromSwitchWebview,
      b02: fromSideMenu,
      b03: url != null,
      b04: startParam != null,
      b00: themeParams != null,
    );

    return v;
  }

  /// from_switch_webview: bit 1 of flags.1?true
  final bool fromSwitchWebview;

  /// from_side_menu: bit 2 of flags.2?true
  final bool fromSideMenu;

  /// Bot.
  final InputUserBase bot;

  /// Url.
  final String? url;

  /// Start Param.
  final String? startParam;

  /// Theme Params.
  final DataJSONBase? themeParams;

  /// Platform.
  final String platform;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1a46500a.
    buffer.writeInt32(0x1a46500a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(bot);
    final localUrlCopy = url;
    if (localUrlCopy != null) {
      buffer.writeString(localUrlCopy);
    }
    final localStartParamCopy = startParam;
    if (localStartParamCopy != null) {
      buffer.writeString(localStartParamCopy);
    }
    final localThemeParamsCopy = themeParams;
    if (localThemeParamsCopy != null) {
      buffer.writeObject(localThemeParamsCopy);
    }
    buffer.writeString(platform);

    // Finished serialization.
  }
}

/// Messages Send Web View Result Message.
///
/// ID: `0a4314f5`.
class MessagesSendWebViewResultMessage
    extends TlMethod<WebViewMessageSentBase> {
  /// Messages Send Web View Result Message constructor.
  const MessagesSendWebViewResultMessage({
    required this.botQueryId,
    required this.result,
  }) : super._();

  /// Deserialize.
  factory MessagesSendWebViewResultMessage.deserialize(BinaryReader reader) {
    // Read [MessagesSendWebViewResultMessage] fields.
    final botQueryId = reader.readString();
    final result = reader.readObject() as InputBotInlineResultBase;

    // Construct [MessagesSendWebViewResultMessage] object.
    final returnValue = MessagesSendWebViewResultMessage(
      botQueryId: botQueryId,
      result: result,
    );

    // Now return the deserialized [MessagesSendWebViewResultMessage].
    return returnValue;
  }

  /// Bot Query Id.
  final String botQueryId;

  /// Result.
  final InputBotInlineResultBase result;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0a4314f5.
    buffer.writeInt32(0x0a4314f5);

    // Write fields.
    buffer.writeString(botQueryId);
    buffer.writeObject(result);

    // Finished serialization.
  }
}

/// Messages Send Web View Data.
///
/// ID: `dc0242c8`.
class MessagesSendWebViewData extends TlMethod<UpdatesBase> {
  /// Messages Send Web View Data constructor.
  const MessagesSendWebViewData({
    required this.bot,
    required this.randomId,
    required this.buttonText,
    required this.data,
  }) : super._();

  /// Deserialize.
  factory MessagesSendWebViewData.deserialize(BinaryReader reader) {
    // Read [MessagesSendWebViewData] fields.
    final bot = reader.readObject() as InputUserBase;
    final randomId = reader.readInt64();
    final buttonText = reader.readString();
    final data = reader.readString();

    // Construct [MessagesSendWebViewData] object.
    final returnValue = MessagesSendWebViewData(
      bot: bot,
      randomId: randomId,
      buttonText: buttonText,
      data: data,
    );

    // Now return the deserialized [MessagesSendWebViewData].
    return returnValue;
  }

  /// Bot.
  final InputUserBase bot;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Button Text.
  final String buttonText;

  /// Data.
  final String data;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdc0242c8.
    buffer.writeInt32(0xdc0242c8);

    // Write fields.
    buffer.writeObject(bot);
    buffer.writeInt64(randomId);
    buffer.writeString(buttonText);
    buffer.writeString(data);

    // Finished serialization.
  }
}

/// Bots Set Bot Menu Button.
///
/// ID: `4504d54f`.
class BotsSetBotMenuButton extends TlMethod<bool> {
  /// Bots Set Bot Menu Button constructor.
  const BotsSetBotMenuButton({
    required this.userId,
    required this.button,
  }) : super._();

  /// Deserialize.
  factory BotsSetBotMenuButton.deserialize(BinaryReader reader) {
    // Read [BotsSetBotMenuButton] fields.
    final userId = reader.readObject() as InputUserBase;
    final button = reader.readObject() as BotMenuButtonBase;

    // Construct [BotsSetBotMenuButton] object.
    final returnValue = BotsSetBotMenuButton(
      userId: userId,
      button: button,
    );

    // Now return the deserialized [BotsSetBotMenuButton].
    return returnValue;
  }

  /// User Id.
  final InputUserBase userId;

  /// Button.
  final BotMenuButtonBase button;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4504d54f.
    buffer.writeInt32(0x4504d54f);

    // Write fields.
    buffer.writeObject(userId);
    buffer.writeObject(button);

    // Finished serialization.
  }
}

/// Bots Get Bot Menu Button.
///
/// ID: `9c60eb28`.
class BotsGetBotMenuButton extends TlMethod<BotMenuButtonBase> {
  /// Bots Get Bot Menu Button constructor.
  const BotsGetBotMenuButton({
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory BotsGetBotMenuButton.deserialize(BinaryReader reader) {
    // Read [BotsGetBotMenuButton] fields.
    final userId = reader.readObject() as InputUserBase;

    // Construct [BotsGetBotMenuButton] object.
    final returnValue = BotsGetBotMenuButton(
      userId: userId,
    );

    // Now return the deserialized [BotsGetBotMenuButton].
    return returnValue;
  }

  /// User Id.
  final InputUserBase userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9c60eb28.
    buffer.writeInt32(0x9c60eb28);

    // Write fields.
    buffer.writeObject(userId);

    // Finished serialization.
  }
}

/// Account Get Saved Ringtones.
///
/// ID: `e1902288`.
class AccountGetSavedRingtones extends TlMethod<AccountSavedRingtonesBase> {
  /// Account Get Saved Ringtones constructor.
  const AccountGetSavedRingtones({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetSavedRingtones.deserialize(BinaryReader reader) {
    // Read [AccountGetSavedRingtones] fields.
    final hash = reader.readInt64();

    // Construct [AccountGetSavedRingtones] object.
    final returnValue = AccountGetSavedRingtones(
      hash: hash,
    );

    // Now return the deserialized [AccountGetSavedRingtones].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe1902288.
    buffer.writeInt32(0xe1902288);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Account Save Ringtone.
///
/// ID: `3dea5b03`.
class AccountSaveRingtone extends TlMethod<AccountSavedRingtoneBase> {
  /// Account Save Ringtone constructor.
  const AccountSaveRingtone({
    required this.id,
    required this.unsave,
  }) : super._();

  /// Deserialize.
  factory AccountSaveRingtone.deserialize(BinaryReader reader) {
    // Read [AccountSaveRingtone] fields.
    final id = reader.readObject() as InputDocumentBase;
    final unsave = reader.readBool();

    // Construct [AccountSaveRingtone] object.
    final returnValue = AccountSaveRingtone(
      id: id,
      unsave: unsave,
    );

    // Now return the deserialized [AccountSaveRingtone].
    return returnValue;
  }

  /// Id.
  final InputDocumentBase id;

  /// Unsave.
  final bool unsave;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3dea5b03.
    buffer.writeInt32(0x3dea5b03);

    // Write fields.
    buffer.writeObject(id);
    buffer.writeBool(unsave);

    // Finished serialization.
  }
}

/// Account Upload Ringtone.
///
/// ID: `831a83a2`.
class AccountUploadRingtone extends TlMethod<DocumentBase> {
  /// Account Upload Ringtone constructor.
  const AccountUploadRingtone({
    required this.file,
    required this.fileName,
    required this.mimeType,
  }) : super._();

  /// Deserialize.
  factory AccountUploadRingtone.deserialize(BinaryReader reader) {
    // Read [AccountUploadRingtone] fields.
    final file = reader.readObject() as InputFileBase;
    final fileName = reader.readString();
    final mimeType = reader.readString();

    // Construct [AccountUploadRingtone] object.
    final returnValue = AccountUploadRingtone(
      file: file,
      fileName: fileName,
      mimeType: mimeType,
    );

    // Now return the deserialized [AccountUploadRingtone].
    return returnValue;
  }

  /// File.
  final InputFileBase file;

  /// File Name.
  final String fileName;

  /// Mime Type.
  final String mimeType;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x831a83a2.
    buffer.writeInt32(0x831a83a2);

    // Write fields.
    buffer.writeObject(file);
    buffer.writeString(fileName);
    buffer.writeString(mimeType);

    // Finished serialization.
  }
}

/// Bots Set Bot Broadcast Default Admin Rights.
///
/// ID: `788464e1`.
class BotsSetBotBroadcastDefaultAdminRights extends TlMethod<bool> {
  /// Bots Set Bot Broadcast Default Admin Rights constructor.
  const BotsSetBotBroadcastDefaultAdminRights({
    required this.adminRights,
  }) : super._();

  /// Deserialize.
  factory BotsSetBotBroadcastDefaultAdminRights.deserialize(
      BinaryReader reader) {
    // Read [BotsSetBotBroadcastDefaultAdminRights] fields.
    final adminRights = reader.readObject() as ChatAdminRightsBase;

    // Construct [BotsSetBotBroadcastDefaultAdminRights] object.
    final returnValue = BotsSetBotBroadcastDefaultAdminRights(
      adminRights: adminRights,
    );

    // Now return the deserialized [BotsSetBotBroadcastDefaultAdminRights].
    return returnValue;
  }

  /// Admin Rights.
  final ChatAdminRightsBase adminRights;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x788464e1.
    buffer.writeInt32(0x788464e1);

    // Write fields.
    buffer.writeObject(adminRights);

    // Finished serialization.
  }
}

/// Bots Set Bot Group Default Admin Rights.
///
/// ID: `925ec9ea`.
class BotsSetBotGroupDefaultAdminRights extends TlMethod<bool> {
  /// Bots Set Bot Group Default Admin Rights constructor.
  const BotsSetBotGroupDefaultAdminRights({
    required this.adminRights,
  }) : super._();

  /// Deserialize.
  factory BotsSetBotGroupDefaultAdminRights.deserialize(BinaryReader reader) {
    // Read [BotsSetBotGroupDefaultAdminRights] fields.
    final adminRights = reader.readObject() as ChatAdminRightsBase;

    // Construct [BotsSetBotGroupDefaultAdminRights] object.
    final returnValue = BotsSetBotGroupDefaultAdminRights(
      adminRights: adminRights,
    );

    // Now return the deserialized [BotsSetBotGroupDefaultAdminRights].
    return returnValue;
  }

  /// Admin Rights.
  final ChatAdminRightsBase adminRights;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x925ec9ea.
    buffer.writeInt32(0x925ec9ea);

    // Write fields.
    buffer.writeObject(adminRights);

    // Finished serialization.
  }
}

/// Phone Save Call Log.
///
/// ID: `41248786`.
class PhoneSaveCallLog extends TlMethod<bool> {
  /// Phone Save Call Log constructor.
  const PhoneSaveCallLog({
    required this.peer,
    required this.file,
  }) : super._();

  /// Deserialize.
  factory PhoneSaveCallLog.deserialize(BinaryReader reader) {
    // Read [PhoneSaveCallLog] fields.
    final peer = reader.readObject() as InputPhoneCallBase;
    final file = reader.readObject() as InputFileBase;

    // Construct [PhoneSaveCallLog] object.
    final returnValue = PhoneSaveCallLog(
      peer: peer,
      file: file,
    );

    // Now return the deserialized [PhoneSaveCallLog].
    return returnValue;
  }

  /// Peer.
  final InputPhoneCallBase peer;

  /// File.
  final InputFileBase file;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x41248786.
    buffer.writeInt32(0x41248786);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(file);

    // Finished serialization.
  }
}

/// Channels Toggle Join To Send.
///
/// ID: `e4cb9580`.
class ChannelsToggleJoinToSend extends TlMethod<UpdatesBase> {
  /// Channels Toggle Join To Send constructor.
  const ChannelsToggleJoinToSend({
    required this.channel,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory ChannelsToggleJoinToSend.deserialize(BinaryReader reader) {
    // Read [ChannelsToggleJoinToSend] fields.
    final channel = reader.readObject() as InputChannelBase;
    final enabled = reader.readBool();

    // Construct [ChannelsToggleJoinToSend] object.
    final returnValue = ChannelsToggleJoinToSend(
      channel: channel,
      enabled: enabled,
    );

    // Now return the deserialized [ChannelsToggleJoinToSend].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe4cb9580.
    buffer.writeInt32(0xe4cb9580);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Channels Toggle Join Request.
///
/// ID: `4c2985b6`.
class ChannelsToggleJoinRequest extends TlMethod<UpdatesBase> {
  /// Channels Toggle Join Request constructor.
  const ChannelsToggleJoinRequest({
    required this.channel,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory ChannelsToggleJoinRequest.deserialize(BinaryReader reader) {
    // Read [ChannelsToggleJoinRequest] fields.
    final channel = reader.readObject() as InputChannelBase;
    final enabled = reader.readBool();

    // Construct [ChannelsToggleJoinRequest] object.
    final returnValue = ChannelsToggleJoinRequest(
      channel: channel,
      enabled: enabled,
    );

    // Now return the deserialized [ChannelsToggleJoinRequest].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x4c2985b6.
    buffer.writeInt32(0x4c2985b6);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Payments Export Invoice.
///
/// ID: `0f91b065`.
class PaymentsExportInvoice extends TlMethod<PaymentsExportedInvoiceBase> {
  /// Payments Export Invoice constructor.
  const PaymentsExportInvoice({
    required this.invoiceMedia,
  }) : super._();

  /// Deserialize.
  factory PaymentsExportInvoice.deserialize(BinaryReader reader) {
    // Read [PaymentsExportInvoice] fields.
    final invoiceMedia = reader.readObject() as InputMediaBase;

    // Construct [PaymentsExportInvoice] object.
    final returnValue = PaymentsExportInvoice(
      invoiceMedia: invoiceMedia,
    );

    // Now return the deserialized [PaymentsExportInvoice].
    return returnValue;
  }

  /// Invoice Media.
  final InputMediaBase invoiceMedia;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0f91b065.
    buffer.writeInt32(0x0f91b065);

    // Write fields.
    buffer.writeObject(invoiceMedia);

    // Finished serialization.
  }
}

/// Messages Transcribe Audio.
///
/// ID: `269e9a49`.
class MessagesTranscribeAudio extends TlMethod<MessagesTranscribedAudioBase> {
  /// Messages Transcribe Audio constructor.
  const MessagesTranscribeAudio({
    required this.peer,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory MessagesTranscribeAudio.deserialize(BinaryReader reader) {
    // Read [MessagesTranscribeAudio] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();

    // Construct [MessagesTranscribeAudio] object.
    final returnValue = MessagesTranscribeAudio(
      peer: peer,
      msgId: msgId,
    );

    // Now return the deserialized [MessagesTranscribeAudio].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x269e9a49.
    buffer.writeInt32(0x269e9a49);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Messages Rate Transcribed Audio.
///
/// ID: `7f1d072f`.
class MessagesRateTranscribedAudio extends TlMethod<bool> {
  /// Messages Rate Transcribed Audio constructor.
  const MessagesRateTranscribedAudio({
    required this.peer,
    required this.msgId,
    required this.transcriptionId,
    required this.good,
  }) : super._();

  /// Deserialize.
  factory MessagesRateTranscribedAudio.deserialize(BinaryReader reader) {
    // Read [MessagesRateTranscribedAudio] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final transcriptionId = reader.readInt64();
    final good = reader.readBool();

    // Construct [MessagesRateTranscribedAudio] object.
    final returnValue = MessagesRateTranscribedAudio(
      peer: peer,
      msgId: msgId,
      transcriptionId: transcriptionId,
      good: good,
    );

    // Now return the deserialized [MessagesRateTranscribedAudio].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Transcription Id.
  ///
  /// Field type is Int64.
  final int transcriptionId;

  /// Good.
  final bool good;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7f1d072f.
    buffer.writeInt32(0x7f1d072f);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeInt64(transcriptionId);
    buffer.writeBool(good);

    // Finished serialization.
  }
}

/// Payments Assign App Store Transaction.
///
/// ID: `80ed747d`.
class PaymentsAssignAppStoreTransaction extends TlMethod<UpdatesBase> {
  /// Payments Assign App Store Transaction constructor.
  const PaymentsAssignAppStoreTransaction({
    required this.receipt,
    required this.purpose,
  }) : super._();

  /// Deserialize.
  factory PaymentsAssignAppStoreTransaction.deserialize(BinaryReader reader) {
    // Read [PaymentsAssignAppStoreTransaction] fields.
    final receipt = reader.readBytes();
    final purpose = reader.readObject() as InputStorePaymentPurposeBase;

    // Construct [PaymentsAssignAppStoreTransaction] object.
    final returnValue = PaymentsAssignAppStoreTransaction(
      receipt: receipt,
      purpose: purpose,
    );

    // Now return the deserialized [PaymentsAssignAppStoreTransaction].
    return returnValue;
  }

  /// Receipt.
  final Uint8List receipt;

  /// Purpose.
  final InputStorePaymentPurposeBase purpose;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x80ed747d.
    buffer.writeInt32(0x80ed747d);

    // Write fields.
    buffer.writeBytes(receipt);
    buffer.writeObject(purpose);

    // Finished serialization.
  }
}

/// Payments Assign Play Market Transaction.
///
/// ID: `dffd50d3`.
class PaymentsAssignPlayMarketTransaction extends TlMethod<UpdatesBase> {
  /// Payments Assign Play Market Transaction constructor.
  const PaymentsAssignPlayMarketTransaction({
    required this.receipt,
    required this.purpose,
  }) : super._();

  /// Deserialize.
  factory PaymentsAssignPlayMarketTransaction.deserialize(BinaryReader reader) {
    // Read [PaymentsAssignPlayMarketTransaction] fields.
    final receipt = reader.readObject() as DataJSONBase;
    final purpose = reader.readObject() as InputStorePaymentPurposeBase;

    // Construct [PaymentsAssignPlayMarketTransaction] object.
    final returnValue = PaymentsAssignPlayMarketTransaction(
      receipt: receipt,
      purpose: purpose,
    );

    // Now return the deserialized [PaymentsAssignPlayMarketTransaction].
    return returnValue;
  }

  /// Receipt.
  final DataJSONBase receipt;

  /// Purpose.
  final InputStorePaymentPurposeBase purpose;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdffd50d3.
    buffer.writeInt32(0xdffd50d3);

    // Write fields.
    buffer.writeObject(receipt);
    buffer.writeObject(purpose);

    // Finished serialization.
  }
}

/// Payments Can Purchase Premium.
///
/// ID: `9fc19eb6`.
class PaymentsCanPurchasePremium extends TlMethod<bool> {
  /// Payments Can Purchase Premium constructor.
  const PaymentsCanPurchasePremium({
    required this.purpose,
  }) : super._();

  /// Deserialize.
  factory PaymentsCanPurchasePremium.deserialize(BinaryReader reader) {
    // Read [PaymentsCanPurchasePremium] fields.
    final purpose = reader.readObject() as InputStorePaymentPurposeBase;

    // Construct [PaymentsCanPurchasePremium] object.
    final returnValue = PaymentsCanPurchasePremium(
      purpose: purpose,
    );

    // Now return the deserialized [PaymentsCanPurchasePremium].
    return returnValue;
  }

  /// Purpose.
  final InputStorePaymentPurposeBase purpose;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9fc19eb6.
    buffer.writeInt32(0x9fc19eb6);

    // Write fields.
    buffer.writeObject(purpose);

    // Finished serialization.
  }
}

/// Help Get Premium Promo.
///
/// ID: `b81b93d4`.
class HelpGetPremiumPromo extends TlMethod<HelpPremiumPromoBase> {
  /// Help Get Premium Promo constructor.
  const HelpGetPremiumPromo() : super._();

  /// Deserialize.
  factory HelpGetPremiumPromo.deserialize(BinaryReader reader) {
    // Construct [HelpGetPremiumPromo] object.
    final returnValue = HelpGetPremiumPromo();

    // Now return the deserialized [HelpGetPremiumPromo].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb81b93d4.
    buffer.writeInt32(0xb81b93d4);

    // Finished serialization.
  }
}

/// Messages Get Custom Emoji Documents.
///
/// ID: `d9ab0f54`.
class MessagesGetCustomEmojiDocuments extends TlMethod<List<DocumentBase>> {
  /// Messages Get Custom Emoji Documents constructor.
  const MessagesGetCustomEmojiDocuments({
    required this.documentId,
  }) : super._();

  /// Deserialize.
  factory MessagesGetCustomEmojiDocuments.deserialize(BinaryReader reader) {
    // Read [MessagesGetCustomEmojiDocuments] fields.
    final documentId = reader.readVectorInt64();

    // Construct [MessagesGetCustomEmojiDocuments] object.
    final returnValue = MessagesGetCustomEmojiDocuments(
      documentId: documentId,
    );

    // Now return the deserialized [MessagesGetCustomEmojiDocuments].
    return returnValue;
  }

  /// Document Id.
  final List<int> documentId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd9ab0f54.
    buffer.writeInt32(0xd9ab0f54);

    // Write fields.
    buffer.writeVectorInt64(documentId);

    // Finished serialization.
  }
}

/// Messages Get Emoji Stickers.
///
/// ID: `fbfca18f`.
class MessagesGetEmojiStickers extends TlMethod<MessagesAllStickersBase> {
  /// Messages Get Emoji Stickers constructor.
  const MessagesGetEmojiStickers({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetEmojiStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetEmojiStickers] fields.
    final hash = reader.readInt64();

    // Construct [MessagesGetEmojiStickers] object.
    final returnValue = MessagesGetEmojiStickers(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetEmojiStickers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfbfca18f.
    buffer.writeInt32(0xfbfca18f);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Get Featured Emoji Stickers.
///
/// ID: `0ecf6736`.
class MessagesGetFeaturedEmojiStickers
    extends TlMethod<MessagesFeaturedStickersBase> {
  /// Messages Get Featured Emoji Stickers constructor.
  const MessagesGetFeaturedEmojiStickers({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetFeaturedEmojiStickers.deserialize(BinaryReader reader) {
    // Read [MessagesGetFeaturedEmojiStickers] fields.
    final hash = reader.readInt64();

    // Construct [MessagesGetFeaturedEmojiStickers] object.
    final returnValue = MessagesGetFeaturedEmojiStickers(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetFeaturedEmojiStickers].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0ecf6736.
    buffer.writeInt32(0x0ecf6736);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Account Update Emoji Status.
///
/// ID: `fbd3de6b`.
class AccountUpdateEmojiStatus extends TlMethod<bool> {
  /// Account Update Emoji Status constructor.
  const AccountUpdateEmojiStatus({
    required this.emojiStatus,
  }) : super._();

  /// Deserialize.
  factory AccountUpdateEmojiStatus.deserialize(BinaryReader reader) {
    // Read [AccountUpdateEmojiStatus] fields.
    final emojiStatus = reader.readObject() as EmojiStatusBase;

    // Construct [AccountUpdateEmojiStatus] object.
    final returnValue = AccountUpdateEmojiStatus(
      emojiStatus: emojiStatus,
    );

    // Now return the deserialized [AccountUpdateEmojiStatus].
    return returnValue;
  }

  /// Emoji Status.
  final EmojiStatusBase emojiStatus;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfbd3de6b.
    buffer.writeInt32(0xfbd3de6b);

    // Write fields.
    buffer.writeObject(emojiStatus);

    // Finished serialization.
  }
}

/// Account Get Default Emoji Statuses.
///
/// ID: `d6753386`.
class AccountGetDefaultEmojiStatuses
    extends TlMethod<AccountEmojiStatusesBase> {
  /// Account Get Default Emoji Statuses constructor.
  const AccountGetDefaultEmojiStatuses({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetDefaultEmojiStatuses.deserialize(BinaryReader reader) {
    // Read [AccountGetDefaultEmojiStatuses] fields.
    final hash = reader.readInt64();

    // Construct [AccountGetDefaultEmojiStatuses] object.
    final returnValue = AccountGetDefaultEmojiStatuses(
      hash: hash,
    );

    // Now return the deserialized [AccountGetDefaultEmojiStatuses].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd6753386.
    buffer.writeInt32(0xd6753386);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Account Get Recent Emoji Statuses.
///
/// ID: `0f578105`.
class AccountGetRecentEmojiStatuses extends TlMethod<AccountEmojiStatusesBase> {
  /// Account Get Recent Emoji Statuses constructor.
  const AccountGetRecentEmojiStatuses({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetRecentEmojiStatuses.deserialize(BinaryReader reader) {
    // Read [AccountGetRecentEmojiStatuses] fields.
    final hash = reader.readInt64();

    // Construct [AccountGetRecentEmojiStatuses] object.
    final returnValue = AccountGetRecentEmojiStatuses(
      hash: hash,
    );

    // Now return the deserialized [AccountGetRecentEmojiStatuses].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0f578105.
    buffer.writeInt32(0x0f578105);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Account Clear Recent Emoji Statuses.
///
/// ID: `18201aae`.
class AccountClearRecentEmojiStatuses extends TlMethod<bool> {
  /// Account Clear Recent Emoji Statuses constructor.
  const AccountClearRecentEmojiStatuses() : super._();

  /// Deserialize.
  factory AccountClearRecentEmojiStatuses.deserialize(BinaryReader reader) {
    // Construct [AccountClearRecentEmojiStatuses] object.
    final returnValue = AccountClearRecentEmojiStatuses();

    // Now return the deserialized [AccountClearRecentEmojiStatuses].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x18201aae.
    buffer.writeInt32(0x18201aae);

    // Finished serialization.
  }
}

/// Messages Report Reaction.
///
/// ID: `3f64c076`.
class MessagesReportReaction extends TlMethod<bool> {
  /// Messages Report Reaction constructor.
  const MessagesReportReaction({
    required this.peer,
    required this.id,
    required this.reactionPeer,
  }) : super._();

  /// Deserialize.
  factory MessagesReportReaction.deserialize(BinaryReader reader) {
    // Read [MessagesReportReaction] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();
    final reactionPeer = reader.readObject() as InputPeerBase;

    // Construct [MessagesReportReaction] object.
    final returnValue = MessagesReportReaction(
      peer: peer,
      id: id,
      reactionPeer: reactionPeer,
    );

    // Now return the deserialized [MessagesReportReaction].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Reaction Peer.
  final InputPeerBase reactionPeer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3f64c076.
    buffer.writeInt32(0x3f64c076);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    buffer.writeObject(reactionPeer);

    // Finished serialization.
  }
}

/// Messages Get Top Reactions.
///
/// ID: `bb8125ba`.
class MessagesGetTopReactions extends TlMethod<MessagesReactionsBase> {
  /// Messages Get Top Reactions constructor.
  const MessagesGetTopReactions({
    required this.limit,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetTopReactions.deserialize(BinaryReader reader) {
    // Read [MessagesGetTopReactions] fields.
    final limit = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [MessagesGetTopReactions] object.
    final returnValue = MessagesGetTopReactions(
      limit: limit,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetTopReactions].
    return returnValue;
  }

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbb8125ba.
    buffer.writeInt32(0xbb8125ba);

    // Write fields.
    buffer.writeInt32(limit);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Get Recent Reactions.
///
/// ID: `39461db2`.
class MessagesGetRecentReactions extends TlMethod<MessagesReactionsBase> {
  /// Messages Get Recent Reactions constructor.
  const MessagesGetRecentReactions({
    required this.limit,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetRecentReactions.deserialize(BinaryReader reader) {
    // Read [MessagesGetRecentReactions] fields.
    final limit = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [MessagesGetRecentReactions] object.
    final returnValue = MessagesGetRecentReactions(
      limit: limit,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetRecentReactions].
    return returnValue;
  }

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x39461db2.
    buffer.writeInt32(0x39461db2);

    // Write fields.
    buffer.writeInt32(limit);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Clear Recent Reactions.
///
/// ID: `9dfeefb4`.
class MessagesClearRecentReactions extends TlMethod<bool> {
  /// Messages Clear Recent Reactions constructor.
  const MessagesClearRecentReactions() : super._();

  /// Deserialize.
  factory MessagesClearRecentReactions.deserialize(BinaryReader reader) {
    // Construct [MessagesClearRecentReactions] object.
    final returnValue = MessagesClearRecentReactions();

    // Now return the deserialized [MessagesClearRecentReactions].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9dfeefb4.
    buffer.writeInt32(0x9dfeefb4);

    // Finished serialization.
  }
}

/// Messages Get Extended Media.
///
/// ID: `84f80814`.
class MessagesGetExtendedMedia extends TlMethod<UpdatesBase> {
  /// Messages Get Extended Media constructor.
  const MessagesGetExtendedMedia({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesGetExtendedMedia.deserialize(BinaryReader reader) {
    // Read [MessagesGetExtendedMedia] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();

    // Construct [MessagesGetExtendedMedia] object.
    final returnValue = MessagesGetExtendedMedia(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [MessagesGetExtendedMedia].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x84f80814.
    buffer.writeInt32(0x84f80814);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Auth Import Web Token Authorization.
///
/// ID: `2db873a9`.
class AuthImportWebTokenAuthorization extends TlMethod<AuthAuthorizationBase> {
  /// Auth Import Web Token Authorization constructor.
  const AuthImportWebTokenAuthorization({
    required this.apiId,
    required this.apiHash,
    required this.webAuthToken,
  }) : super._();

  /// Deserialize.
  factory AuthImportWebTokenAuthorization.deserialize(BinaryReader reader) {
    // Read [AuthImportWebTokenAuthorization] fields.
    final apiId = reader.readInt32();
    final apiHash = reader.readString();
    final webAuthToken = reader.readString();

    // Construct [AuthImportWebTokenAuthorization] object.
    final returnValue = AuthImportWebTokenAuthorization(
      apiId: apiId,
      apiHash: apiHash,
      webAuthToken: webAuthToken,
    );

    // Now return the deserialized [AuthImportWebTokenAuthorization].
    return returnValue;
  }

  /// Api Id.
  ///
  /// Field type is Int32.
  final int apiId;

  /// Api Hash.
  final String apiHash;

  /// Web Auth Token.
  final String webAuthToken;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2db873a9.
    buffer.writeInt32(0x2db873a9);

    // Write fields.
    buffer.writeInt32(apiId);
    buffer.writeString(apiHash);
    buffer.writeString(webAuthToken);

    // Finished serialization.
  }
}

/// Account Reorder Usernames.
///
/// ID: `ef500eab`.
class AccountReorderUsernames extends TlMethod<bool> {
  /// Account Reorder Usernames constructor.
  const AccountReorderUsernames({
    required this.order,
  }) : super._();

  /// Deserialize.
  factory AccountReorderUsernames.deserialize(BinaryReader reader) {
    // Read [AccountReorderUsernames] fields.
    final order = reader.readVectorString();

    // Construct [AccountReorderUsernames] object.
    final returnValue = AccountReorderUsernames(
      order: order,
    );

    // Now return the deserialized [AccountReorderUsernames].
    return returnValue;
  }

  /// Order.
  final List<String> order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xef500eab.
    buffer.writeInt32(0xef500eab);

    // Write fields.
    buffer.writeVectorString(order);

    // Finished serialization.
  }
}

/// Account Toggle Username.
///
/// ID: `58d6b376`.
class AccountToggleUsername extends TlMethod<bool> {
  /// Account Toggle Username constructor.
  const AccountToggleUsername({
    required this.username,
    required this.active,
  }) : super._();

  /// Deserialize.
  factory AccountToggleUsername.deserialize(BinaryReader reader) {
    // Read [AccountToggleUsername] fields.
    final username = reader.readString();
    final active = reader.readBool();

    // Construct [AccountToggleUsername] object.
    final returnValue = AccountToggleUsername(
      username: username,
      active: active,
    );

    // Now return the deserialized [AccountToggleUsername].
    return returnValue;
  }

  /// Username.
  final String username;

  /// Active.
  final bool active;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x58d6b376.
    buffer.writeInt32(0x58d6b376);

    // Write fields.
    buffer.writeString(username);
    buffer.writeBool(active);

    // Finished serialization.
  }
}

/// Channels Reorder Usernames.
///
/// ID: `b45ced1d`.
class ChannelsReorderUsernames extends TlMethod<bool> {
  /// Channels Reorder Usernames constructor.
  const ChannelsReorderUsernames({
    required this.channel,
    required this.order,
  }) : super._();

  /// Deserialize.
  factory ChannelsReorderUsernames.deserialize(BinaryReader reader) {
    // Read [ChannelsReorderUsernames] fields.
    final channel = reader.readObject() as InputChannelBase;
    final order = reader.readVectorString();

    // Construct [ChannelsReorderUsernames] object.
    final returnValue = ChannelsReorderUsernames(
      channel: channel,
      order: order,
    );

    // Now return the deserialized [ChannelsReorderUsernames].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Order.
  final List<String> order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb45ced1d.
    buffer.writeInt32(0xb45ced1d);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeVectorString(order);

    // Finished serialization.
  }
}

/// Channels Toggle Username.
///
/// ID: `50f24105`.
class ChannelsToggleUsername extends TlMethod<bool> {
  /// Channels Toggle Username constructor.
  const ChannelsToggleUsername({
    required this.channel,
    required this.username,
    required this.active,
  }) : super._();

  /// Deserialize.
  factory ChannelsToggleUsername.deserialize(BinaryReader reader) {
    // Read [ChannelsToggleUsername] fields.
    final channel = reader.readObject() as InputChannelBase;
    final username = reader.readString();
    final active = reader.readBool();

    // Construct [ChannelsToggleUsername] object.
    final returnValue = ChannelsToggleUsername(
      channel: channel,
      username: username,
      active: active,
    );

    // Now return the deserialized [ChannelsToggleUsername].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Username.
  final String username;

  /// Active.
  final bool active;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x50f24105.
    buffer.writeInt32(0x50f24105);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeString(username);
    buffer.writeBool(active);

    // Finished serialization.
  }
}

/// Channels Deactivate All Usernames.
///
/// ID: `0a245dd3`.
class ChannelsDeactivateAllUsernames extends TlMethod<bool> {
  /// Channels Deactivate All Usernames constructor.
  const ChannelsDeactivateAllUsernames({
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory ChannelsDeactivateAllUsernames.deserialize(BinaryReader reader) {
    // Read [ChannelsDeactivateAllUsernames] fields.
    final channel = reader.readObject() as InputChannelBase;

    // Construct [ChannelsDeactivateAllUsernames] object.
    final returnValue = ChannelsDeactivateAllUsernames(
      channel: channel,
    );

    // Now return the deserialized [ChannelsDeactivateAllUsernames].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0a245dd3.
    buffer.writeInt32(0x0a245dd3);

    // Write fields.
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Channels Toggle Forum.
///
/// ID: `a4298b29`.
class ChannelsToggleForum extends TlMethod<UpdatesBase> {
  /// Channels Toggle Forum constructor.
  const ChannelsToggleForum({
    required this.channel,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory ChannelsToggleForum.deserialize(BinaryReader reader) {
    // Read [ChannelsToggleForum] fields.
    final channel = reader.readObject() as InputChannelBase;
    final enabled = reader.readBool();

    // Construct [ChannelsToggleForum] object.
    final returnValue = ChannelsToggleForum(
      channel: channel,
      enabled: enabled,
    );

    // Now return the deserialized [ChannelsToggleForum].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa4298b29.
    buffer.writeInt32(0xa4298b29);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Channels Create Forum Topic.
///
/// ID: `f40c0224`.
class ChannelsCreateForumTopic extends TlMethod<UpdatesBase> {
  /// Channels Create Forum Topic constructor.
  const ChannelsCreateForumTopic({
    required this.channel,
    required this.title,
    this.iconColor,
    this.iconEmojiId,
    required this.randomId,
    this.sendAs,
  }) : super._();

  /// Deserialize.
  factory ChannelsCreateForumTopic.deserialize(BinaryReader reader) {
    // Read [ChannelsCreateForumTopic] fields.
    final flags = reader.readInt32();
    final channel = reader.readObject() as InputChannelBase;
    final title = reader.readString();
    final hasIconColorField = (flags & 1) != 0;
    final iconColor = hasIconColorField ? reader.readInt32() : null;
    final hasIconEmojiIdField = (flags & 8) != 0;
    final iconEmojiId = hasIconEmojiIdField ? reader.readInt64() : null;
    final randomId = reader.readInt64();
    final hasSendAsField = (flags & 4) != 0;
    final sendAs = hasSendAsField ? reader.readObject() as InputPeerBase : null;

    // Construct [ChannelsCreateForumTopic] object.
    final returnValue = ChannelsCreateForumTopic(
      channel: channel,
      title: title,
      iconColor: iconColor,
      iconEmojiId: iconEmojiId,
      randomId: randomId,
      sendAs: sendAs,
    );

    // Now return the deserialized [ChannelsCreateForumTopic].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: iconColor != null,
      b03: iconEmojiId != null,
      b02: sendAs != null,
    );

    return v;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Title.
  final String title;

  /// Icon Color.
  final int? iconColor;

  /// Icon Emoji Id.
  final int? iconEmojiId;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Send As.
  final InputPeerBase? sendAs;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf40c0224.
    buffer.writeInt32(0xf40c0224);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);
    buffer.writeString(title);
    final localIconColorCopy = iconColor;
    if (localIconColorCopy != null) {
      buffer.writeInt32(localIconColorCopy);
    }
    final localIconEmojiIdCopy = iconEmojiId;
    if (localIconEmojiIdCopy != null) {
      buffer.writeInt64(localIconEmojiIdCopy);
    }
    buffer.writeInt64(randomId);
    final localSendAsCopy = sendAs;
    if (localSendAsCopy != null) {
      buffer.writeObject(localSendAsCopy);
    }

    // Finished serialization.
  }
}

/// Channels Get Forum Topics.
///
/// ID: `0de560d1`.
class ChannelsGetForumTopics extends TlMethod<MessagesForumTopicsBase> {
  /// Channels Get Forum Topics constructor.
  const ChannelsGetForumTopics({
    required this.channel,
    this.q,
    required this.offsetDate,
    required this.offsetId,
    required this.offsetTopic,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetForumTopics.deserialize(BinaryReader reader) {
    // Read [ChannelsGetForumTopics] fields.
    final flags = reader.readInt32();
    final channel = reader.readObject() as InputChannelBase;
    final hasQField = (flags & 1) != 0;
    final q = hasQField ? reader.readString() : null;
    final offsetDate = reader.readDateTime();
    final offsetId = reader.readInt32();
    final offsetTopic = reader.readInt32();
    final limit = reader.readInt32();

    // Construct [ChannelsGetForumTopics] object.
    final returnValue = ChannelsGetForumTopics(
      channel: channel,
      q: q,
      offsetDate: offsetDate,
      offsetId: offsetId,
      offsetTopic: offsetTopic,
      limit: limit,
    );

    // Now return the deserialized [ChannelsGetForumTopics].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: q != null,
    );

    return v;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Q.
  final String? q;

  /// Offset Date.
  final DateTime offsetDate;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Offset Topic.
  ///
  /// Field type is Int32.
  final int offsetTopic;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0de560d1.
    buffer.writeInt32(0x0de560d1);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);
    final localQCopy = q;
    if (localQCopy != null) {
      buffer.writeString(localQCopy);
    }
    buffer.writeDateTime(offsetDate);
    buffer.writeInt32(offsetId);
    buffer.writeInt32(offsetTopic);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Channels Get Forum Topics By I D.
///
/// ID: `b0831eb9`.
class ChannelsGetForumTopicsByID extends TlMethod<MessagesForumTopicsBase> {
  /// Channels Get Forum Topics By I D constructor.
  const ChannelsGetForumTopicsByID({
    required this.channel,
    required this.topics,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetForumTopicsByID.deserialize(BinaryReader reader) {
    // Read [ChannelsGetForumTopicsByID] fields.
    final channel = reader.readObject() as InputChannelBase;
    final topics = reader.readVectorInt32();

    // Construct [ChannelsGetForumTopicsByID] object.
    final returnValue = ChannelsGetForumTopicsByID(
      channel: channel,
      topics: topics,
    );

    // Now return the deserialized [ChannelsGetForumTopicsByID].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Topics.
  final List<int> topics;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb0831eb9.
    buffer.writeInt32(0xb0831eb9);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeVectorInt32(topics);

    // Finished serialization.
  }
}

/// Channels Edit Forum Topic.
///
/// ID: `f4dfa185`.
class ChannelsEditForumTopic extends TlMethod<UpdatesBase> {
  /// Channels Edit Forum Topic constructor.
  const ChannelsEditForumTopic({
    required this.channel,
    required this.topicId,
    this.title,
    this.iconEmojiId,
    required this.closed,
    required this.hidden,
  }) : super._();

  /// Deserialize.
  factory ChannelsEditForumTopic.deserialize(BinaryReader reader) {
    // Read [ChannelsEditForumTopic] fields.
    final flags = reader.readInt32();
    final channel = reader.readObject() as InputChannelBase;
    final topicId = reader.readInt32();
    final hasTitleField = (flags & 1) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasIconEmojiIdField = (flags & 2) != 0;
    final iconEmojiId = hasIconEmojiIdField ? reader.readInt64() : null;
    final closed = (flags & 4) != 0;
    final hidden = (flags & 8) != 0;

    // Construct [ChannelsEditForumTopic] object.
    final returnValue = ChannelsEditForumTopic(
      channel: channel,
      topicId: topicId,
      title: title,
      iconEmojiId: iconEmojiId,
      closed: closed,
      hidden: hidden,
    );

    // Now return the deserialized [ChannelsEditForumTopic].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: title != null,
      b01: iconEmojiId != null,
      b02: closed,
      b03: hidden,
    );

    return v;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Topic Id.
  ///
  /// Field type is Int32.
  final int topicId;

  /// Title.
  final String? title;

  /// Icon Emoji Id.
  final int? iconEmojiId;

  /// closed: bit 2 of flags.2?Bool
  final bool closed;

  /// hidden: bit 3 of flags.3?Bool
  final bool hidden;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf4dfa185.
    buffer.writeInt32(0xf4dfa185);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);
    buffer.writeInt32(topicId);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localIconEmojiIdCopy = iconEmojiId;
    if (localIconEmojiIdCopy != null) {
      buffer.writeInt64(localIconEmojiIdCopy);
    }

    // Finished serialization.
  }
}

/// Channels Update Pinned Forum Topic.
///
/// ID: `6c2d9026`.
class ChannelsUpdatePinnedForumTopic extends TlMethod<UpdatesBase> {
  /// Channels Update Pinned Forum Topic constructor.
  const ChannelsUpdatePinnedForumTopic({
    required this.channel,
    required this.topicId,
    required this.pinned,
  }) : super._();

  /// Deserialize.
  factory ChannelsUpdatePinnedForumTopic.deserialize(BinaryReader reader) {
    // Read [ChannelsUpdatePinnedForumTopic] fields.
    final channel = reader.readObject() as InputChannelBase;
    final topicId = reader.readInt32();
    final pinned = reader.readBool();

    // Construct [ChannelsUpdatePinnedForumTopic] object.
    final returnValue = ChannelsUpdatePinnedForumTopic(
      channel: channel,
      topicId: topicId,
      pinned: pinned,
    );

    // Now return the deserialized [ChannelsUpdatePinnedForumTopic].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Topic Id.
  ///
  /// Field type is Int32.
  final int topicId;

  /// Pinned.
  final bool pinned;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6c2d9026.
    buffer.writeInt32(0x6c2d9026);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeInt32(topicId);
    buffer.writeBool(pinned);

    // Finished serialization.
  }
}

/// Channels Delete Topic History.
///
/// ID: `34435f2d`.
class ChannelsDeleteTopicHistory extends TlMethod<MessagesAffectedHistoryBase> {
  /// Channels Delete Topic History constructor.
  const ChannelsDeleteTopicHistory({
    required this.channel,
    required this.topMsgId,
  }) : super._();

  /// Deserialize.
  factory ChannelsDeleteTopicHistory.deserialize(BinaryReader reader) {
    // Read [ChannelsDeleteTopicHistory] fields.
    final channel = reader.readObject() as InputChannelBase;
    final topMsgId = reader.readInt32();

    // Construct [ChannelsDeleteTopicHistory] object.
    final returnValue = ChannelsDeleteTopicHistory(
      channel: channel,
      topMsgId: topMsgId,
    );

    // Now return the deserialized [ChannelsDeleteTopicHistory].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Top Msg Id.
  ///
  /// Field type is Int32.
  final int topMsgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x34435f2d.
    buffer.writeInt32(0x34435f2d);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeInt32(topMsgId);

    // Finished serialization.
  }
}

/// Channels Reorder Pinned Forum Topics.
///
/// ID: `2950a18f`.
class ChannelsReorderPinnedForumTopics extends TlMethod<UpdatesBase> {
  /// Channels Reorder Pinned Forum Topics constructor.
  const ChannelsReorderPinnedForumTopics({
    required this.force,
    required this.channel,
    required this.order,
  }) : super._();

  /// Deserialize.
  factory ChannelsReorderPinnedForumTopics.deserialize(BinaryReader reader) {
    // Read [ChannelsReorderPinnedForumTopics] fields.
    final flags = reader.readInt32();
    final force = (flags & 1) != 0;
    final channel = reader.readObject() as InputChannelBase;
    final order = reader.readVectorInt32();

    // Construct [ChannelsReorderPinnedForumTopics] object.
    final returnValue = ChannelsReorderPinnedForumTopics(
      force: force,
      channel: channel,
      order: order,
    );

    // Now return the deserialized [ChannelsReorderPinnedForumTopics].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: force,
    );

    return v;
  }

  /// force: bit 0 of flags.0?true
  final bool force;

  /// Channel.
  final InputChannelBase channel;

  /// Order.
  final List<int> order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2950a18f.
    buffer.writeInt32(0x2950a18f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);
    buffer.writeVectorInt32(order);

    // Finished serialization.
  }
}

/// Channels Toggle Anti Spam.
///
/// ID: `68f3e4eb`.
class ChannelsToggleAntiSpam extends TlMethod<UpdatesBase> {
  /// Channels Toggle Anti Spam constructor.
  const ChannelsToggleAntiSpam({
    required this.channel,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory ChannelsToggleAntiSpam.deserialize(BinaryReader reader) {
    // Read [ChannelsToggleAntiSpam] fields.
    final channel = reader.readObject() as InputChannelBase;
    final enabled = reader.readBool();

    // Construct [ChannelsToggleAntiSpam] object.
    final returnValue = ChannelsToggleAntiSpam(
      channel: channel,
      enabled: enabled,
    );

    // Now return the deserialized [ChannelsToggleAntiSpam].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x68f3e4eb.
    buffer.writeInt32(0x68f3e4eb);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Channels Report Anti Spam False Positive.
///
/// ID: `a850a693`.
class ChannelsReportAntiSpamFalsePositive extends TlMethod<bool> {
  /// Channels Report Anti Spam False Positive constructor.
  const ChannelsReportAntiSpamFalsePositive({
    required this.channel,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory ChannelsReportAntiSpamFalsePositive.deserialize(BinaryReader reader) {
    // Read [ChannelsReportAntiSpamFalsePositive] fields.
    final channel = reader.readObject() as InputChannelBase;
    final msgId = reader.readInt32();

    // Construct [ChannelsReportAntiSpamFalsePositive] object.
    final returnValue = ChannelsReportAntiSpamFalsePositive(
      channel: channel,
      msgId: msgId,
    );

    // Now return the deserialized [ChannelsReportAntiSpamFalsePositive].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa850a693.
    buffer.writeInt32(0xa850a693);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Messages Set Default History T T L.
///
/// ID: `9eb51445`.
class MessagesSetDefaultHistoryTTL extends TlMethod<bool> {
  /// Messages Set Default History T T L constructor.
  const MessagesSetDefaultHistoryTTL({
    required this.period,
  }) : super._();

  /// Deserialize.
  factory MessagesSetDefaultHistoryTTL.deserialize(BinaryReader reader) {
    // Read [MessagesSetDefaultHistoryTTL] fields.
    final period = reader.readInt32();

    // Construct [MessagesSetDefaultHistoryTTL] object.
    final returnValue = MessagesSetDefaultHistoryTTL(
      period: period,
    );

    // Now return the deserialized [MessagesSetDefaultHistoryTTL].
    return returnValue;
  }

  /// Period.
  ///
  /// Field type is Int32.
  final int period;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9eb51445.
    buffer.writeInt32(0x9eb51445);

    // Write fields.
    buffer.writeInt32(period);

    // Finished serialization.
  }
}

/// Messages Get Default History T T L.
///
/// ID: `658b7188`.
class MessagesGetDefaultHistoryTTL extends TlMethod<DefaultHistoryTTLBase> {
  /// Messages Get Default History T T L constructor.
  const MessagesGetDefaultHistoryTTL() : super._();

  /// Deserialize.
  factory MessagesGetDefaultHistoryTTL.deserialize(BinaryReader reader) {
    // Construct [MessagesGetDefaultHistoryTTL] object.
    final returnValue = MessagesGetDefaultHistoryTTL();

    // Now return the deserialized [MessagesGetDefaultHistoryTTL].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x658b7188.
    buffer.writeInt32(0x658b7188);

    // Finished serialization.
  }
}

/// Contacts Export Contact Token.
///
/// ID: `f8654027`.
class ContactsExportContactToken extends TlMethod<ExportedContactTokenBase> {
  /// Contacts Export Contact Token constructor.
  const ContactsExportContactToken() : super._();

  /// Deserialize.
  factory ContactsExportContactToken.deserialize(BinaryReader reader) {
    // Construct [ContactsExportContactToken] object.
    final returnValue = ContactsExportContactToken();

    // Now return the deserialized [ContactsExportContactToken].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf8654027.
    buffer.writeInt32(0xf8654027);

    // Finished serialization.
  }
}

/// Contacts Import Contact Token.
///
/// ID: `13005788`.
class ContactsImportContactToken extends TlMethod<UserBase> {
  /// Contacts Import Contact Token constructor.
  const ContactsImportContactToken({
    required this.token,
  }) : super._();

  /// Deserialize.
  factory ContactsImportContactToken.deserialize(BinaryReader reader) {
    // Read [ContactsImportContactToken] fields.
    final token = reader.readString();

    // Construct [ContactsImportContactToken] object.
    final returnValue = ContactsImportContactToken(
      token: token,
    );

    // Now return the deserialized [ContactsImportContactToken].
    return returnValue;
  }

  /// Token.
  final String token;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x13005788.
    buffer.writeInt32(0x13005788);

    // Write fields.
    buffer.writeString(token);

    // Finished serialization.
  }
}

/// Photos Upload Contact Profile Photo.
///
/// ID: `e14c4a71`.
class PhotosUploadContactProfilePhoto extends TlMethod<PhotosPhotoBase> {
  /// Photos Upload Contact Profile Photo constructor.
  const PhotosUploadContactProfilePhoto({
    required this.suggest,
    required this.save,
    required this.userId,
    this.file,
    this.video,
    this.videoStartTs,
    this.videoEmojiMarkup,
  }) : super._();

  /// Deserialize.
  factory PhotosUploadContactProfilePhoto.deserialize(BinaryReader reader) {
    // Read [PhotosUploadContactProfilePhoto] fields.
    final flags = reader.readInt32();
    final suggest = (flags & 8) != 0;
    final save = (flags & 16) != 0;
    final userId = reader.readObject() as InputUserBase;
    final hasFileField = (flags & 1) != 0;
    final file = hasFileField ? reader.readObject() as InputFileBase : null;
    final hasVideoField = (flags & 2) != 0;
    final video = hasVideoField ? reader.readObject() as InputFileBase : null;
    final hasVideoStartTsField = (flags & 4) != 0;
    final videoStartTs = hasVideoStartTsField ? reader.readFloat64() : null;
    final hasVideoEmojiMarkupField = (flags & 32) != 0;
    final videoEmojiMarkup =
        hasVideoEmojiMarkupField ? reader.readObject() as VideoSizeBase : null;

    // Construct [PhotosUploadContactProfilePhoto] object.
    final returnValue = PhotosUploadContactProfilePhoto(
      suggest: suggest,
      save: save,
      userId: userId,
      file: file,
      video: video,
      videoStartTs: videoStartTs,
      videoEmojiMarkup: videoEmojiMarkup,
    );

    // Now return the deserialized [PhotosUploadContactProfilePhoto].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: suggest,
      b04: save,
      b00: file != null,
      b01: video != null,
      b02: videoStartTs != null,
      b05: videoEmojiMarkup != null,
    );

    return v;
  }

  /// suggest: bit 3 of flags.3?true
  final bool suggest;

  /// save: bit 4 of flags.4?true
  final bool save;

  /// User Id.
  final InputUserBase userId;

  /// File.
  final InputFileBase? file;

  /// Video.
  final InputFileBase? video;

  /// Video Start Ts.
  final double? videoStartTs;

  /// Video Emoji Markup.
  final VideoSizeBase? videoEmojiMarkup;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe14c4a71.
    buffer.writeInt32(0xe14c4a71);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(userId);
    final localFileCopy = file;
    if (localFileCopy != null) {
      buffer.writeObject(localFileCopy);
    }
    final localVideoCopy = video;
    if (localVideoCopy != null) {
      buffer.writeObject(localVideoCopy);
    }
    final localVideoStartTsCopy = videoStartTs;
    if (localVideoStartTsCopy != null) {
      buffer.writeDouble(localVideoStartTsCopy);
    }
    final localVideoEmojiMarkupCopy = videoEmojiMarkup;
    if (localVideoEmojiMarkupCopy != null) {
      buffer.writeObject(localVideoEmojiMarkupCopy);
    }

    // Finished serialization.
  }
}

/// Channels Toggle Participants Hidden.
///
/// ID: `6a6e7854`.
class ChannelsToggleParticipantsHidden extends TlMethod<UpdatesBase> {
  /// Channels Toggle Participants Hidden constructor.
  const ChannelsToggleParticipantsHidden({
    required this.channel,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory ChannelsToggleParticipantsHidden.deserialize(BinaryReader reader) {
    // Read [ChannelsToggleParticipantsHidden] fields.
    final channel = reader.readObject() as InputChannelBase;
    final enabled = reader.readBool();

    // Construct [ChannelsToggleParticipantsHidden] object.
    final returnValue = ChannelsToggleParticipantsHidden(
      channel: channel,
      enabled: enabled,
    );

    // Now return the deserialized [ChannelsToggleParticipantsHidden].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6a6e7854.
    buffer.writeInt32(0x6a6e7854);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Messages Send Bot Requested Peer.
///
/// ID: `91b2d060`.
class MessagesSendBotRequestedPeer extends TlMethod<UpdatesBase> {
  /// Messages Send Bot Requested Peer constructor.
  const MessagesSendBotRequestedPeer({
    required this.peer,
    required this.msgId,
    required this.buttonId,
    required this.requestedPeers,
  }) : super._();

  /// Deserialize.
  factory MessagesSendBotRequestedPeer.deserialize(BinaryReader reader) {
    // Read [MessagesSendBotRequestedPeer] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();
    final buttonId = reader.readInt32();
    final requestedPeers = reader.readVectorObject<InputPeerBase>();

    // Construct [MessagesSendBotRequestedPeer] object.
    final returnValue = MessagesSendBotRequestedPeer(
      peer: peer,
      msgId: msgId,
      buttonId: buttonId,
      requestedPeers: requestedPeers,
    );

    // Now return the deserialized [MessagesSendBotRequestedPeer].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Button Id.
  ///
  /// Field type is Int32.
  final int buttonId;

  /// Requested Peers.
  final List<InputPeerBase> requestedPeers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x91b2d060.
    buffer.writeInt32(0x91b2d060);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);
    buffer.writeInt32(buttonId);
    buffer.writeVectorObject(requestedPeers);

    // Finished serialization.
  }
}

/// Account Get Default Profile Photo Emojis.
///
/// ID: `e2750328`.
class AccountGetDefaultProfilePhotoEmojis extends TlMethod<EmojiListBase> {
  /// Account Get Default Profile Photo Emojis constructor.
  const AccountGetDefaultProfilePhotoEmojis({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetDefaultProfilePhotoEmojis.deserialize(BinaryReader reader) {
    // Read [AccountGetDefaultProfilePhotoEmojis] fields.
    final hash = reader.readInt64();

    // Construct [AccountGetDefaultProfilePhotoEmojis] object.
    final returnValue = AccountGetDefaultProfilePhotoEmojis(
      hash: hash,
    );

    // Now return the deserialized [AccountGetDefaultProfilePhotoEmojis].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe2750328.
    buffer.writeInt32(0xe2750328);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Account Get Default Group Photo Emojis.
///
/// ID: `915860ae`.
class AccountGetDefaultGroupPhotoEmojis extends TlMethod<EmojiListBase> {
  /// Account Get Default Group Photo Emojis constructor.
  const AccountGetDefaultGroupPhotoEmojis({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetDefaultGroupPhotoEmojis.deserialize(BinaryReader reader) {
    // Read [AccountGetDefaultGroupPhotoEmojis] fields.
    final hash = reader.readInt64();

    // Construct [AccountGetDefaultGroupPhotoEmojis] object.
    final returnValue = AccountGetDefaultGroupPhotoEmojis(
      hash: hash,
    );

    // Now return the deserialized [AccountGetDefaultGroupPhotoEmojis].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x915860ae.
    buffer.writeInt32(0x915860ae);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Auth Request Firebase Sms.
///
/// ID: `89464b50`.
class AuthRequestFirebaseSms extends TlMethod<bool> {
  /// Auth Request Firebase Sms constructor.
  const AuthRequestFirebaseSms({
    required this.phoneNumber,
    required this.phoneCodeHash,
    this.safetyNetToken,
    this.iosPushSecret,
  }) : super._();

  /// Deserialize.
  factory AuthRequestFirebaseSms.deserialize(BinaryReader reader) {
    // Read [AuthRequestFirebaseSms] fields.
    final flags = reader.readInt32();
    final phoneNumber = reader.readString();
    final phoneCodeHash = reader.readString();
    final hasSafetyNetTokenField = (flags & 1) != 0;
    final safetyNetToken = hasSafetyNetTokenField ? reader.readString() : null;
    final hasIosPushSecretField = (flags & 2) != 0;
    final iosPushSecret = hasIosPushSecretField ? reader.readString() : null;

    // Construct [AuthRequestFirebaseSms] object.
    final returnValue = AuthRequestFirebaseSms(
      phoneNumber: phoneNumber,
      phoneCodeHash: phoneCodeHash,
      safetyNetToken: safetyNetToken,
      iosPushSecret: iosPushSecret,
    );

    // Now return the deserialized [AuthRequestFirebaseSms].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: safetyNetToken != null,
      b01: iosPushSecret != null,
    );

    return v;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// Safety Net Token.
  final String? safetyNetToken;

  /// Ios Push Secret.
  final String? iosPushSecret;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x89464b50.
    buffer.writeInt32(0x89464b50);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(phoneNumber);
    buffer.writeString(phoneCodeHash);
    final localSafetyNetTokenCopy = safetyNetToken;
    if (localSafetyNetTokenCopy != null) {
      buffer.writeString(localSafetyNetTokenCopy);
    }
    final localIosPushSecretCopy = iosPushSecret;
    if (localIosPushSecretCopy != null) {
      buffer.writeString(localIosPushSecretCopy);
    }

    // Finished serialization.
  }
}

/// Messages Get Emoji Groups.
///
/// ID: `7488ce5b`.
class MessagesGetEmojiGroups extends TlMethod<MessagesEmojiGroupsBase> {
  /// Messages Get Emoji Groups constructor.
  const MessagesGetEmojiGroups({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetEmojiGroups.deserialize(BinaryReader reader) {
    // Read [MessagesGetEmojiGroups] fields.
    final hash = reader.readInt32();

    // Construct [MessagesGetEmojiGroups] object.
    final returnValue = MessagesGetEmojiGroups(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetEmojiGroups].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7488ce5b.
    buffer.writeInt32(0x7488ce5b);

    // Write fields.
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Messages Get Emoji Status Groups.
///
/// ID: `2ecd56cd`.
class MessagesGetEmojiStatusGroups extends TlMethod<MessagesEmojiGroupsBase> {
  /// Messages Get Emoji Status Groups constructor.
  const MessagesGetEmojiStatusGroups({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetEmojiStatusGroups.deserialize(BinaryReader reader) {
    // Read [MessagesGetEmojiStatusGroups] fields.
    final hash = reader.readInt32();

    // Construct [MessagesGetEmojiStatusGroups] object.
    final returnValue = MessagesGetEmojiStatusGroups(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetEmojiStatusGroups].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2ecd56cd.
    buffer.writeInt32(0x2ecd56cd);

    // Write fields.
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Messages Get Emoji Profile Photo Groups.
///
/// ID: `21a548f3`.
class MessagesGetEmojiProfilePhotoGroups
    extends TlMethod<MessagesEmojiGroupsBase> {
  /// Messages Get Emoji Profile Photo Groups constructor.
  const MessagesGetEmojiProfilePhotoGroups({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetEmojiProfilePhotoGroups.deserialize(BinaryReader reader) {
    // Read [MessagesGetEmojiProfilePhotoGroups] fields.
    final hash = reader.readInt32();

    // Construct [MessagesGetEmojiProfilePhotoGroups] object.
    final returnValue = MessagesGetEmojiProfilePhotoGroups(
      hash: hash,
    );

    // Now return the deserialized [MessagesGetEmojiProfilePhotoGroups].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x21a548f3.
    buffer.writeInt32(0x21a548f3);

    // Write fields.
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Messages Search Custom Emoji.
///
/// ID: `2c11c0d7`.
class MessagesSearchCustomEmoji extends TlMethod<EmojiListBase> {
  /// Messages Search Custom Emoji constructor.
  const MessagesSearchCustomEmoji({
    required this.emoticon,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesSearchCustomEmoji.deserialize(BinaryReader reader) {
    // Read [MessagesSearchCustomEmoji] fields.
    final emoticon = reader.readString();
    final hash = reader.readInt64();

    // Construct [MessagesSearchCustomEmoji] object.
    final returnValue = MessagesSearchCustomEmoji(
      emoticon: emoticon,
      hash: hash,
    );

    // Now return the deserialized [MessagesSearchCustomEmoji].
    return returnValue;
  }

  /// Emoticon.
  final String emoticon;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2c11c0d7.
    buffer.writeInt32(0x2c11c0d7);

    // Write fields.
    buffer.writeString(emoticon);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Toggle Peer Translations.
///
/// ID: `e47cb579`.
class MessagesTogglePeerTranslations extends TlMethod<bool> {
  /// Messages Toggle Peer Translations constructor.
  const MessagesTogglePeerTranslations({
    required this.disabled,
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesTogglePeerTranslations.deserialize(BinaryReader reader) {
    // Read [MessagesTogglePeerTranslations] fields.
    final flags = reader.readInt32();
    final disabled = (flags & 1) != 0;
    final peer = reader.readObject() as InputPeerBase;

    // Construct [MessagesTogglePeerTranslations] object.
    final returnValue = MessagesTogglePeerTranslations(
      disabled: disabled,
      peer: peer,
    );

    // Now return the deserialized [MessagesTogglePeerTranslations].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: disabled,
    );

    return v;
  }

  /// disabled: bit 0 of flags.0?true
  final bool disabled;

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe47cb579.
    buffer.writeInt32(0xe47cb579);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Account Get Auto Save Settings.
///
/// ID: `adcbbcda`.
class AccountGetAutoSaveSettings extends TlMethod<AccountAutoSaveSettingsBase> {
  /// Account Get Auto Save Settings constructor.
  const AccountGetAutoSaveSettings() : super._();

  /// Deserialize.
  factory AccountGetAutoSaveSettings.deserialize(BinaryReader reader) {
    // Construct [AccountGetAutoSaveSettings] object.
    final returnValue = AccountGetAutoSaveSettings();

    // Now return the deserialized [AccountGetAutoSaveSettings].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xadcbbcda.
    buffer.writeInt32(0xadcbbcda);

    // Finished serialization.
  }
}

/// Account Save Auto Save Settings.
///
/// ID: `d69b8361`.
class AccountSaveAutoSaveSettings extends TlMethod<bool> {
  /// Account Save Auto Save Settings constructor.
  const AccountSaveAutoSaveSettings({
    required this.users,
    required this.chats,
    required this.broadcasts,
    this.peer,
    required this.settings,
  }) : super._();

  /// Deserialize.
  factory AccountSaveAutoSaveSettings.deserialize(BinaryReader reader) {
    // Read [AccountSaveAutoSaveSettings] fields.
    final flags = reader.readInt32();
    final users = (flags & 1) != 0;
    final chats = (flags & 2) != 0;
    final broadcasts = (flags & 4) != 0;
    final hasPeerField = (flags & 8) != 0;
    final peer = hasPeerField ? reader.readObject() as InputPeerBase : null;
    final settings = reader.readObject() as AutoSaveSettingsBase;

    // Construct [AccountSaveAutoSaveSettings] object.
    final returnValue = AccountSaveAutoSaveSettings(
      users: users,
      chats: chats,
      broadcasts: broadcasts,
      peer: peer,
      settings: settings,
    );

    // Now return the deserialized [AccountSaveAutoSaveSettings].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: users,
      b01: chats,
      b02: broadcasts,
      b03: peer != null,
    );

    return v;
  }

  /// users: bit 0 of flags.0?true
  final bool users;

  /// chats: bit 1 of flags.1?true
  final bool chats;

  /// broadcasts: bit 2 of flags.2?true
  final bool broadcasts;

  /// Peer.
  final InputPeerBase? peer;

  /// Settings.
  final AutoSaveSettingsBase settings;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd69b8361.
    buffer.writeInt32(0xd69b8361);

    // Write fields.
    buffer.writeInt32(flags);
    final localPeerCopy = peer;
    if (localPeerCopy != null) {
      buffer.writeObject(localPeerCopy);
    }
    buffer.writeObject(settings);

    // Finished serialization.
  }
}

/// Account Delete Auto Save Exceptions.
///
/// ID: `53bc0020`.
class AccountDeleteAutoSaveExceptions extends TlMethod<bool> {
  /// Account Delete Auto Save Exceptions constructor.
  const AccountDeleteAutoSaveExceptions() : super._();

  /// Deserialize.
  factory AccountDeleteAutoSaveExceptions.deserialize(BinaryReader reader) {
    // Construct [AccountDeleteAutoSaveExceptions] object.
    final returnValue = AccountDeleteAutoSaveExceptions();

    // Now return the deserialized [AccountDeleteAutoSaveExceptions].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x53bc0020.
    buffer.writeInt32(0x53bc0020);

    // Finished serialization.
  }
}

/// Stickers Change Sticker.
///
/// ID: `f5537ebc`.
class StickersChangeSticker extends TlMethod<MessagesStickerSetBase> {
  /// Stickers Change Sticker constructor.
  const StickersChangeSticker({
    required this.sticker,
    this.emoji,
    this.maskCoords,
    this.keywords,
  }) : super._();

  /// Deserialize.
  factory StickersChangeSticker.deserialize(BinaryReader reader) {
    // Read [StickersChangeSticker] fields.
    final flags = reader.readInt32();
    final sticker = reader.readObject() as InputDocumentBase;
    final hasEmojiField = (flags & 1) != 0;
    final emoji = hasEmojiField ? reader.readString() : null;
    final hasMaskCoordsField = (flags & 2) != 0;
    final maskCoords =
        hasMaskCoordsField ? reader.readObject() as MaskCoordsBase : null;
    final hasKeywordsField = (flags & 4) != 0;
    final keywords = hasKeywordsField ? reader.readString() : null;

    // Construct [StickersChangeSticker] object.
    final returnValue = StickersChangeSticker(
      sticker: sticker,
      emoji: emoji,
      maskCoords: maskCoords,
      keywords: keywords,
    );

    // Now return the deserialized [StickersChangeSticker].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: emoji != null,
      b01: maskCoords != null,
      b02: keywords != null,
    );

    return v;
  }

  /// Sticker.
  final InputDocumentBase sticker;

  /// Emoji.
  final String? emoji;

  /// Mask Coords.
  final MaskCoordsBase? maskCoords;

  /// Keywords.
  final String? keywords;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf5537ebc.
    buffer.writeInt32(0xf5537ebc);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(sticker);
    final localEmojiCopy = emoji;
    if (localEmojiCopy != null) {
      buffer.writeString(localEmojiCopy);
    }
    final localMaskCoordsCopy = maskCoords;
    if (localMaskCoordsCopy != null) {
      buffer.writeObject(localMaskCoordsCopy);
    }
    final localKeywordsCopy = keywords;
    if (localKeywordsCopy != null) {
      buffer.writeString(localKeywordsCopy);
    }

    // Finished serialization.
  }
}

/// Stickers Rename Sticker Set.
///
/// ID: `124b1c00`.
class StickersRenameStickerSet extends TlMethod<MessagesStickerSetBase> {
  /// Stickers Rename Sticker Set constructor.
  const StickersRenameStickerSet({
    required this.stickerset,
    required this.title,
  }) : super._();

  /// Deserialize.
  factory StickersRenameStickerSet.deserialize(BinaryReader reader) {
    // Read [StickersRenameStickerSet] fields.
    final stickerset = reader.readObject() as InputStickerSetBase;
    final title = reader.readString();

    // Construct [StickersRenameStickerSet] object.
    final returnValue = StickersRenameStickerSet(
      stickerset: stickerset,
      title: title,
    );

    // Now return the deserialized [StickersRenameStickerSet].
    return returnValue;
  }

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Title.
  final String title;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x124b1c00.
    buffer.writeInt32(0x124b1c00);

    // Write fields.
    buffer.writeObject(stickerset);
    buffer.writeString(title);

    // Finished serialization.
  }
}

/// Stickers Delete Sticker Set.
///
/// ID: `87704394`.
class StickersDeleteStickerSet extends TlMethod<bool> {
  /// Stickers Delete Sticker Set constructor.
  const StickersDeleteStickerSet({
    required this.stickerset,
  }) : super._();

  /// Deserialize.
  factory StickersDeleteStickerSet.deserialize(BinaryReader reader) {
    // Read [StickersDeleteStickerSet] fields.
    final stickerset = reader.readObject() as InputStickerSetBase;

    // Construct [StickersDeleteStickerSet] object.
    final returnValue = StickersDeleteStickerSet(
      stickerset: stickerset,
    );

    // Now return the deserialized [StickersDeleteStickerSet].
    return returnValue;
  }

  /// Stickerset.
  final InputStickerSetBase stickerset;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x87704394.
    buffer.writeInt32(0x87704394);

    // Write fields.
    buffer.writeObject(stickerset);

    // Finished serialization.
  }
}

/// Messages Get Bot App.
///
/// ID: `34fdc5c3`.
class MessagesGetBotApp extends TlMethod<MessagesBotAppBase> {
  /// Messages Get Bot App constructor.
  const MessagesGetBotApp({
    required this.app,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetBotApp.deserialize(BinaryReader reader) {
    // Read [MessagesGetBotApp] fields.
    final app = reader.readObject() as InputBotAppBase;
    final hash = reader.readInt64();

    // Construct [MessagesGetBotApp] object.
    final returnValue = MessagesGetBotApp(
      app: app,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetBotApp].
    return returnValue;
  }

  /// App.
  final InputBotAppBase app;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x34fdc5c3.
    buffer.writeInt32(0x34fdc5c3);

    // Write fields.
    buffer.writeObject(app);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Request App Web View.
///
/// ID: `8c5a3b3c`.
class MessagesRequestAppWebView extends TlMethod<AppWebViewResultBase> {
  /// Messages Request App Web View constructor.
  const MessagesRequestAppWebView({
    required this.writeAllowed,
    required this.peer,
    required this.app,
    this.startParam,
    this.themeParams,
    required this.platform,
  }) : super._();

  /// Deserialize.
  factory MessagesRequestAppWebView.deserialize(BinaryReader reader) {
    // Read [MessagesRequestAppWebView] fields.
    final flags = reader.readInt32();
    final writeAllowed = (flags & 1) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final app = reader.readObject() as InputBotAppBase;
    final hasStartParamField = (flags & 2) != 0;
    final startParam = hasStartParamField ? reader.readString() : null;
    final hasThemeParamsField = (flags & 4) != 0;
    final themeParams =
        hasThemeParamsField ? reader.readObject() as DataJSONBase : null;
    final platform = reader.readString();

    // Construct [MessagesRequestAppWebView] object.
    final returnValue = MessagesRequestAppWebView(
      writeAllowed: writeAllowed,
      peer: peer,
      app: app,
      startParam: startParam,
      themeParams: themeParams,
      platform: platform,
    );

    // Now return the deserialized [MessagesRequestAppWebView].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: writeAllowed,
      b01: startParam != null,
      b02: themeParams != null,
    );

    return v;
  }

  /// write_allowed: bit 0 of flags.0?true
  final bool writeAllowed;

  /// Peer.
  final InputPeerBase peer;

  /// App.
  final InputBotAppBase app;

  /// Start Param.
  final String? startParam;

  /// Theme Params.
  final DataJSONBase? themeParams;

  /// Platform.
  final String platform;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8c5a3b3c.
    buffer.writeInt32(0x8c5a3b3c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeObject(app);
    final localStartParamCopy = startParam;
    if (localStartParamCopy != null) {
      buffer.writeString(localStartParamCopy);
    }
    final localThemeParamsCopy = themeParams;
    if (localThemeParamsCopy != null) {
      buffer.writeObject(localThemeParamsCopy);
    }
    buffer.writeString(platform);

    // Finished serialization.
  }
}

/// Bots Set Bot Info.
///
/// ID: `10cf3123`.
class BotsSetBotInfo extends TlMethod<bool> {
  /// Bots Set Bot Info constructor.
  const BotsSetBotInfo({
    this.bot,
    required this.langCode,
    this.name,
    this.about,
    this.description,
  }) : super._();

  /// Deserialize.
  factory BotsSetBotInfo.deserialize(BinaryReader reader) {
    // Read [BotsSetBotInfo] fields.
    final flags = reader.readInt32();
    final hasBotField = (flags & 4) != 0;
    final bot = hasBotField ? reader.readObject() as InputUserBase : null;
    final langCode = reader.readString();
    final hasNameField = (flags & 8) != 0;
    final name = hasNameField ? reader.readString() : null;
    final hasAboutField = (flags & 1) != 0;
    final about = hasAboutField ? reader.readString() : null;
    final hasDescriptionField = (flags & 2) != 0;
    final description = hasDescriptionField ? reader.readString() : null;

    // Construct [BotsSetBotInfo] object.
    final returnValue = BotsSetBotInfo(
      bot: bot,
      langCode: langCode,
      name: name,
      about: about,
      description: description,
    );

    // Now return the deserialized [BotsSetBotInfo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: bot != null,
      b03: name != null,
      b00: about != null,
      b01: description != null,
    );

    return v;
  }

  /// Bot.
  final InputUserBase? bot;

  /// Lang Code.
  final String langCode;

  /// Name.
  final String? name;

  /// About.
  final String? about;

  /// Description.
  final String? description;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x10cf3123.
    buffer.writeInt32(0x10cf3123);

    // Write fields.
    buffer.writeInt32(flags);
    final localBotCopy = bot;
    if (localBotCopy != null) {
      buffer.writeObject(localBotCopy);
    }
    buffer.writeString(langCode);
    final localNameCopy = name;
    if (localNameCopy != null) {
      buffer.writeString(localNameCopy);
    }
    final localAboutCopy = about;
    if (localAboutCopy != null) {
      buffer.writeString(localAboutCopy);
    }
    final localDescriptionCopy = description;
    if (localDescriptionCopy != null) {
      buffer.writeString(localDescriptionCopy);
    }

    // Finished serialization.
  }
}

/// Bots Get Bot Info.
///
/// ID: `dcd914fd`.
class BotsGetBotInfo extends TlMethod<BotsBotInfoBase> {
  /// Bots Get Bot Info constructor.
  const BotsGetBotInfo({
    this.bot,
    required this.langCode,
  }) : super._();

  /// Deserialize.
  factory BotsGetBotInfo.deserialize(BinaryReader reader) {
    // Read [BotsGetBotInfo] fields.
    final flags = reader.readInt32();
    final hasBotField = (flags & 1) != 0;
    final bot = hasBotField ? reader.readObject() as InputUserBase : null;
    final langCode = reader.readString();

    // Construct [BotsGetBotInfo] object.
    final returnValue = BotsGetBotInfo(
      bot: bot,
      langCode: langCode,
    );

    // Now return the deserialized [BotsGetBotInfo].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: bot != null,
    );

    return v;
  }

  /// Bot.
  final InputUserBase? bot;

  /// Lang Code.
  final String langCode;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xdcd914fd.
    buffer.writeInt32(0xdcd914fd);

    // Write fields.
    buffer.writeInt32(flags);
    final localBotCopy = bot;
    if (localBotCopy != null) {
      buffer.writeObject(localBotCopy);
    }
    buffer.writeString(langCode);

    // Finished serialization.
  }
}

/// Auth Reset Login Email.
///
/// ID: `7e960193`.
class AuthResetLoginEmail extends TlMethod<AuthSentCodeBase> {
  /// Auth Reset Login Email constructor.
  const AuthResetLoginEmail({
    required this.phoneNumber,
    required this.phoneCodeHash,
  }) : super._();

  /// Deserialize.
  factory AuthResetLoginEmail.deserialize(BinaryReader reader) {
    // Read [AuthResetLoginEmail] fields.
    final phoneNumber = reader.readString();
    final phoneCodeHash = reader.readString();

    // Construct [AuthResetLoginEmail] object.
    final returnValue = AuthResetLoginEmail(
      phoneNumber: phoneNumber,
      phoneCodeHash: phoneCodeHash,
    );

    // Now return the deserialized [AuthResetLoginEmail].
    return returnValue;
  }

  /// Phone Number.
  final String phoneNumber;

  /// Phone Code Hash.
  final String phoneCodeHash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7e960193.
    buffer.writeInt32(0x7e960193);

    // Write fields.
    buffer.writeString(phoneNumber);
    buffer.writeString(phoneCodeHash);

    // Finished serialization.
  }
}

/// Chatlists Export Chatlist Invite.
///
/// ID: `8472478e`.
class ChatlistsExportChatlistInvite
    extends TlMethod<ChatlistsExportedChatlistInviteBase> {
  /// Chatlists Export Chatlist Invite constructor.
  const ChatlistsExportChatlistInvite({
    required this.chatlist,
    required this.title,
    required this.peers,
  }) : super._();

  /// Deserialize.
  factory ChatlistsExportChatlistInvite.deserialize(BinaryReader reader) {
    // Read [ChatlistsExportChatlistInvite] fields.
    final chatlist = reader.readObject() as InputChatlistBase;
    final title = reader.readString();
    final peers = reader.readVectorObject<InputPeerBase>();

    // Construct [ChatlistsExportChatlistInvite] object.
    final returnValue = ChatlistsExportChatlistInvite(
      chatlist: chatlist,
      title: title,
      peers: peers,
    );

    // Now return the deserialized [ChatlistsExportChatlistInvite].
    return returnValue;
  }

  /// Chatlist.
  final InputChatlistBase chatlist;

  /// Title.
  final String title;

  /// Peers.
  final List<InputPeerBase> peers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8472478e.
    buffer.writeInt32(0x8472478e);

    // Write fields.
    buffer.writeObject(chatlist);
    buffer.writeString(title);
    buffer.writeVectorObject(peers);

    // Finished serialization.
  }
}

/// Chatlists Delete Exported Invite.
///
/// ID: `719c5c5e`.
class ChatlistsDeleteExportedInvite extends TlMethod<bool> {
  /// Chatlists Delete Exported Invite constructor.
  const ChatlistsDeleteExportedInvite({
    required this.chatlist,
    required this.slug,
  }) : super._();

  /// Deserialize.
  factory ChatlistsDeleteExportedInvite.deserialize(BinaryReader reader) {
    // Read [ChatlistsDeleteExportedInvite] fields.
    final chatlist = reader.readObject() as InputChatlistBase;
    final slug = reader.readString();

    // Construct [ChatlistsDeleteExportedInvite] object.
    final returnValue = ChatlistsDeleteExportedInvite(
      chatlist: chatlist,
      slug: slug,
    );

    // Now return the deserialized [ChatlistsDeleteExportedInvite].
    return returnValue;
  }

  /// Chatlist.
  final InputChatlistBase chatlist;

  /// Slug.
  final String slug;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x719c5c5e.
    buffer.writeInt32(0x719c5c5e);

    // Write fields.
    buffer.writeObject(chatlist);
    buffer.writeString(slug);

    // Finished serialization.
  }
}

/// Chatlists Edit Exported Invite.
///
/// ID: `653db63d`.
class ChatlistsEditExportedInvite extends TlMethod<ExportedChatlistInviteBase> {
  /// Chatlists Edit Exported Invite constructor.
  const ChatlistsEditExportedInvite({
    required this.chatlist,
    required this.slug,
    this.title,
    this.peers,
  }) : super._();

  /// Deserialize.
  factory ChatlistsEditExportedInvite.deserialize(BinaryReader reader) {
    // Read [ChatlistsEditExportedInvite] fields.
    final flags = reader.readInt32();
    final chatlist = reader.readObject() as InputChatlistBase;
    final slug = reader.readString();
    final hasTitleField = (flags & 2) != 0;
    final title = hasTitleField ? reader.readString() : null;
    final hasPeersField = (flags & 4) != 0;
    final peers =
        hasPeersField ? reader.readVectorObject<InputPeerBase>() : null;

    // Construct [ChatlistsEditExportedInvite] object.
    final returnValue = ChatlistsEditExportedInvite(
      chatlist: chatlist,
      slug: slug,
      title: title,
      peers: peers,
    );

    // Now return the deserialized [ChatlistsEditExportedInvite].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: title != null,
      b02: peers != null,
    );

    return v;
  }

  /// Chatlist.
  final InputChatlistBase chatlist;

  /// Slug.
  final String slug;

  /// Title.
  final String? title;

  /// Peers.
  final List<InputPeerBase>? peers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x653db63d.
    buffer.writeInt32(0x653db63d);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(chatlist);
    buffer.writeString(slug);
    final localTitleCopy = title;
    if (localTitleCopy != null) {
      buffer.writeString(localTitleCopy);
    }
    final localPeersCopy = peers;
    if (localPeersCopy != null) {
      buffer.writeVectorObject(localPeersCopy);
    }

    // Finished serialization.
  }
}

/// Chatlists Get Exported Invites.
///
/// ID: `ce03da83`.
class ChatlistsGetExportedInvites
    extends TlMethod<ChatlistsExportedInvitesBase> {
  /// Chatlists Get Exported Invites constructor.
  const ChatlistsGetExportedInvites({
    required this.chatlist,
  }) : super._();

  /// Deserialize.
  factory ChatlistsGetExportedInvites.deserialize(BinaryReader reader) {
    // Read [ChatlistsGetExportedInvites] fields.
    final chatlist = reader.readObject() as InputChatlistBase;

    // Construct [ChatlistsGetExportedInvites] object.
    final returnValue = ChatlistsGetExportedInvites(
      chatlist: chatlist,
    );

    // Now return the deserialized [ChatlistsGetExportedInvites].
    return returnValue;
  }

  /// Chatlist.
  final InputChatlistBase chatlist;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xce03da83.
    buffer.writeInt32(0xce03da83);

    // Write fields.
    buffer.writeObject(chatlist);

    // Finished serialization.
  }
}

/// Chatlists Check Chatlist Invite.
///
/// ID: `41c10fff`.
class ChatlistsCheckChatlistInvite
    extends TlMethod<ChatlistsChatlistInviteBase> {
  /// Chatlists Check Chatlist Invite constructor.
  const ChatlistsCheckChatlistInvite({
    required this.slug,
  }) : super._();

  /// Deserialize.
  factory ChatlistsCheckChatlistInvite.deserialize(BinaryReader reader) {
    // Read [ChatlistsCheckChatlistInvite] fields.
    final slug = reader.readString();

    // Construct [ChatlistsCheckChatlistInvite] object.
    final returnValue = ChatlistsCheckChatlistInvite(
      slug: slug,
    );

    // Now return the deserialized [ChatlistsCheckChatlistInvite].
    return returnValue;
  }

  /// Slug.
  final String slug;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x41c10fff.
    buffer.writeInt32(0x41c10fff);

    // Write fields.
    buffer.writeString(slug);

    // Finished serialization.
  }
}

/// Chatlists Join Chatlist Invite.
///
/// ID: `a6b1e39a`.
class ChatlistsJoinChatlistInvite extends TlMethod<UpdatesBase> {
  /// Chatlists Join Chatlist Invite constructor.
  const ChatlistsJoinChatlistInvite({
    required this.slug,
    required this.peers,
  }) : super._();

  /// Deserialize.
  factory ChatlistsJoinChatlistInvite.deserialize(BinaryReader reader) {
    // Read [ChatlistsJoinChatlistInvite] fields.
    final slug = reader.readString();
    final peers = reader.readVectorObject<InputPeerBase>();

    // Construct [ChatlistsJoinChatlistInvite] object.
    final returnValue = ChatlistsJoinChatlistInvite(
      slug: slug,
      peers: peers,
    );

    // Now return the deserialized [ChatlistsJoinChatlistInvite].
    return returnValue;
  }

  /// Slug.
  final String slug;

  /// Peers.
  final List<InputPeerBase> peers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa6b1e39a.
    buffer.writeInt32(0xa6b1e39a);

    // Write fields.
    buffer.writeString(slug);
    buffer.writeVectorObject(peers);

    // Finished serialization.
  }
}

/// Chatlists Get Chatlist Updates.
///
/// ID: `89419521`.
class ChatlistsGetChatlistUpdates
    extends TlMethod<ChatlistsChatlistUpdatesBase> {
  /// Chatlists Get Chatlist Updates constructor.
  const ChatlistsGetChatlistUpdates({
    required this.chatlist,
  }) : super._();

  /// Deserialize.
  factory ChatlistsGetChatlistUpdates.deserialize(BinaryReader reader) {
    // Read [ChatlistsGetChatlistUpdates] fields.
    final chatlist = reader.readObject() as InputChatlistBase;

    // Construct [ChatlistsGetChatlistUpdates] object.
    final returnValue = ChatlistsGetChatlistUpdates(
      chatlist: chatlist,
    );

    // Now return the deserialized [ChatlistsGetChatlistUpdates].
    return returnValue;
  }

  /// Chatlist.
  final InputChatlistBase chatlist;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x89419521.
    buffer.writeInt32(0x89419521);

    // Write fields.
    buffer.writeObject(chatlist);

    // Finished serialization.
  }
}

/// Chatlists Join Chatlist Updates.
///
/// ID: `e089f8f5`.
class ChatlistsJoinChatlistUpdates extends TlMethod<UpdatesBase> {
  /// Chatlists Join Chatlist Updates constructor.
  const ChatlistsJoinChatlistUpdates({
    required this.chatlist,
    required this.peers,
  }) : super._();

  /// Deserialize.
  factory ChatlistsJoinChatlistUpdates.deserialize(BinaryReader reader) {
    // Read [ChatlistsJoinChatlistUpdates] fields.
    final chatlist = reader.readObject() as InputChatlistBase;
    final peers = reader.readVectorObject<InputPeerBase>();

    // Construct [ChatlistsJoinChatlistUpdates] object.
    final returnValue = ChatlistsJoinChatlistUpdates(
      chatlist: chatlist,
      peers: peers,
    );

    // Now return the deserialized [ChatlistsJoinChatlistUpdates].
    return returnValue;
  }

  /// Chatlist.
  final InputChatlistBase chatlist;

  /// Peers.
  final List<InputPeerBase> peers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe089f8f5.
    buffer.writeInt32(0xe089f8f5);

    // Write fields.
    buffer.writeObject(chatlist);
    buffer.writeVectorObject(peers);

    // Finished serialization.
  }
}

/// Chatlists Hide Chatlist Updates.
///
/// ID: `66e486fb`.
class ChatlistsHideChatlistUpdates extends TlMethod<bool> {
  /// Chatlists Hide Chatlist Updates constructor.
  const ChatlistsHideChatlistUpdates({
    required this.chatlist,
  }) : super._();

  /// Deserialize.
  factory ChatlistsHideChatlistUpdates.deserialize(BinaryReader reader) {
    // Read [ChatlistsHideChatlistUpdates] fields.
    final chatlist = reader.readObject() as InputChatlistBase;

    // Construct [ChatlistsHideChatlistUpdates] object.
    final returnValue = ChatlistsHideChatlistUpdates(
      chatlist: chatlist,
    );

    // Now return the deserialized [ChatlistsHideChatlistUpdates].
    return returnValue;
  }

  /// Chatlist.
  final InputChatlistBase chatlist;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x66e486fb.
    buffer.writeInt32(0x66e486fb);

    // Write fields.
    buffer.writeObject(chatlist);

    // Finished serialization.
  }
}

/// Chatlists Get Leave Chatlist Suggestions.
///
/// ID: `fdbcd714`.
class ChatlistsGetLeaveChatlistSuggestions extends TlMethod<List<PeerBase>> {
  /// Chatlists Get Leave Chatlist Suggestions constructor.
  const ChatlistsGetLeaveChatlistSuggestions({
    required this.chatlist,
  }) : super._();

  /// Deserialize.
  factory ChatlistsGetLeaveChatlistSuggestions.deserialize(
      BinaryReader reader) {
    // Read [ChatlistsGetLeaveChatlistSuggestions] fields.
    final chatlist = reader.readObject() as InputChatlistBase;

    // Construct [ChatlistsGetLeaveChatlistSuggestions] object.
    final returnValue = ChatlistsGetLeaveChatlistSuggestions(
      chatlist: chatlist,
    );

    // Now return the deserialized [ChatlistsGetLeaveChatlistSuggestions].
    return returnValue;
  }

  /// Chatlist.
  final InputChatlistBase chatlist;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xfdbcd714.
    buffer.writeInt32(0xfdbcd714);

    // Write fields.
    buffer.writeObject(chatlist);

    // Finished serialization.
  }
}

/// Chatlists Leave Chatlist.
///
/// ID: `74fae13a`.
class ChatlistsLeaveChatlist extends TlMethod<UpdatesBase> {
  /// Chatlists Leave Chatlist constructor.
  const ChatlistsLeaveChatlist({
    required this.chatlist,
    required this.peers,
  }) : super._();

  /// Deserialize.
  factory ChatlistsLeaveChatlist.deserialize(BinaryReader reader) {
    // Read [ChatlistsLeaveChatlist] fields.
    final chatlist = reader.readObject() as InputChatlistBase;
    final peers = reader.readVectorObject<InputPeerBase>();

    // Construct [ChatlistsLeaveChatlist] object.
    final returnValue = ChatlistsLeaveChatlist(
      chatlist: chatlist,
      peers: peers,
    );

    // Now return the deserialized [ChatlistsLeaveChatlist].
    return returnValue;
  }

  /// Chatlist.
  final InputChatlistBase chatlist;

  /// Peers.
  final List<InputPeerBase> peers;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x74fae13a.
    buffer.writeInt32(0x74fae13a);

    // Write fields.
    buffer.writeObject(chatlist);
    buffer.writeVectorObject(peers);

    // Finished serialization.
  }
}

/// Bots Reorder Usernames.
///
/// ID: `9709b1c2`.
class BotsReorderUsernames extends TlMethod<bool> {
  /// Bots Reorder Usernames constructor.
  const BotsReorderUsernames({
    required this.bot,
    required this.order,
  }) : super._();

  /// Deserialize.
  factory BotsReorderUsernames.deserialize(BinaryReader reader) {
    // Read [BotsReorderUsernames] fields.
    final bot = reader.readObject() as InputUserBase;
    final order = reader.readVectorString();

    // Construct [BotsReorderUsernames] object.
    final returnValue = BotsReorderUsernames(
      bot: bot,
      order: order,
    );

    // Now return the deserialized [BotsReorderUsernames].
    return returnValue;
  }

  /// Bot.
  final InputUserBase bot;

  /// Order.
  final List<String> order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9709b1c2.
    buffer.writeInt32(0x9709b1c2);

    // Write fields.
    buffer.writeObject(bot);
    buffer.writeVectorString(order);

    // Finished serialization.
  }
}

/// Bots Toggle Username.
///
/// ID: `053ca973`.
class BotsToggleUsername extends TlMethod<bool> {
  /// Bots Toggle Username constructor.
  const BotsToggleUsername({
    required this.bot,
    required this.username,
    required this.active,
  }) : super._();

  /// Deserialize.
  factory BotsToggleUsername.deserialize(BinaryReader reader) {
    // Read [BotsToggleUsername] fields.
    final bot = reader.readObject() as InputUserBase;
    final username = reader.readString();
    final active = reader.readBool();

    // Construct [BotsToggleUsername] object.
    final returnValue = BotsToggleUsername(
      bot: bot,
      username: username,
      active: active,
    );

    // Now return the deserialized [BotsToggleUsername].
    return returnValue;
  }

  /// Bot.
  final InputUserBase bot;

  /// Username.
  final String username;

  /// Active.
  final bool active;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x053ca973.
    buffer.writeInt32(0x053ca973);

    // Write fields.
    buffer.writeObject(bot);
    buffer.writeString(username);
    buffer.writeBool(active);

    // Finished serialization.
  }
}

/// Messages Set Chat Wall Paper.
///
/// ID: `8ffacae1`.
class MessagesSetChatWallPaper extends TlMethod<UpdatesBase> {
  /// Messages Set Chat Wall Paper constructor.
  const MessagesSetChatWallPaper({
    required this.forBoth,
    required this.revert,
    required this.peer,
    this.wallpaper,
    this.settings,
    this.id,
  }) : super._();

  /// Deserialize.
  factory MessagesSetChatWallPaper.deserialize(BinaryReader reader) {
    // Read [MessagesSetChatWallPaper] fields.
    final flags = reader.readInt32();
    final forBoth = (flags & 8) != 0;
    final revert = (flags & 16) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final hasWallpaperField = (flags & 1) != 0;
    final wallpaper =
        hasWallpaperField ? reader.readObject() as InputWallPaperBase : null;
    final hasSettingsField = (flags & 4) != 0;
    final settings =
        hasSettingsField ? reader.readObject() as WallPaperSettingsBase : null;
    final hasIdField = (flags & 2) != 0;
    final id = hasIdField ? reader.readInt32() : null;

    // Construct [MessagesSetChatWallPaper] object.
    final returnValue = MessagesSetChatWallPaper(
      forBoth: forBoth,
      revert: revert,
      peer: peer,
      wallpaper: wallpaper,
      settings: settings,
      id: id,
    );

    // Now return the deserialized [MessagesSetChatWallPaper].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b03: forBoth,
      b04: revert,
      b00: wallpaper != null,
      b02: settings != null,
      b01: id != null,
    );

    return v;
  }

  /// for_both: bit 3 of flags.3?true
  final bool forBoth;

  /// revert: bit 4 of flags.4?true
  final bool revert;

  /// Peer.
  final InputPeerBase peer;

  /// Wallpaper.
  final InputWallPaperBase? wallpaper;

  /// Settings.
  final WallPaperSettingsBase? settings;

  /// Id.
  final int? id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8ffacae1.
    buffer.writeInt32(0x8ffacae1);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localWallpaperCopy = wallpaper;
    if (localWallpaperCopy != null) {
      buffer.writeObject(localWallpaperCopy);
    }
    final localSettingsCopy = settings;
    if (localSettingsCopy != null) {
      buffer.writeObject(localSettingsCopy);
    }
    final localIdCopy = id;
    if (localIdCopy != null) {
      buffer.writeInt32(localIdCopy);
    }

    // Finished serialization.
  }
}

/// Account Invalidate Sign In Codes.
///
/// ID: `ca8ae8ba`.
class AccountInvalidateSignInCodes extends TlMethod<bool> {
  /// Account Invalidate Sign In Codes constructor.
  const AccountInvalidateSignInCodes({
    required this.codes,
  }) : super._();

  /// Deserialize.
  factory AccountInvalidateSignInCodes.deserialize(BinaryReader reader) {
    // Read [AccountInvalidateSignInCodes] fields.
    final codes = reader.readVectorString();

    // Construct [AccountInvalidateSignInCodes] object.
    final returnValue = AccountInvalidateSignInCodes(
      codes: codes,
    );

    // Now return the deserialized [AccountInvalidateSignInCodes].
    return returnValue;
  }

  /// Codes.
  final List<String> codes;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xca8ae8ba.
    buffer.writeInt32(0xca8ae8ba);

    // Write fields.
    buffer.writeVectorString(codes);

    // Finished serialization.
  }
}

/// Channels Click Sponsored Message.
///
/// ID: `18afbc93`.
class ChannelsClickSponsoredMessage extends TlMethod<bool> {
  /// Channels Click Sponsored Message constructor.
  const ChannelsClickSponsoredMessage({
    required this.channel,
    required this.randomId,
  }) : super._();

  /// Deserialize.
  factory ChannelsClickSponsoredMessage.deserialize(BinaryReader reader) {
    // Read [ChannelsClickSponsoredMessage] fields.
    final channel = reader.readObject() as InputChannelBase;
    final randomId = reader.readBytes();

    // Construct [ChannelsClickSponsoredMessage] object.
    final returnValue = ChannelsClickSponsoredMessage(
      channel: channel,
      randomId: randomId,
    );

    // Now return the deserialized [ChannelsClickSponsoredMessage].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Random Id.
  final Uint8List randomId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x18afbc93.
    buffer.writeInt32(0x18afbc93);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeBytes(randomId);

    // Finished serialization.
  }
}

/// Contacts Edit Close Friends.
///
/// ID: `ba6705f0`.
class ContactsEditCloseFriends extends TlMethod<bool> {
  /// Contacts Edit Close Friends constructor.
  const ContactsEditCloseFriends({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory ContactsEditCloseFriends.deserialize(BinaryReader reader) {
    // Read [ContactsEditCloseFriends] fields.
    final id = reader.readVectorInt64();

    // Construct [ContactsEditCloseFriends] object.
    final returnValue = ContactsEditCloseFriends(
      id: id,
    );

    // Now return the deserialized [ContactsEditCloseFriends].
    return returnValue;
  }

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xba6705f0.
    buffer.writeInt32(0xba6705f0);

    // Write fields.
    buffer.writeVectorInt64(id);

    // Finished serialization.
  }
}

/// Stories Can Send Story.
///
/// ID: `c7dfdfdd`.
class StoriesCanSendStory extends TlMethod<bool> {
  /// Stories Can Send Story constructor.
  const StoriesCanSendStory({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory StoriesCanSendStory.deserialize(BinaryReader reader) {
    // Read [StoriesCanSendStory] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [StoriesCanSendStory] object.
    final returnValue = StoriesCanSendStory(
      peer: peer,
    );

    // Now return the deserialized [StoriesCanSendStory].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xc7dfdfdd.
    buffer.writeInt32(0xc7dfdfdd);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Stories Send Story.
///
/// ID: `e4e6694b`.
class StoriesSendStory extends TlMethod<UpdatesBase> {
  /// Stories Send Story constructor.
  const StoriesSendStory({
    required this.pinned,
    required this.noforwards,
    required this.fwdModified,
    required this.peer,
    required this.media,
    this.mediaAreas,
    this.caption,
    this.entities,
    required this.privacyRules,
    required this.randomId,
    this.period,
    this.fwdFromId,
    this.fwdFromStory,
  }) : super._();

  /// Deserialize.
  factory StoriesSendStory.deserialize(BinaryReader reader) {
    // Read [StoriesSendStory] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 4) != 0;
    final noforwards = (flags & 16) != 0;
    final fwdModified = (flags & 128) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final media = reader.readObject() as InputMediaBase;
    final hasMediaAreasField = (flags & 32) != 0;
    final mediaAreas =
        hasMediaAreasField ? reader.readVectorObject<MediaAreaBase>() : null;
    final hasCaptionField = (flags & 1) != 0;
    final caption = hasCaptionField ? reader.readString() : null;
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final privacyRules = reader.readVectorObject<InputPrivacyRuleBase>();
    final randomId = reader.readInt64();
    final hasPeriodField = (flags & 8) != 0;
    final period = hasPeriodField ? reader.readInt32() : null;
    final hasFwdFromIdField = (flags & 64) != 0;
    final fwdFromId =
        hasFwdFromIdField ? reader.readObject() as InputPeerBase : null;
    final hasFwdFromStoryField = (flags & 64) != 0;
    final fwdFromStory = hasFwdFromStoryField ? reader.readInt32() : null;

    // Construct [StoriesSendStory] object.
    final returnValue = StoriesSendStory(
      pinned: pinned,
      noforwards: noforwards,
      fwdModified: fwdModified,
      peer: peer,
      media: media,
      mediaAreas: mediaAreas,
      caption: caption,
      entities: entities,
      privacyRules: privacyRules,
      randomId: randomId,
      period: period,
      fwdFromId: fwdFromId,
      fwdFromStory: fwdFromStory,
    );

    // Now return the deserialized [StoriesSendStory].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: pinned,
      b04: noforwards,
      b07: fwdModified,
      b05: mediaAreas != null,
      b00: caption != null,
      b01: entities != null,
      b03: period != null,
      b06: fwdFromId != null || fwdFromStory != null,
    );

    return v;
  }

  /// pinned: bit 2 of flags.2?true
  final bool pinned;

  /// noforwards: bit 4 of flags.4?true
  final bool noforwards;

  /// fwd_modified: bit 7 of flags.7?true
  final bool fwdModified;

  /// Peer.
  final InputPeerBase peer;

  /// Media.
  final InputMediaBase media;

  /// Media Areas.
  final List<MediaAreaBase>? mediaAreas;

  /// Caption.
  final String? caption;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Privacy Rules.
  final List<InputPrivacyRuleBase> privacyRules;

  /// Random Id.
  ///
  /// Field type is Int64.
  final int randomId;

  /// Period.
  final int? period;

  /// Fwd From Id.
  final InputPeerBase? fwdFromId;

  /// Fwd From Story.
  final int? fwdFromStory;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xe4e6694b.
    buffer.writeInt32(0xe4e6694b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeObject(media);
    final localMediaAreasCopy = mediaAreas;
    if (localMediaAreasCopy != null) {
      buffer.writeVectorObject(localMediaAreasCopy);
    }
    final localCaptionCopy = caption;
    if (localCaptionCopy != null) {
      buffer.writeString(localCaptionCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    buffer.writeVectorObject(privacyRules);
    buffer.writeInt64(randomId);
    final localPeriodCopy = period;
    if (localPeriodCopy != null) {
      buffer.writeInt32(localPeriodCopy);
    }
    final localFwdFromIdCopy = fwdFromId;
    if (localFwdFromIdCopy != null) {
      buffer.writeObject(localFwdFromIdCopy);
    }
    final localFwdFromStoryCopy = fwdFromStory;
    if (localFwdFromStoryCopy != null) {
      buffer.writeInt32(localFwdFromStoryCopy);
    }

    // Finished serialization.
  }
}

/// Stories Edit Story.
///
/// ID: `b583ba46`.
class StoriesEditStory extends TlMethod<UpdatesBase> {
  /// Stories Edit Story constructor.
  const StoriesEditStory({
    required this.peer,
    required this.id,
    this.media,
    this.mediaAreas,
    this.caption,
    this.entities,
    this.privacyRules,
  }) : super._();

  /// Deserialize.
  factory StoriesEditStory.deserialize(BinaryReader reader) {
    // Read [StoriesEditStory] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();
    final hasMediaField = (flags & 1) != 0;
    final media = hasMediaField ? reader.readObject() as InputMediaBase : null;
    final hasMediaAreasField = (flags & 8) != 0;
    final mediaAreas =
        hasMediaAreasField ? reader.readVectorObject<MediaAreaBase>() : null;
    final hasCaptionField = (flags & 2) != 0;
    final caption = hasCaptionField ? reader.readString() : null;
    final hasEntitiesField = (flags & 2) != 0;
    final entities =
        hasEntitiesField ? reader.readVectorObject<MessageEntityBase>() : null;
    final hasPrivacyRulesField = (flags & 4) != 0;
    final privacyRules = hasPrivacyRulesField
        ? reader.readVectorObject<InputPrivacyRuleBase>()
        : null;

    // Construct [StoriesEditStory] object.
    final returnValue = StoriesEditStory(
      peer: peer,
      id: id,
      media: media,
      mediaAreas: mediaAreas,
      caption: caption,
      entities: entities,
      privacyRules: privacyRules,
    );

    // Now return the deserialized [StoriesEditStory].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: media != null,
      b03: mediaAreas != null,
      b01: caption != null || entities != null,
      b02: privacyRules != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Media.
  final InputMediaBase? media;

  /// Media Areas.
  final List<MediaAreaBase>? mediaAreas;

  /// Caption.
  final String? caption;

  /// Entities.
  final List<MessageEntityBase>? entities;

  /// Privacy Rules.
  final List<InputPrivacyRuleBase>? privacyRules;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb583ba46.
    buffer.writeInt32(0xb583ba46);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    final localMediaCopy = media;
    if (localMediaCopy != null) {
      buffer.writeObject(localMediaCopy);
    }
    final localMediaAreasCopy = mediaAreas;
    if (localMediaAreasCopy != null) {
      buffer.writeVectorObject(localMediaAreasCopy);
    }
    final localCaptionCopy = caption;
    if (localCaptionCopy != null) {
      buffer.writeString(localCaptionCopy);
    }
    final localEntitiesCopy = entities;
    if (localEntitiesCopy != null) {
      buffer.writeVectorObject(localEntitiesCopy);
    }
    final localPrivacyRulesCopy = privacyRules;
    if (localPrivacyRulesCopy != null) {
      buffer.writeVectorObject(localPrivacyRulesCopy);
    }

    // Finished serialization.
  }
}

/// Stories Delete Stories.
///
/// ID: `ae59db5f`.
class StoriesDeleteStories extends TlMethod<List<int>> {
  /// Stories Delete Stories constructor.
  const StoriesDeleteStories({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory StoriesDeleteStories.deserialize(BinaryReader reader) {
    // Read [StoriesDeleteStories] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();

    // Construct [StoriesDeleteStories] object.
    final returnValue = StoriesDeleteStories(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [StoriesDeleteStories].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xae59db5f.
    buffer.writeInt32(0xae59db5f);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Stories Toggle Pinned.
///
/// ID: `9a75a1ef`.
class StoriesTogglePinned extends TlMethod<List<int>> {
  /// Stories Toggle Pinned constructor.
  const StoriesTogglePinned({
    required this.peer,
    required this.id,
    required this.pinned,
  }) : super._();

  /// Deserialize.
  factory StoriesTogglePinned.deserialize(BinaryReader reader) {
    // Read [StoriesTogglePinned] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();
    final pinned = reader.readBool();

    // Construct [StoriesTogglePinned] object.
    final returnValue = StoriesTogglePinned(
      peer: peer,
      id: id,
      pinned: pinned,
    );

    // Now return the deserialized [StoriesTogglePinned].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Pinned.
  final bool pinned;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9a75a1ef.
    buffer.writeInt32(0x9a75a1ef);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);
    buffer.writeBool(pinned);

    // Finished serialization.
  }
}

/// Stories Get All Stories.
///
/// ID: `eeb0d625`.
class StoriesGetAllStories extends TlMethod<StoriesAllStoriesBase> {
  /// Stories Get All Stories constructor.
  const StoriesGetAllStories({
    required this.next,
    required this.hidden,
    this.state,
  }) : super._();

  /// Deserialize.
  factory StoriesGetAllStories.deserialize(BinaryReader reader) {
    // Read [StoriesGetAllStories] fields.
    final flags = reader.readInt32();
    final next = (flags & 2) != 0;
    final hidden = (flags & 4) != 0;
    final hasStateField = (flags & 1) != 0;
    final state = hasStateField ? reader.readString() : null;

    // Construct [StoriesGetAllStories] object.
    final returnValue = StoriesGetAllStories(
      next: next,
      hidden: hidden,
      state: state,
    );

    // Now return the deserialized [StoriesGetAllStories].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: next,
      b02: hidden,
      b00: state != null,
    );

    return v;
  }

  /// next: bit 1 of flags.1?true
  final bool next;

  /// hidden: bit 2 of flags.2?true
  final bool hidden;

  /// State.
  final String? state;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xeeb0d625.
    buffer.writeInt32(0xeeb0d625);

    // Write fields.
    buffer.writeInt32(flags);
    final localStateCopy = state;
    if (localStateCopy != null) {
      buffer.writeString(localStateCopy);
    }

    // Finished serialization.
  }
}

/// Stories Get Pinned Stories.
///
/// ID: `5821a5dc`.
class StoriesGetPinnedStories extends TlMethod<StoriesStoriesBase> {
  /// Stories Get Pinned Stories constructor.
  const StoriesGetPinnedStories({
    required this.peer,
    required this.offsetId,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory StoriesGetPinnedStories.deserialize(BinaryReader reader) {
    // Read [StoriesGetPinnedStories] fields.
    final peer = reader.readObject() as InputPeerBase;
    final offsetId = reader.readInt32();
    final limit = reader.readInt32();

    // Construct [StoriesGetPinnedStories] object.
    final returnValue = StoriesGetPinnedStories(
      peer: peer,
      offsetId: offsetId,
      limit: limit,
    );

    // Now return the deserialized [StoriesGetPinnedStories].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5821a5dc.
    buffer.writeInt32(0x5821a5dc);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(offsetId);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Stories Get Stories Archive.
///
/// ID: `b4352016`.
class StoriesGetStoriesArchive extends TlMethod<StoriesStoriesBase> {
  /// Stories Get Stories Archive constructor.
  const StoriesGetStoriesArchive({
    required this.peer,
    required this.offsetId,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory StoriesGetStoriesArchive.deserialize(BinaryReader reader) {
    // Read [StoriesGetStoriesArchive] fields.
    final peer = reader.readObject() as InputPeerBase;
    final offsetId = reader.readInt32();
    final limit = reader.readInt32();

    // Construct [StoriesGetStoriesArchive] object.
    final returnValue = StoriesGetStoriesArchive(
      peer: peer,
      offsetId: offsetId,
      limit: limit,
    );

    // Now return the deserialized [StoriesGetStoriesArchive].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb4352016.
    buffer.writeInt32(0xb4352016);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(offsetId);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Stories Get Stories By I D.
///
/// ID: `5774ca74`.
class StoriesGetStoriesByID extends TlMethod<StoriesStoriesBase> {
  /// Stories Get Stories By I D constructor.
  const StoriesGetStoriesByID({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory StoriesGetStoriesByID.deserialize(BinaryReader reader) {
    // Read [StoriesGetStoriesByID] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();

    // Construct [StoriesGetStoriesByID] object.
    final returnValue = StoriesGetStoriesByID(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [StoriesGetStoriesByID].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5774ca74.
    buffer.writeInt32(0x5774ca74);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Stories Toggle All Stories Hidden.
///
/// ID: `7c2557c4`.
class StoriesToggleAllStoriesHidden extends TlMethod<bool> {
  /// Stories Toggle All Stories Hidden constructor.
  const StoriesToggleAllStoriesHidden({
    required this.hidden,
  }) : super._();

  /// Deserialize.
  factory StoriesToggleAllStoriesHidden.deserialize(BinaryReader reader) {
    // Read [StoriesToggleAllStoriesHidden] fields.
    final hidden = reader.readBool();

    // Construct [StoriesToggleAllStoriesHidden] object.
    final returnValue = StoriesToggleAllStoriesHidden(
      hidden: hidden,
    );

    // Now return the deserialized [StoriesToggleAllStoriesHidden].
    return returnValue;
  }

  /// Hidden.
  final bool hidden;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7c2557c4.
    buffer.writeInt32(0x7c2557c4);

    // Write fields.
    buffer.writeBool(hidden);

    // Finished serialization.
  }
}

/// Stories Read Stories.
///
/// ID: `a556dac8`.
class StoriesReadStories extends TlMethod<List<int>> {
  /// Stories Read Stories constructor.
  const StoriesReadStories({
    required this.peer,
    required this.maxId,
  }) : super._();

  /// Deserialize.
  factory StoriesReadStories.deserialize(BinaryReader reader) {
    // Read [StoriesReadStories] fields.
    final peer = reader.readObject() as InputPeerBase;
    final maxId = reader.readInt32();

    // Construct [StoriesReadStories] object.
    final returnValue = StoriesReadStories(
      peer: peer,
      maxId: maxId,
    );

    // Now return the deserialized [StoriesReadStories].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa556dac8.
    buffer.writeInt32(0xa556dac8);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(maxId);

    // Finished serialization.
  }
}

/// Stories Increment Story Views.
///
/// ID: `b2028afb`.
class StoriesIncrementStoryViews extends TlMethod<bool> {
  /// Stories Increment Story Views constructor.
  const StoriesIncrementStoryViews({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory StoriesIncrementStoryViews.deserialize(BinaryReader reader) {
    // Read [StoriesIncrementStoryViews] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();

    // Construct [StoriesIncrementStoryViews] object.
    final returnValue = StoriesIncrementStoryViews(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [StoriesIncrementStoryViews].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb2028afb.
    buffer.writeInt32(0xb2028afb);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Stories Get Story Views List.
///
/// ID: `7ed23c57`.
class StoriesGetStoryViewsList extends TlMethod<StoriesStoryViewsListBase> {
  /// Stories Get Story Views List constructor.
  const StoriesGetStoryViewsList({
    required this.justContacts,
    required this.reactionsFirst,
    required this.forwardsFirst,
    required this.peer,
    this.q,
    required this.id,
    required this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory StoriesGetStoryViewsList.deserialize(BinaryReader reader) {
    // Read [StoriesGetStoryViewsList] fields.
    final flags = reader.readInt32();
    final justContacts = (flags & 1) != 0;
    final reactionsFirst = (flags & 4) != 0;
    final forwardsFirst = (flags & 8) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final hasQField = (flags & 2) != 0;
    final q = hasQField ? reader.readString() : null;
    final id = reader.readInt32();
    final offset = reader.readString();
    final limit = reader.readInt32();

    // Construct [StoriesGetStoryViewsList] object.
    final returnValue = StoriesGetStoryViewsList(
      justContacts: justContacts,
      reactionsFirst: reactionsFirst,
      forwardsFirst: forwardsFirst,
      peer: peer,
      q: q,
      id: id,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [StoriesGetStoryViewsList].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: justContacts,
      b02: reactionsFirst,
      b03: forwardsFirst,
      b01: q != null,
    );

    return v;
  }

  /// just_contacts: bit 0 of flags.0?true
  final bool justContacts;

  /// reactions_first: bit 2 of flags.2?true
  final bool reactionsFirst;

  /// forwards_first: bit 3 of flags.3?true
  final bool forwardsFirst;

  /// Peer.
  final InputPeerBase peer;

  /// Q.
  final String? q;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Offset.
  final String offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7ed23c57.
    buffer.writeInt32(0x7ed23c57);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    final localQCopy = q;
    if (localQCopy != null) {
      buffer.writeString(localQCopy);
    }
    buffer.writeInt32(id);
    buffer.writeString(offset);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Stories Get Stories Views.
///
/// ID: `28e16cc8`.
class StoriesGetStoriesViews extends TlMethod<StoriesStoryViewsBase> {
  /// Stories Get Stories Views constructor.
  const StoriesGetStoriesViews({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory StoriesGetStoriesViews.deserialize(BinaryReader reader) {
    // Read [StoriesGetStoriesViews] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();

    // Construct [StoriesGetStoriesViews] object.
    final returnValue = StoriesGetStoriesViews(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [StoriesGetStoriesViews].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x28e16cc8.
    buffer.writeInt32(0x28e16cc8);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);

    // Finished serialization.
  }
}

/// Stories Export Story Link.
///
/// ID: `7b8def20`.
class StoriesExportStoryLink extends TlMethod<ExportedStoryLinkBase> {
  /// Stories Export Story Link constructor.
  const StoriesExportStoryLink({
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory StoriesExportStoryLink.deserialize(BinaryReader reader) {
    // Read [StoriesExportStoryLink] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();

    // Construct [StoriesExportStoryLink] object.
    final returnValue = StoriesExportStoryLink(
      peer: peer,
      id: id,
    );

    // Now return the deserialized [StoriesExportStoryLink].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7b8def20.
    buffer.writeInt32(0x7b8def20);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Stories Report.
///
/// ID: `1923fa8c`.
class StoriesReport extends TlMethod<bool> {
  /// Stories Report constructor.
  const StoriesReport({
    required this.peer,
    required this.id,
    required this.reason,
    required this.message,
  }) : super._();

  /// Deserialize.
  factory StoriesReport.deserialize(BinaryReader reader) {
    // Read [StoriesReport] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readVectorInt32();
    final reason = reader.readObject() as ReportReasonBase;
    final message = reader.readString();

    // Construct [StoriesReport] object.
    final returnValue = StoriesReport(
      peer: peer,
      id: id,
      reason: reason,
      message: message,
    );

    // Now return the deserialized [StoriesReport].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  final List<int> id;

  /// Reason.
  final ReportReasonBase reason;

  /// Message.
  final String message;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1923fa8c.
    buffer.writeInt32(0x1923fa8c);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeVectorInt32(id);
    buffer.writeObject(reason);
    buffer.writeString(message);

    // Finished serialization.
  }
}

/// Stories Activate Stealth Mode.
///
/// ID: `57bbd166`.
class StoriesActivateStealthMode extends TlMethod<UpdatesBase> {
  /// Stories Activate Stealth Mode constructor.
  const StoriesActivateStealthMode({
    required this.past,
    required this.future,
  }) : super._();

  /// Deserialize.
  factory StoriesActivateStealthMode.deserialize(BinaryReader reader) {
    // Read [StoriesActivateStealthMode] fields.
    final flags = reader.readInt32();
    final past = (flags & 1) != 0;
    final future = (flags & 2) != 0;

    // Construct [StoriesActivateStealthMode] object.
    final returnValue = StoriesActivateStealthMode(
      past: past,
      future: future,
    );

    // Now return the deserialized [StoriesActivateStealthMode].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: past,
      b01: future,
    );

    return v;
  }

  /// past: bit 0 of flags.0?true
  final bool past;

  /// future: bit 1 of flags.1?true
  final bool future;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x57bbd166.
    buffer.writeInt32(0x57bbd166);

    // Write fields.
    buffer.writeInt32(flags);

    // Finished serialization.
  }
}

/// Contacts Set Blocked.
///
/// ID: `94c65c76`.
class ContactsSetBlocked extends TlMethod<bool> {
  /// Contacts Set Blocked constructor.
  const ContactsSetBlocked({
    required this.myStoriesFrom,
    required this.id,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory ContactsSetBlocked.deserialize(BinaryReader reader) {
    // Read [ContactsSetBlocked] fields.
    final flags = reader.readInt32();
    final myStoriesFrom = (flags & 1) != 0;
    final id = reader.readVectorObject<InputPeerBase>();
    final limit = reader.readInt32();

    // Construct [ContactsSetBlocked] object.
    final returnValue = ContactsSetBlocked(
      myStoriesFrom: myStoriesFrom,
      id: id,
      limit: limit,
    );

    // Now return the deserialized [ContactsSetBlocked].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: myStoriesFrom,
    );

    return v;
  }

  /// my_stories_from: bit 0 of flags.0?true
  final bool myStoriesFrom;

  /// Id.
  final List<InputPeerBase> id;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x94c65c76.
    buffer.writeInt32(0x94c65c76);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(id);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Stories Send Reaction.
///
/// ID: `7fd736b2`.
class StoriesSendReaction extends TlMethod<UpdatesBase> {
  /// Stories Send Reaction constructor.
  const StoriesSendReaction({
    required this.addToRecent,
    required this.peer,
    required this.storyId,
    required this.reaction,
  }) : super._();

  /// Deserialize.
  factory StoriesSendReaction.deserialize(BinaryReader reader) {
    // Read [StoriesSendReaction] fields.
    final flags = reader.readInt32();
    final addToRecent = (flags & 1) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final storyId = reader.readInt32();
    final reaction = reader.readObject() as ReactionBase;

    // Construct [StoriesSendReaction] object.
    final returnValue = StoriesSendReaction(
      addToRecent: addToRecent,
      peer: peer,
      storyId: storyId,
      reaction: reaction,
    );

    // Now return the deserialized [StoriesSendReaction].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: addToRecent,
    );

    return v;
  }

  /// add_to_recent: bit 0 of flags.0?true
  final bool addToRecent;

  /// Peer.
  final InputPeerBase peer;

  /// Story Id.
  ///
  /// Field type is Int32.
  final int storyId;

  /// Reaction.
  final ReactionBase reaction;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7fd736b2.
    buffer.writeInt32(0x7fd736b2);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(storyId);
    buffer.writeObject(reaction);

    // Finished serialization.
  }
}

/// Bots Can Send Message.
///
/// ID: `1359f4e6`.
class BotsCanSendMessage extends TlMethod<bool> {
  /// Bots Can Send Message constructor.
  const BotsCanSendMessage({
    required this.bot,
  }) : super._();

  /// Deserialize.
  factory BotsCanSendMessage.deserialize(BinaryReader reader) {
    // Read [BotsCanSendMessage] fields.
    final bot = reader.readObject() as InputUserBase;

    // Construct [BotsCanSendMessage] object.
    final returnValue = BotsCanSendMessage(
      bot: bot,
    );

    // Now return the deserialized [BotsCanSendMessage].
    return returnValue;
  }

  /// Bot.
  final InputUserBase bot;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x1359f4e6.
    buffer.writeInt32(0x1359f4e6);

    // Write fields.
    buffer.writeObject(bot);

    // Finished serialization.
  }
}

/// Bots Allow Send Message.
///
/// ID: `f132e3ef`.
class BotsAllowSendMessage extends TlMethod<UpdatesBase> {
  /// Bots Allow Send Message constructor.
  const BotsAllowSendMessage({
    required this.bot,
  }) : super._();

  /// Deserialize.
  factory BotsAllowSendMessage.deserialize(BinaryReader reader) {
    // Read [BotsAllowSendMessage] fields.
    final bot = reader.readObject() as InputUserBase;

    // Construct [BotsAllowSendMessage] object.
    final returnValue = BotsAllowSendMessage(
      bot: bot,
    );

    // Now return the deserialized [BotsAllowSendMessage].
    return returnValue;
  }

  /// Bot.
  final InputUserBase bot;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf132e3ef.
    buffer.writeInt32(0xf132e3ef);

    // Write fields.
    buffer.writeObject(bot);

    // Finished serialization.
  }
}

/// Bots Invoke Web View Custom Method.
///
/// ID: `087fc5e7`.
class BotsInvokeWebViewCustomMethod extends TlMethod<DataJSONBase> {
  /// Bots Invoke Web View Custom Method constructor.
  const BotsInvokeWebViewCustomMethod({
    required this.bot,
    required this.customMethod,
    required this.params,
  }) : super._();

  /// Deserialize.
  factory BotsInvokeWebViewCustomMethod.deserialize(BinaryReader reader) {
    // Read [BotsInvokeWebViewCustomMethod] fields.
    final bot = reader.readObject() as InputUserBase;
    final customMethod = reader.readString();
    final params = reader.readObject() as DataJSONBase;

    // Construct [BotsInvokeWebViewCustomMethod] object.
    final returnValue = BotsInvokeWebViewCustomMethod(
      bot: bot,
      customMethod: customMethod,
      params: params,
    );

    // Now return the deserialized [BotsInvokeWebViewCustomMethod].
    return returnValue;
  }

  /// Bot.
  final InputUserBase bot;

  /// Custom Method.
  final String customMethod;

  /// Params.
  final DataJSONBase params;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x087fc5e7.
    buffer.writeInt32(0x087fc5e7);

    // Write fields.
    buffer.writeObject(bot);
    buffer.writeString(customMethod);
    buffer.writeObject(params);

    // Finished serialization.
  }
}

/// Stories Get Peer Stories.
///
/// ID: `2c4ada50`.
class StoriesGetPeerStories extends TlMethod<StoriesPeerStoriesBase> {
  /// Stories Get Peer Stories constructor.
  const StoriesGetPeerStories({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory StoriesGetPeerStories.deserialize(BinaryReader reader) {
    // Read [StoriesGetPeerStories] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [StoriesGetPeerStories] object.
    final returnValue = StoriesGetPeerStories(
      peer: peer,
    );

    // Now return the deserialized [StoriesGetPeerStories].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2c4ada50.
    buffer.writeInt32(0x2c4ada50);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Stories Get All Read Peer Stories.
///
/// ID: `9b5ae7f9`.
class StoriesGetAllReadPeerStories extends TlMethod<UpdatesBase> {
  /// Stories Get All Read Peer Stories constructor.
  const StoriesGetAllReadPeerStories() : super._();

  /// Deserialize.
  factory StoriesGetAllReadPeerStories.deserialize(BinaryReader reader) {
    // Construct [StoriesGetAllReadPeerStories] object.
    final returnValue = StoriesGetAllReadPeerStories();

    // Now return the deserialized [StoriesGetAllReadPeerStories].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9b5ae7f9.
    buffer.writeInt32(0x9b5ae7f9);

    // Finished serialization.
  }
}

/// Stories Get Peer Max I Ds.
///
/// ID: `535983c3`.
class StoriesGetPeerMaxIDs extends TlMethod<List<int>> {
  /// Stories Get Peer Max I Ds constructor.
  const StoriesGetPeerMaxIDs({
    required this.id,
  }) : super._();

  /// Deserialize.
  factory StoriesGetPeerMaxIDs.deserialize(BinaryReader reader) {
    // Read [StoriesGetPeerMaxIDs] fields.
    final id = reader.readVectorObject<InputPeerBase>();

    // Construct [StoriesGetPeerMaxIDs] object.
    final returnValue = StoriesGetPeerMaxIDs(
      id: id,
    );

    // Now return the deserialized [StoriesGetPeerMaxIDs].
    return returnValue;
  }

  /// Id.
  final List<InputPeerBase> id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x535983c3.
    buffer.writeInt32(0x535983c3);

    // Write fields.
    buffer.writeVectorObject(id);

    // Finished serialization.
  }
}

/// Stories Get Chats To Send.
///
/// ID: `a56a8b60`.
class StoriesGetChatsToSend extends TlMethod<MessagesChatsBase> {
  /// Stories Get Chats To Send constructor.
  const StoriesGetChatsToSend() : super._();

  /// Deserialize.
  factory StoriesGetChatsToSend.deserialize(BinaryReader reader) {
    // Construct [StoriesGetChatsToSend] object.
    final returnValue = StoriesGetChatsToSend();

    // Now return the deserialized [StoriesGetChatsToSend].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa56a8b60.
    buffer.writeInt32(0xa56a8b60);

    // Finished serialization.
  }
}

/// Stories Toggle Peer Stories Hidden.
///
/// ID: `bd0415c4`.
class StoriesTogglePeerStoriesHidden extends TlMethod<bool> {
  /// Stories Toggle Peer Stories Hidden constructor.
  const StoriesTogglePeerStoriesHidden({
    required this.peer,
    required this.hidden,
  }) : super._();

  /// Deserialize.
  factory StoriesTogglePeerStoriesHidden.deserialize(BinaryReader reader) {
    // Read [StoriesTogglePeerStoriesHidden] fields.
    final peer = reader.readObject() as InputPeerBase;
    final hidden = reader.readBool();

    // Construct [StoriesTogglePeerStoriesHidden] object.
    final returnValue = StoriesTogglePeerStoriesHidden(
      peer: peer,
      hidden: hidden,
    );

    // Now return the deserialized [StoriesTogglePeerStoriesHidden].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Hidden.
  final bool hidden;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xbd0415c4.
    buffer.writeInt32(0xbd0415c4);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeBool(hidden);

    // Finished serialization.
  }
}

/// Payments Get Premium Gift Code Options.
///
/// ID: `2757ba54`.
class PaymentsGetPremiumGiftCodeOptions
    extends TlMethod<List<PremiumGiftCodeOptionBase>> {
  /// Payments Get Premium Gift Code Options constructor.
  const PaymentsGetPremiumGiftCodeOptions({
    this.boostPeer,
  }) : super._();

  /// Deserialize.
  factory PaymentsGetPremiumGiftCodeOptions.deserialize(BinaryReader reader) {
    // Read [PaymentsGetPremiumGiftCodeOptions] fields.
    final flags = reader.readInt32();
    final hasBoostPeerField = (flags & 1) != 0;
    final boostPeer =
        hasBoostPeerField ? reader.readObject() as InputPeerBase : null;

    // Construct [PaymentsGetPremiumGiftCodeOptions] object.
    final returnValue = PaymentsGetPremiumGiftCodeOptions(
      boostPeer: boostPeer,
    );

    // Now return the deserialized [PaymentsGetPremiumGiftCodeOptions].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: boostPeer != null,
    );

    return v;
  }

  /// Boost Peer.
  final InputPeerBase? boostPeer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x2757ba54.
    buffer.writeInt32(0x2757ba54);

    // Write fields.
    buffer.writeInt32(flags);
    final localBoostPeerCopy = boostPeer;
    if (localBoostPeerCopy != null) {
      buffer.writeObject(localBoostPeerCopy);
    }

    // Finished serialization.
  }
}

/// Payments Check Gift Code.
///
/// ID: `8e51b4c1`.
class PaymentsCheckGiftCode extends TlMethod<PaymentsCheckedGiftCodeBase> {
  /// Payments Check Gift Code constructor.
  const PaymentsCheckGiftCode({
    required this.slug,
  }) : super._();

  /// Deserialize.
  factory PaymentsCheckGiftCode.deserialize(BinaryReader reader) {
    // Read [PaymentsCheckGiftCode] fields.
    final slug = reader.readString();

    // Construct [PaymentsCheckGiftCode] object.
    final returnValue = PaymentsCheckGiftCode(
      slug: slug,
    );

    // Now return the deserialized [PaymentsCheckGiftCode].
    return returnValue;
  }

  /// Slug.
  final String slug;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8e51b4c1.
    buffer.writeInt32(0x8e51b4c1);

    // Write fields.
    buffer.writeString(slug);

    // Finished serialization.
  }
}

/// Payments Apply Gift Code.
///
/// ID: `f6e26854`.
class PaymentsApplyGiftCode extends TlMethod<UpdatesBase> {
  /// Payments Apply Gift Code constructor.
  const PaymentsApplyGiftCode({
    required this.slug,
  }) : super._();

  /// Deserialize.
  factory PaymentsApplyGiftCode.deserialize(BinaryReader reader) {
    // Read [PaymentsApplyGiftCode] fields.
    final slug = reader.readString();

    // Construct [PaymentsApplyGiftCode] object.
    final returnValue = PaymentsApplyGiftCode(
      slug: slug,
    );

    // Now return the deserialized [PaymentsApplyGiftCode].
    return returnValue;
  }

  /// Slug.
  final String slug;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf6e26854.
    buffer.writeInt32(0xf6e26854);

    // Write fields.
    buffer.writeString(slug);

    // Finished serialization.
  }
}

/// Payments Get Giveaway Info.
///
/// ID: `f4239425`.
class PaymentsGetGiveawayInfo extends TlMethod<PaymentsGiveawayInfoBase> {
  /// Payments Get Giveaway Info constructor.
  const PaymentsGetGiveawayInfo({
    required this.peer,
    required this.msgId,
  }) : super._();

  /// Deserialize.
  factory PaymentsGetGiveawayInfo.deserialize(BinaryReader reader) {
    // Read [PaymentsGetGiveawayInfo] fields.
    final peer = reader.readObject() as InputPeerBase;
    final msgId = reader.readInt32();

    // Construct [PaymentsGetGiveawayInfo] object.
    final returnValue = PaymentsGetGiveawayInfo(
      peer: peer,
      msgId: msgId,
    );

    // Now return the deserialized [PaymentsGetGiveawayInfo].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Msg Id.
  ///
  /// Field type is Int32.
  final int msgId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf4239425.
    buffer.writeInt32(0xf4239425);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(msgId);

    // Finished serialization.
  }
}

/// Payments Launch Prepaid Giveaway.
///
/// ID: `5ff58f20`.
class PaymentsLaunchPrepaidGiveaway extends TlMethod<UpdatesBase> {
  /// Payments Launch Prepaid Giveaway constructor.
  const PaymentsLaunchPrepaidGiveaway({
    required this.peer,
    required this.giveawayId,
    required this.purpose,
  }) : super._();

  /// Deserialize.
  factory PaymentsLaunchPrepaidGiveaway.deserialize(BinaryReader reader) {
    // Read [PaymentsLaunchPrepaidGiveaway] fields.
    final peer = reader.readObject() as InputPeerBase;
    final giveawayId = reader.readInt64();
    final purpose = reader.readObject() as InputStorePaymentPurposeBase;

    // Construct [PaymentsLaunchPrepaidGiveaway] object.
    final returnValue = PaymentsLaunchPrepaidGiveaway(
      peer: peer,
      giveawayId: giveawayId,
      purpose: purpose,
    );

    // Now return the deserialized [PaymentsLaunchPrepaidGiveaway].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Giveaway Id.
  ///
  /// Field type is Int64.
  final int giveawayId;

  /// Purpose.
  final InputStorePaymentPurposeBase purpose;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5ff58f20.
    buffer.writeInt32(0x5ff58f20);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt64(giveawayId);
    buffer.writeObject(purpose);

    // Finished serialization.
  }
}

/// Account Update Color.
///
/// ID: `7cefa15d`.
class AccountUpdateColor extends TlMethod<bool> {
  /// Account Update Color constructor.
  const AccountUpdateColor({
    required this.forProfile,
    this.color,
    this.backgroundEmojiId,
  }) : super._();

  /// Deserialize.
  factory AccountUpdateColor.deserialize(BinaryReader reader) {
    // Read [AccountUpdateColor] fields.
    final flags = reader.readInt32();
    final forProfile = (flags & 2) != 0;
    final hasColorField = (flags & 4) != 0;
    final color = hasColorField ? reader.readInt32() : null;
    final hasBackgroundEmojiIdField = (flags & 1) != 0;
    final backgroundEmojiId =
        hasBackgroundEmojiIdField ? reader.readInt64() : null;

    // Construct [AccountUpdateColor] object.
    final returnValue = AccountUpdateColor(
      forProfile: forProfile,
      color: color,
      backgroundEmojiId: backgroundEmojiId,
    );

    // Now return the deserialized [AccountUpdateColor].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: forProfile,
      b02: color != null,
      b00: backgroundEmojiId != null,
    );

    return v;
  }

  /// for_profile: bit 1 of flags.1?true
  final bool forProfile;

  /// Color.
  final int? color;

  /// Background Emoji Id.
  final int? backgroundEmojiId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7cefa15d.
    buffer.writeInt32(0x7cefa15d);

    // Write fields.
    buffer.writeInt32(flags);
    final localColorCopy = color;
    if (localColorCopy != null) {
      buffer.writeInt32(localColorCopy);
    }
    final localBackgroundEmojiIdCopy = backgroundEmojiId;
    if (localBackgroundEmojiIdCopy != null) {
      buffer.writeInt64(localBackgroundEmojiIdCopy);
    }

    // Finished serialization.
  }
}

/// Channels Update Color.
///
/// ID: `d8aa3671`.
class ChannelsUpdateColor extends TlMethod<UpdatesBase> {
  /// Channels Update Color constructor.
  const ChannelsUpdateColor({
    required this.forProfile,
    required this.channel,
    this.color,
    this.backgroundEmojiId,
  }) : super._();

  /// Deserialize.
  factory ChannelsUpdateColor.deserialize(BinaryReader reader) {
    // Read [ChannelsUpdateColor] fields.
    final flags = reader.readInt32();
    final forProfile = (flags & 2) != 0;
    final channel = reader.readObject() as InputChannelBase;
    final hasColorField = (flags & 4) != 0;
    final color = hasColorField ? reader.readInt32() : null;
    final hasBackgroundEmojiIdField = (flags & 1) != 0;
    final backgroundEmojiId =
        hasBackgroundEmojiIdField ? reader.readInt64() : null;

    // Construct [ChannelsUpdateColor] object.
    final returnValue = ChannelsUpdateColor(
      forProfile: forProfile,
      channel: channel,
      color: color,
      backgroundEmojiId: backgroundEmojiId,
    );

    // Now return the deserialized [ChannelsUpdateColor].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b01: forProfile,
      b02: color != null,
      b00: backgroundEmojiId != null,
    );

    return v;
  }

  /// for_profile: bit 1 of flags.1?true
  final bool forProfile;

  /// Channel.
  final InputChannelBase channel;

  /// Color.
  final int? color;

  /// Background Emoji Id.
  final int? backgroundEmojiId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd8aa3671.
    buffer.writeInt32(0xd8aa3671);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(channel);
    final localColorCopy = color;
    if (localColorCopy != null) {
      buffer.writeInt32(localColorCopy);
    }
    final localBackgroundEmojiIdCopy = backgroundEmojiId;
    if (localBackgroundEmojiIdCopy != null) {
      buffer.writeInt64(localBackgroundEmojiIdCopy);
    }

    // Finished serialization.
  }
}

/// Account Get Default Background Emojis.
///
/// ID: `a60ab9ce`.
class AccountGetDefaultBackgroundEmojis extends TlMethod<EmojiListBase> {
  /// Account Get Default Background Emojis constructor.
  const AccountGetDefaultBackgroundEmojis({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetDefaultBackgroundEmojis.deserialize(BinaryReader reader) {
    // Read [AccountGetDefaultBackgroundEmojis] fields.
    final hash = reader.readInt64();

    // Construct [AccountGetDefaultBackgroundEmojis] object.
    final returnValue = AccountGetDefaultBackgroundEmojis(
      hash: hash,
    );

    // Now return the deserialized [AccountGetDefaultBackgroundEmojis].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa60ab9ce.
    buffer.writeInt32(0xa60ab9ce);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Premium Get Boosts List.
///
/// ID: `60f67660`.
class PremiumGetBoostsList extends TlMethod<PremiumBoostsListBase> {
  /// Premium Get Boosts List constructor.
  const PremiumGetBoostsList({
    required this.gifts,
    required this.peer,
    required this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory PremiumGetBoostsList.deserialize(BinaryReader reader) {
    // Read [PremiumGetBoostsList] fields.
    final flags = reader.readInt32();
    final gifts = (flags & 1) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final offset = reader.readString();
    final limit = reader.readInt32();

    // Construct [PremiumGetBoostsList] object.
    final returnValue = PremiumGetBoostsList(
      gifts: gifts,
      peer: peer,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [PremiumGetBoostsList].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: gifts,
    );

    return v;
  }

  /// gifts: bit 0 of flags.0?true
  final bool gifts;

  /// Peer.
  final InputPeerBase peer;

  /// Offset.
  final String offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x60f67660.
    buffer.writeInt32(0x60f67660);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeString(offset);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Premium Get My Boosts.
///
/// ID: `0be77b4a`.
class PremiumGetMyBoosts extends TlMethod<PremiumMyBoostsBase> {
  /// Premium Get My Boosts constructor.
  const PremiumGetMyBoosts() : super._();

  /// Deserialize.
  factory PremiumGetMyBoosts.deserialize(BinaryReader reader) {
    // Construct [PremiumGetMyBoosts] object.
    final returnValue = PremiumGetMyBoosts();

    // Now return the deserialized [PremiumGetMyBoosts].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x0be77b4a.
    buffer.writeInt32(0x0be77b4a);

    // Finished serialization.
  }
}

/// Premium Apply Boost.
///
/// ID: `6b7da746`.
class PremiumApplyBoost extends TlMethod<PremiumMyBoostsBase> {
  /// Premium Apply Boost constructor.
  const PremiumApplyBoost({
    this.slots,
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory PremiumApplyBoost.deserialize(BinaryReader reader) {
    // Read [PremiumApplyBoost] fields.
    final flags = reader.readInt32();
    final hasSlotsField = (flags & 1) != 0;
    final slots = hasSlotsField ? reader.readVectorInt32() : null;
    final peer = reader.readObject() as InputPeerBase;

    // Construct [PremiumApplyBoost] object.
    final returnValue = PremiumApplyBoost(
      slots: slots,
      peer: peer,
    );

    // Now return the deserialized [PremiumApplyBoost].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: slots != null,
    );

    return v;
  }

  /// Slots.
  final List<int>? slots;

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6b7da746.
    buffer.writeInt32(0x6b7da746);

    // Write fields.
    buffer.writeInt32(flags);
    final localSlotsCopy = slots;
    if (localSlotsCopy != null) {
      buffer.writeVectorInt32(localSlotsCopy);
    }
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Premium Get Boosts Status.
///
/// ID: `042f1f61`.
class PremiumGetBoostsStatus extends TlMethod<PremiumBoostsStatusBase> {
  /// Premium Get Boosts Status constructor.
  const PremiumGetBoostsStatus({
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory PremiumGetBoostsStatus.deserialize(BinaryReader reader) {
    // Read [PremiumGetBoostsStatus] fields.
    final peer = reader.readObject() as InputPeerBase;

    // Construct [PremiumGetBoostsStatus] object.
    final returnValue = PremiumGetBoostsStatus(
      peer: peer,
    );

    // Now return the deserialized [PremiumGetBoostsStatus].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x042f1f61.
    buffer.writeInt32(0x042f1f61);

    // Write fields.
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Premium Get User Boosts.
///
/// ID: `39854d1f`.
class PremiumGetUserBoosts extends TlMethod<PremiumBoostsListBase> {
  /// Premium Get User Boosts constructor.
  const PremiumGetUserBoosts({
    required this.peer,
    required this.userId,
  }) : super._();

  /// Deserialize.
  factory PremiumGetUserBoosts.deserialize(BinaryReader reader) {
    // Read [PremiumGetUserBoosts] fields.
    final peer = reader.readObject() as InputPeerBase;
    final userId = reader.readObject() as InputUserBase;

    // Construct [PremiumGetUserBoosts] object.
    final returnValue = PremiumGetUserBoosts(
      peer: peer,
      userId: userId,
    );

    // Now return the deserialized [PremiumGetUserBoosts].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// User Id.
  final InputUserBase userId;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x39854d1f.
    buffer.writeInt32(0x39854d1f);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeObject(userId);

    // Finished serialization.
  }
}

/// Channels Toggle View Forum As Messages.
///
/// ID: `9738bb15`.
class ChannelsToggleViewForumAsMessages extends TlMethod<UpdatesBase> {
  /// Channels Toggle View Forum As Messages constructor.
  const ChannelsToggleViewForumAsMessages({
    required this.channel,
    required this.enabled,
  }) : super._();

  /// Deserialize.
  factory ChannelsToggleViewForumAsMessages.deserialize(BinaryReader reader) {
    // Read [ChannelsToggleViewForumAsMessages] fields.
    final channel = reader.readObject() as InputChannelBase;
    final enabled = reader.readBool();

    // Construct [ChannelsToggleViewForumAsMessages] object.
    final returnValue = ChannelsToggleViewForumAsMessages(
      channel: channel,
      enabled: enabled,
    );

    // Now return the deserialized [ChannelsToggleViewForumAsMessages].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Enabled.
  final bool enabled;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x9738bb15.
    buffer.writeInt32(0x9738bb15);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeBool(enabled);

    // Finished serialization.
  }
}

/// Messages Search Emoji Sticker Sets.
///
/// ID: `92b4494c`.
class MessagesSearchEmojiStickerSets
    extends TlMethod<MessagesFoundStickerSetsBase> {
  /// Messages Search Emoji Sticker Sets constructor.
  const MessagesSearchEmojiStickerSets({
    required this.excludeFeatured,
    required this.q,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesSearchEmojiStickerSets.deserialize(BinaryReader reader) {
    // Read [MessagesSearchEmojiStickerSets] fields.
    final flags = reader.readInt32();
    final excludeFeatured = (flags & 1) != 0;
    final q = reader.readString();
    final hash = reader.readInt64();

    // Construct [MessagesSearchEmojiStickerSets] object.
    final returnValue = MessagesSearchEmojiStickerSets(
      excludeFeatured: excludeFeatured,
      q: q,
      hash: hash,
    );

    // Now return the deserialized [MessagesSearchEmojiStickerSets].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: excludeFeatured,
    );

    return v;
  }

  /// exclude_featured: bit 0 of flags.0?true
  final bool excludeFeatured;

  /// Q.
  final String q;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x92b4494c.
    buffer.writeInt32(0x92b4494c);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeString(q);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Channels Get Channel Recommendations.
///
/// ID: `83b70d97`.
class ChannelsGetChannelRecommendations extends TlMethod<MessagesChatsBase> {
  /// Channels Get Channel Recommendations constructor.
  const ChannelsGetChannelRecommendations({
    required this.channel,
  }) : super._();

  /// Deserialize.
  factory ChannelsGetChannelRecommendations.deserialize(BinaryReader reader) {
    // Read [ChannelsGetChannelRecommendations] fields.
    final channel = reader.readObject() as InputChannelBase;

    // Construct [ChannelsGetChannelRecommendations] object.
    final returnValue = ChannelsGetChannelRecommendations(
      channel: channel,
    );

    // Now return the deserialized [ChannelsGetChannelRecommendations].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x83b70d97.
    buffer.writeInt32(0x83b70d97);

    // Write fields.
    buffer.writeObject(channel);

    // Finished serialization.
  }
}

/// Stats Get Story Stats.
///
/// ID: `374fef40`.
class StatsGetStoryStats extends TlMethod<StatsStoryStatsBase> {
  /// Stats Get Story Stats constructor.
  const StatsGetStoryStats({
    required this.dark,
    required this.peer,
    required this.id,
  }) : super._();

  /// Deserialize.
  factory StatsGetStoryStats.deserialize(BinaryReader reader) {
    // Read [StatsGetStoryStats] fields.
    final flags = reader.readInt32();
    final dark = (flags & 1) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();

    // Construct [StatsGetStoryStats] object.
    final returnValue = StatsGetStoryStats(
      dark: dark,
      peer: peer,
      id: id,
    );

    // Now return the deserialized [StatsGetStoryStats].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: dark,
    );

    return v;
  }

  /// dark: bit 0 of flags.0?true
  final bool dark;

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x374fef40.
    buffer.writeInt32(0x374fef40);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(id);

    // Finished serialization.
  }
}

/// Stats Get Story Public Forwards.
///
/// ID: `a6437ef6`.
class StatsGetStoryPublicForwards extends TlMethod<StatsPublicForwardsBase> {
  /// Stats Get Story Public Forwards constructor.
  const StatsGetStoryPublicForwards({
    required this.peer,
    required this.id,
    required this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory StatsGetStoryPublicForwards.deserialize(BinaryReader reader) {
    // Read [StatsGetStoryPublicForwards] fields.
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();
    final offset = reader.readString();
    final limit = reader.readInt32();

    // Construct [StatsGetStoryPublicForwards] object.
    final returnValue = StatsGetStoryPublicForwards(
      peer: peer,
      id: id,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [StatsGetStoryPublicForwards].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Offset.
  final String offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xa6437ef6.
    buffer.writeInt32(0xa6437ef6);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    buffer.writeString(offset);
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Help Get Peer Colors.
///
/// ID: `da80f42f`.
class HelpGetPeerColors extends TlMethod<HelpPeerColorsBase> {
  /// Help Get Peer Colors constructor.
  const HelpGetPeerColors({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory HelpGetPeerColors.deserialize(BinaryReader reader) {
    // Read [HelpGetPeerColors] fields.
    final hash = reader.readInt32();

    // Construct [HelpGetPeerColors] object.
    final returnValue = HelpGetPeerColors(
      hash: hash,
    );

    // Now return the deserialized [HelpGetPeerColors].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xda80f42f.
    buffer.writeInt32(0xda80f42f);

    // Write fields.
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Help Get Peer Profile Colors.
///
/// ID: `abcfa9fd`.
class HelpGetPeerProfileColors extends TlMethod<HelpPeerColorsBase> {
  /// Help Get Peer Profile Colors constructor.
  const HelpGetPeerProfileColors({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory HelpGetPeerProfileColors.deserialize(BinaryReader reader) {
    // Read [HelpGetPeerProfileColors] fields.
    final hash = reader.readInt32();

    // Construct [HelpGetPeerProfileColors] object.
    final returnValue = HelpGetPeerProfileColors(
      hash: hash,
    );

    // Now return the deserialized [HelpGetPeerProfileColors].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int32.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xabcfa9fd.
    buffer.writeInt32(0xabcfa9fd);

    // Write fields.
    buffer.writeInt32(hash);

    // Finished serialization.
  }
}

/// Stories Get Story Reactions List.
///
/// ID: `b9b2881f`.
class StoriesGetStoryReactionsList
    extends TlMethod<StoriesStoryReactionsListBase> {
  /// Stories Get Story Reactions List constructor.
  const StoriesGetStoryReactionsList({
    required this.forwardsFirst,
    required this.peer,
    required this.id,
    this.reaction,
    this.offset,
    required this.limit,
  }) : super._();

  /// Deserialize.
  factory StoriesGetStoryReactionsList.deserialize(BinaryReader reader) {
    // Read [StoriesGetStoryReactionsList] fields.
    final flags = reader.readInt32();
    final forwardsFirst = (flags & 4) != 0;
    final peer = reader.readObject() as InputPeerBase;
    final id = reader.readInt32();
    final hasReactionField = (flags & 1) != 0;
    final reaction =
        hasReactionField ? reader.readObject() as ReactionBase : null;
    final hasOffsetField = (flags & 2) != 0;
    final offset = hasOffsetField ? reader.readString() : null;
    final limit = reader.readInt32();

    // Construct [StoriesGetStoryReactionsList] object.
    final returnValue = StoriesGetStoryReactionsList(
      forwardsFirst: forwardsFirst,
      peer: peer,
      id: id,
      reaction: reaction,
      offset: offset,
      limit: limit,
    );

    // Now return the deserialized [StoriesGetStoryReactionsList].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: forwardsFirst,
      b00: reaction != null,
      b01: offset != null,
    );

    return v;
  }

  /// forwards_first: bit 2 of flags.2?true
  final bool forwardsFirst;

  /// Peer.
  final InputPeerBase peer;

  /// Id.
  ///
  /// Field type is Int32.
  final int id;

  /// Reaction.
  final ReactionBase? reaction;

  /// Offset.
  final String? offset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xb9b2881f.
    buffer.writeInt32(0xb9b2881f);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(id);
    final localReactionCopy = reaction;
    if (localReactionCopy != null) {
      buffer.writeObject(localReactionCopy);
    }
    final localOffsetCopy = offset;
    if (localOffsetCopy != null) {
      buffer.writeString(localOffsetCopy);
    }
    buffer.writeInt32(limit);

    // Finished serialization.
  }
}

/// Channels Update Emoji Status.
///
/// ID: `f0d3e6a8`.
class ChannelsUpdateEmojiStatus extends TlMethod<UpdatesBase> {
  /// Channels Update Emoji Status constructor.
  const ChannelsUpdateEmojiStatus({
    required this.channel,
    required this.emojiStatus,
  }) : super._();

  /// Deserialize.
  factory ChannelsUpdateEmojiStatus.deserialize(BinaryReader reader) {
    // Read [ChannelsUpdateEmojiStatus] fields.
    final channel = reader.readObject() as InputChannelBase;
    final emojiStatus = reader.readObject() as EmojiStatusBase;

    // Construct [ChannelsUpdateEmojiStatus] object.
    final returnValue = ChannelsUpdateEmojiStatus(
      channel: channel,
      emojiStatus: emojiStatus,
    );

    // Now return the deserialized [ChannelsUpdateEmojiStatus].
    return returnValue;
  }

  /// Channel.
  final InputChannelBase channel;

  /// Emoji Status.
  final EmojiStatusBase emojiStatus;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xf0d3e6a8.
    buffer.writeInt32(0xf0d3e6a8);

    // Write fields.
    buffer.writeObject(channel);
    buffer.writeObject(emojiStatus);

    // Finished serialization.
  }
}

/// Account Get Channel Default Emoji Statuses.
///
/// ID: `7727a7d5`.
class AccountGetChannelDefaultEmojiStatuses
    extends TlMethod<AccountEmojiStatusesBase> {
  /// Account Get Channel Default Emoji Statuses constructor.
  const AccountGetChannelDefaultEmojiStatuses({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetChannelDefaultEmojiStatuses.deserialize(
      BinaryReader reader) {
    // Read [AccountGetChannelDefaultEmojiStatuses] fields.
    final hash = reader.readInt64();

    // Construct [AccountGetChannelDefaultEmojiStatuses] object.
    final returnValue = AccountGetChannelDefaultEmojiStatuses(
      hash: hash,
    );

    // Now return the deserialized [AccountGetChannelDefaultEmojiStatuses].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x7727a7d5.
    buffer.writeInt32(0x7727a7d5);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Account Get Channel Restricted Status Emojis.
///
/// ID: `35a9e0d5`.
class AccountGetChannelRestrictedStatusEmojis extends TlMethod<EmojiListBase> {
  /// Account Get Channel Restricted Status Emojis constructor.
  const AccountGetChannelRestrictedStatusEmojis({
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory AccountGetChannelRestrictedStatusEmojis.deserialize(
      BinaryReader reader) {
    // Read [AccountGetChannelRestrictedStatusEmojis] fields.
    final hash = reader.readInt64();

    // Construct [AccountGetChannelRestrictedStatusEmojis] object.
    final returnValue = AccountGetChannelRestrictedStatusEmojis(
      hash: hash,
    );

    // Now return the deserialized [AccountGetChannelRestrictedStatusEmojis].
    return returnValue;
  }

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x35a9e0d5.
    buffer.writeInt32(0x35a9e0d5);

    // Write fields.
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Get Saved Dialogs.
///
/// ID: `5381d21a`.
class MessagesGetSavedDialogs extends TlMethod<MessagesSavedDialogsBase> {
  /// Messages Get Saved Dialogs constructor.
  const MessagesGetSavedDialogs({
    required this.excludePinned,
    required this.offsetDate,
    required this.offsetId,
    required this.offsetPeer,
    required this.limit,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetSavedDialogs.deserialize(BinaryReader reader) {
    // Read [MessagesGetSavedDialogs] fields.
    final flags = reader.readInt32();
    final excludePinned = (flags & 1) != 0;
    final offsetDate = reader.readDateTime();
    final offsetId = reader.readInt32();
    final offsetPeer = reader.readObject() as InputPeerBase;
    final limit = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [MessagesGetSavedDialogs] object.
    final returnValue = MessagesGetSavedDialogs(
      excludePinned: excludePinned,
      offsetDate: offsetDate,
      offsetId: offsetId,
      offsetPeer: offsetPeer,
      limit: limit,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetSavedDialogs].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: excludePinned,
    );

    return v;
  }

  /// exclude_pinned: bit 0 of flags.0?true
  final bool excludePinned;

  /// Offset Date.
  final DateTime offsetDate;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Offset Peer.
  final InputPeerBase offsetPeer;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x5381d21a.
    buffer.writeInt32(0x5381d21a);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeDateTime(offsetDate);
    buffer.writeInt32(offsetId);
    buffer.writeObject(offsetPeer);
    buffer.writeInt32(limit);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Get Saved History.
///
/// ID: `3d9a414d`.
class MessagesGetSavedHistory extends TlMethod<MessagesMessagesBase> {
  /// Messages Get Saved History constructor.
  const MessagesGetSavedHistory({
    required this.peer,
    required this.offsetId,
    required this.offsetDate,
    required this.addOffset,
    required this.limit,
    required this.maxId,
    required this.minId,
    required this.hash,
  }) : super._();

  /// Deserialize.
  factory MessagesGetSavedHistory.deserialize(BinaryReader reader) {
    // Read [MessagesGetSavedHistory] fields.
    final peer = reader.readObject() as InputPeerBase;
    final offsetId = reader.readInt32();
    final offsetDate = reader.readDateTime();
    final addOffset = reader.readInt32();
    final limit = reader.readInt32();
    final maxId = reader.readInt32();
    final minId = reader.readInt32();
    final hash = reader.readInt64();

    // Construct [MessagesGetSavedHistory] object.
    final returnValue = MessagesGetSavedHistory(
      peer: peer,
      offsetId: offsetId,
      offsetDate: offsetDate,
      addOffset: addOffset,
      limit: limit,
      maxId: maxId,
      minId: minId,
      hash: hash,
    );

    // Now return the deserialized [MessagesGetSavedHistory].
    return returnValue;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Offset Id.
  ///
  /// Field type is Int32.
  final int offsetId;

  /// Offset Date.
  final DateTime offsetDate;

  /// Add Offset.
  ///
  /// Field type is Int32.
  final int addOffset;

  /// Limit.
  ///
  /// Field type is Int32.
  final int limit;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Min Id.
  ///
  /// Field type is Int32.
  final int minId;

  /// Hash.
  ///
  /// Field type is Int64.
  final int hash;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x3d9a414d.
    buffer.writeInt32(0x3d9a414d);

    // Write fields.
    buffer.writeObject(peer);
    buffer.writeInt32(offsetId);
    buffer.writeDateTime(offsetDate);
    buffer.writeInt32(addOffset);
    buffer.writeInt32(limit);
    buffer.writeInt32(maxId);
    buffer.writeInt32(minId);
    buffer.writeInt64(hash);

    // Finished serialization.
  }
}

/// Messages Delete Saved History.
///
/// ID: `6e98102b`.
class MessagesDeleteSavedHistory extends TlMethod<MessagesAffectedHistoryBase> {
  /// Messages Delete Saved History constructor.
  const MessagesDeleteSavedHistory({
    required this.peer,
    required this.maxId,
    this.minDate,
    this.maxDate,
  }) : super._();

  /// Deserialize.
  factory MessagesDeleteSavedHistory.deserialize(BinaryReader reader) {
    // Read [MessagesDeleteSavedHistory] fields.
    final flags = reader.readInt32();
    final peer = reader.readObject() as InputPeerBase;
    final maxId = reader.readInt32();
    final hasMinDateField = (flags & 4) != 0;
    final minDate = hasMinDateField ? reader.readDateTime() : null;
    final hasMaxDateField = (flags & 8) != 0;
    final maxDate = hasMaxDateField ? reader.readDateTime() : null;

    // Construct [MessagesDeleteSavedHistory] object.
    final returnValue = MessagesDeleteSavedHistory(
      peer: peer,
      maxId: maxId,
      minDate: minDate,
      maxDate: maxDate,
    );

    // Now return the deserialized [MessagesDeleteSavedHistory].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b02: minDate != null,
      b03: maxDate != null,
    );

    return v;
  }

  /// Peer.
  final InputPeerBase peer;

  /// Max Id.
  ///
  /// Field type is Int32.
  final int maxId;

  /// Min Date.
  final DateTime? minDate;

  /// Max Date.
  final DateTime? maxDate;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x6e98102b.
    buffer.writeInt32(0x6e98102b);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);
    buffer.writeInt32(maxId);
    final localMinDateCopy = minDate;
    if (localMinDateCopy != null) {
      buffer.writeDateTime(localMinDateCopy);
    }
    final localMaxDateCopy = maxDate;
    if (localMaxDateCopy != null) {
      buffer.writeDateTime(localMaxDateCopy);
    }

    // Finished serialization.
  }
}

/// Messages Get Pinned Saved Dialogs.
///
/// ID: `d63d94e0`.
class MessagesGetPinnedSavedDialogs extends TlMethod<MessagesSavedDialogsBase> {
  /// Messages Get Pinned Saved Dialogs constructor.
  const MessagesGetPinnedSavedDialogs() : super._();

  /// Deserialize.
  factory MessagesGetPinnedSavedDialogs.deserialize(BinaryReader reader) {
    // Construct [MessagesGetPinnedSavedDialogs] object.
    final returnValue = MessagesGetPinnedSavedDialogs();

    // Now return the deserialized [MessagesGetPinnedSavedDialogs].
    return returnValue;
  }

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xd63d94e0.
    buffer.writeInt32(0xd63d94e0);

    // Finished serialization.
  }
}

/// Messages Toggle Saved Dialog Pin.
///
/// ID: `ac81bbde`.
class MessagesToggleSavedDialogPin extends TlMethod<bool> {
  /// Messages Toggle Saved Dialog Pin constructor.
  const MessagesToggleSavedDialogPin({
    required this.pinned,
    required this.peer,
  }) : super._();

  /// Deserialize.
  factory MessagesToggleSavedDialogPin.deserialize(BinaryReader reader) {
    // Read [MessagesToggleSavedDialogPin] fields.
    final flags = reader.readInt32();
    final pinned = (flags & 1) != 0;
    final peer = reader.readObject() as InputDialogPeerBase;

    // Construct [MessagesToggleSavedDialogPin] object.
    final returnValue = MessagesToggleSavedDialogPin(
      pinned: pinned,
      peer: peer,
    );

    // Now return the deserialized [MessagesToggleSavedDialogPin].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: pinned,
    );

    return v;
  }

  /// pinned: bit 0 of flags.0?true
  final bool pinned;

  /// Peer.
  final InputDialogPeerBase peer;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0xac81bbde.
    buffer.writeInt32(0xac81bbde);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeObject(peer);

    // Finished serialization.
  }
}

/// Messages Reorder Pinned Saved Dialogs.
///
/// ID: `8b716587`.
class MessagesReorderPinnedSavedDialogs extends TlMethod<bool> {
  /// Messages Reorder Pinned Saved Dialogs constructor.
  const MessagesReorderPinnedSavedDialogs({
    required this.force,
    required this.order,
  }) : super._();

  /// Deserialize.
  factory MessagesReorderPinnedSavedDialogs.deserialize(BinaryReader reader) {
    // Read [MessagesReorderPinnedSavedDialogs] fields.
    final flags = reader.readInt32();
    final force = (flags & 1) != 0;
    final order = reader.readVectorObject<InputDialogPeerBase>();

    // Construct [MessagesReorderPinnedSavedDialogs] object.
    final returnValue = MessagesReorderPinnedSavedDialogs(
      force: force,
      order: order,
    );

    // Now return the deserialized [MessagesReorderPinnedSavedDialogs].
    return returnValue;
  }

  /// Flags.
  int get flags {
    final v = _flag(
      b00: force,
    );

    return v;
  }

  /// force: bit 0 of flags.0?true
  final bool force;

  /// Order.
  final List<InputDialogPeerBase> order;

  /// Serialize.
  @override
  void serialize(List<int> buffer) {
    // Write type-id 0x8b716587.
    buffer.writeInt32(0x8b716587);

    // Write fields.
    buffer.writeInt32(flags);
    buffer.writeVectorObject(order);

    // Finished serialization.
  }
}
